// Copyright 2022 xensik. All rights reserved.
//
// Use of this source code is governed by a GNU GPLv3 license
// that can be found in the LICENSE file.

#include "stdafx.hpp"
#include "h1.hpp"

#ifdef _MSC_VER
#pragma warning(push)
#pragma warning(disable:4244)
#endif

namespace xsk::gsc::h1
{

std::unordered_map<std::uint8_t, std::string_view> opcode_map;
std::unordered_map<std::uint16_t, std::string_view> function_map;
std::unordered_map<std::uint16_t, std::string_view> method_map;
std::unordered_map<std::uint16_t, std::string_view> token_map;
std::unordered_map<std::string_view, std::uint8_t> opcode_map_rev;
std::unordered_map<std::string_view, std::uint16_t> function_map_rev;
std::unordered_map<std::string_view, std::uint16_t> method_map_rev;
std::unordered_map<std::string_view, std::uint16_t> token_map_rev;
std::unordered_map<std::string, std::vector<std::uint8_t>> files;
read_cb_type read_callback = nullptr;
std::set<std::string> string_map;

void resolver::init(read_cb_type callback)
{
    read_callback = callback;
}

void resolver::cleanup()
{
    files.clear();
}

auto resolver::opcode_id(const std::string& name) -> std::uint8_t
{
    const auto itr = opcode_map_rev.find(name);

    if (itr != opcode_map_rev.end())
    {
        return itr->second;
    }

    throw error(utils::string::va("couldn't resolve opcode id for name '%s'!", name.data()));
}

auto resolver::opcode_name(std::uint8_t id) -> std::string
{
    const auto itr = opcode_map.find(id);

    if (itr != opcode_map.end())
    {
        return std::string(itr->second);
    }

    throw error(utils::string::va("couldn't resolve opcode name for id '0x%hhX'!", id));
}

auto resolver::function_id(const std::string& name) -> std::uint16_t
{
    if (name.starts_with("_func_"))
    {
        return static_cast<std::uint16_t>(std::stoul(name.substr(6), nullptr, 16));
    }

    const auto itr = function_map_rev.find(name);

    if (itr != function_map_rev.end())
    {
        return itr->second;
    }

    throw error(utils::string::va("couldn't resolve builtin function id for name '%s'!", name.data()));
}

auto resolver::function_name(std::uint16_t id) -> std::string
{
    const auto itr = function_map.find(id);

    if (itr != function_map.end())
    {
        return std::string(itr->second);
    }

    return utils::string::va("_func_%04X", id);
}

auto resolver::method_id(const std::string& name) -> std::uint16_t
{
    if (name.starts_with("_meth_"))
    {
        return static_cast<std::uint16_t>(std::stoul(name.substr(6), nullptr, 16));
    }

    const auto itr = method_map_rev.find(name);

    if (itr != method_map_rev.end())
    {
        return itr->second;
    }

    throw error(utils::string::va("couldn't resolve builtin method id for name '%s'!", name.data()));
}

auto resolver::method_name(std::uint16_t id) -> std::string
{
    const auto itr = method_map.find(id);

    if (itr != method_map.end())
    {
        return std::string(itr->second);
    }

    return utils::string::va("_meth_%04X", id);
}

auto resolver::token_id(const std::string& name) -> std::uint16_t
{
    if (name.starts_with("_id_"))
    {
        return static_cast<std::uint16_t>(std::stoul(name.substr(4), nullptr, 16));
    }

    const auto itr = token_map_rev.find(name);

    if (itr != token_map_rev.end())
    {
        return itr->second;
    }

    return 0;
}

auto resolver::token_name(std::uint16_t id) -> std::string
{
    const auto itr = token_map.find(id);

    if (itr != token_map.end())
    {
        return std::string(itr->second);
    }

    return utils::string::va("_id_%04X", id);
}

auto resolver::find_function(const std::string& name) -> bool
{
    if (name.starts_with("_func_")) return true;

    const auto itr = function_map_rev.find(name);

    if (itr != function_map_rev.end())
    {
        return true;
    }

    return false;
}

auto resolver::find_method(const std::string& name) -> bool
{
    if (name.starts_with("_meth_")) return true;

    const auto itr = method_map_rev.find(name);

    if (itr != method_map_rev.end())
    {
        return true;
    }

    return false;
}

auto resolver::make_token(std::string_view str) -> std::string
{
    if (str.starts_with("_id_") || str.starts_with("_func_") || str.starts_with("_meth_"))
    {
        return std::string(str);
    }

    auto data = std::string(str.begin(), str.end());

    for (std::size_t i = 0; i < data.size(); i++)
    {
        data[i] = static_cast<char>(std::tolower(static_cast<unsigned char>(str[i])));
        if (data[i] == '\\') data[i] = '/';
    }

    return data;
}

auto resolver::file_data(const std::string& name) -> std::tuple<const std::string*, char*, size_t>
{
    const auto& itr = files.find(name);

    if (itr != files.end())
    {
        return { &itr->first ,reinterpret_cast<char*>(itr->second.data()), itr->second.size() };
    }

    auto data = read_callback(name);

    const auto& res = files.insert({ name, std::move(data)});

    if (res.second)
    {
        return { &res.first->first, reinterpret_cast<char*>(res.first->second.data()), res.first->second.size() };
    }

    throw error("couldn't open gsc file '" + name + "'");
}

std::set<std::string_view> paths
{
    "animscripts"sv,
    "animscripts/traverse"sv,
    "character"sv,
    "codescripts"sv,
    "common_scripts"sv,
    "destructible_scripts"sv,
    "maps"sv,
    "maps/animated_models"sv,
    "maps/createart"sv,
    "maps/createfx"sv,
    "maps/mp"sv,
    "maps/mp/gametypes"sv,
    "maps/mp/killstreaks"sv,
    "maps/mp/perks"sv,
    "mptype"sv,
    "soundscripts"sv,
    "vehicle_scripts"sv,
    "xmodelalias"sv,
};

auto resolver::fs_to_game_path(const std::filesystem::path& file) -> std::filesystem::path
{
    auto result = std::filesystem::path();
    auto root = false;

    for (auto& entry : file)
    {
        if (!root && paths.contains(entry.string()))
        {
            result = entry;
            root = true;
        }
        else if (paths.contains(result.string()))
        {
            result /= entry;
        }
    }

    return result.empty() ? file : result;
}

const std::array<std::pair<std::uint8_t, const char*>, 154> opcode_list
{{
    { 0x17, "SET_NEW_LOCAL_VARIABLE_FIELD_CACHED0" },
    { 0x18, "EVAL_SELF_FIELD_VARIABLE" },
    { 0x19, "RETN" },
    { 0x1A, "CALL_BUILTIN_FUNC_0" },
    { 0x1B, "CALL_BUILTIN_FUNC_1" },
    { 0x1C, "CALL_BUILTIN_FUNC_2" },
    { 0x1D, "CALL_BUILTIN_FUNC_3" },
    { 0x1E, "CALL_BUILTIN_FUNC_4" },
    { 0x1F, "CALL_BUILTIN_FUNC_5" },
    { 0x20, "CALL_BUILTIN_FUNC" },
    { 0x21, "BOOL_NOT" },
    { 0x22, "CALL_FAR_METHOD_THEAD" },
    { 0x23, "JMP_EXPR_TRUE" },
    { 0x24, "SET_LEVEL_FIELD_VARIABLE_FIELD" },
    { 0x25, "CAST_BOOL" },
    { 0x26, "EVAL_NEW_LOCAL_ARRAY_REF_CACHED0" },
    { 0x27, "CALL_BUILTIN_FUNC_POINTER" },
    { 0x28, "INEQUALITY" },
    { 0x29, "GET_THISTHREAD" },
    { 0x2A, "CLEAR_FIELD_VARIABLE" },
    { 0x2B, "GET_FLOAT" },
    { 0x2C, "SAFE_CREATE_VARIABLE_FIELD_CACHED" },
    { 0x2D, "CALL_FAR_FUNC2" },
    { 0x2E, "CALL_FAR_FUNC" },
    { 0x2F, "CALL_FAR_FUNC_CHILD_THREAD" },
    { 0x30, "CLEAR_LOCAL_VARIABLE_FIELD_CACHED0" },
    { 0x31, "CLEAR_LOCAL_VARIABLE_FIELD_CACHED" },
    { 0x32, "CHECK_CLEAR_PARAMS" },
    { 0x33, "CAST_FIELD_OBJ" },
    { 0x34, "END" },
    { 0x35, "SIZE" },
    { 0x36, "EMPTY_ARRAY" },
    { 0x37, "BIT_AND" },
    { 0x38, "LESSEQUAL" },
    { 0x39, "VOIDCODEPOS" },
    { 0x3A, "CALL_METHOD_THREAD_POINTER" },
    { 0x3B, "ENDSWITCH" },
    { 0x3C, "CLEAR_VARIABLE_FIELD" },
    { 0x3D, "DIV" },
    { 0x3E, "CALL_FAR_METHOD_CHILD_THEAD" },
    { 0x3F, "GET_USHORT" },
    { 0x40, "JMP_TRUE" },
    { 0x41, "GET_SELF" },
    { 0x42, "CALL_FAR_FUNC_THREAD" },
    { 0x43, "CALL_LOCAL_FUNC_THREAD" },
    { 0x44, "SET_LOCAL_VARIABLE_FIELD_CACHED0" },
    { 0x45, "SET_LOCAL_VARIABLE_FIELD_CACHED" },
    { 0x46, "PLUS" },
    { 0x47, "BOOL_COMPLEMENT" },
    { 0x48, "CALL_METHOD_POINTER" },
    { 0x49, "INC" },
    { 0x4A, "REMOVE_LOCAL_VARIABLES" },
    { 0x4B, "JMP_EXPR_FALSE" },
    { 0x4C, "SWITCH" },
    { 0x4D, "CLEAR_PARAMS" },
    { 0x4E, "EVAL_LOCAL_VARIABLE_REF_CACHED0" },
    { 0x4F, "EVAL_LOCAL_VARIABLE_REF_CACHED" },
    { 0x50, "CALL_LOCAL_METHOD" },
    { 0x51, "EVAL_FIELD_VARIABLE" },
    { 0x52, "EVAL_FIELD_VARIABLE_REF" },
    { 0x53, "GET_STRING" },
    { 0x54, "CALL_FUNC_POINTER" },
    { 0x55, "EVAL_LEVEL_FIELD_VARIABLE" },
    { 0x56, "GET_VECTOR" },
    { 0x57, "ENDON" },
    { 0x58, "GREATEREQUAL" },
    { 0x59, "GET_SELF_OBJ" },
    { 0x5A, "SET_ANIM_FIELD_VARIABLE_FIELD" },
    { 0x5B, "SET_VARIABLE_FIELD" },
    { 0x5C, "CALL_LOCAL_FUNC2" },
    { 0x5D, "CALL_LOCAL_FUNC" },
    { 0x5E, "EVAL_LOCAL_ARRAY_REF_CACHED0" },
    { 0x5F, "EVAL_LOCAL_ARRAY_REF_CACHED" },
    { 0x60, "GET_FAR_FUNC" },
    { 0x61, "LESS" },
    { 0x62, "GET_GAME_REF" },
    { 0x63, "WAITFRAME" },
    { 0x64, "WAITTILLFRAMEEND" },
    { 0x65, "SAFE_SET_VARIABLE_FIELD_CACHED0" },
    { 0x66, "SAFE_SET_VARIABLE_FIELD_CACHED" },
    { 0x67, "CALL_METHOD_CHILD_THREAD_POINTER" },
    { 0x68, "GET_LEVEL" },
    { 0x69, "NOTIFY" },
    { 0x6A, "DEC_TOP" },
    { 0x6B, "SHIFT_LEFT" },
    { 0x6C, "CALL_LOCAL_METHOD_THREAD" },
    { 0x6D, "CALL_LOCAL_METHOD_CHILD_THREAD" },
    { 0x6E, "GREATER" },
    { 0x6F, "EVAL_LOCAL_VARIABLE_CACHED0" },
    { 0x70, "EVAL_LOCAL_VARIABLE_CACHED1" },
    { 0x71, "EVAL_LOCAL_VARIABLE_CACHED2" },
    { 0x72, "EVAL_LOCAL_VARIABLE_CACHED3" },
    { 0x73, "EVAL_LOCAL_VARIABLE_CACHED4" },
    { 0x74, "EVAL_LOCAL_VARIABLE_CACHED5" },
    { 0x75, "EVAL_LOCAL_VARIABLE_CACHED" },
    { 0x76, "SAFE_SET_WAITTILL_VARIABLE_FIELD_CACHED" },
    { 0x77, "JMP" },
    { 0x78, "CALL_FUNC_THREAD_POINTER" },
    { 0x79, "GET_ZERO" },
    { 0x7A, "WAIT" },
    { 0x7B, "MINUS" },
    { 0x7C, "SET_SELF_FIELD_VARIABLE_FIELD" },
    { 0x7D, "EVAL_NEW_LOCAL_VARIABLE_REF_CACHED0" },
    { 0x7E, "MULT" },
    { 0x7F, "CREATE_LOCAL_VARIABLE" },
    { 0x80, "CALL_LOCAL_FUNC_CHILD_THREAD" },
    { 0x81, "GET_INT" },
    { 0x82, "MOD" },
    { 0x83, "EVAL_ANIM_FIELD_VARIABLE_REF" },
    { 0x84, "GET_BUILTIN_FUNC" },
    { 0x85, "GET_GAME" },
    { 0x86, "WAITTILL" },
    { 0x87, "DEC" },
    { 0x88, "EVAL_LOCAL_VARIABLE_OBJECT_CACHED" },
    { 0x89, "PRE_CALL" },
    { 0x8A, "GET_ANIM" },
    { 0x8B, "GET_UNDEFINED" },
    { 0x8C, "EVAL_LEVEL_FIELD_VARIABLE_REF" },
    { 0x8D, "GET_ANIM_OBJ" },
    { 0x8E, "GET_LEVEL_OBJ" },
    { 0x8F, "BIT_EXOR" },
    { 0x90, "EQUALITY" },
    { 0x91, "CLEAR_ARRAY" },
    { 0x92, "JMP_BACK" },
    { 0x93, "GET_ANIMATION" },
    { 0x94, "EVAL_ANIM_FIELD_VARIABLE" },
    { 0x95, "GET_ANIMTREE" },
    { 0x96, "GET_ISTRING" },
    { 0x97, "EVAL_ARRAY_REF" },
    { 0x98, "EVAL_SELF_FIELD_VARIABLE_REF" },
    { 0x99, "GET_NBYTE" },
    { 0x9A, "GET_BUILTIN_METHOD" },
    { 0x9B, "CALL_BUILTIN_METHOD_POINTER" },
    { 0x9C, "EVAL_ARRAY" },
    { 0x9D, "VECTOR" },
    { 0x9E, "CALL_FAR_METHOD" },
    { 0x9F, "EVAL_LOCAL_ARRAY_CACHED" },
    { 0xA0, "GET_BYTE" },
    { 0xA1, "CALL_FUNC_CHILD_THREAD_POINTER" },
    { 0xA2, "BIT_OR" },
    { 0xA3, "ADD_ARRAY" },
    { 0xA4, "WAITTILLMATCH2" },
    { 0xA5, "WAITTILLMATCH" },
    { 0xA6, "GET_LOCAL_FUNC" },
    { 0xA7, "GET_NUSHORT" },
    { 0xA8, "SHIFT_RIGHT" },
    { 0xA9, "CALL_BUILTIN_METHOD_0" },
    { 0xAA, "CALL_BUILTIN_METHOD_1" },
    { 0xAB, "CALL_BUILTIN_METHOD_2" },
    { 0xAC, "CALL_BUILTIN_METHOD_3" },
    { 0xAD, "CALL_BUILTIN_METHOD_4" },
    { 0xAE, "CALL_BUILTIN_METHOD_5" },
    { 0xAF, "CALL_BUILTIN_METHOD" },
    { 0xB0, "JMP_FALSE" },
}};

const std::array<std::pair<std::uint16_t, const char*>, 778> function_list
{{
    { 0x001, "precacheturret" },
    { 0x002, "getweaponarray" },
    { 0x003, "createprintchannel" },
    { 0x004, "updategamerprofileall" },
    { 0x005, "clearlocalizedstrings" },
    { 0x006, "setphysicsgravitydir" },
    { 0x007, "gettimescale" },
    { 0x008, "settimescale" },
    { 0x009, "setslowmotionview" },
    { 0x00A, "teleportscene" },
    { 0x00B, "forcesharedammo" },
    { 0x00C, "refreshhudcompass" },
    { 0x00D, "refreshhudammocounter" },
    { 0x00E, "notifyoncommand" },
    { 0x00F, "setprintchannel" },
    { 0x010, "print" },
    { 0x011, "println" },
    { 0x012, "print3d" },
    { 0x013, "line" },
    { 0x014, "box" },
    { 0x015, "orientedbox" },
    { 0x016, "sphere" },
    { 0x017, "cylinder" },
    { 0x018, "spawnturret" },
    { 0x019, "canspawnturret" },
    { 0x01A, "assert" },
    { 0x01B, "pausecinematicingame" },
    { 0x01C, "drawcompassfriendlies" },
    { 0x01D, "bulletspread" },
    { 0x01E, "bullettracer" },
    { 0x01F, "badplace_delete" },
    { 0x020, "badplace_cylinder" },
    { 0x021, "badplace_arc" },
    { 0x022, "badplace_brush" },
    { 0x023, "clearallcorpses" },
    { 0x024, "setturretnode" },
    { 0x025, "unsetturretnode" },
    { 0x026, "setnodepriority" },
    { 0x027, "_func_027" },
    { 0x028, "_func_028" },
    { 0x029, "_func_029" },
    { 0x02A, "setdebugorigin" },
    { 0x02B, "setdebugangles" },
    { 0x02C, "updategamerprofile" },
    { 0x02D, "assertex" },
    { 0x02E, "assertmsg" },
    { 0x02F, "isdefined" },
    { 0x030, "isvalidmissile" },
    { 0x031, "isstring" },
    { 0x032, "setomnvar" },
    { 0x033, "getomnvar" },
    { 0x034, "setdvar" },
    { 0x035, "setdynamicdvar" },
    { 0x036, "setdvarifuninitialized" },
    { 0x037, "setdevdvar" },
    { 0x038, "setdevdvarifuninitialized" },
    { 0x039, "getdvar" },
    { 0x03A, "getdvarint" },
    { 0x03B, "getdvarfloat" },
    { 0x03C, "getdvarvector" },
    { 0x03D, "gettime" },
    { 0x03E, "gettimeutc" },
    { 0x03F, "getradiometricunit" },
    { 0x040, "getentbynum" },
    { 0x041, "getscreenwidth" },
    { 0x042, "getscreenheight" },
    { 0x043, "getweaponmodel" },
    { 0x044, "getculldist" },
    { 0x045, "sethalfresparticles" },
    { 0x046, "getmapsunlight" },
    { 0x047, "setsunlight" },
    { 0x048, "resetsunlight" },
    { 0x049, "getmapsundirection" },
    { 0x04A, "getmapsunangles" },
    { 0x04B, "setsundirection" },
    { 0x04C, "lerpsundirection" },
    { 0x04D, "lerpsunangles" },
    { 0x04E, "resetsundirection" },
    { 0x04F, "enableforcedsunshadows" },
    { 0x050, "enableforcednosunshadows" },
    { 0x051, "disableforcedsunshadows" },
    { 0x052, "enableouterspacemodellighting" },
    { 0x053, "disableouterspacemodellighting" },
    { 0x054, "remapstage" },
    { 0x055, "changelevel" },
    { 0x056, "missionsuccess" },
    { 0x057, "missionfailed" },
    { 0x058, "cinematic" },
    { 0x059, "cinematicingame" },
    { 0x05A, "cinematicingamesync" },
    { 0x05B, "cinematicingameloop" },
    { 0x05C, "cinematicingameloopresident" },
    { 0x05D, "iscinematicplaying" },
    { 0x05E, "stopcinematicingame" },
    { 0x05F, "getweapondisplayname" },
    { 0x060, "getweaponbasename" },
    { 0x061, "getweaponattachments" },
    { 0x062, "getweaponattachmentdisplaynames" },
    { 0x063, "getweaponcamoname" },
    { 0x064, "getweaponreticlename" },
    { 0x065, "getanimlength" },
    { 0x066, "animhasnotetrack" },
    { 0x067, "getnotetracktimes" },
    { 0x068, "spawn" },
    { 0x069, "spawnloopsound" },
    { 0x06A, "spawnloopingsound" },
    { 0x06B, "bullettrace" },
    { 0x06C, "target_setmaxsize" },
    { 0x06D, "target_setcolor" },
    { 0x06E, "target_setdelay" },
    { 0x06F, "getstartorigin" },
    { 0x070, "getstartangles" },
    { 0x071, "getcycleoriginoffset" },
    { 0x072, "magicgrenade" },
    { 0x073, "magicgrenademanual" },
    { 0x074, "setblur" },
    { 0x075, "musicplay" },
    { 0x076, "musicstop" },
    { 0x077, "soundfade" },
    { 0x078, "addsoundsubmix" },
    { 0x079, "clearsoundsubmix" },
    { 0x07A, "clearallsubmixes" },
    { 0x07B, "blendsoundsubmix" },
    { 0x07C, "makesoundsubmixsticky" },
    { 0x07D, "makesoundsubmixunsticky" },
    { 0x07E, "soundsettimescalefactor" },
    { 0x07F, "soundresettimescale" },
    { 0x080, "levelsoundfade" },
    { 0x081, "precachenightvisioncodeassets" },
    { 0x082, "precachedigitaldistortcodeassets" },
    { 0x083, "precachesonarvisioncodeassets" },
    { 0x084, "precacheminimapsentrycodeassets" },
    { 0x085, "savegame" },
    { 0x086, "issavesuccessful" },
    { 0x087, "issaverecentlyloaded" },
    { 0x088, "savegamenocommit" },
    { 0x089, "commitsave" },
    { 0x08A, "commitwouldbevalid" },
    { 0x08B, "getfxvisibility" },
    { 0x08C, "setculldist" },
    { 0x08D, "bullettracepassed" },
    { 0x08E, "sighttracepassed" },
    { 0x08F, "physicstrace" },
    { 0x090, "playerphysicstrace" },
    { 0x091, "getgroundposition" },
    { 0x092, "getmovedelta" },
    { 0x093, "getangledelta" },
    { 0x094, "getnorthyaw" },
    { 0x095, "getcommandfromkey" },
    { 0x096, "getsticksconfig" },
    { 0x097, "weaponfightdist" },
    { 0x098, "weaponmaxdist" },
    { 0x099, "isturretactive" },
    { 0x09A, "getturretfov" },
    { 0x09B, "target_alloc" },
    { 0x09C, "target_flush" },
    { 0x09D, "target_set" },
    { 0x09E, "target_remove" },
    { 0x09F, "target_setshader" },
    { 0x0A0, "target_setoffscreenshader" },
    { 0x0A1, "target_isinrect" },
    { 0x0A2, "target_isincircle" },
    { 0x0A3, "target_startreticlelockon" },
    { 0x0A4, "target_clearreticlelockon" },
    { 0x0A5, "target_getarray" },
    { 0x0A6, "target_istarget" },
    { 0x0A7, "target_setattackmode" },
    { 0x0A8, "target_setjavelinonly" },
    { 0x0A9, "target_hidefromplayer" },
    { 0x0AA, "target_showtoplayer" },
    { 0x0AB, "target_setscaledrendermode" },
    { 0x0AC, "target_drawcornersonly" },
    { 0x0AD, "target_drawsquare" },
    { 0x0AE, "target_drawsingle" },
    { 0x0AF, "target_setminsize" },
    { 0x0B0, "setnorthyaw" },
    { 0x0B1, "setslowmotion" },
    { 0x0B2, "randomint" },
    { 0x0B3, "randomfloat" },
    { 0x0B4, "randomintrange" },
    { 0x0B5, "randomfloatrange" },
    { 0x0B6, "sin" },
    { 0x0B7, "cos" },
    { 0x0B8, "tan" },
    { 0x0B9, "asin" },
    { 0x0BA, "acos" },
    { 0x0BB, "atan" },
    { 0x0BC, "int" },
    { 0x0BD, "float" },
    { 0x0BE, "abs" },
    { 0x0BF, "min" },
    { 0x0C0, "objective_additionalcurrent" },
    { 0x0C1, "objective_ring" },
    { 0x0C2, "objective_setpointertextoverride" },
    { 0x0C3, "getnode" },
    { 0x0C4, "getnodearray" },
    { 0x0C5, "getallnodes" },
    { 0x0C6, "getnodesinradius" },
    { 0x0C7, "getnodesinradiussorted" },
    { 0x0C8, "getclosestnodeinsight" },
    { 0x0C9, "getreflectionlocs" },
    { 0x0CA, "getreflectionreferencelocs" },
    { 0x0CB, "getvehicletracksegment" },
    { 0x0CC, "getvehicletracksegmentarray" },
    { 0x0CD, "getallvehicletracksegments" },
    { 0x0CE, "isarray" },
    { 0x0CF, "isai" },
    { 0x0D0, "getindexforluincstring" },
    { 0x0D1, "issentient" },
    { 0x0D2, "isgodmode" },
    { 0x0D3, "getdebugdvar" },
    { 0x0D4, "getdebugdvarint" },
    { 0x0D5, "getdebugdvarfloat" },
    { 0x0D6, "setsaveddvar" },
    { 0x0D7, "getfreeaicount" },
    { 0x0D8, "getaicount" },
    { 0x0D9, "getaiarray" },
    { 0x0DA, "getaispeciesarray" },
    { 0x0DB, "getspawnerarray" },
    { 0x0DC, "getcorpsearray" },
    { 0x0DD, "getspawnerteamarray" },
    { 0x0DE, "getweaponclipmodel" },
    { 0x0DF, "getbrushmodelcenter" },
    { 0x0E0, "getkeybinding" },
    { 0x0E1, "max" },
    { 0x0E2, "floor" },
    { 0x0E3, "ceil" },
    { 0x0E4, "exp" },
    { 0x0E5, "_func_0E5" },
    { 0x0E6, "log" },
    { 0x0E7, "sqrt" },
    { 0x0E8, "squared" },
    { 0x0E9, "clamp" },
    { 0x0EA, "angleclamp" },
    { 0x0EB, "angleclamp180" },
    { 0x0EC, "vectorfromlinetopoint" },
    { 0x0ED, "pointonsegmentnearesttopoint" },
    { 0x0EE, "distance" },
    { 0x0EF, "distance2d" },
    { 0x0F0, "distancesquared" },
    { 0x0F1, "length" },
    { 0x0F2, "length2d" },
    { 0x0F3, "lengthsquared" },
    { 0x0F4, "length2dsquared" },
    { 0x0F5, "closer" },
    { 0x0F6, "vectordot" },
    { 0x0F7, "vectorcross" },
    { 0x0F8, "axistoangles" },
    { 0x0F9, "visionsetthermal" },
    { 0x0FA, "visionsetpain" },
    { 0x0FB, "endlobby" },
    { 0x0FC, "setac130ambience" },
    { 0x0FD, "getmapcustom" },
    { 0x0FE, "spawnsighttrace" },
    { 0x0FF, "incrementcounter" },
    { 0x100, "getcountertotal" },
    { 0x101, "getlevelticks" },
    { 0x102, "perlinnoise2d" },
    { 0x103, "calcrockingangles" },
    { 0x104, "reconevent" },
    { 0x105, "reconspatialevent" },
    { 0x106, "setsunflareposition" },
    { 0x107, "createthreatbiasgroup" },
    { 0x108, "threatbiasgroupexists" },
    { 0x109, "getthreatbias" },
    { 0x10A, "setthreatbias" },
    { 0x10B, "setthreatbiasagainstall" },
    { 0x10C, "setignoremegroup" },
    { 0x10D, "isenemyteam" },
    { 0x10E, "objective_additionalentity" },
    { 0x10F, "objective_state_nomessage" },
    { 0x110, "objective_string" },
    { 0x111, "objective_string_nomessage" },
    { 0x112, "objective_additionalposition" },
    { 0x113, "objective_current_nomessage" },
    { 0x114, "vectornormalize" },
    { 0x115, "vectortoangles" },
    { 0x116, "vectortoyaw" },
    { 0x117, "vectorlerp" },
    { 0x118, "anglestoup" },
    { 0x119, "anglestoright" },
    { 0x11A, "anglestoforward" },
    { 0x11B, "anglesdelta" },
    { 0x11C, "combineangles" },
    { 0x11D, "transformmove" },
    { 0x11E, "rotatevector" },
    { 0x11F, "rotatepointaroundvector" },
    { 0x120, "issubstr" },
    { 0x121, "isendstr" },
    { 0x122, "getsubstr" },
    { 0x123, "tolower" },
    { 0x124, "strtok" },
    { 0x125, "stricmp" },
    { 0x126, "ambientplay" },
    { 0x127, "getuavstrengthmax" },
    { 0x128, "getuavstrengthlevelneutral" },
    { 0x129, "getuavstrengthlevelshowenemyfastsweep" },
    { 0x12A, "getuavstrengthlevelshowenemydirectional" },
    { 0x12B, "blockteamradar" },
    { 0x12C, "unblockteamradar" },
    { 0x12D, "isteamradarblocked" },
    { 0x12E, "getassignedteam" },
    { 0x12F, "setmatchdata" },
    { 0x130, "getmatchdata" },
    { 0x131, "sendmatchdata" },
    { 0x132, "clearmatchdata" },
    { 0x133, "setmatchdatadef" },
    { 0x134, "setmatchclientip" },
    { 0x135, "setmatchdataid" },
    { 0x136, "setclientmatchdata" },
    { 0x137, "getclientmatchdata" },
    { 0x138, "setclientmatchdatadef" },
    { 0x139, "sendclientmatchdata" },
    { 0x13A, "getbuildversion" },
    { 0x13B, "getbuildnumber" },
    { 0x13C, "getsystemtime" },
    { 0x13D, "getmatchrulesdata" },
    { 0x13E, "isusingmatchrulesdata" },
    { 0x13F, "kick" },
    { 0x140, "issplitscreen" },
    { 0x141, "setmapcenter" },
    { 0x142, "setgameendtime" },
    { 0x143, "visionsetnaked" },
    { 0x144, "visionsetnight" },
    { 0x145, "visionsetmissilecam" },
    { 0x146, "ambientstop" },
    { 0x147, "precachemodel" },
    { 0x148, "precacheshellshock" },
    { 0x149, "precacheitem" },
    { 0x14A, "precacheshader" },
    { 0x14B, "precachestring" },
    { 0x14C, "precachemenu" },
    { 0x14D, "precacherumble" },
    { 0x14E, "precachelocationselector" },
    { 0x14F, "precacheleaderboards" },
    { 0x150, "loadfx" },
    { 0x151, "playfx" },
    { 0x152, "playfxontag" },
    { 0x153, "stopfxontag" },
    { 0x154, "killfxontag" },
    { 0x155, "playloopedfx" },
    { 0x156, "spawnfx" },
    { 0x157, "triggerfx" },
    { 0x158, "playfxontagforclients" },
    { 0x159, "setfxkillondelete" },
    { 0x15A, "playimpactheadfatalfx" },
    { 0x15B, "setwinningteam" },
    { 0x15C, "announcement" },
    { 0x15D, "clientannouncement" },
    { 0x15E, "setteammode" },
    { 0x15F, "getteamscore" },
    { 0x160, "setteamscore" },
    { 0x161, "setclientnamemode" },
    { 0x162, "updateclientnames" },
    { 0x163, "getteamplayersalive" },
    { 0x164, "logprint" },
    { 0x165, "worldentnumber" },
    { 0x166, "obituary" },
    { 0x167, "positionwouldtelefrag" },
    { 0x168, "canspawn" },
    { 0x169, "getstarttime" },
    { 0x16A, "precacheheadicon" },
    { 0x16B, "precacheminimapicon" },
    { 0x16C, "precachempanim" },
    { 0x16D, "map_restart" },
    { 0x16E, "exitlevel" },
    { 0x16F, "addtestclient" },
    { 0x170, "addagent" },
    { 0x171, "setarchive" },
    { 0x172, "allclientsprint" },
    { 0x173, "clientprint" },
    { 0x174, "mapexists" },
    { 0x175, "isvalidgametype" },
    { 0x176, "matchend" },
    { 0x177, "setplayerteamrank" },
    { 0x178, "endparty" },
    { 0x179, "setteamradar" },
    { 0x17A, "getteamradar" },
    { 0x17B, "setteamradarstrength" },
    { 0x17C, "getteamradarstrength" },
    { 0x17D, "getuavstrengthmin" },
    { 0x17E, "physicsexplosionsphere" },
    { 0x17F, "physicsexplosioncylinder" },
    { 0x180, "physicsjolt" },
    { 0x181, "physicsjitter" },
    { 0x182, "setexpfog" },
    { 0x183, "setexpfogext" },
    { 0x184, "setexpfogdvarsonly" },
    { 0x185, "setexpfogextdvarsonly" },
    { 0x186, "setatmosfog" },
    { 0x187, "setatmosfogdvarsonly" },
    { 0x188, "isexplosivedamagemod" },
    { 0x189, "radiusdamage" },
    { 0x18A, "setplayerignoreradiusdamage" },
    { 0x18B, "glassradiusdamage" },
    { 0x18C, "earthquake" },
    { 0x18D, "getnumparts" },
    { 0x18E, "objective_onentity" },
    { 0x18F, "objective_onentitywithrotation" },
    { 0x190, "objective_team" },
    { 0x191, "objective_player" },
    { 0x192, "objective_playerteam" },
    { 0x193, "objective_playerenemyteam" },
    { 0x194, "objective_playermask_hidefromall" },
    { 0x195, "objective_playermask_hidefrom" },
    { 0x196, "objective_playermask_showtoall" },
    { 0x197, "objective_playermask_showto" },
    { 0x198, "iprintln" },
    { 0x199, "iprintlnbold" },
    { 0x19A, "logstring" },
    { 0x19B, "getent" },
    { 0x19C, "getentarray" },
    { 0x19D, "getspawnarray" },
    { 0x19E, "spawnplane" },
    { 0x19F, "spawnstruct" },
    { 0x1A0, "spawnhelicopter" },
    { 0x1A1, "isalive" },
    { 0x1A2, "isspawner" },
    { 0x1A3, "missile_createattractorent" },
    { 0x1A4, "missile_createattractororigin" },
    { 0x1A5, "missile_createrepulsorent" },
    { 0x1A6, "missile_createrepulsororigin" },
    { 0x1A7, "missile_deleteattractor" },
    { 0x1A8, "playsoundatpos" },
    { 0x1A9, "newhudelem" },
    { 0x1AA, "newclienthudelem" },
    { 0x1AB, "newteamhudelem" },
    { 0x1AC, "resettimeout" },
    { 0x1AD, "isplayer" },
    { 0x1AE, "isplayernumber" },
    { 0x1AF, "getpartname" },
    { 0x1B0, "weaponfiretime" },
    { 0x1B1, "weaponclipsize" },
    { 0x1B2, "weaponisauto" },
    { 0x1B3, "weaponissemiauto" },
    { 0x1B4, "weaponisboltaction" },
    { 0x1B5, "weaponinheritsperks" },
    { 0x1B6, "weaponburstcount" },
    { 0x1B7, "weapontype" },
    { 0x1B8, "weaponclass" },
    { 0x1B9, "getnextarraykey" },
    { 0x1BA, "sortbydistance" },
    { 0x1BB, "tablelookup" },
    { 0x1BC, "tablelookupbyrow" },
    { 0x1BD, "tablelookupistring" },
    { 0x1BE, "tablelookupistringbyrow" },
    { 0x1BF, "tablelookuprownum" },
    { 0x1C0, "tableexists" },
    { 0x1C1, "getmissileowner" },
    { 0x1C2, "magicbullet" },
    { 0x1C3, "getweaponflashtagname" },
    { 0x1C4, "averagepoint" },
    { 0x1C5, "averagenormal" },
    { 0x1C6, "vehicle_getspawnerarray" },
    { 0x1C7, "playrumbleonposition" },
    { 0x1C8, "playrumblelooponposition" },
    { 0x1C9, "stopallrumbles" },
    { 0x1CA, "soundexists" },
    { 0x1CB, "openfile" },
    { 0x1CC, "closefile" },
    { 0x1CD, "fprintln" },
    { 0x1CE, "fprintfields" },
    { 0x1CF, "freadln" },
    { 0x1D0, "fgetarg" },
    { 0x1D1, "setminimap" },
    { 0x1D2, "setthermalbodymaterial" },
    { 0x1D3, "getarraykeys" },
    { 0x1D4, "getfirstarraykey" },
    { 0x1D5, "getglass" },
    { 0x1D6, "getglassarray" },
    { 0x1D7, "getglassorigin" },
    { 0x1D8, "isglassdestroyed" },
    { 0x1D9, "destroyglass" },
    { 0x1DA, "deleteglass" },
    { 0x1DB, "getentchannelscount" },
    { 0x1DC, "getentchannelname" },
    { 0x1DD, "objective_add" },
    { 0x1DE, "objective_delete" },
    { 0x1DF, "objective_state" },
    { 0x1E0, "objective_icon" },
    { 0x1E1, "objective_indentlevel" },
    { 0x1E2, "objective_position" },
    { 0x1E3, "objective_current" },
    { 0x1E4, "weaponinventorytype" },
    { 0x1E5, "weaponstartammo" },
    { 0x1E6, "weaponmaxammo" },
    { 0x1E7, "weaponaltweaponname" },
    { 0x1E8, "isweaponcliponly" },
    { 0x1E9, "isweapondetonationtimed" },
    { 0x1EA, "isweaponmanuallydetonatedbyemptythrow" },
    { 0x1EB, "weaponhasthermalscope" },
    { 0x1EC, "getvehiclenode" },
    { 0x1ED, "getvehiclenodearray" },
    { 0x1EE, "getallvehiclenodes" },
    { 0x1EF, "getnumvehicles" },
    { 0x1F0, "precachevehicle" },
    { 0x1F1, "spawnvehicle" },
    { 0x1F2, "vehicle_getarray" },
    { 0x1F3, "pow" },
    { 0x1F4, "atan2" },
    { 0x1F5, "botgetmemoryevents" },
    { 0x1F6, "botautoconnectenabled" },
    { 0x1F7, "botzonegetcount" },
    { 0x1F8, "botzonesetteam" },
    { 0x1F9, "botzonenearestcount" },
    { 0x1FA, "botmemoryflags" },
    { 0x1FB, "botflagmemoryevents" },
    { 0x1FC, "botzonegetindoorpercent" },
    { 0x1FD, "botsentientswap" },
    { 0x1FE, "isbot" },
    { 0x1FF, "isagent" },
    { 0x200, "getmaxagents" },
    { 0x201, "botdebugdrawtrigger" },
    { 0x202, "botgetclosestnavigablepoint" },
    { 0x203, "getnodesintrigger" },
    { 0x204, "nodesvisible" },
    { 0x205, "getnodesonpath" },
    { 0x206, "getzonecount" },
    { 0x207, "getzonenearest" },
    { 0x208, "getzonenodes" },
    { 0x209, "getzonepath" },
    { 0x20A, "getzoneorigin" },
    { 0x20B, "getnodezone" },
    { 0x20C, "getzonenodesbydist" },
    { 0x20D, "getzonenodeforindex" },
    { 0x20E, "getweaponexplosionradius" },
    { 0x20F, "markdangerousnodes" },
    { 0x210, "markdangerousnodesintrigger" },
    { 0x211, "nodeexposedtosky" },
    { 0x212, "findentrances" },
    { 0x213, "badplace_global" },
    { 0x214, "getpathdist" },
    { 0x215, "getlinkednodes" },
    { 0x216, "disconnectnodepair" },
    { 0x217, "connectnodepair" },
    { 0x218, "gettimesincelastpaused" },
    { 0x219, "precachefxontag" },
    { 0x21A, "precachetag" },
    { 0x21B, "precachesound" },
    { 0x21C, "devsetminimapdvarsettings" },
    { 0x21D, "loadtransient" },
    { 0x21E, "unloadtransient" },
    { 0x21F, "unloadalltransients" },
    { 0x220, "synctransients" },
    { 0x221, "aretransientsbusy" },
    { 0x222, "istransientqueued" },
    { 0x223, "istransientloaded" },
    { 0x224, "loadstartpointtransient" },
    { 0x225, "distance2dsquared" },
    { 0x226, "getangledelta3d" },
    { 0x227, "activateclientexploder" },
    { 0x228, "trajectorycalculateinitialvelocity" },
    { 0x229, "trajectorycalculateminimumvelocity" },
    { 0x22A, "trajectorycalculateexitangle" },
    { 0x22B, "trajectoryestimatedesiredinairtime" },
    { 0x22C, "trajectorycomputedeltaheightattime" },
    { 0x22D, "trajectorycanattemptaccuratejump" },
    { 0x22E, "adddebugcommand" },
    { 0x22F, "ispointinvolume" },
    { 0x230, "cinematicgettimeinmsec" },
    { 0x231, "cinematicgetframe" },
    { 0x232, "iscinematicloaded" },
    { 0x233, "bbprint" },
    { 0x234, "getenemysquaddata" },
    { 0x235, "lookupsoundlength" },
    { 0x236, "getscriptablearray" },
    { 0x237, "clearfog" },
    { 0x238, "setleveldopplerpreset" },
    { 0x239, "screenshake" },
    { 0x23A, "isusinghdr" },
    { 0x23B, "isusingssao" },
    { 0x23C, "grantloot" },
    { 0x23D, "playerphysicstraceinfo" },
    { 0x23E, "_func_23E" },
    { 0x23F, "getminchargetime" },
    { 0x240, "getchargetimepershot" },
    { 0x241, "getmaxchargeshots" },
    { 0x242, "weaponischargeable" },
    { 0x243, "weaponusesheat" },
    { 0x244, "lootserviceonendgame" },
    { 0x245, "luinotifyevent" },
    { 0x246, "lootserviceonstartgame" },
    { 0x247, "tournamentreportplayerspm" },
    { 0x248, "tournamentreportwinningteam" },
    { 0x249, "tournamentreportendofgame" },
    { 0x24A, "wakeupphysicssphere" },
    { 0x24B, "wakeupragdollsphere" },
    { 0x24C, "dopplerpitch" },
    { 0x24D, "piecewiselinearlookup" },
    { 0x24E, "anglestoaxis" },
    { 0x24F, "visionsetwater" },
    { 0x250, "sendscriptusageanalysisdata" },
    { 0x251, "resetscriptusageanalysisdata" },
    { 0x252, "instantlylogusageanalysisdata" },
    { 0x253, "invertangles" },
    { 0x254, "rotatevectorinverted" },
    { 0x255, "calculatestartorientation" },
    { 0x256, "droptoground" },
    { 0x257, "setdemigodmode" },
    { 0x258, "precachelaser" },
    { 0x259, "_func_259" },
    { 0x25A, "getcsplinecount" },
    { 0x25B, "getcsplinepointcount" },
    { 0x25C, "getcsplinelength" },
    { 0x25D, "getcsplinepointid" },
    { 0x25E, "getcsplinepointlabel" },
    { 0x25F, "getcsplinepointtension" },
    { 0x260, "getcsplinepointposition" },
    { 0x261, "getcsplinepointcorridordims" },
    { 0x262, "getcsplinepointtangent" },
    { 0x263, "getcsplinepointdisttonextpoint" },
    { 0x264, "calccsplineposition" },
    { 0x265, "calccsplinetangent" },
    { 0x266, "calccsplinecorridor" },
    { 0x267, "setnojipscore" },
    { 0x268, "setnojiptime" },
    { 0x269, "getpredictedentityposition" },
    { 0x26A, "gamedvrprohibitrecording" },
    { 0x26B, "gamedvrstartrecording" },
    { 0x26C, "gamedvrstoprecording" },
    { 0x26D, "gamedvrsetvideometadata" },
    { 0x26E, "gamedvrprohibitscreenshots" },
    { 0x26F, "gamedvrsetscreenshotmetadata" },
    { 0x270, "queuedialog" },
    { 0x271, "speechenablegrammar" },
    { 0x272, "speechenable" },
    { 0x273, "livestreamingenable" },
    { 0x274, "livestreamingsetbitrate" },
    { 0x275, "livestreamingsetmetadata" },
    { 0x276, "livestreamingenablearchiving" },
    { 0x277, "triggerportableradarping" },
    { 0x278, "setglaregrimematerial" },
    { 0x279, "botgetteamlimit" },
    { 0x27A, "spawnfxforclient" },
    { 0x27B, "botgetteamdifficulty" },
    { 0x27C, "debugstar" },
    { 0x27D, "newdebughudelem" },
    { 0x27E, "printlightsetsettings" },
    { 0x27F, "lightsetdumpstate" },
    { 0x280, "getsquadassaultelo" },
    { 0x281, "loadluifile" },
    { 0x282, "isdedicatedserver" },
    { 0x283, "getplaylistversion" },
    { 0x284, "getplaylistid" },
    { 0x285, "getactiveclientcount" },
    { 0x286, "issquadsmode" },
    { 0x287, "getsquadassaultsquadindex" },
    { 0x288, "visionsetpostapply" },
    { 0x289, "addbot" },
    { 0x28A, "ishairrunning" },
    { 0x28B, "getnearbyarrayelements" },
    { 0x28C, "vectorclamp" },
    { 0x28D, "isalliedsentient" },
    { 0x28E, "istestclient" },
    { 0x28F, "getrandomnodedestination" },
    { 0x290, "debuglocalizestring" },
    { 0x291, "enablesoundcontextoverride" },
    { 0x292, "disablesoundcontextoverride" },
    { 0x293, "notifyoncommandremove" },
    { 0x294, "getsndaliasvalue" },
    { 0x295, "setsndaliasvalue" },
    { 0x296, "packedtablelookup" },
    { 0x297, "packedtablesectionlookup" },
    { 0x298, "packedtablelookupwithrange" },
    { 0x299, "grappletrace" },
    { 0x29A, "stopclientexploder" },
    { 0x29B, "closestpointstwosegs" },
    { 0x29C, "isremovedentity" },
    { 0x29D, "tablegetrowcount" },
    { 0x29E, "tablegetcolumncount" },
    { 0x29F, "batteryusepershot" },
    { 0x2A0, "batteryreqtouse" },
    { 0x2A1, "isweaponmanuallydetonatedbydoubletap" },
    { 0x2A2, "grapplegetmagnets" },
    { 0x2A3, "getweaponname" },
    { 0x2A4, "activatepersistentclientexploder" },
    { 0x2A5, "deployriotshield" },
    { 0x2A6, "validatecostume" },
    { 0x2A7, "randomcostume" },
    { 0x2A8, "shootblank" },
    { 0x2A9, "boidflockupdate" },
    { 0x2AA, "debuggetanimname" },
    { 0x2AB, "setspmatchdata" },
    { 0x2AC, "getspmatchdata" },
    { 0x2AD, "sendspmatchdata" },
    { 0x2AE, "clearspmatchdata" },
    { 0x2AF, "setspmatchdatadef" },
    { 0x2B0, "playcinematicforall" },
    { 0x2B1, "preloadcinematicforall" },
    { 0x2B2, "stopcinematicforall" },
    { 0x2B3, "capsuletracepassed" },
    { 0x2B4, "stopfxontagforclient" },
    { 0x2B5, "killfxontagforclient" },
    { 0x2B6, "isvector" },
    { 0x2B7, "notifychallengecomplete" },
    { 0x2B8, "lootservicestarttrackingplaytime" },
    { 0x2B9, "lootservicestoptrackingplaytime" },
    { 0x2BA, "lootservicevalidateplaytime" },
    { 0x2BB, "recordbreadcrumbdataforplayer" },
    { 0x2BC, "getweaponandattachmentmodels" },
    { 0x2BD, "changewhizbyautosimparams" },
    { 0x2BE, "sysprint" },
    { 0x2BF, "objective_mlgspectator" },
    { 0x2C0, "setspcheckpointdata" },
    { 0x2C1, "getspcheckpointdata" },
    { 0x2C2, "isnumber" },
    { 0x2C3, "isonlinegame" },
    { 0x2C4, "issystemlink" },
    { 0x2C5, "setsoundmasteringfadetime" },
    { 0x2C6, "getstanceandmotionstateforplayer" },
    { 0x2C7, "nodeisnotusable" },
    { 0x2C8, "nodesetnotusable" },
    { 0x2C9, "spawnlinkedfx" },
    { 0x2CA, "spawnlinkedfxforclient" },
    { 0x2CB, "getplaylistname" },
    { 0x2CC, "getlocaltimestring" },
    { 0x2CD, "isonwifi" },
    { 0x2CE, "getbuttonsconfig" },
    { 0x2CF, "getchallengeid" },
    { 0x2D0, "nodehasremotemissileset" },
    { 0x2D1, "nodegetremotemissilename" },
    { 0x2D2, "remotemissileenttracetooriginpassed" },
    { 0x2D3, "bombingruntracepassed" },
    { 0x2D4, "soundsettraceflags" },
    { 0x2D5, "handlepickupdeployedriotshield" },
    { 0x2D6, "getcodanywherecurrentplatform" },
    { 0x2D7, "getcostumefromtable" },
    { 0x2D8, "visionsetoverdrive" },
    { 0x2D9, "nodegetsplitgroup" },
    { 0x2DA, "recordbreadcrumbdataforplayersp" },
    { 0x2DB, "getchallengerewarditem" },
    { 0x2DC, "setentplayerxuidforemblem" },
    { 0x2DD, "resetentplayerxuidforemblems" },
    { 0x2DE, "nodesetremotemissilename" },
    { 0x2DF, "isshipbuild" },
    { 0x2E0, "strinsertnumericdelimiters" },
    { 0x2E1, "isscriptedagent" },
    { 0x2E2, "playfxonweapon" },
    { 0x2E3, "stopfxonweapon" },
    { 0x2E4, "killfxonweapon" },
    { 0x2E5, "getdefaultmaxfaceenemydistance" },
    { 0x2E6, "applyaccelerationonentity" },
    { 0x2E7, "applyimpulseonentity" },
    { 0x2E8, "setshaderconstant" },
    { 0x2E9, "getinventoryitemtype" },
    { 0x2EA, "getweaponmodelbounds" },
    { 0x2EB, "weaponitemplayidleanim" },
    { 0x2EC, "_func_2EC" },
    { 0x2ED, "getstaticmodelcount" },
    { 0x2EE, "getstaticmodelname" },
    { 0x2EF, "getstaticmodelbounds" },
    { 0x2F0, "findstaticmodelindex" },
    { 0x2F1, "getdynentcount" },
    { 0x2F2, "getdynentmodelname" },
    { 0x2F3, "getdynentmodelbounds" },
    { 0x2F4, "finddynentwithmodelindex" },
    { 0x2F5, "getentitymodelname" },
    { 0x2F6, "getentitymodelbounds" },
    { 0x2F7, "findentitywithmodelindex" },
    { 0x2F8, "_func_2F8" },
    { 0x2F9, "_func_2F9" },
    { 0x2FA, "_func_2FA" },
    { 0x2FB, "_func_2FB" },
    { 0x2FC, "_func_2FC" },
    { 0x2FD, "_func_2FD" },
    { 0x2FE, "_func_2FE" },
    { 0x2FF, "_func_2FF" },
    { 0x300, "_func_300" },
    { 0x301, "_func_301" },
    { 0x302, "_func_302" },
    { 0x303, "_func_303" },
    { 0x304, "_func_304" },
    { 0x305, "_func_305" },
    { 0x306, "_func_306" },
    { 0x307, "_func_307" },
    { 0x308, "_func_308" },
    { 0x309, "_func_309" },
    { 0x30A, "_func_30A" },
}};

const std::array<std::pair<std::uint16_t, const char*>, 1415> method_list
{{
    { 0x8000, "motionblurhqenable" },
    { 0x8001, "setturretdismountorg" },
    { 0x8002, "setdamagestage" },
    { 0x8003, "playsoundtoteam" },
    { 0x8004, "playsoundtoplayer" },
    { 0x8005, "playerhide" },
    { 0x8006, "playershow" },
    { 0x8007, "showtoplayer" },
    { 0x8008, "threatdetectedtoplayer" },
    { 0x8009, "clearthreatdetected" },
    { 0x800A, "enableplayeruse" },
    { 0x800B, "disableplayeruse" },
    { 0x800C, "enableammogeneration" },
    { 0x800D, "disableammogeneration" },
    { 0x800E, "makescrambler" },
    { 0x800F, "makeportableradar" },
    { 0x8010, "clearscrambler" },
    { 0x8011, "clearportableradar" },
    { 0x8012, "addplayermantleblockage" },
    { 0x8013, "setteamfortrigger" },
    { 0x8014, "clientclaimtrigger" },
    { 0x8015, "clientreleasetrigger" },
    { 0x8016, "releaseclaimedtrigger" },
    { 0x8017, "isusingonlinedataoffline" },
    { 0x8018, "getrestedtime" },
    { 0x8019, "sendleaderboards" },
    { 0x801A, "isonladder" },
    { 0x801B, "getcorpseanim" },
    { 0x801C, "playerforcedeathanim" },
    { 0x801D, "attach" },
    { 0x801E, "getlightfovinner" },
    { 0x801F, "getlightfovouter" },
    { 0x8020, "setlightfovrange" },
    { 0x8021, "getlightexponent" },
    { 0x8022, "setlightexponent" },
    { 0x8023, "startragdoll" },
    { 0x8024, "startragdollfromimpact" },
    { 0x8025, "queryshouldearlyragdoll" },
    { 0x8026, "logstring" },
    { 0x8027, "_meth_8027" },
    { 0x8028, "_meth_8028" },
    { 0x8029, "thermaldrawenable" },
    { 0x802A, "detach" },
    { 0x802B, "detachall" },
    { 0x802C, "getattachsize" },
    { 0x802D, "getattachmodelname" },
    { 0x802E, "getattachtagname" },
    { 0x802F, "setturretcanaidetach" },
    { 0x8030, "setturretfov" },
    { 0x8031, "setplayerturretfov" },
    { 0x8032, "lerpfov" },
    { 0x8033, "lerpfovscale" },
    { 0x8034, "getvalidcoverpeekouts" },
    { 0x8035, "gethighestnodestance" },
    { 0x8036, "doesnodeallowstance" },
    { 0x8037, "doesnodeforcecombat" },
    { 0x8038, "getgunangles" },
    { 0x8039, "magicgrenade" },
    { 0x803A, "magicgrenademanual" },
    { 0x803B, "getentnum" },
    { 0x803C, "launch" },
    { 0x803D, "setsoundblend" },
    { 0x803E, "makefakeai" },
    { 0x803F, "spawndrone" },
    { 0x8040, "setcorpseremovetimer" },
    { 0x8041, "setlookattext" },
    { 0x8042, "setspawnerteam" },
    { 0x8043, "addaieventlistener" },
    { 0x8044, "removeaieventlistener" },
    { 0x8045, "getlightcolor" },
    { 0x8046, "setlightcolor" },
    { 0x8047, "getlightradius" },
    { 0x8048, "setlightradius" },
    { 0x8049, "getattachignorecollision" },
    { 0x804A, "hidepart" },
    { 0x804B, "hidepart_allinstances" },
    { 0x804C, "hideallparts" },
    { 0x804D, "showpart" },
    { 0x804E, "showallparts" },
    { 0x804F, "linkto" },
    { 0x8050, "linktoblendtotag" },
    { 0x8051, "unlink" },
    { 0x8052, "setnormalhealth" },
    { 0x8053, "dodamage" },
    { 0x8054, "kill" },
    { 0x8055, "show" },
    { 0x8056, "hide" },
    { 0x8057, "showonclient" },
    { 0x8058, "hideonclient" },
    { 0x8059, "disconnectpaths" },
    { 0x805A, "connectpaths" },
    { 0x805B, "disconnectnode" },
    { 0x805C, "connectnode" },
    { 0x805D, "startusingheroonlylighting" },
    { 0x805E, "stopusingheroonlylighting" },
    { 0x805F, "startusinglessfrequentlighting" },
    { 0x8060, "stopusinglessfrequentlighting" },
    { 0x8061, "setmovingplatformplayerturnrate" },
    { 0x8062, "setthermalfog" },
    { 0x8063, "setnightvisionfog" },
    { 0x8064, "clearthermalfog" },
    { 0x8065, "clearnightvisionfog" },
    { 0x8066, "_meth_8066" },
    { 0x8067, "setmode" },
    { 0x8068, "getmode" },
    { 0x8069, "setturretignoregoals" },
    { 0x806A, "islinked" },
    { 0x806B, "enablelinkto" },
    { 0x806C, "playsoundatviewheight" },
    { 0x806D, "_meth_806D" },
    { 0x806E, "setpitch" },
    { 0x806F, "scalepitch" },
    { 0x8070, "setvolume" },
    { 0x8071, "scalevolume" },
    { 0x8072, "enableportalgroup" },
    { 0x8073, "setspeakermapmonotostereo" },
    { 0x8074, "setspeakermapmonoto51" },
    { 0x8075, "setdistributed2dsound" },
    { 0x8076, "playsoundasmaster" },
    { 0x8077, "playloopsound" },
    { 0x8078, "eqon" },
    { 0x8079, "eqoff" },
    { 0x807A, "haseq" },
    { 0x807B, "iswaitingonsound" },
    { 0x807C, "playfoley" },
    { 0x807D, "getnormalhealth" },
    { 0x807E, "playerlinkto" },
    { 0x807F, "playerlinktodelta" },
    { 0x8080, "playerlinkweaponviewtodelta" },
    { 0x8081, "playerlinktoabsolute" },
    { 0x8082, "playerlinktoblend" },
    { 0x8083, "playerlinkedoffsetenable" },
    { 0x8084, "setwaypointedgestyle_secondaryarrow" },
    { 0x8085, "setwaypointiconoffscreenonly" },
    { 0x8086, "fadeovertime" },
    { 0x8087, "scaleovertime" },
    { 0x8088, "moveovertime" },
    { 0x8089, "reset" },
    { 0x808A, "destroy" },
    { 0x808B, "setpulsefx" },
    { 0x808C, "setplayernamestring" },
    { 0x808D, "changefontscaleovertime" },
    { 0x808E, "startignoringspotlight" },
    { 0x808F, "stopignoringspotlight" },
    { 0x8090, "dontcastshadows" },
    { 0x8091, "castshadows" },
    { 0x8092, "setstablemissile" },
    { 0x8093, "playersetgroundreferenceent" },
    { 0x8094, "dontinterpolate" },
    { 0x8095, "dospawn" },
    { 0x8096, "stalingradspawn" },
    { 0x8097, "getorigin" },
    { 0x8098, "getcentroid" },
    { 0x8099, "getshootatpos" },
    { 0x809A, "getdebugeye" },
    { 0x809B, "useby" },
    { 0x809C, "playsound" },
    { 0x809D, "_meth_809D" },
    { 0x809E, "_meth_809E" },
    { 0x809F, "_meth_809F" },
    { 0x80A0, "_meth_80A0" },
    { 0x80A1, "playerlinkedoffsetdisable" },
    { 0x80A2, "playerlinkedsetviewznear" },
    { 0x80A3, "playerlinkedsetusebaseangleforviewclamp" },
    { 0x80A4, "lerpviewangleclamp" },
    { 0x80A5, "setviewangleresistance" },
    { 0x80A6, "springcamenabled" },
    { 0x80A7, "springcamdisabled" },
    { 0x80A8, "linktoplayerview" },
    { 0x80A9, "unlinkfromplayerview" },
    { 0x80AA, "geteye" },
    { 0x80AB, "istouching" },
    { 0x80AC, "getistouchingentities" },
    { 0x80AD, "stoploopsound" },
    { 0x80AE, "stopsounds" },
    { 0x80AF, "playrumbleonentity" },
    { 0x80B0, "playrumblelooponentity" },
    { 0x80B1, "stoprumble" },
    { 0x80B2, "delete" },
    { 0x80B3, "setmodel" },
    { 0x80B4, "laseron" },
    { 0x80B5, "laseroff" },
    { 0x80B6, "laseraltviewon" },
    { 0x80B7, "laseraltviewoff" },
    { 0x80B8, "thermalvisionon" },
    { 0x80B9, "thermalvisionoff" },
    { 0x80BA, "thermalvisionfofoverlayon" },
    { 0x80BB, "thermalvisionfofoverlayoff" },
    { 0x80BC, "autospotoverlayon" },
    { 0x80BD, "autospotoverlayoff" },
    { 0x80BE, "seteyesonuplinkenabled" },
    { 0x80BF, "setdamagefeedback" },
    { 0x80C0, "setcontents" },
    { 0x80C1, "makeusable" },
    { 0x80C2, "makeunusable" },
    { 0x80C3, "makeglobalusable" },
    { 0x80C4, "makeglobalunusable" },
    { 0x80C5, "setwhizbyprobabilities" },
    { 0x80C6, "visionsetnakedforplayer_lerp" },
    { 0x80C7, "setwaitnode" },
    { 0x80C8, "returnplayercontrol" },
    { 0x80C9, "vehphys_starttrack" },
    { 0x80CA, "vehphys_clearautodisable" },
    { 0x80CB, "vehicleusealtblendedaudio" },
    { 0x80CC, "settext" },
    { 0x80CD, "clearalltextafterhudelem" },
    { 0x80CE, "setshader" },
    { 0x80CF, "settargetent" },
    { 0x80D0, "cleartargetent" },
    { 0x80D1, "settimer" },
    { 0x80D2, "settimerup" },
    { 0x80D3, "settimerstatic" },
    { 0x80D4, "settenthstimer" },
    { 0x80D5, "settenthstimerup" },
    { 0x80D6, "settenthstimerstatic" },
    { 0x80D7, "setclock" },
    { 0x80D8, "setclockup" },
    { 0x80D9, "setvalue" },
    { 0x80DA, "setwaypoint" },
    { 0x80DB, "setwaypointedgestyle_rotatingicon" },
    { 0x80DC, "setcursorhint" },
    { 0x80DD, "sethintstring" },
    { 0x80DE, "settertiaryhintstring" },
    { 0x80DF, "forceusehinton" },
    { 0x80E0, "forceusehintoff" },
    { 0x80E1, "makesoft" },
    { 0x80E2, "makehard" },
    { 0x80E3, "willneverchange" },
    { 0x80E4, "startfiring" },
    { 0x80E5, "stopfiring" },
    { 0x80E6, "isfiringturret" },
    { 0x80E7, "startbarrelspin" },
    { 0x80E8, "stopbarrelspin" },
    { 0x80E9, "getbarrelspinrate" },
    { 0x80EA, "remotecontrolturret" },
    { 0x80EB, "remotecontrolturretoff" },
    { 0x80EC, "shootturret" },
    { 0x80ED, "getturretowner" },
    { 0x80EE, "enabledeathshield" },
    { 0x80EF, "nightvisiongogglesforceon" },
    { 0x80F0, "nightvisiongogglesforceoff" },
    { 0x80F1, "enableinvulnerability" },
    { 0x80F2, "disableinvulnerability" },
    { 0x80F3, "enablebreaching" },
    { 0x80F4, "disablebreaching" },
    { 0x80F5, "forceviewmodelanimation" },
    { 0x80F6, "disableturretdismount" },
    { 0x80F7, "enableturretdismount" },
    { 0x80F8, "uploadscore" },
    { 0x80F9, "uploadtime" },
    { 0x80FA, "uploadleaderboards" },
    { 0x80FB, "giveachievement" },
    { 0x80FC, "hidehud" },
    { 0x80FD, "showhud" },
    { 0x80FE, "mountvehicle" },
    { 0x80FF, "dismountvehicle" },
    { 0x8100, "enableslowaim" },
    { 0x8101, "disableslowaim" },
    { 0x8102, "usehintsinvehicle" },
    { 0x8103, "vehicleattackbuttonpressed" },
    { 0x8104, "setwhizbyoffset" },
    { 0x8105, "setsentryowner" },
    { 0x8106, "setsentrycarrier" },
    { 0x8107, "setturretminimapvisible" },
    { 0x8108, "settargetentity" },
    { 0x8109, "snaptotargetentity" },
    { 0x810A, "cleartargetentity" },
    { 0x810B, "getturrettarget" },
    { 0x810C, "setplayerspread" },
    { 0x810D, "setaispread" },
    { 0x810E, "setsuppressiontime" },
    { 0x810F, "setflaggedanimknobrestart" },
    { 0x8110, "setflaggedanimknoblimitedrestart" },
    { 0x8111, "setflaggedanimknoball" },
    { 0x8112, "setflaggedanimknoballrestart" },
    { 0x8113, "setflaggedanim" },
    { 0x8114, "setflaggedanimlimited" },
    { 0x8115, "setflaggedanimrestart" },
    { 0x8116, "setflaggedanimlimitedrestart" },
    { 0x8117, "useanimtree" },
    { 0x8118, "stopuseanimtree" },
    { 0x8119, "setanimtime" },
    { 0x811A, "allowstand" },
    { 0x811B, "allowcrouch" },
    { 0x811C, "allowprone" },
    { 0x811D, "allowlean" },
    { 0x811E, "allowswim" },
    { 0x811F, "setocclusion" },
    { 0x8120, "_meth_8120" },
    { 0x8121, "deactivateocclusion" },
    { 0x8122, "deactivateallocclusion" },
    { 0x8123, "isocclusionenabled" },
    { 0x8124, "_meth_8124" },
    { 0x8125, "_meth_8125" },
    { 0x8126, "_meth_8126" },
    { 0x8127, "_meth_8127" },
    { 0x8128, "iseqenabled" },
    { 0x8129, "seteq" },
    { 0x812A, "seteqbands" },
    { 0x812B, "deactivateeq" },
    { 0x812C, "seteqlerp" },
    { 0x812D, "islookingat" },
    { 0x812E, "isthrowinggrenade" },
    { 0x812F, "isfiring" },
    { 0x8130, "ismeleeing" },
    { 0x8131, "setautopickup" },
    { 0x8132, "allowmelee" },
    { 0x8133, "allowfire" },
    { 0x8134, "enablehealthshield" },
    { 0x8135, "setconvergencetime" },
    { 0x8136, "setconvergenceheightpercent" },
    { 0x8137, "setturretteam" },
    { 0x8138, "maketurretsolid" },
    { 0x8139, "maketurretoperable" },
    { 0x813A, "maketurretinoperable" },
    { 0x813B, "makeentitysentient" },
    { 0x813C, "freeentitysentient" },
    { 0x813D, "isindoor" },
    { 0x813E, "getdroptofloorposition" },
    { 0x813F, "isbadguy" },
    { 0x8140, "animscripted" },
    { 0x8141, "animscriptedthirdperson" },
    { 0x8142, "animrelative" },
    { 0x8143, "stopanimscripted" },
    { 0x8144, "clearanim" },
    { 0x8145, "setanimknob" },
    { 0x8146, "setanimknoblimited" },
    { 0x8147, "setanimknobrestart" },
    { 0x8148, "setanimknoblimitedrestart" },
    { 0x8149, "setanimknoball" },
    { 0x814A, "setanimknoballlimited" },
    { 0x814B, "setanimknoballrestart" },
    { 0x814C, "setanimknoballlimitedrestart" },
    { 0x814D, "setanim" },
    { 0x814E, "setanimlimited" },
    { 0x814F, "setanimrestart" },
    { 0x8150, "setanimlimitedrestart" },
    { 0x8151, "getanimtime" },
    { 0x8152, "getanimweight" },
    { 0x8153, "getanimassettype" },
    { 0x8154, "setflaggedanimknob" },
    { 0x8155, "setflaggedanimknoblimited" },
    { 0x8156, "_meth_8156" },
    { 0x8157, "_meth_8157" },
    { 0x8158, "_meth_8158" },
    { 0x8159, "_meth_8159" },
    { 0x815A, "_meth_815A" },
    { 0x815B, "setautorotationdelay" },
    { 0x815C, "setdefaultdroppitch" },
    { 0x815D, "restoredefaultdroppitch" },
    { 0x815E, "turretfiredisable" },
    { 0x815F, "_meth_815F" },
    { 0x8160, "clearfixednodesafevolume" },
    { 0x8161, "isingoal" },
    { 0x8162, "setruntopos" },
    { 0x8163, "nearnode" },
    { 0x8164, "nearclaimnode" },
    { 0x8165, "nearclaimnodeandangle" },
    { 0x8166, "atdangerousnode" },
    { 0x8167, "getisforcedincombat" },
    { 0x8168, "setisforcedincombat" },
    { 0x8169, "getenemyinfo" },
    { 0x816A, "clearenemy" },
    { 0x816B, "setentitytarget" },
    { 0x816C, "clearentitytarget" },
    { 0x816D, "setpotentialthreat" },
    { 0x816E, "clearpotentialthreat" },
    { 0x816F, "setflashbanged" },
    { 0x8170, "setengagementmindist" },
    { 0x8171, "setengagementmaxdist" },
    { 0x8172, "isknownenemyinradius" },
    { 0x8173, "isknownenemyinvolume" },
    { 0x8174, "settalktospecies" },
    { 0x8175, "invisiblenotsolid" },
    { 0x8176, "visiblesolid" },
    { 0x8177, "setdefaultaimlimits" },
    { 0x8178, "initriotshieldhealth" },
    { 0x8179, "getenemysqdist" },
    { 0x817A, "getclosestenemysqdist" },
    { 0x817B, "setthreatbiasgroup" },
    { 0x817C, "getthreatbiasgroup" },
    { 0x817D, "turretfireenable" },
    { 0x817E, "setturretmodechangewait" },
    { 0x817F, "usetriggerrequirelookat" },
    { 0x8180, "getstance" },
    { 0x8181, "setstance" },
    { 0x8182, "itemweaponsetammo" },
    { 0x8183, "getammocount" },
    { 0x8184, "gettagorigin" },
    { 0x8185, "gettagangles" },
    { 0x8186, "shellshock" },
    { 0x8187, "stunplayer" },
    { 0x8188, "stopshellshock" },
    { 0x8189, "fadeoutshellshock" },
    { 0x818A, "setdepthoffield" },
    { 0x818B, "setviewmodeldepthoffield" },
    { 0x818C, "throwgrenade" },
    { 0x818D, "pickupgrenade" },
    { 0x818E, "useturret" },
    { 0x818F, "stopuseturret" },
    { 0x8190, "canuseturret" },
    { 0x8191, "traversemode" },
    { 0x8192, "animmode" },
    { 0x8193, "orientmode" },
    { 0x8194, "getmotionangle" },
    { 0x8195, "shouldfacemotion" },
    { 0x8196, "getanglestolikelyenemypath" },
    { 0x8197, "setturretanim" },
    { 0x8198, "getturret" },
    { 0x8199, "getgroundenttype" },
    { 0x819A, "forcestartnegotiation" },
    { 0x819B, "setalienjumpcostscale" },
    { 0x819C, "setalienruncostscale" },
    { 0x819D, "setalientraversecostscale" },
    { 0x819E, "animcustom" },
    { 0x819F, "isinscriptedstate" },
    { 0x81A0, "canattackenemynode" },
    { 0x81A1, "getnegotiationstartnode" },
    { 0x81A2, "getnegotiationendnode" },
    { 0x81A3, "getnegotiationnextnode" },
    { 0x81A4, "getdoorpathnode" },
    { 0x81A5, "comparenodedirtopathdir" },
    { 0x81A6, "checkprone" },
    { 0x81A7, "pushplayer" },
    { 0x81A8, "checkgrenadethrowpos" },
    { 0x81A9, "getgoalvolume" },
    { 0x81AA, "setgoalpos" },
    { 0x81AB, "setgoalentity" },
    { 0x81AC, "setgoalvolume" },
    { 0x81AD, "setgoalvolumeauto" },
    { 0x81AE, "getgoalvolume" },
    { 0x81AF, "cleargoalvolume" },
    { 0x81B0, "setfixednodesafevolume" },
    { 0x81B1, "_meth_81B1" },
    { 0x81B2, "_meth_81B2" },
    { 0x81B3, "viewkick" },
    { 0x81B4, "localtoworldcoords" },
    { 0x81B5, "getentitynumber" },
    { 0x81B6, "getentityvelocity" },
    { 0x81B7, "enablegrenadetouchdamage" },
    { 0x81B8, "disablegrenadetouchdamage" },
    { 0x81B9, "enableaimassist" },
    { 0x81BA, "disableaimassist" },
    { 0x81BB, "_meth_81BB" },
    { 0x81BC, "getmuzzlepos" },
    { 0x81BD, "getmuzzleangle" },
    { 0x81BE, "_meth_81BE" },
    { 0x81BF, "_meth_81BF" },
    { 0x81C0, "_meth_81C0" },
    { 0x81C1, "_meth_81C1" },
    { 0x81C2, "cansee" },
    { 0x81C3, "_meth_81C3" },
    { 0x81C4, "_meth_81C4" },
    { 0x81C5, "lastknownpos" },
    { 0x81C6, "_meth_81C6" },
    { 0x81C7, "_meth_81C7" },
    { 0x81C8, "_meth_81C8" },
    { 0x81C9, "teleport" },
    { 0x81CA, "_meth_81CA" },
    { 0x81CB, "_meth_81CB" },
    { 0x81CC, "_meth_81CC" },
    { 0x81CD, "_meth_81CD" },
    { 0x81CE, "_meth_81CE" },
    { 0x81CF, "_meth_81CF" },
    { 0x81D0, "_meth_81D0" },
    { 0x81D1, "_meth_81D1" },
    { 0x81D2, "_meth_81D2" },
    { 0x81D3, "checkgrenadethrowpos" },
    { 0x81D4, "_meth_81D4" },
    { 0x81D5, "_meth_81D5" },
    { 0x81D6, "_meth_81D6" },
    { 0x81D7, "_meth_81D7" },
    { 0x81D8, "entityradiusdamage" },
    { 0x81D9, "detonate" },
    { 0x81DA, "damageconetrace" },
    { 0x81DB, "_meth_81DB" },
    { 0x81DC, "_meth_81DC" },
    { 0x81DD, "_meth_81DD" },
    { 0x81DE, "_meth_81DE" },
    { 0x81DF, "missilesetflightmodedirect" },
    { 0x81E0, "missilesetflightmodetop" },
    { 0x81E1, "getlightintensity" },
    { 0x81E2, "setlightintensity" },
    { 0x81E3, "isragdoll" },
    { 0x81E4, "setmovespeedscale" },
    { 0x81E5, "cameralinkto" },
    { 0x81E6, "cameraunlink" },
    { 0x81E7, "_meth_81E7" },
    { 0x81E8, "_meth_81E8" },
    { 0x81E9, "_meth_81E9" },
    { 0x81EA, "_meth_81EA" },
    { 0x81EB, "_meth_81EB" },
    { 0x81EC, "_meth_81EC" },
    { 0x81ED, "updateplayersightaccuracy" },
    { 0x81EE, "_meth_81EE" },
    { 0x81EF, "_meth_81EF" },
    { 0x81F0, "_meth_81F0" },
    { 0x81F1, "_meth_81F1" },
    { 0x81F2, "_meth_81F2" },
    { 0x81F3, "_meth_81F3" },
    { 0x81F4, "_meth_81F4" },
    { 0x81F5, "_meth_81F5" },
    { 0x81F6, "_meth_81F6" },
    { 0x81F7, "_meth_81F7" },
    { 0x81F8, "_meth_81F8" },
    { 0x81F9, "_meth_81F9" },
    { 0x81FA, "_meth_81FA" },
    { 0x81FB, "_meth_81FB" },
    { 0x81FC, "_meth_81FC" },
    { 0x81FD, "_meth_81FD" },
    { 0x81FE, "updateprone" },
    { 0x81FF, "_meth_81FF" },
    { 0x8200, "_meth_8200" },
    { 0x8201, "_meth_8201" },
    { 0x8202, "_meth_8202" },
    { 0x8203, "_meth_8203" },
    { 0x8204, "controlslinkto" },
    { 0x8205, "controlsunlink" },
    { 0x8206, "_meth_8206" },
    { 0x8207, "_meth_8207" },
    { 0x8208, "_meth_8208" },
    { 0x8209, "_meth_8209" },
    { 0x820A, "_meth_820A" },
    { 0x820B, "_meth_820B" },
    { 0x820C, "_meth_820C" },
    { 0x820D, "_meth_820D" },
    { 0x820E, "_meth_820E" },
    { 0x820F, "drivevehicleandcontrolturret" },
    { 0x8210, "drivevehicleandcontrolturretoff" },
    { 0x8211, "_meth_8211" },
    { 0x8212, "_meth_8212" },
    { 0x8213, "_meth_8213" },
    { 0x8214, "_meth_8214" },
    { 0x8215, "_meth_8215" },
    { 0x8216, "_meth_8216" },
    { 0x8217, "_meth_8217" },
    { 0x8218, "circle" },
    { 0x8219, "rect" },
    { 0x821A, "getpointinbounds" },
    { 0x821B, "transfermarkstonewscriptmodel" },
    { 0x821C, "setwatersheeting" },
    { 0x821D, "_meth_821D" },
    { 0x821E, "_meth_821E" },
    { 0x821F, "setweaponhudiconoverride" },
    { 0x8220, "getweaponhudiconoverride" },
    { 0x8221, "_meth_8221" },
    { 0x8222, "_meth_8222" },
    { 0x8223, "_meth_8223" },
    { 0x8224, "_meth_8224" },
    { 0x8225, "isitemunlocked" },
    { 0x8226, "getrankedplayerdata" },
    { 0x8227, "vehicleturretcontroloff" },
    { 0x8228, "isturretready" },
    { 0x8229, "_meth_8229" },
    { 0x822A, "vehicle_dospawn" },
    { 0x822B, "vehicle_isphysveh" },
    { 0x822C, "vehphys_crash" },
    { 0x822D, "vehphys_launch" },
    { 0x822E, "vehphys_disablecrashing" },
    { 0x822F, "vehphys_enablecrashing" },
    { 0x8230, "vehphys_setspeed" },
    { 0x8231, "vehphys_setconveyorbelt" },
    { 0x8232, "freevehicle" },
    { 0x8233, "_meth_8233" },
    { 0x8234, "_meth_8234" },
    { 0x8235, "_meth_8235" },
    { 0x8236, "_meth_8236" },
    { 0x8237, "_meth_8237" },
    { 0x8238, "_meth_8238" },
    { 0x8239, "_meth_8239" },
    { 0x823A, "_meth_823A" },
    { 0x823B, "_meth_823B" },
    { 0x823C, "_meth_823C" },
    { 0x823D, "_meth_823D" },
    { 0x823E, "_meth_823E" },
    { 0x823F, "_meth_823F" },
    { 0x8240, "_meth_8240" },
    { 0x8241, "_meth_8241" },
    { 0x8242, "_meth_8242" },
    { 0x8243, "setcommonplayerdata" },
    { 0x8244, "_meth_8244" },
    { 0x8245, "_meth_8245" },
    { 0x8246, "trackerupdate" },
    { 0x8247, "pingplayer" },
    { 0x8248, "buttonpressed" },
    { 0x8249, "sayteam" },
    { 0x824A, "sayall" },
    { 0x824B, "setspawnweapon" },
    { 0x824C, "dropitem" },
    { 0x824D, "dropscavengerbag" },
    { 0x824E, "setjitterparams" },
    { 0x824F, "sethoverparams" },
    { 0x8250, "joltbody" },
    { 0x8251, "_meth_8251" },
    { 0x8252, "_meth_8252" },
    { 0x8253, "getvehicleowner" },
    { 0x8254, "setvehiclelookattext" },
    { 0x8255, "setvehicleteam" },
    { 0x8256, "neargoalnotifydist" },
    { 0x8257, "setgoalpos" },
    { 0x8258, "setgoalyaw" },
    { 0x8259, "cleargoalyaw" },
    { 0x825A, "settargetyaw" },
    { 0x825B, "cleartargetyaw" },
    { 0x825C, "helisetgoal" },
    { 0x825D, "_meth_825D" },
    { 0x825E, "setturrettargetent" },
    { 0x825F, "clearturrettargetent" },
    { 0x8260, "canturrettargetpoint" },
    { 0x8261, "setlookatent" },
    { 0x8262, "clearlookatent" },
    { 0x8263, "setvehweapon" },
    { 0x8264, "fireweapon" },
    { 0x8265, "vehicleturretcontrolon" },
    { 0x8266, "finishplayerdamage" },
    { 0x8267, "suicide" },
    { 0x8268, "_meth_8268" },
    { 0x8269, "clientiprintln" },
    { 0x826A, "clientiprintlnbold" },
    { 0x826B, "spawnspectator" },
    { 0x826C, "_meth_826C" },
    { 0x826D, "cloneplayer" },
    { 0x826E, "istalking" },
    { 0x826F, "allowspectateteam" },
    { 0x8270, "_meth_8270" },
    { 0x8271, "getguid" },
    { 0x8272, "_meth_8272" },
    { 0x8273, "_meth_8273" },
    { 0x8274, "clonebrushmodeltoscriptmodel" },
    { 0x8275, "scriptmodelplayanim" },
    { 0x8276, "scriptmodelclearanim" },
    { 0x8277, "_meth_8277" },
    { 0x8278, "_meth_8278" },
    { 0x8279, "attachpath" },
    { 0x827A, "getattachpos" },
    { 0x827B, "startpath" },
    { 0x827C, "setswitchnode" },
    { 0x827D, "setwaitspeed" },
    { 0x827E, "finishdamage" },
    { 0x827F, "vehicle_setspeed" },
    { 0x8280, "vehicle_setspeedimmediate" },
    { 0x8281, "vehicle_rotateyaw" },
    { 0x8282, "vehicle_getspeed" },
    { 0x8283, "vehicle_getvelocity" },
    { 0x8284, "vehicle_getbodyvelocity" },
    { 0x8285, "vehicle_getsteering" },
    { 0x8286, "vehicle_getthrottle" },
    { 0x8287, "vehicle_turnengineoff" },
    { 0x8288, "vehicle_turnengineon" },
    { 0x8289, "vehicle_orientto" },
    { 0x828A, "getgoalspeedmph" },
    { 0x828B, "setacceleration" },
    { 0x828C, "setdeceleration" },
    { 0x828D, "resumespeed" },
    { 0x828E, "setyawspeed" },
    { 0x828F, "setyawspeedbyname" },
    { 0x8290, "setmaxpitchroll" },
    { 0x8291, "setairresitance" },
    { 0x8292, "setturningability" },
    { 0x8293, "getxuid" },
    { 0x8294, "getucdidhigh" },
    { 0x8295, "ismlgspectator" },
    { 0x8296, "getclanidhigh" },
    { 0x8297, "getclanidlow" },
    { 0x8298, "ishost" },
    { 0x8299, "getspectatingplayer" },
    { 0x829A, "predictstreampos" },
    { 0x829B, "updatescores" },
    { 0x829C, "updatedmscores" },
    { 0x829D, "setrank" },
    { 0x829E, "_meth_829E" },
    { 0x829F, "setmlgspectator" },
    { 0x82A0, "visionsyncwithplayer" },
    { 0x82A1, "showhudsplash" },
    { 0x82A2, "setperk" },
    { 0x82A3, "hasperk" },
    { 0x82A4, "clearperks" },
    { 0x82A5, "unsetperk" },
    { 0x82A6, "registerparty" },
    { 0x82A7, "getfireteammembers" },
    { 0x82A8, "noclip" },
    { 0x82A9, "ufo" },
    { 0x82AA, "moveto" },
    { 0x82AB, "movex" },
    { 0x82AC, "movey" },
    { 0x82AD, "movez" },
    { 0x82AE, "movegravity" },
    { 0x82AF, "moveslide" },
    { 0x82B0, "stopmoveslide" },
    { 0x82B1, "rotateto" },
    { 0x82B2, "rotatepitch" },
    { 0x82B3, "rotateyaw" },
    { 0x82B4, "rotateroll" },
    { 0x82B5, "addpitch" },
    { 0x82B6, "addyaw" },
    { 0x82B7, "addroll" },
    { 0x82B8, "vibrate" },
    { 0x82B9, "rotatevelocity" },
    { 0x82BA, "solid" },
    { 0x82BB, "notsolid" },
    { 0x82BC, "setcandamage" },
    { 0x82BD, "setcanradiusdamage" },
    { 0x82BE, "physicslaunch" },
    { 0x82BF, "setcardicon" },
    { 0x82C0, "setcardnameplate" },
    { 0x82C1, "setcarddisplayslot" },
    { 0x82C2, "regweaponforfxremoval" },
    { 0x82C3, "laststandrevive" },
    { 0x82C4, "startlaststand" },
    { 0x82C5, "setspectatedefaults" },
    { 0x82C6, "getthirdpersoncrosshairoffset" },
    { 0x82C7, "disableweaponpickup" },
    { 0x82C8, "enableweaponpickup" },
    { 0x82C9, "issplitscreenplayer" },
    { 0x82CA, "issplitscreenplayerprimary" },
    { 0x82CB, "getweaponslistoffhands" },
    { 0x82CC, "getweaponslistitems" },
    { 0x82CD, "getweaponslistexclusives" },
    { 0x82CE, "getweaponslist" },
    { 0x82CF, "canplayerplacesentry" },
    { 0x82D0, "canplayerplacetank" },
    { 0x82D1, "visionsetnakedforplayer" },
    { 0x82D2, "visionsetnightforplayer" },
    { 0x82D3, "visionsetmissilecamforplayer" },
    { 0x82D4, "visionsetthermalforplayer" },
    { 0x82D5, "visionsetpainforplayer" },
    { 0x82D6, "setblurforplayer" },
    { 0x82D7, "getplayerweaponmodel" },
    { 0x82D8, "getplayerknifemodel" },
    { 0x82D9, "updateplayermodelwithweapons" },
    { 0x82DA, "notifyonplayercommand" },
    { 0x82DB, "canmantle" },
    { 0x82DC, "forcemantle" },
    { 0x82DD, "ismantling" },
    { 0x82DE, "playfx" },
    { 0x82DF, "player_recoilscaleon" },
    { 0x82E0, "player_recoilscaleoff" },
    { 0x82E1, "weaponlockstart" },
    { 0x82E2, "weaponlockfinalize" },
    { 0x82E3, "weaponlockfree" },
    { 0x82E4, "setentertime" },
    { 0x82E5, "usinggamepad" },
    { 0x82E6, "_meth_82E6" },
    { 0x82E7, "issighted" },
    { 0x82E8, "_meth_82E8" },
    { 0x82E9, "_meth_82E9" },
    { 0x82EA, "_meth_82EA" },
    { 0x82EB, "fragbuttonpressed" },
    { 0x82EC, "secondaryoffhandbuttonpressed" },
    { 0x82ED, "_meth_82ED" },
    { 0x82EE, "setvelocity" },
    { 0x82EF, "_meth_82EF" },
    { 0x82F0, "getnormalizedmovement" },
    { 0x82F1, "playlocalsound" },
    { 0x82F2, "stoplocalsound" },
    { 0x82F3, "setweaponammoclip" },
    { 0x82F4, "setweaponammostock" },
    { 0x82F5, "getweaponammoclip" },
    { 0x82F6, "getweaponammostock" },
    { 0x82F7, "anyammoforweaponmodes" },
    { 0x82F8, "setclientomnvar" },
    { 0x82F9, "setclientdvar" },
    { 0x82FA, "setclientdvars" },
    { 0x82FB, "setclientspawnsighttraces" },
    { 0x82FC, "clientspawnsighttracepassed" },
    { 0x82FD, "allowads" },
    { 0x82FE, "allowjump" },
    { 0x82FF, "allowladder" },
    { 0x8300, "allowmantle" },
    { 0x8301, "allowsprint" },
    { 0x8302, "setspreadoverride" },
    { 0x8303, "resetspreadoverride" },
    { 0x8304, "setaimspreadmovementscale" },
    { 0x8305, "setactionslot" },
    { 0x8306, "setviewkickscale" },
    { 0x8307, "getviewkickscale" },
    { 0x8308, "getweaponslistall" },
    { 0x8309, "getweaponslistprimaries" },
    { 0x830A, "getnormalizedcameramovement" },
    { 0x830B, "giveweapon" },
    { 0x830C, "takeweapon" },
    { 0x830D, "takeallweapons" },
    { 0x830E, "getcurrentweapon" },
    { 0x830F, "getcurrentprimaryweapon" },
    { 0x8310, "getcurrentoffhand" },
    { 0x8311, "hasweapon" },
    { 0x8312, "switchtoweapon" },
    { 0x8313, "switchtoweaponimmediate" },
    { 0x8314, "gethybridscopestate" },
    { 0x8315, "switchtooffhand" },
    { 0x8316, "setoffhandsecondaryclass" },
    { 0x8317, "getoffhandsecondaryclass" },
    { 0x8318, "beginlocationselection" },
    { 0x8319, "endlocationselection" },
    { 0x831A, "disableweapons" },
    { 0x831B, "enableweapons" },
    { 0x831C, "disableoffhandweapons" },
    { 0x831D, "enableoffhandweapons" },
    { 0x831E, "disableweaponswitch" },
    { 0x831F, "enableweaponswitch" },
    { 0x8320, "openpopupmenu" },
    { 0x8321, "openpopupmenunomouse" },
    { 0x8322, "closepopupmenu" },
    { 0x8323, "openmenu" },
    { 0x8324, "closemenu" },
    { 0x8325, "_meth_8325" },
    { 0x8326, "freezecontrols" },
    { 0x8327, "disableusability" },
    { 0x8328, "enableusability" },
    { 0x8329, "setwhizbyspreads" },
    { 0x832A, "setwhizbyradii" },
    { 0x832B, "setreverb" },
    { 0x832C, "deactivatereverb" },
    { 0x832D, "setvolmod" },
    { 0x832E, "givestartammo" },
    { 0x832F, "givemaxammo" },
    { 0x8330, "getfractionstartammo" },
    { 0x8331, "getfractionmaxammo" },
    { 0x8332, "isdualwielding" },
    { 0x8333, "isreloading" },
    { 0x8334, "isswitchingweapon" },
    { 0x8335, "setorigin" },
    { 0x8336, "getvelocity" },
    { 0x8337, "setplayerangles" },
    { 0x8338, "getplayerangles" },
    { 0x8339, "usebuttonpressed" },
    { 0x833A, "attackbuttonpressed" },
    { 0x833B, "adsbuttonpressed" },
    { 0x833C, "meleebuttonpressed" },
    { 0x833D, "playerads" },
    { 0x833E, "isonground" },
    { 0x833F, "isusingturret" },
    { 0x8340, "setviewmodel" },
    { 0x8341, "setoffhandprimaryclass" },
    { 0x8342, "getoffhandprimaryclass" },
    { 0x8343, "enablefocus" },
    { 0x8344, "disablefocus" },
    { 0x8345, "enableaudiozoom" },
    { 0x8346, "disableaudiozoom" },
    { 0x8347, "_meth_8347" },
    { 0x8348, "forcethirdpersonwhenfollowing" },
    { 0x8349, "disableforcethirdpersonwhenfollowing" },
    { 0x834A, "_meth_834A" },
    { 0x834B, "setscriptmoverkillcam" },
    { 0x834C, "_meth_834C" },
    { 0x834D, "_meth_834D" },
    { 0x834E, "_meth_834E" },
    { 0x834F, "botsetflag" },
    { 0x8350, "botsetstance" },
    { 0x8351, "botsetscriptmove" },
    { 0x8352, "_meth_8352" },
    { 0x8353, "botsetscriptgoal" },
    { 0x8354, "botclearscriptgoal" },
    { 0x8355, "getnearestnode" },
    { 0x8356, "botclearscriptenemy" },
    { 0x8357, "botsetattacker" },
    { 0x8358, "botgetscriptgoal" },
    { 0x8359, "botgetscriptgoalradius" },
    { 0x835A, "botgetscriptgoalyaw" },
    { 0x835B, "botgetscriptgoaltype" },
    { 0x835C, "_meth_835C" },
    { 0x835D, "_meth_835D" },
    { 0x835E, "_meth_835E" },
    { 0x835F, "botfindnoderandom" },
    { 0x8360, "botmemoryevent" },
    { 0x8361, "_meth_8361" },
    { 0x8362, "botnodepick" },
    { 0x8363, "bothasscriptgoal" },
    { 0x8364, "botgetpersonality" },
    { 0x8365, "_meth_8365" },
    { 0x8366, "_meth_8366" },
    { 0x8367, "botsetpersonality" },
    { 0x8368, "botsetdifficulty" },
    { 0x8369, "botgetdifficulty" },
    { 0x836A, "botgetworldclosestedge" },
    { 0x836B, "_meth_836B" },
    { 0x836C, "botpredictseepoint" },
    { 0x836D, "botcanseeentity" },
    { 0x836E, "botgetnodesonpath" },
    { 0x836F, "_meth_836F" },
    { 0x8370, "_meth_8370" },
    { 0x8371, "_meth_8371" },
    { 0x8372, "botsetawareness" },
    { 0x8373, "_meth_8373" },
    { 0x8374, "botgetscriptgoalnode" },
    { 0x8375, "botgetimperfectenemyinfo" },
    { 0x8376, "_meth_8376" },
    { 0x8377, "botsetpathingstyle" },
    { 0x8378, "botsetdifficultysetting" },
    { 0x8379, "botgetdifficultysetting" },
    { 0x837A, "botgetpathdist" },
    { 0x837B, "_meth_837B" },
    { 0x837C, "_meth_837C" },
    { 0x837D, "botclearbutton" },
    { 0x837E, "_meth_837E" },
    { 0x837F, "getnodenumber" },
    { 0x8380, "setclientowner" },
    { 0x8381, "setotherent" },
    { 0x8382, "setaisightlinevisible" },
    { 0x8383, "setentityowner" },
    { 0x8384, "nodeisdisconnected" },
    { 0x8385, "_meth_8385" },
    { 0x8386, "_meth_8386" },
    { 0x8387, "_meth_8387" },
    { 0x8388, "_meth_8388" },
    { 0x8389, "_meth_8389" },
    { 0x838A, "setagentattacker" },
    { 0x838B, "_meth_838B" },
    { 0x838C, "agentcanseesentient" },
    { 0x838D, "_meth_838D" },
    { 0x838E, "_meth_838E" },
    { 0x838F, "getgoalpos" },
    { 0x8390, "setgoalnode" },
    { 0x8391, "setgoalentity" },
    { 0x8392, "setgoalradius" },
    { 0x8393, "scragentsetanimscale" },
    { 0x8394, "setorientmode" },
    { 0x8395, "setanimmode" },
    { 0x8396, "setphysicsmode" },
    { 0x8397, "setclipmode" },
    { 0x8398, "setmaxturnspeed" },
    { 0x8399, "getmaxturnspeed" },
    { 0x839A, "beginmelee" },
    { 0x839B, "getmlgspectatorteam" },
    { 0x839C, "dotrajectory" },
    { 0x839D, "doanimlerp" },
    { 0x839E, "setviewheight" },
    { 0x839F, "claimnode" },
    { 0x83A0, "relinquishclaimednode" },
    { 0x83A1, "_meth_83A1" },
    { 0x83A2, "_meth_83A2" },
    { 0x83A3, "_meth_83A3" },
    { 0x83A4, "_meth_83A4" },
    { 0x83A5, "_meth_83A5" },
    { 0x83A6, "_meth_83A6" },
    { 0x83A7, "_meth_83A7" },
    { 0x83A8, "_meth_83A8" },
    { 0x83A9, "_meth_83A9" },
    { 0x83AA, "_meth_83AA" },
    { 0x83AB, "_meth_83AB" },
    { 0x83AC, "_meth_83AC" },
    { 0x83AD, "_meth_83AD" },
    { 0x83AE, "_meth_83AE" },
    { 0x83AF, "_meth_83AF" },
    { 0x83B0, "_meth_83B0" },
    { 0x83B1, "_meth_83B1" },
    { 0x83B2, "_meth_83B2" },
    { 0x83B3, "_meth_83B3" },
    { 0x83B4, "_meth_83B4" },
    { 0x83B5, "_meth_83B5" },
    { 0x83B6, "_meth_83B6" },
    { 0x83B7, "_meth_83B7" },
    { 0x83B8, "_meth_83B8" },
    { 0x83B9, "_meth_83B9" },
    { 0x83BA, "_meth_83BA" },
    { 0x83BB, "_meth_83BB" },
    { 0x83BC, "_meth_83BC" },
    { 0x83BD, "_meth_83BD" },
    { 0x83BE, "_meth_83BE" },
    { 0x83BF, "_meth_83BF" },
    { 0x83C0, "_meth_83C0" },
    { 0x83C1, "_meth_83C1" },
    { 0x83C2, "_meth_83C2" },
    { 0x83C3, "_meth_83C3" },
    { 0x83C4, "_meth_83C4" },
    { 0x83C5, "_meth_83C5" },
    { 0x83C6, "_meth_83C6" },
    { 0x83C7, "_meth_83C7" },
    { 0x83C8, "_meth_83C8" },
    { 0x83C9, "_meth_83C9" },
    { 0x83CA, "_meth_83CA" },
    { 0x83CB, "_meth_83CB" },
    { 0x83CC, "_meth_83CC" },
    { 0x83CD, "_meth_83CD" },
    { 0x83CE, "setanimclass" },
    { 0x83CF, "enableanimstate" },
    { 0x83D0, "setanimstate" },
    { 0x83D1, "getanimentry" },
    { 0x83D2, "getanimentryname" },
    { 0x83D3, "getanimentryalias" },
    { 0x83D4, "getanimentrycount" },
    { 0x83D5, "_meth_83D5" },
    { 0x83D6, "issprinting" },
    { 0x83D7, "_meth_83D7" },
    { 0x83D8, "shootstopsound" },
    { 0x83D9, "setclothtype" },
    { 0x83DA, "_meth_83DA" },
    { 0x83DB, "_meth_83DB" },
    { 0x83DC, "_meth_83DC" },
    { 0x83DD, "_meth_83DD" },
    { 0x83DE, "getlookaheaddir" },
    { 0x83DF, "getpathgoalpos" },
    { 0x83E0, "setrocketcorpse" },
    { 0x83E1, "setcorpsefalling" },
    { 0x83E2, "setsurfacetype" },
    { 0x83E3, "aiphysicstrace" },
    { 0x83E4, "_meth_83E4" },
    { 0x83E5, "_meth_83E5" },
    { 0x83E6, "_meth_83E6" },
    { 0x83E7, "_meth_83E7" },
    { 0x83E8, "visionsetstage" },
    { 0x83E9, "hudoutlineenableforclients" },
    { 0x83EA, "getlinkedparent" },
    { 0x83EB, "getmovingplatformparent" },
    { 0x83EC, "setnameplatematerial" },
    { 0x83ED, "_meth_83ED" },
    { 0x83EE, "_meth_83EE" },
    { 0x83EF, "_meth_83EF" },
    { 0x83F0, "_meth_83F0" },
    { 0x83F1, "makevehiclenotcollidewithplayers" },
    { 0x83F2, "_meth_83F2" },
    { 0x83F3, "_meth_83F3" },
    { 0x83F4, "setscriptablepartstate" },
    { 0x83F5, "_meth_83F5" },
    { 0x83F6, "_meth_83F6" },
    { 0x83F7, "_meth_83F7" },
    { 0x83F8, "_meth_83F8" },
    { 0x83F9, "_meth_83F9" },
    { 0x83FA, "motionblurhqdisable" },
    { 0x83FB, "_meth_83FB" },
    { 0x83FC, "_meth_83FC" },
    { 0x83FD, "_meth_83FD" },
    { 0x83FE, "worldpointtoscreenpos" },
    { 0x83FF, "_meth_83FF" },
    { 0x8400, "_meth_8400" },
    { 0x8401, "_meth_8401" },
    { 0x8402, "_meth_8402" },
    { 0x8403, "_meth_8403" },
    { 0x8404, "_meth_8404" },
    { 0x8405, "_meth_8405" },
    { 0x8406, "_meth_8406" },
    { 0x8407, "emissiveblend" },
    { 0x8408, "_meth_8408" },
    { 0x8409, "_meth_8409" },
    { 0x840A, "_meth_840A" },
    { 0x840B, "_meth_840B" },
    { 0x840C, "_meth_840C" },
    { 0x840D, "_meth_840D" },
    { 0x840E, "_meth_840E" },
    { 0x840F, "physicsgetlinspeed" },
    { 0x8410, "_meth_8410" },
    { 0x8411, "physicsgetangvel" },
    { 0x8412, "physicsgetangspeed" },
    { 0x8413, "disablemissileboosting" },
    { 0x8414, "enablemissileboosting" },
    { 0x8415, "canspawntestclient" },
    { 0x8416, "spawntestclient" },
    { 0x8417, "setgrenadethrowscale" },
    { 0x8418, "_meth_8418" },
    { 0x8419, "_meth_8419" },
    { 0x841A, "_meth_841A" },
    { 0x841B, "_meth_841B" },
    { 0x841C, "_meth_841C" },
    { 0x841D, "_meth_841D" },
    { 0x841E, "turretsetbarrelspinenabled" },
    { 0x841F, "_meth_841F" },
    { 0x8420, "_meth_8420" },
    { 0x8421, "_meth_8421" },
    { 0x8422, "_meth_8422" },
    { 0x8423, "doanimrelative" },
    { 0x8424, "_meth_8424" },
    { 0x8425, "_meth_8425" },
    { 0x8426, "_meth_8426" },
    { 0x8427, "getcorpseentity" },
    { 0x8428, "_meth_8428" },
    { 0x8429, "_meth_8429" },
    { 0x842A, "_meth_842A" },
    { 0x842B, "queuedialogforplayer" },
    { 0x842C, "setmlgcameradefaults" },
    { 0x842D, "_meth_842D" },
    { 0x842E, "_meth_842E" },
    { 0x842F, "_meth_842F" },
    { 0x8430, "_meth_8430" },
    { 0x8431, "getlinkedchildren" },
    { 0x8432, "_meth_8432" },
    { 0x8433, "playsoundonmovingent" },
    { 0x8434, "cancelmantle" },
    { 0x8435, "hasfemalecustomizationmodel" },
    { 0x8436, "_meth_8436" },
    { 0x8437, "setscriptabledamageowner" },
    { 0x8438, "_meth_8438" },
    { 0x8439, "_meth_8439" },
    { 0x843A, "_meth_843A" },
    { 0x843B, "_meth_843B" },
    { 0x843C, "_meth_843C" },
    { 0x843D, "_meth_843D" },
    { 0x843E, "_meth_843E" },
    { 0x843F, "_meth_843F" },
    { 0x8440, "_meth_8440" },
    { 0x8441, "_meth_8441" },
    { 0x8442, "_meth_8442" },
    { 0x8443, "_meth_8443" },
    { 0x8444, "_meth_8444" },
    { 0x8445, "_meth_8445" },
    { 0x8446, "getcacplayerdata" },
    { 0x8447, "_meth_8447" },
    { 0x8448, "_meth_8448" },
    { 0x8449, "_meth_8449" },
    { 0x844A, "_meth_844A" },
    { 0x844B, "_meth_844B" },
    { 0x844C, "_meth_844C" },
    { 0x844D, "_meth_844D" },
    { 0x844E, "_meth_844E" },
    { 0x844F, "_meth_844F" },
    { 0x8450, "_meth_8450" },
    { 0x8451, "_meth_8451" },
    { 0x8452, "_meth_8452" },
    { 0x8453, "_meth_8453" },
    { 0x8454, "_meth_8454" },
    { 0x8455, "_meth_8455" },
    { 0x8456, "_meth_8456" },
    { 0x8457, "_meth_8457" },
    { 0x8458, "getvieworigin" },
    { 0x8459, "_meth_8459" },
    { 0x845A, "_meth_845A" },
    { 0x845B, "stopridingvehicle" },
    { 0x845C, "_meth_845C" },
    { 0x845D, "_meth_845D" },
    { 0x845E, "disablemissilestick" },
    { 0x845F, "enablemissilestick" },
    { 0x8460, "setmissileminimapvisible" },
    { 0x8461, "isoffhandweaponreadytothrow" },
    { 0x8462, "isleaning" },
    { 0x8463, "makecollidewithitemclip" },
    { 0x8464, "_meth_8464" },
    { 0x8465, "visionsetpostapplyforplayer" },
    { 0x8466, "_meth_8466" },
    { 0x8467, "_meth_8467" },
    { 0x8468, "_meth_8468" },
    { 0x8469, "_meth_8469" },
    { 0x846A, "_meth_846A" },
    { 0x846B, "_meth_846B" },
    { 0x846C, "_meth_846C" },
    { 0x846D, "_meth_846D" },
    { 0x846E, "_meth_846E" },
    { 0x846F, "_meth_846F" },
    { 0x8470, "_meth_8470" },
    { 0x8471, "_meth_8471" },
    { 0x8472, "_meth_8472" },
    { 0x8473, "_meth_8473" },
    { 0x8474, "_meth_8474" },
    { 0x8475, "_meth_8475" },
    { 0x8476, "_meth_8476" },
    { 0x8477, "_meth_8477" },
    { 0x8478, "_meth_8478" },
    { 0x8479, "_meth_8479" },
    { 0x847A, "_meth_847A" },
    { 0x847B, "_meth_847B" },
    { 0x847C, "_meth_847C" },
    { 0x847D, "_meth_847D" },
    { 0x847E, "_meth_847E" },
    { 0x847F, "_meth_847F" },
    { 0x8480, "_meth_8480" },
    { 0x8481, "_meth_8481" },
    { 0x8482, "_meth_8482" },
    { 0x8483, "_meth_8483" },
    { 0x8484, "_meth_8484" },
    { 0x8485, "_meth_8485" },
    { 0x8486, "_meth_8486" },
    { 0x8487, "_meth_8487" },
    { 0x8488, "_meth_8488" },
    { 0x8489, "_meth_8489" },
    { 0x848A, "_meth_848A" },
    { 0x848B, "_meth_848B" },
    { 0x848C, "_meth_848C" },
    { 0x848D, "_meth_848D" },
    { 0x848E, "_meth_848E" },
    { 0x848F, "_meth_848F" },
    { 0x8490, "_meth_8490" },
    { 0x8491, "_meth_8491" },
    { 0x8492, "_meth_8492" },
    { 0x8493, "_meth_8493" },
    { 0x8494, "_meth_8494" },
    { 0x8495, "_meth_8495" },
    { 0x8496, "_meth_8496" },
    { 0x8497, "_meth_8497" },
    { 0x8498, "_meth_8498" },
    { 0x8499, "_meth_8499" },
    { 0x849A, "_meth_849A" },
    { 0x849B, "_meth_849B" },
    { 0x849C, "_meth_849C" },
    { 0x849D, "_meth_849D" },
    { 0x849E, "_meth_849E" },
    { 0x849F, "_meth_849F" },
    { 0x84A0, "_meth_84A0" },
    { 0x84A1, "_meth_84A1" },
    { 0x84A2, "_meth_84A2" },
    { 0x84A3, "_meth_84A3" },
    { 0x84A4, "_meth_84A4" },
    { 0x84A5, "_meth_84A5" },
    { 0x84A6, "_meth_84A6" },
    { 0x84A7, "_meth_84A7" },
    { 0x84A8, "_meth_84A8" },
    { 0x84A9, "_meth_84A9" },
    { 0x84AA, "_meth_84AA" },
    { 0x84AB, "_meth_84AB" },
    { 0x84AC, "_meth_84AC" },
    { 0x84AD, "_meth_84AD" },
    { 0x84AE, "_meth_84AE" },
    { 0x84AF, "_meth_84AF" },
    { 0x84B0, "_meth_84B0" },
    { 0x84B1, "_meth_84B1" },
    { 0x84B2, "_meth_84B2" },
    { 0x84B3, "_meth_84B3" },
    { 0x84B4, "_meth_84B4" },
    { 0x84B5, "_meth_84B5" },
    { 0x84B6, "_meth_84B6" },
    { 0x84B7, "_meth_84B7" },
    { 0x84B8, "_meth_84B8" },
    { 0x84B9, "_meth_84B9" },
    { 0x84BA, "_meth_84BA" },
    { 0x84BB, "_meth_84BB" },
    { 0x84BC, "_meth_84BC" },
    { 0x84BD, "_meth_84BD" },
    { 0x84BE, "_meth_84BE" },
    { 0x84BF, "_meth_84BF" },
    { 0x84C0, "_meth_84C0" },
    { 0x84C1, "_meth_84C1" },
    { 0x84C2, "_meth_84C2" },
    { 0x84C3, "_meth_84C3" },
    { 0x84C4, "_meth_84C4" },
    { 0x84C5, "_meth_84C5" },
    { 0x84C6, "_meth_84C6" },
    { 0x84C7, "_meth_84C7" },
    { 0x84C8, "_meth_84C8" },
    { 0x84C9, "_meth_84C9" },
    { 0x84CA, "_meth_84CA" },
    { 0x84CB, "_meth_84CB" },
    { 0x84CC, "_meth_84CC" },
    { 0x84CD, "_meth_84CD" },
    { 0x84CE, "_meth_84CE" },
    { 0x84CF, "_meth_84CF" },
    { 0x84D0, "_meth_84D0" },
    { 0x84D1, "_meth_84D1" },
    { 0x84D2, "_meth_84D2" },
    { 0x84D3, "_meth_84D3" },
    { 0x84D4, "_meth_84D4" },
    { 0x84D5, "_meth_84D5" },
    { 0x84D6, "_meth_84D6" },
    { 0x84D7, "_meth_84D7" },
    { 0x84D8, "_meth_84D8" },
    { 0x84D9, "_meth_84D9" },
    { 0x84DA, "_meth_84DA" },
    { 0x84DB, "_meth_84DB" },
    { 0x84DC, "_meth_84DC" },
    { 0x84DD, "_meth_84DD" },
    { 0x84DE, "_meth_84DE" },
    { 0x84DF, "_meth_84DF" },
    { 0x84E0, "_meth_84E0" },
    { 0x84E1, "_meth_84E1" },
    { 0x84E2, "_meth_84E2" },
    { 0x84E3, "_meth_84E3" },
    { 0x84E4, "_meth_84E4" },
    { 0x84E5, "_meth_84E5" },
    { 0x84E6, "_meth_84E6" },
    { 0x84E7, "_meth_84E7" },
    { 0x84E8, "_meth_84E8" },
    { 0x84E9, "_meth_84E9" },
    { 0x84EA, "_meth_84EA" },
    { 0x84EB, "_meth_84EB" },
    { 0x84EC, "_meth_84EC" },
    { 0x84ED, "_meth_84ED" },
    { 0x84EE, "_meth_84EE" },
    { 0x84EF, "_meth_84EF" },
    { 0x84F0, "_meth_84F0" },
    { 0x84F1, "_meth_84F1" },
    { 0x84F2, "_meth_84F2" },
    { 0x84F3, "_meth_84F3" },
    { 0x84F4, "_meth_84F4" },
    { 0x84F5, "_meth_84F5" },
    { 0x84F6, "_meth_84F6" },
    { 0x84F7, "_meth_84F7" },
    { 0x84F8, "_meth_84F8" },
    { 0x84F9, "_meth_84F9" },
    { 0x84FA, "_meth_84FA" },
    { 0x84FB, "_meth_84FB" },
    { 0x84FC, "_meth_84FC" },
    { 0x84FD, "_meth_84FD" },
    { 0x84FE, "_meth_84FE" },
    { 0x84FF, "_meth_84FF" },
    { 0x8500, "_meth_8500" },
    { 0x8501, "_meth_8501" },
    { 0x8502, "_meth_8502" },
    { 0x8503, "_meth_8503" },
    { 0x8504, "_meth_8504" },
    { 0x8505, "_meth_8505" },
    { 0x8506, "_meth_8506" },
    { 0x8507, "_meth_8507" },
    { 0x8508, "_meth_8508" },
    { 0x8509, "_meth_8509" },
    { 0x850A, "_meth_850A" },
    { 0x850B, "_meth_850B" },
    { 0x850C, "_meth_850C" },
    { 0x850D, "_meth_850D" },
    { 0x850E, "_meth_850E" },
    { 0x850F, "_meth_850F" },
    { 0x8510, "_meth_8510" },
    { 0x8511, "_meth_8511" },
    { 0x8512, "_meth_8512" },
    { 0x8513, "_meth_8513" },
    { 0x8514, "_meth_8514" },
    { 0x8515, "_meth_8515" },
    { 0x8516, "_meth_8516" },
    { 0x8517, "_meth_8517" },
    { 0x8518, "_meth_8518" },
    { 0x8519, "_meth_8519" },
    { 0x851A, "_meth_851A" },
    { 0x851B, "_meth_851B" },
    { 0x851C, "_meth_851C" },
    { 0x851D, "_meth_851D" },
    { 0x851E, "_meth_851E" },
    { 0x851F, "_meth_851F" },
    { 0x8520, "_meth_8520" },
    { 0x8521, "_meth_8521" },
    { 0x8522, "_meth_8522" },
    { 0x8523, "_meth_8523" },
    { 0x8524, "_meth_8524" },
    { 0x8525, "_meth_8525" },
    { 0x8526, "_meth_8526" },
    { 0x8527, "_meth_8527" },
    { 0x8528, "_meth_8528" },
    { 0x8529, "_meth_8529" },
    { 0x852A, "_meth_852A" },
    { 0x852B, "_meth_852B" },
    { 0x852C, "_meth_852C" },
    { 0x852D, "_meth_852D" },
    { 0x852E, "_meth_852E" },
    { 0x852F, "_meth_852F" },
    { 0x8530, "_meth_8530" },
    { 0x8531, "_meth_8531" },
    { 0x8532, "_meth_8532" },
    { 0x8533, "_meth_8533" },
    { 0x8534, "_meth_8534" },
    { 0x8535, "_meth_8535" },
    { 0x8536, "_meth_8536" },
    { 0x8537, "_meth_8537" },
    { 0x8538, "_meth_8538" },
    { 0x8539, "_meth_8539" },
    { 0x853A, "_meth_853A" },
    { 0x853B, "_meth_853B" },
    { 0x853C, "_meth_853C" },
    { 0x853D, "_meth_853D" },
    { 0x853E, "_meth_853E" },
    { 0x853F, "_meth_853F" },
    { 0x8540, "_meth_8540" },
    { 0x8541, "_meth_8541" },
    { 0x8542, "_meth_8542" },
    { 0x8543, "_meth_8543" },
    { 0x8544, "_meth_8544" },
    { 0x8545, "_meth_8545" },
    { 0x8546, "_meth_8546" },
    { 0x8547, "_meth_8547" },
    { 0x8548, "_meth_8548" },
    { 0x8549, "_meth_8549" },
    { 0x854A, "_meth_854A" },
    { 0x854B, "_meth_854B" },
    { 0x854C, "_meth_854C" },
    { 0x854D, "_meth_854D" },
    { 0x854E, "_meth_854E" },
    { 0x854F, "_meth_854F" },
    { 0x8550, "_meth_8550" },
    { 0x8551, "_meth_8551" },
    { 0x8552, "_meth_8552" },
    { 0x8553, "_meth_8553" },
    { 0x8554, "_meth_8554" },
    { 0x8555, "_meth_8555" },
    { 0x8556, "_meth_8556" },
    { 0x8557, "_meth_8557" },
    { 0x8558, "_meth_8558" },
    { 0x8559, "_meth_8559" },
    { 0x855A, "_meth_855A" },
    { 0x855B, "_meth_855B" },
    { 0x855C, "_meth_855C" },
    { 0x855D, "_meth_855D" },
    { 0x855E, "_meth_855E" },
    { 0x855F, "_meth_855F" },
    { 0x8560, "_meth_8560" },
    { 0x8561, "_meth_8561" },
    { 0x8562, "_meth_8562" },
    { 0x8563, "_meth_8563" },
    { 0x8564, "_meth_8564" },
    { 0x8565, "_meth_8565" },
    { 0x8566, "_meth_8566" },
    { 0x8567, "_meth_8567" },
    { 0x8568, "_meth_8568" },
    { 0x8569, "_meth_8569" },
    { 0x856A, "_meth_856A" },
    { 0x856B, "_meth_856B" },
    { 0x856C, "_meth_856C" },
    { 0x856D, "_meth_856D" },
    { 0x856E, "_meth_856E" },
    { 0x856F, "_meth_856F" },
    { 0x8570, "_meth_8570" },
    { 0x8571, "_meth_8571" },
    { 0x8572, "_meth_8572" },
    { 0x8573, "_meth_8573" },
    { 0x8574, "_meth_8574" },
    { 0x8575, "_meth_8575" },
    { 0x8576, "_meth_8576" },
    { 0x8577, "_meth_8577" },
    { 0x8578, "_meth_8578" },
    { 0x8579, "_meth_8579" },
    { 0x857A, "_meth_857A" },
    { 0x857B, "_meth_857B" },
    { 0x857C, "_meth_857C" },
    { 0x857D, "_meth_857D" },
    { 0x857E, "_meth_857E" },
    { 0x857F, "_meth_857F" },
    { 0x8580, "_meth_8580" },
    { 0x8581, "_meth_8581" },
    { 0x8582, "_meth_8582" },
    { 0x8583, "_meth_8583" },
    { 0x8584, "_meth_8584" },
    { 0x8585, "_meth_8585" },
    { 0x8586, "_meth_8586" },
}};

const std::array<std::pair<std::uint16_t, const char*>, 26754> token_list
{{
    { 0x0000, "" },
    { 0x0001, "pl#" },
    { 0x0002, "-" },
    { 0x0003, "radius`" },
    { 0x0004, "note:" },
    { 0x0005, "_" },
    { 0x0006, "_custom" },
    { 0x0007, "a" },
    { 0x0008, "ability" },
    { 0x0009, "accumulate" },
    { 0x000A, "accuracy" },
    { 0x000B, "actionslot1" },
    { 0x000C, "actionslot2" },
    { 0x000D, "actionslot3" },
    { 0x000E, "actionslot4" },
    { 0x000F, "actionslot5" },
    { 0x0010, "actionslot6" },
    { 0x0011, "actionslot7" },
    { 0x0012, "actionslot8" },
    { 0x0013, "activator" },
    { 0x0014, "active" },
    { 0x0015, "activecostume" },
    { 0x0016, "activeemblemslot" },
    { 0x0017, "activesquadmember" },
    { 0x0018, "activevisionset" },
    { 0x0019, "activevisionsetduration" },
    { 0x001A, "agent" },
    { 0x001B, "agenthealth" },
    { 0x001C, "agentname" },
    { 0x001D, "agentteam" },
    { 0x001E, "ai_event" },
    { 0x001F, "ai_sight_line_cycle_group" },
    { 0x0020, "ai_sight_line_group" },
    { 0x0021, "aim_highest_bone" },
    { 0x0022, "aim_vis_bone" },
    { 0x0023, "aiSpread" },
    { 0x0024, "aisquadmembers" },
    { 0x0025, "alert" },
    { 0x0026, "alertlevel" },
    { 0x0027, "alertlevelint" },
    { 0x0028, "alien" },
    { 0x0029, "alienplayerloadout" },
    { 0x002A, "alienplayerstats" },
    { 0x002B, "aliensession" },
    { 0x002C, "alignx" },
    { 0x002D, "aligny" },
    { 0x002E, "all" },
    { 0x002F, "allies" },
    { 0x0030, "allowcrouch" },
    { 0x0031, "allowdeath" },
    { 0x0032, "allowjump" },
    { 0x0033, "allowladders" },
    { 0x0034, "allowpain" },
    { 0x0035, "allowprone" },
    { 0x0036, "allstreaksrestricted" },
    { 0x0037, "alpha" },
    { 0x0038, "altmode" },
    { 0x0039, "always" },
    { 0x003A, "ambient" },
    { 0x003B, "ambienttrack" },
    { 0x003C, "ambienttrack_ac130" },
    { 0x003D, "ambush" },
    { 0x003E, "ambush_nodes_only" },
    { 0x003F, "angle_deltas" },
    { 0x0040, "anglelerprate" },
    { 0x0041, "angles" },
    { 0x0042, "anim_angle_delta" },
    { 0x0043, "anim_deltas" },
    { 0x0044, "anim_pose" },
    { 0x0045, "anim_will_finish" },
    { 0x0046, "animation" },
    { 0x0047, "animscript" },
    { 0x0048, "archived" },
    { 0x0049, "archivetime" },
    { 0x004A, "armor" },
    { 0x004B, "asleep" },
    { 0x004C, "aspectratio" },
    { 0x004D, "assaultstreaks" },
    { 0x004E, "assignedbucket" },
    { 0x004F, "assists" },
    { 0x0050, "attachment" },
    { 0x0051, "attachmentclassrestricted" },
    { 0x0052, "attachmentrestricted" },
    { 0x0053, "attachments" },
    { 0x0054, "attachtag" },
    { 0x0055, "attacker" },
    { 0x0056, "attackeraccuracy" },
    { 0x0057, "attackercount" },
    { 0x0058, "attackerisjuggernaut" },
    { 0x0059, "attackerpos" },
    { 0x005A, "author" },
    { 0x005B, "auto_ai" },
    { 0x005C, "auto_change" },
    { 0x005D, "auto_nonai" },
    { 0x005E, "avoidanceboundshalfsize" },
    { 0x005F, "awards" },
    { 0x0060, "axis" },
    { 0x0061, "b" },
    { 0x0062, "back" },
    { 0x0063, "back_left" },
    { 0x0064, "back_low" },
    { 0x0065, "back_mid" },
    { 0x0066, "back_right" },
    { 0x0067, "back_up" },
    { 0x0068, "background" },
    { 0x0069, "bad_guys" },
    { 0x006A, "bad_path" },
    { 0x006B, "badplaceawareness" },
    { 0x006C, "ball_off" },
    { 0x006D, "ball_on" },
    { 0x006E, "ball_pass" },
    { 0x006F, "bandwidthdown" },
    { 0x0070, "bandwidthtestcount" },
    { 0x0071, "bandwidthup" },
    { 0x0072, "baselineoverflow_max" },
    { 0x0073, "baselineoverflow_worst" },
    { 0x0074, "battery_discharge_begin" },
    { 0x0075, "battery_discharge_end" },
    { 0x0076, "begin" },
    { 0x0077, "begin_custom_anim" },
    { 0x0078, "begin_firing" },
    { 0x0079, "begin_firing_left" },
    { 0x007A, "bestweapon" },
    { 0x007B, "bestweaponindex" },
    { 0x007C, "bipods" },
    { 0x007D, "birthtime" },
    { 0x007E, "bl_rotor1" },
    { 0x007F, "bl_rotor2" },
    { 0x0080, "bl_rotor3" },
    { 0x0081, "blackops2prestige" },
    { 0x0082, "blackops2rank" },
    { 0x0083, "blade_hide" },
    { 0x0084, "blade_show" },
    { 0x0085, "blockfriendlies" },
    { 0x0086, "blurradius" },
    { 0x0087, "body" },
    { 0x0088, "body_animate_jnt" },
    { 0x0089, "bottomarc" },
    { 0x008A, "br_rotor1" },
    { 0x008B, "br_rotor2" },
    { 0x008C, "br_rotor3" },
    { 0x008D, "breadcrumbheader" },
    { 0x008E, "buff" },
    { 0x008F, "bullet_hitshield" },
    { 0x0090, "bullethit" },
    { 0x0091, "bulletwhizby" },
    { 0x0092, "c" },
    { 0x0093, "callingcardindex" },
    { 0x0094, "camo" },
    { 0x0095, "cancel_location" },
    { 0x0096, "canclimbladders" },
    { 0x0097, "canjumppath" },
    { 0x0098, "cardicon" },
    { 0x0099, "cardnameplate" },
    { 0x009A, "cardtitle" },
    { 0x009B, "cgmchecksum" },
    { 0x009C, "ch_prestige" },
    { 0x009D, "ch_prestige_max" },
    { 0x009E, "chainfallback" },
    { 0x009F, "chainnode" },
    { 0x00A0, "challengeprogress" },
    { 0x00A1, "challengestate" },
    { 0x00A2, "chest" },
    { 0x00A3, "churnscores" },
    { 0x00A4, "chyron_message1" },
    { 0x00A5, "chyron_message2" },
    { 0x00A6, "chyron_message3" },
    { 0x00A7, "civilian" },
    { 0x00A8, "clanidhigh" },
    { 0x00A9, "clanidlow" },
    { 0x00AA, "classname" },
    { 0x00AB, "clipdistance" },
    { 0x00AC, "code_classname" },
    { 0x00AD, "code_damageradius" },
    { 0x00AE, "code_move" },
    { 0x00AF, "code_move_slide" },
    { 0x00B0, "codecallback_agentadded" },
    { 0x00B1, "codecallback_agentdamaged" },
    { 0x00B2, "codecallback_agentkilled" },
    { 0x00B3, "codecallback_bullethitentity" },
    { 0x00B4, "codecallback_codeendgame" },
    { 0x00B5, "codecallback_entitydamage" },
    { 0x00B6, "codecallback_entityoutofworld" },
    { 0x00B7, "codecallback_handleinstantmessage" },
    { 0x00B8, "codecallback_hostmigration" },
    { 0x00B9, "codecallback_leaderdialog" },
    { 0x00BA, "codecallback_partymembers" },
    { 0x00BB, "codecallback_playerconnect" },
    { 0x00BC, "codecallback_playerdamage" },
    { 0x00BD, "codecallback_playerdisconnect" },
    { 0x00BE, "codecallback_playergrenadesuicide" },
    { 0x00BF, "codecallback_playerkilled" },
    { 0x00C0, "codecallback_playerlaststand" },
    { 0x00C1, "codecallback_playermigrated" },
    { 0x00C2, "codecallback_startgametype" },
    { 0x00C3, "codecallback_vehicledamage" },
    { 0x00C4, "color" },
    { 0x00C5, "color_blind_toggled" },
    { 0x00C6, "combat" },
    { 0x00C7, "combatmode" },
    { 0x00C8, "combatrecord" },
    { 0x00C9, "commonoption" },
    { 0x00CA, "confirm_location" },
    { 0x00CB, "connection_id" },
    { 0x00CC, "connectionidchunkhigh" },
    { 0x00CD, "connectionidchunklow" },
    { 0x00CE, "consolegame" },
    { 0x00CF, "consoleidchunkhigh" },
    { 0x00D0, "consoleidchunklow" },
    { 0x00D1, "constrained" },
    { 0x00D2, "contact" },
    { 0x00D3, "contextleanenabled" },
    { 0x00D4, "convergencetime" },
    { 0x00D5, "coopactivesquadmember" },
    { 0x00D6, "coopsquadmembers" },
    { 0x00D7, "costumes" },
    { 0x00D8, "count" },
    { 0x00D9, "cover" },
    { 0x00DA, "cover_approach" },
    { 0x00DB, "coversearchinterval" },
    { 0x00DC, "createstruct" },
    { 0x00DD, "createtime" },
    { 0x00DE, "criticalbulletdamagedist" },
    { 0x00DF, "crouch" },
    { 0x00E0, "currency" },
    { 0x00E1, "current" },
    { 0x00E2, "currentanimtime" },
    { 0x00E3, "currentgen" },
    { 0x00E4, "currentwinstreak" },
    { 0x00E5, "cursorhint" },
    { 0x00E6, "custom_attach_00" },
    { 0x00E7, "custom_attach_01" },
    { 0x00E8, "custom_attach_02" },
    { 0x00E9, "custom_attach_03" },
    { 0x00EA, "custom_attach_04" },
    { 0x00EB, "custom_attach_05" },
    { 0x00EC, "custom_attach_06" },
    { 0x00ED, "custom_attach_07" },
    { 0x00EE, "custom_attach_08" },
    { 0x00EF, "custom_attach_09" },
    { 0x00F0, "custom_attach_10" },
    { 0x00F1, "custom_attach_11" },
    { 0x00F2, "custom_attach_12" },
    { 0x00F3, "custom_attach_13" },
    { 0x00F4, "custom_attach_14" },
    { 0x00F5, "custom_attach_15" },
    { 0x00F6, "customclasses" },
    { 0x00F7, "customization_loaded" },
    { 0x00F8, "d" },
    { 0x00F9, "dailychallengeid" },
    { 0x00FA, "damage" },
    { 0x00FB, "damage_notdone" },
    { 0x00FC, "damagedir" },
    { 0x00FD, "damagelocation" },
    { 0x00FE, "damagemod" },
    { 0x00FF, "damagemultiplier" },
    { 0x0100, "damageshield" },
    { 0x0101, "damagetaken" },
    { 0x0102, "damageweapon" },
    { 0x0103, "damageyaw" },
    { 0x0104, "dangerreactduration" },
    { 0x0105, "datalength" },
    { 0x0106, "dcid" },
    { 0x0107, "dead" },
    { 0x0108, "death" },
    { 0x0109, "deathangles" },
    { 0x010A, "deathinvulnerabletime" },
    { 0x010B, "deathplant" },
    { 0x010C, "deathpos" },
    { 0x010D, "deaths" },
    { 0x010E, "deathshield" },
    { 0x010F, "defaultclasses" },
    { 0x0110, "defense" },
    { 0x0111, "defense_level" },
    { 0x0112, "delayeddeath" },
    { 0x0113, "deploy_riotshield" },
    { 0x0114, "desc" },
    { 0x0115, "descmodified" },
    { 0x0116, "desiredangle" },
    { 0x0117, "destructible_type" },
    { 0x0118, "detectable" },
    { 0x0119, "detected" },
    { 0x011A, "detonate" },
    { 0x011B, "device_id_high" },
    { 0x011C, "device_id_low" },
    { 0x011D, "deviceconnectionhistory" },
    { 0x011E, "deviceusefrequency" },
    { 0x011F, "diequietly" },
    { 0x0120, "diffusefraction" },
    { 0x0121, "direct" },
    { 0x0122, "disable" },
    { 0x0123, "disableplayeradsloscheck" },
    { 0x0124, "dlight" },
    { 0x0125, "dmg" },
    { 0x0126, "dodamagetoall" },
    { 0x0127, "dodangerreact" },
    { 0x0128, "doffar" },
    { 0x0129, "dofnear" },
    { 0x012A, "dofphysicalfocusdistance" },
    { 0x012B, "dofphysicalfstop" },
    { 0x012C, "dog" },
    { 0x012D, "doghandler" },
    { 0x012E, "doingambush" },
    { 0x012F, "done" },
    { 0x0130, "dontavoidplayer" },
    { 0x0131, "dotofdeath" },
    { 0x0132, "down" },
    { 0x0133, "downaimlimit" },
    { 0x0134, "drawoncompass" },
    { 0x0135, "dropweapon" },
    { 0x0136, "duration" },
    { 0x0137, "eftarc" },
    { 0x0138, "empty" },
    { 0x0139, "empty_offhand" },
    { 0x013A, "enable" },
    { 0x013B, "enablehudlighting" },
    { 0x013C, "enableshadows" },
    { 0x013D, "end_firing" },
    { 0x013E, "end_firing_left" },
    { 0x013F, "end_script" },
    { 0x0140, "enddeaths" },
    { 0x0141, "endkills" },
    { 0x0142, "enemy" },
    { 0x0143, "enemy_sighted" },
    { 0x0144, "enemy_sighted_lost" },
    { 0x0145, "enemy_visible" },
    { 0x0146, "enemyname" },
    { 0x0147, "enemyplatform" },
    { 0x0148, "enemyradarmode" },
    { 0x0149, "enemyxuidhigh" },
    { 0x014A, "enemyxuidlow" },
    { 0x014B, "energy_fire" },
    { 0x014C, "engagemaxdist" },
    { 0x014D, "engagemaxfalloffdist" },
    { 0x014E, "engagemindist" },
    { 0x014F, "engageminfalloffdist" },
    { 0x0150, "enhanceable" },
    { 0x0151, "entity" },
    { 0x0152, "entitydeleted" },
    { 0x0153, "entityoverflow_max" },
    { 0x0154, "entityoverflow_worst" },
    { 0x0155, "equipment" },
    { 0x0156, "equipmentsetups" },
    { 0x0157, "escaped" },
    { 0x0158, "exclusive" },
    { 0x0159, "exo_ability_activate" },
    { 0x015A, "exo_adrenaline_fire" },
    { 0x015B, "exo_boost" },
    { 0x015C, "exo_dodge" },
    { 0x015D, "exo_power" },
    { 0x015E, "exo_slide" },
    { 0x015F, "exo_slide_hit_player" },
    { 0x0160, "exoattachment1" },
    { 0x0161, "exoattachment2" },
    { 0x0162, "experience" },
    { 0x0163, "explode" },
    { 0x0164, "exposedduration" },
    { 0x0165, "extracustomclassesentitlement" },
    { 0x0166, "extracustomclassesprestige" },
    { 0x0167, "extrascore0" },
    { 0x0168, "extrascore1" },
    { 0x0169, "face_angle" },
    { 0x016A, "face_angle_3d" },
    { 0x016B, "face_angle_abs" },
    { 0x016C, "face_angle_rel" },
    { 0x016D, "face_current" },
    { 0x016E, "face_default" },
    { 0x016F, "face_direction" },
    { 0x0170, "face_enemy" },
    { 0x0171, "face_enemy_or_motion" },
    { 0x0172, "face_goal" },
    { 0x0173, "face_motion" },
    { 0x0174, "face_point" },
    { 0x0175, "facemotion" },
    { 0x0176, "failed" },
    { 0x0177, "falling" },
    { 0x0178, "fast_radar" },
    { 0x0179, "favoriteenemy" },
    { 0x017A, "finalaccuracy" },
    { 0x017B, "first_person" },
    { 0x017C, "firstplayedsptime" },
    { 0x017D, "fixednode" },
    { 0x017E, "fixednodesaferadius" },
    { 0x017F, "fl_rotor1" },
    { 0x0180, "fl_rotor2" },
    { 0x0181, "fl_rotor3" },
    { 0x0182, "flash" },
    { 0x0183, "flashbang" },
    { 0x0184, "foley" },
    { 0x0185, "follow" },
    { 0x0186, "followmax" },
    { 0x0187, "followmin" },
    { 0x0188, "font" },
    { 0x0189, "fontscale" },
    { 0x018A, "foot_ik_active" },
    { 0x018B, "foot_ik_blend_in" },
    { 0x018C, "foot_ik_blend_out" },
    { 0x018D, "foot_ik_inactive" },
    { 0x018E, "footstepdetectdist" },
    { 0x018F, "footstepdetectdistsprint" },
    { 0x0190, "footstepdetectdistwalk" },
    { 0x0191, "force_off" },
    { 0x0192, "force_on" },
    { 0x0193, "force_fully_on" },
    { 0x0194, "forcepartyskillignore" },
    { 0x0195, "forceragdollimmediate" },
    { 0x0196, "forcespectatorclient" },
    { 0x0197, "foregrip_off" },
    { 0x0198, "foreground" },
    { 0x0199, "forward" },
    { 0x019A, "fov" },
    { 0x019B, "fovcosine" },
    { 0x019C, "fovcosinebusy" },
    { 0x019D, "fovcosinez" },
    { 0x019E, "fr_rotor1" },
    { 0x019F, "fr_rotor2" },
    { 0x01A0, "fr_rotor3" },
    { 0x01A1, "fraction" },
    { 0x01A2, "frag" },
    { 0x01A3, "free" },
    { 0x01A4, "freecamera" },
    { 0x01A5, "freelook" },
    { 0x01A6, "frequency" },
    { 0x01A7, "friendlyfire" },
    { 0x01A8, "front_left" },
    { 0x01A9, "front_right" },
    { 0x01AA, "frontshieldanglecos" },
    { 0x01AB, "fs_concrete" },
    { 0x01AC, "fs_dirt" },
    { 0x01AD, "fs_metal" },
    { 0x01AE, "fs_wood" },
    { 0x01AF, "game_extrainfo" },
    { 0x01B0, "gamecount" },
    { 0x01B1, "gamertag" },
    { 0x01B2, "gamesplayed" },
    { 0x01B3, "gametype" },
    { 0x01B4, "gender" },
    { 0x01B5, "ghostsprestige" },
    { 0x01B6, "ghostsrank" },
    { 0x01B7, "glass" },
    { 0x01B8, "glass_damaged" },
    { 0x01B9, "glass_destroyed" },
    { 0x01BA, "globalcostume" },
    { 0x01BB, "gloves" },
    { 0x01BC, "glowalpha" },
    { 0x01BD, "glowcolor" },
    { 0x01BE, "goal" },
    { 0x01BF, "goal_changed" },
    { 0x01C0, "goal_reached" },
    { 0x01C1, "goal_yaw" },
    { 0x01C2, "goalheight" },
    { 0x01C3, "goalpos" },
    { 0x01C4, "goalradius" },
    { 0x01C5, "goaltime" },
    { 0x01C6, "goalweight" },
    { 0x01C7, "goingtoruntopos" },
    { 0x01C8, "gravity" },
    { 0x01C9, "gravity_noclip" },
    { 0x01CA, "grenade" },
    { 0x01CB, "grenade_fire" },
    { 0x01CC, "grenade_off" },
    { 0x01CD, "grenade_on" },
    { 0x01CE, "grenade_pullback" },
    { 0x01CF, "grenade_return_hand_tag" },
    { 0x01D0, "grenadeammo" },
    { 0x01D1, "grenadeawareness" },
//  { 0x01D2, "grenade_unknown0" },
//  { 0x01D3, "grenade_unknown1" },
//  { 0x01D4, "grenade_unknown2" },
    { 0x01D5, "grenadedanger" },
    { 0x01D6, "grenadeweapon" },
    { 0x01D7, "ground_slam" },
    { 0x01D8, "ground_slam_hit_player" },
    { 0x01D9, "groundentchanged" },
    { 0x01DA, "groundtype" },
    { 0x01DB, "gunblockedbywall" },
    { 0x01DC, "gunshot" },
    { 0x01DD, "gunshot_teammate" },
    { 0x01DE, "hardcoremodeon" },
    { 0x01DF, "hasdoublexpitem" },
    { 0x01E0, "hasradar" },
    { 0x01E1, "hasvalidcostumeselfieimage" },
    { 0x01E2, "head" },
    { 0x01E3, "headicon" }, 
    { 0x01E4, "headiconteam" }, 
    { 0x01E5, "headshots" }, 
    { 0x01E6, "health" }, 
    { 0x01E7, "healthregen" }, 
    { 0x01E8, "height" }, 
    { 0x01E9, "helmet" }, 
    { 0x01EA, "hidein3rdperson" }, 
    { 0x01EB, "hidewhendead" }, 
    { 0x01EC, "hidewhenindemo" }, 
    { 0x01ED, "hidewheninmenu" }, 
    { 0x01EE, "high_priority" }, 
    { 0x01EF, "highlyawareradius" }, 
    { 0x01F0, "hindlegstraceoffset" }, 
    { 0x01F1, "hintstring" }, 
    { 0x01F2, "hit_by_missile" }, 
    { 0x01F3, "horzalign" }, 
    { 0x01F4, "host_sucks_end_game" }, 
    { 0x01F5, "hostfailures" }, 
    { 0x01F6, "hostquits" }, 
    { 0x01F7, "hostsuccesses" }, 
    { 0x01F8, "human" }, 
    { 0x01F9, "iconnew" }, 
    { 0x01FA, "iconunlocked" }, 
    { 0x01FB, "ignoreall" }, 
    { 0x01FC, "ignoreclosefoliage" }, 
    { 0x01FD, "ignoreexplosionevents" }, 
    { 0x01FE, "ignoreforfixednodesafecheck" }, 
    { 0x01FF, "ignoreme" }, 
    { 0x0200, "ignorerandombulletdamage" }, 
    { 0x0201, "ignoresuppression" }, 
    { 0x0202, "ignoretriggers" }, 
    { 0x0203, "ikweight" }, 
    { 0x0204, "index" }, 
    { 0x0205, "infinite_energy" }, 
    { 0x0206, "info_notnull" }, 
    { 0x0207, "info_player_start" }, 
    { 0x0208, "init" },
    { 0x0209, "initstructs" },
    { 0x020A, "insolid" }, 
    { 0x020B, "intermission" }, 
    { 0x020C, "interval" }, 
    { 0x020D, "inuse" }, 
    { 0x020E, "invalid_parent" }, 
    { 0x020F, "invisible" }, 
    { 0x0210, "isradarblocked" }, 
    { 0x0211, "item" }, 
    { 0x0212, "j_exo_rcket_arm02" }, 
    { 0x0213, "j_exoclav04_l" }, 
    { 0x0214, "j_exoclav04_r" }, 
    { 0x0215, "j_exohip04_l" }, 
    { 0x0216, "j_exohip04_r" }, 
    { 0x0217, "j_eyeball_le" }, 
    { 0x0218, "j_eyeball_ri" }, 
    { 0x0219, "j_gun" }, 
    { 0x021A, "j_head" }, 
    { 0x021B, "j_hip_l" }, 
    { 0x021C, "j_hip_r" }, 
    { 0x021D, "j_knee_le" }, 
    { 0x021E, "j_knee_ri" }, 
    { 0x021F, "j_left_elbow" }, 
    { 0x0220, "j_left_hand" }, 
    { 0x0221, "j_left_shoulder" }, 
    { 0x0222, "j_mainroot" }, 
    { 0x0223, "j_neck" }, 
    { 0x0224, "j_right_elbow" }, 
    { 0x0225, "j_right_hand" }, 
    { 0x0226, "j_right_hand_placement" }, 
    { 0x0227, "j_right_shoulder" }, 
    { 0x0228, "j_rocket" }, 
    { 0x0229, "j_spine4" }, 
    { 0x022A, "j_spinelower" }, 
    { 0x022B, "j_spineupper" }, 
    { 0x022C, "jumpcost" }, 
    { 0x022D, "jumping" }, 
    { 0x022E, "justclass" }, 
    { 0x022F, "kdratio" }, 
    { 0x0230, "keepclaimednode" }, 
    { 0x0231, "keepclaimednodeifvalid" }, 
    { 0x0232, "keepnodeduringscriptedanim" }, 
    { 0x0233, "key1" }, 
    { 0x0234, "key2" }, 
    { 0x0235, "kill_timestamp" }, 
    { 0x0236, "killanimscript" }, 
    { 0x0237, "killcamentity" }, 
    { 0x0238, "killcamentitylookat" }, 
    { 0x0239, "kills" }, 
    { 0x023A, "killstreak" }, 
    { 0x023B, "killstreakcount" }, 
    { 0x023C, "killstreakrestricted" }, 
    { 0x023D, "killstreakunlocked" }, 
    { 0x023E, "knife_off" }, 
    { 0x023F, "knife_on" }, 
    { 0x0240, "known_event" }, 
    { 0x0241, "label" }, 
    { 0x0242, "ladder_down" }, 
    { 0x0243, "ladder_up" }, 
    { 0x0244, "land" }, 
    { 0x0245, "last_stand_count" }, 
    { 0x0246, "lastattacker" }, 
    { 0x0247, "lastenemysightpos" }, 
    { 0x0248, "lastplayedtime" }, 
    { 0x0249, "laststand" }, 
    { 0x024A, "leanamount" }, 
    { 0x024B, "ledge" }, 
    { 0x024C, "left" }, 
    { 0x024D, "leftaimlimit" }, 
    { 0x024E, "leftarc" }, 
    { 0x024F, "lethal" }, 
    { 0x0250, "lifecount" }, 
    { 0x0251, "light" }, 
    { 0x0252, "lives" }, 
    { 0x0253, "loadouts" }, 
    { 0x0254, "lockorientation" }, 
    { 0x0255, "lod" }, 
    { 0x0256, "look" }, 
    { 0x0257, "lookahead" }, 
    { 0x0258, "lookaheaddir" }, 
    { 0x0259, "lookaheaddist" }, 
    { 0x025A, "lookaheadhitsstairs" }, 
    { 0x025B, "lookforward" }, 
    { 0x025C, "lookright" }, 
    { 0x025D, "looktarget" }, 
    { 0x025E, "lookup" }, 
    { 0x025F, "loot" }, 
    { 0x0260, "lootnew" }, 
    { 0x0261, "loses" }, 
    { 0x0262, "low_priority" }, 
    { 0x0263, "lowresbackground" }, 
    { 0x0264, "luinotifyserver" }, 
    { 0x0265, "mag_eject" }, 
    { 0x0266, "mag_eject_left" }, 
    { 0x0267, "main" },
    { 0x0268, "manual" }, 
    { 0x0269, "manual_ai" }, 
    { 0x026A, "manual_change" }, 
    { 0x026B, "map" }, 
    { 0x026C, "matchid" }, 
    { 0x026D, "matchmakingsettingsversion" }, 
    { 0x026E, "matchmakingtesttype" }, 
    { 0x026F, "max_time" }, 
    { 0x0270, "maxfaceenemydist" }, 
    { 0x0271, "maxhealth" }, 
    { 0x0272, "maxrange" }, 
    { 0x0273, "maxsightdistsqrd" }, 
    { 0x0274, "maxturnspeed" }, 
    { 0x0275, "maxvisibledist" }, 
    { 0x0276, "melee_fired" }, 
    { 0x0277, "melee_hit_react" }, 
    { 0x0278, "meleeattackdist" }, 
    { 0x0279, "menuresponse" }, 
    { 0x027A, "micro_dlc_bits_last_gen" }, 
    { 0x027B, "micro_dlc_bits_next_gen" }, 
    { 0x027C, "middle_left" }, 
    { 0x027D, "middle_right" }, 
    { 0x027E, "migrateablequits" }, 
    { 0x027F, "min_energy" }, 
    { 0x0280, "min_time" }, 
    { 0x0281, "minpaindamage" }, 
    { 0x0282, "minusedistsq" }, 
    { 0x0283, "missile_fire" }, 
    { 0x0284, "missile_passed_target" }, 
    { 0x0285, "missile_stuck" }, 
    { 0x0286, "mlgversion" }, 
    { 0x0287, "mod" }, 
    { 0x0288, "mod_crush" }, 
    { 0x0289, "mod_energy" }, 
    { 0x028A, "mod_explosive" }, 
    { 0x028B, "mod_explosive_bullet" }, 
    { 0x028C, "mod_falling" }, 
    { 0x028D, "mod_grenade" }, 
    { 0x028E, "mod_grenade_splash" }, 
    { 0x028F, "mod_head_shot" }, 
    { 0x0290, "mod_impact" }, 
    { 0x0291, "mod_melee" }, 
    { 0x0292, "mod_melee_alien" }, 
    { 0x0293, "mod_melee_alt" }, 
    { 0x0294, "mod_melee_dog" }, 
    { 0x0295, "mod_pistol_bullet" }, 
    { 0x0296, "mod_projectile" }, 
    { 0x0297, "mod_projectile_splash" }, 
    { 0x0298, "mod_rifle_bullet" }, 
    { 0x0299, "mod_suicide" }, 
    { 0x029A, "mod_trigger_hurt" }, 
    { 0x029B, "mod_unknown" }, 
    { 0x029C, "model" }, 
    { 0x029D, "modeprefix" }, 
    { 0x029E, "modifiers" }, 
    { 0x029F, "motiontrackerenabled" }, 
    { 0x02A0, "mounted_dlc_bits" }, 
    { 0x02A1, "movedone" }, 
    { 0x02A2, "movemode" }, 
    { 0x02A3, "munition" }, 
    { 0x02A4, "munition_level" }, 
    { 0x02A5, "mw3prestige" }, 
    { 0x02A6, "mw3rank" }, 
    { 0x02A7, "name" }, 
    { 0x02A8, "namemodified" }, 
    { 0x02A9, "near_goal" }, 
    { 0x02AA, "nearz" }, 
    { 0x02AB, "neutral" }, 
    { 0x02AC, "never" }, 
    { 0x02AD, "newenemyreactiondistsq" }, 
    { 0x02AE, "newentitlement" }, 
    { 0x02AF, "nextgen" }, 
    { 0x02B0, "nextreadblackops2" }, 
    { 0x02B1, "nextreadghosts0" }, 
    { 0x02B2, "nextreadghosts1" }, 
    { 0x02B3, "nextreadmw3" }, 
    { 0x02B4, "night_vision_off" }, 
    { 0x02B5, "night_vision_on" }, 
    { 0x02B6, "no_bot_random_path" }, 
    { 0x02B7, "no_cover" }, 
    { 0x02B8, "no_gravity" }, 
    { 0x02B9, "noattackeraccuracymod" }, 
    { 0x02BA, "noclip" }, 
    { 0x02BB, "node" }, 
    { 0x02BC, "node_not_safe" }, 
    { 0x02BD, "node_out_of_range" }, 
    { 0x02BE, "node_relinquished" }, 
    { 0x02BF, "node_taken" }, 
    { 0x02C0, "nodeoffsetpos" }, 
    { 0x02C1, "nododgemove" }, 
    { 0x02C2, "nogravity" }, 
    { 0x02C3, "nogrenadereturnthrow" }, 
    { 0x02C4, "noncombat" }, 
    { 0x02C5, "none" }, 
    { 0x02C6, "nonmigrateablequits" }, 
    { 0x02C7, "nophysics" }, 
    { 0x02C8, "normal" }, 
    { 0x02C9, "normal_radar" }, 
    { 0x02CA, "northyaw" }, 
    { 0x02CB, "notifyname" }, 
    { 0x02CC, "notinsolid" }, 
    { 0x02CD, "num0" }, 
    { 0x02CE, "num1" }, 
    { 0x02CF, "num2" }, 
    { 0x02D0, "num3" }, 
    { 0x02D1, "num4" }, 
    { 0x02D2, "objective" }, 
    { 0x02D3, "obstacle" }, 
    { 0x02D4, "offense" }, 
    { 0x02D5, "offense_level" }, 
    { 0x02D6, "offhand" }, 
    { 0x02D7, "offhand_end" }, 
    { 0x02D8, "offhandweapon" }, 
    { 0x02D9, "oldtime" }, 
    { 0x02DA, "ondeactivate" }, 
    { 0x02DB, "onenterstate" }, 
    { 0x02DC, "only_sky" }, 
    { 0x02DD, "onlygoodnearestnodes" }, 
    { 0x02DE, "onwifi" }, 
    { 0x02DF, "operationsdeadline" }, 
    { 0x02E0, "oriented" }, 
    { 0x02E1, "orientto_complete" }, 
    { 0x02E2, "origin" }, 
    { 0x02E3, "other" }, 
    { 0x02E4, "over" }, 
    { 0x02E5, "owner" }, 
    { 0x02E6, "pacifist" }, 
    { 0x02E7, "pacifistwait" }, 
    { 0x02E8, "pain" }, 
    { 0x02E9, "pantssize" }, 
    { 0x02EA, "parentindex" }, 
    { 0x02EB, "parentname" }, 
    { 0x02EC, "partyid" }, 
    { 0x02ED, "pasttitledata" }, 
    { 0x02EE, "patch" }, 
    { 0x02EF, "patchbacking" }, 
    { 0x02F0, "path_blocked" }, 
    { 0x02F1, "path_changed" }, 
    { 0x02F2, "path_dir_change" }, 
    { 0x02F3, "path_enemy" }, 
    { 0x02F4, "path_need_dodge" }, 
    { 0x02F5, "path_set" }, 
    { 0x02F6, "pathenemyfightdist" }, 
    { 0x02F7, "pathenemylookahead" }, 
    { 0x02F8, "pathgoalpos" }, 
    { 0x02F9, "pathlookaheaddist" }, 
    { 0x02FA, "pathrandompercent" }, 
    { 0x02FB, "pc" }, 
    { 0x02FC, "pccg" }, 
    { 0x02FD, "pelvis" }, 
    { 0x02FE, "perk1" }, 
    { 0x02FF, "perk2" }, 
    { 0x0300, "perk3" }, 
    { 0x0301, "perk4" }, 
    { 0x0302, "perk5" }, 
    { 0x0303, "perk6" }, 
    { 0x0304, "perkclassrestricted" }, 
    { 0x0305, "perkrestricted" }, 
    { 0x0306, "perks" }, 
    { 0x0307, "perkslots" }, 
    { 0x0308, "pers" }, 
    { 0x0309, "persistentperksunlocked" }, 
    { 0x030A, "persistentweaponsunlocked" }, 
    { 0x030B, "phone_off" }, 
    { 0x030C, "phone_on" }, 
    { 0x030D, "physics_finished" }, 
    { 0x030E, "physics_impact" }, 
    { 0x030F, "pickup" }, 
    { 0x0310, "pickup_riotshield" }, 
    { 0x0311, "pistol" }, 
    { 0x0312, "pitchamount" }, 
    { 0x0313, "pitchconvergencetime" }, 
    { 0x0314, "plane_waypoint" }, 
    { 0x0315, "playedblackops2" }, 
    { 0x0316, "playedghosts" }, 
    { 0x0317, "playedmw3" }, 
    { 0x0318, "player" }, 
    { 0x0319, "player_controller" }, 
    { 0x031A, "player_pushed" }, 
    { 0x031B, "playercardbackground" }, 
    { 0x031C, "playercardpatch" }, 
    { 0x031D, "playercardpatchbacking" }, 
    { 0x031E, "playerconnectionhistory" }, 
    { 0x031F, "playerid" }, 
    { 0x0320, "playerip" }, 
    { 0x0321, "playername" }, 
    { 0x0322, "playerpositions" }, 
    { 0x0323, "players" }, 
    { 0x0324, "playerSpread" }, 
    { 0x0325, "playerxuidhigh" }, 
    { 0x0326, "playerxuidlow" }, 
    { 0x0327, "playing" }, 
    { 0x0328, "points" }, 
    { 0x0329, "position" }, 
    { 0x032A, "positioninworld" }, 
    { 0x032B, "postsharpturnlookaheaddist" }, 
    { 0x032C, "precache" }, 
    { 0x032D, "predicted_projectile_impact" }, 
    { 0x032E, "prestige" }, 
    { 0x032F, "prestigedoublexp" }, 
    { 0x0330, "prestigedoublexpmaxtimeplayed" }, 
    { 0x0331, "prestigeshoptokens" }, 
    { 0x0332, "prestigeshoptokensentitlement" }, 
    { 0x0333, "prevanimdelta" }, 
    { 0x0334, "prevnode" }, 
    { 0x0335, "prevscript" }, 
    { 0x0336, "primary" }, 
    { 0x0337, "primaryattachment1" }, 
    { 0x0338, "primaryattachment2" }, 
    { 0x0339, "primaryattachment3" }, 
    { 0x033A, "primaryattachments" }, 
    { 0x033B, "primaryattachkit" }, 
    { 0x033C, "primarycamo" }, 
    { 0x033D, "primaryfurniturekit" }, 
    { 0x033E, "primaryoffhand" }, 
    { 0x033F, "primaryreticle" }, 
    { 0x0340, "primaryweapon" }, 
    { 0x0341, "privatematchactivesquadmember" }, 
    { 0x0342, "privatematchcustomclasses" }, 
    { 0x0343, "privatematchsquadmembers" }, 
    { 0x0344, "projectile_impact" }, 
    { 0x0345, "projectile_impact_player" }, 
    { 0x0346, "prone" }, 
    { 0x0347, "proneok" }, 
    { 0x0348, "providecoveringfire" }, 
    { 0x0349, "ps3" }, 
    { 0x034A, "ps4" }, 
    { 0x034B, "psoffsettime" }, 
    { 0x034C, "pushable" }, 
    { 0x034D, "radaralwayson" }, 
    { 0x034E, "radarmode" }, 
    { 0x034F, "radarshowenemydirection" }, 
    { 0x0350, "radarstrength" }, 
    { 0x0351, "radius" }, 
    { 0x0352, "ragdoll_early_result" }, 
    { 0x0353, "raise_riotshield" }, 
    { 0x0354, "rank" }, 
    { 0x0355, "rate" }, 
    { 0x0356, "reached_end_node" }, 
    { 0x0357, "reached_wait_node" }, 
    { 0x0358, "reached_wait_speed" }, 
    { 0x0359, "reactiontargetpos" }, 
    { 0x035A, "realtimedelta" }, 
    { 0x035B, "receiver" }, 
    { 0x035C, "recipename" }, 
    { 0x035D, "reciprocality" }, 
    { 0x035E, "reflection_clear_color" }, 
    { 0x035F, "reinforcement" }, 
    { 0x0360, "relativedir" }, 
    { 0x0361, "relativeoffset" }, 
    { 0x0362, "reload" }, 
    { 0x0363, "reload_start" }, 
    { 0x0364, "remotemissilespawn" }, 
    { 0x0365, "rendertotexture" }, 
    { 0x0366, "reportindex" }, 
    { 0x0367, "reports" }, 
    { 0x0368, "reputation" }, 
    { 0x0369, "requestarrivalnotify" }, 
    { 0x036A, "requirement_beat100waves" }, 
    { 0x036B, "requirement_beat200waves" }, 
    { 0x036C, "requirement_beat50waves" }, 
    { 0x036D, "requirement_beatenzombies" }, 
    { 0x036E, "requirement_maxarmorproficiency" }, 
    { 0x036F, "requirement_maxweaponproficiency" }, 
    { 0x0370, "requirement_playedallmaps" }, 
    { 0x0371, "requirement_unlockedprison" }, 
    { 0x0372, "requirement_unlockedtier2" }, 
    { 0x0373, "requirement_unlockedtier3" }, 
    { 0x0374, "reserved" }, 
    { 0x0375, "respawndelay" }, 
    { 0x0376, "result" }, 
    { 0x0377, "reticle" }, 
    { 0x0378, "return_pitch" }, 
    { 0x0379, "reverse" }, 
    { 0x037A, "revives" }, 
    { 0x037B, "right" }, 
    { 0x037C, "rightaimlimit" }, 
    { 0x037D, "rightarc" }, 
    { 0x037E, "riotshield_damaged" }, 
    { 0x037F, "riotshield_hit" }, 
    { 0x0380, "rocket" }, 
    { 0x0381, "rocket_off" }, 
    { 0x0382, "rocket_on" }, 
    { 0x0383, "rotatedone" }, 
    { 0x0384, "rotation" }, 
    { 0x0385, "run" }, 
    { 0x0386, "runcost" }, 
    { 0x0387, "runto_arrived" }, 
    { 0x0388, "safetochangescript" }, 
    { 0x0389, "scavenger" }, 
    { 0x038A, "scope_cap" }, 
    { 0x038B, "scope_center" }, 
    { 0x038C, "scope_top" }, 
    { 0x038D, "score" }, 
    { 0x038E, "script" }, 
    { 0x038F, "script_brushmodel" }, 
    { 0x0390, "script_clut" }, 
    { 0x0391, "script_context" }, 
    { 0x0392, "script_delay" }, 
    { 0x0393, "script_goal_changed" }, 
    { 0x0394, "script_label" }, 
    { 0x0395, "script_lightset" }, 
    { 0x0396, "script_linkname" }, 
    { 0x0397, "script_model" }, 
    { 0x0398, "script_noteworthy" }, 
    { 0x0399, "script_origin" }, 
    { 0x039A, "script_parent" }, 
    { 0x039B, "script_parentname" }, 
    { 0x039C, "script_pushable" }, 
    { 0x039D, "script_vehicle" }, 
    { 0x039E, "script_vehicle_collision" }, 
    { 0x039F, "script_vehicle_collmap" }, 
    { 0x03A0, "script_vehicle_corpse" }, 
    { 0x03A1, "script_visionset" }, 
    { 0x03A2, "script_water" }, 
    { 0x03A3, "script_reverb" }, 
    { 0x03A4, "script_zone" }, 
    { 0x03A5, "scriptable" }, 
    { 0x03A6, "scriptableactor" }, 
    { 0x03A7, "scripted_viewmodel_anim" }, 
    { 0x03A8, "scriptedarrivalent" }, 
    { 0x03A9, "search_end" }, 
    { 0x03AA, "secondary" }, 
    { 0x03AB, "secondaryattachment1" }, 
    { 0x03AC, "secondaryattachment2" }, 
    { 0x03AD, "secondaryattachments" }, 
    { 0x03AE, "secondaryattachkit" }, 
    { 0x03AF, "secondarycamo" }, 
    { 0x03B0, "secondaryfurniturekit" }, 
    { 0x03B1, "secondaryoffhand" }, 
    { 0x03B2, "secondaryreticle" }, 
    { 0x03B3, "secondaryweapon" }, 
    { 0x03B4, "sentry" }, 
    { 0x03B5, "sentry_manual" }, 
    { 0x03B6, "sentry_offline" }, 
    { 0x03B7, "servertimecount" }, 
    { 0x03B8, "servertimeexceedcount" }, 
    { 0x03B9, "servertimemax" }, 
    { 0x03BA, "servertimetotal" }, 
    { 0x03BB, "servertimetotalexceed" }, 
    { 0x03BC, "sessionstate" }, 
    { 0x03BD, "sessionteam" }, 
    { 0x03BE, "sharpturn" }, 
    { 0x03BF, "sharpturnlookaheaddist" }, 
    { 0x03C0, "sharpturnnotifydist" }, 
    { 0x03C1, "sharpturntooclosetodestdist" }, 
    { 0x03C2, "shirt" }, 
    { 0x03C3, "showinkillcam" }, 
    { 0x03C4, "showkillcam" }, 
    { 0x03C5, "sightlatency" }, 
    { 0x03C6, "silenced_shot" }, 
    { 0x03C7, "skill_points" }, 
    { 0x03C8, "skillbucket" }, 
    { 0x03C9, "skillrating" }, 
    { 0x03CA, "skillratingtype" }, 
    { 0x03CB, "slidevelocity" }, 
    { 0x03CC, "slowmo_active" }, 
    { 0x03CD, "slowmo_passive" }, 
    { 0x03CE, "smoke" }, 
    { 0x03CF, "snd_channelvolprio_holdbreath" }, 
    { 0x03D0, "snd_channelvolprio_pain" }, 
    { 0x03D1, "snd_channelvolprio_shellshock" }, 
    { 0x03D2, "snd_enveffectsprio_level" }, 
    { 0x03D3, "snd_enveffectsprio_shellshock" }, 
    { 0x03D4, "sort" }, 
    { 0x03D5, "sound_blend" }, 
    { 0x03D6, "soundeventdone" }, 
    { 0x03D7, "space" }, 
    { 0x03D8, "spawned" }, 
    { 0x03D9, "spawner" }, 
    { 0x03DA, "spawnflags" }, 
    { 0x03DB, "spawnpos" }, 
    { 0x03DC, "spawntime" }, 
    { 0x03DD, "specialgrenade" }, 
    { 0x03DE, "spectatekillcam" }, 
    { 0x03DF, "spectating_cycle" }, 
    { 0x03E0, "spectator" }, 
    { 0x03E1, "speechcommand" }, 
    { 0x03E2, "speed" }, 
    { 0x03E3, "splatter" }, 
    { 0x03E4, "splineplanereachednode" }, 
    { 0x03E5, "sprint_begin" }, 
    { 0x03E6, "sprint_end" }, 
    { 0x03E7, "sprint_slide_begin" }, 
    { 0x03E8, "sprint_slide_end" }, 
    { 0x03E9, "squad_base" }, 
    { 0x03EA, "squad_mode" }, 
    { 0x03EB, "squad_name" }, 
    { 0x03EC, "squadhq" }, 
    { 0x03ED, "squadmembers" }, 
    { 0x03EE, "squadmemxp" }, 
    { 0x03EF, "squadname" }, 
    { 0x03F0, "stairs" }, 
    { 0x03F1, "stairsstate" }, 
    { 0x03F2, "stand" }, 
    { 0x03F3, "start_blend" }, 
    { 0x03F4, "start_move" }, 
    { 0x03F5, "start_ragdoll" }, 
    { 0x03F6, "startdeaths" }, 
    { 0x03F7, "startdeploy_riotshield" }, 
    { 0x03F8, "startingoffsetforlife" }, 
    { 0x03F9, "startkills" }, 
    { 0x03FA, "state_changed" }, 
    { 0x03FB, "statelocked" }, 
    { 0x03FC, "stencil_disable" }, 
    { 0x03FD, "stencil_onesided" }, 
    { 0x03FE, "stencil_twosided" }, 
    { 0x03FF, "stencilfunc_always" }, 
    { 0x0400, "stencilfunc_equal" }, 
    { 0x0401, "stencilfunc_greater" }, 
    { 0x0402, "stencilfunc_greaterequal" }, 
    { 0x0403, "stencilfunc_less" }, 
    { 0x0404, "stencilfunc_lessequal" }, 
    { 0x0405, "stencilfunc_never" }, 
    { 0x0406, "stencilfunc_notequal" }, 
    { 0x0407, "stencilop_decr" }, 
    { 0x0408, "stencilop_decrsat" }, 
    { 0x0409, "stencilop_incr" }, 
    { 0x040A, "stencilop_incrsat" }, 
    { 0x040B, "stencilop_invert" }, 
    { 0x040C, "stencilop_keep" }, 
    { 0x040D, "stencilop_replace" }, 
    { 0x040E, "stencilop_zero" }, 
    { 0x040F, "stop" }, 
    { 0x0410, "stop_soon" }, 
    { 0x0411, "stopanimdistsq" }, 
    { 0x0412, "stopsoonnotifydist" }, 
    { 0x0413, "streak" }, 
    { 0x0414, "streaktype" }, 
    { 0x0415, "suckedashost" }, 
    { 0x0416, "suncolor" }, 
    { 0x0417, "sundirection" }, 
    { 0x0418, "sunlight" }, 
    { 0x0419, "support" }, 
    { 0x041A, "support_level" }, 
    { 0x041B, "suppression" }, 
    { 0x041C, "suppression_end" }, 
    { 0x041D, "suppressionduration" }, 
    { 0x041E, "suppressionmeter" }, 
    { 0x041F, "suppressionstarttime" }, 
    { 0x0420, "suppressionTime" }, 
    { 0x0421, "suppressionwait" }, 
    { 0x0422, "surfacetype" }, 
    { 0x0423, "surprisedbymedistsq" }, 
    { 0x0424, "swimmer" }, 
    { 0x0425, "switched_var_grenade" }, 
    { 0x0426, "syncedmeleetarget" }, 
    { 0x0427, "tactical" }, 
    { 0x0428, "tag" }, 
    { 0x0429, "tag_ai_aim_target" }, 
    { 0x042A, "tag_aim" }, 
    { 0x042B, "tag_aim_animated" }, 
    { 0x042C, "tag_aim_pivot" }, 
    { 0x042D, "tag_barrel" }, 
    { 0x042E, "tag_blade_off" }, 
    { 0x042F, "tag_body" }, 
    { 0x0430, "tag_brass" }, 
    { 0x0431, "tag_brass_2" }, 
    { 0x0432, "tag_butt" }, 
    { 0x0433, "tag_camera" }, 
    { 0x0434, "tag_clip" }, 
    { 0x0435, "tag_clip_dual" }, 
    { 0x0436, "tag_clip_dual2" }, 
    { 0x0437, "tag_detach" }, 
    { 0x0438, "tag_engine_left" }, 
    { 0x0439, "tag_engine_right" }, 
    { 0x043A, "tag_eotech_reticle" }, 
    { 0x043B, "tag_eye" }, 
    { 0x043C, "tag_flash" }, 
    { 0x043D, "tag_flash_11" }, 
    { 0x043E, "tag_flash_2" }, 
    { 0x043F, "tag_flash_22" }, 
    { 0x0440, "tag_flash_3" }, 
    { 0x0441, "tag_flash_launcher" }, 
    { 0x0442, "tag_flash_silenced" }, 
    { 0x0443, "tag_fx" }, 
    { 0x0444, "tag_gasmask" }, 
    { 0x0445, "tag_gasmask2" }, 
    { 0x0446, "tag_ik_ankle_fl" }, 
    { 0x0447, "tag_ik_ankle_fr" }, 
    { 0x0448, "tag_ik_ankle_kl" }, 
    { 0x0449, "tag_ik_ankle_kr" }, 
    { 0x044A, "tag_ik_ankle_ml" }, 
    { 0x044B, "tag_ik_ankle_mr" }, 
    { 0x044C, "tag_ik_footflat_fl" }, 
    { 0x044D, "tag_ik_footflat_fr" }, 
    { 0x044E, "tag_ik_footflat_kl" }, 
    { 0x044F, "tag_ik_footflat_kr" }, 
    { 0x0450, "tag_ik_footflat_ml" }, 
    { 0x0451, "tag_ik_footflat_mr" }, 
    { 0x0452, "tag_ik_hip_fl" }, 
    { 0x0453, "tag_ik_hip_fr" }, 
    { 0x0454, "tag_ik_hip_kl" }, 
    { 0x0455, "tag_ik_hip_kr" }, 
    { 0x0456, "tag_ik_hip_ml" }, 
    { 0x0457, "tag_ik_hip_mr" }, 
    { 0x0458, "tag_ik_knee_fl" }, 
    { 0x0459, "tag_ik_knee_fr" }, 
    { 0x045A, "tag_ik_knee_kl" }, 
    { 0x045B, "tag_ik_knee_kr" }, 
    { 0x045C, "tag_ik_knee_ml" }, 
    { 0x045D, "tag_ik_knee_mr" }, 
    { 0x045E, "tag_ik_loc_le" }, 
    { 0x045F, "tag_ik_loc_le_foregrip" }, 
    { 0x0460, "tag_ik_loc_le_launcher" }, 
    { 0x0461, "tag_ik_loc_le_shotgun" }, 
    { 0x0462, "tag_ik_target" }, 
    { 0x0463, "tag_inhand" }, 
    { 0x0464, "tag_jetblast_fx" }, 
    { 0x0465, "tag_jetpack" }, 
    { 0x0466, "tag_knife_attach" }, 
    { 0x0467, "tag_knife_fx" }, 
    { 0x0468, "tag_laser" }, 
    { 0x0469, "tag_launcher" }, 
    { 0x046A, "tag_magnifier_eotech_reticle" }, 
    { 0x046B, "tag_mobile_cover_upright" }, 
    { 0x046C, "tag_motion_tracker_bl" }, 
    { 0x046D, "tag_motion_tracker_br" }, 
    { 0x046E, "tag_motion_tracker_fx" }, 
    { 0x046F, "tag_motion_tracker_tl" }, 
    { 0x0470, "tag_origin" }, 
    { 0x0471, "tag_player" }, 
    { 0x0472, "tag_popout" }, 
    { 0x0473, "tag_rail_master_off" }, 
    { 0x0474, "tag_rail_master_on" }, 
    { 0x0475, "tag_rail_side_off" }, 
    { 0x0476, "tag_rail_side_on" }, 
    { 0x0477, "tag_reticle_acog" }, 
    { 0x0478, "tag_reticle_default" }, 
    { 0x0479, "tag_reticle_default2" }, 
    { 0x047A, "tag_reticle_hamr" }, 
    { 0x047B, "tag_reticle_on" }, 
    { 0x047C, "tag_reticle_red_dot" }, 
    { 0x047D, "tag_reticle_reflex" }, 
    { 0x047E, "tag_reticle_tavor_scope" }, 
    { 0x047F, "tag_reticle_thermal_scope" }, 
    { 0x0480, "tag_rider" }, 
    { 0x0481, "tag_riot_shield" }, 
    { 0x0482, "tag_rocket" }, 
    { 0x0483, "tag_scope_ads_off" }, 
    { 0x0484, "tag_scope_ads_on" }, 
    { 0x0485, "tag_shield_back" }, 
    { 0x0486, "tag_shotgun" }, 
    { 0x0487, "tag_show_alt" }, 
    { 0x0488, "tag_sight_off" }, 
    { 0x0489, "tag_sight_on" }, 
    { 0x048A, "tag_stow_back_mid_attach" }, 
    { 0x048B, "tag_stowed_back" }, 
    { 0x048C, "tag_stowed_hip_rear" }, 
    { 0x048D, "tag_sync" }, 
    { 0x048E, "tag_tip" }, 
    { 0x048F, "tag_turret" }, 
    { 0x0490, "tag_turret_base" }, 
    { 0x0491, "tag_turret_pitch" }, 
    { 0x0492, "tag_turret_yaw" }, 
    { 0x0493, "tag_weapon" }, 
    { 0x0494, "tag_weapon_chest" }, 
    { 0x0495, "tag_weapon_left" }, 
    { 0x0496, "tag_weapon_right" }, 
    { 0x0497, "tag_wheel_back_left" }, 
    { 0x0498, "tag_wheel_back_right" }, 
    { 0x0499, "tag_wheel_front_left" }, 
    { 0x049A, "tag_wheel_front_right" }, 
    { 0x049B, "tag_wheel_middle_left" }, 
    { 0x049C, "tag_wheel_middle_right" }, 
    { 0x049D, "tag_wheel_spin_left01" }, 
    { 0x049E, "tag_wheel_spin_left02" }, 
    { 0x049F, "tag_wheel_spin_left03" }, 
    { 0x04A0, "tag_wheel_spin_right01" }, 
    { 0x04A1, "tag_wheel_spin_right02" }, 
    { 0x04A2, "tag_wheel_spin_right03" }, 
    { 0x04A3, "takedamage" }, 
    { 0x04A4, "target" }, 
    { 0x04A5, "target_script_trigger" }, 
    { 0x04A6, "targetname" }, 
    { 0x04A7, "team" }, 
    { 0x04A8, "team3" }, 
    { 0x04A9, "teambalanced" }, 
    { 0x04AA, "teammode_axisallies" }, 
    { 0x04AB, "teammode_ffa" }, 
    { 0x04AC, "teammovewaittime" }, 
    { 0x04AD, "their_score" }, 
    { 0x04AE, "thermal" }, 
    { 0x04AF, "thermalbodymaterial" }, 
    { 0x04B0, "third_person" }, 
    { 0x04B1, "threatbias" }, 
    { 0x04B2, "threatbiasgroup" }, 
    { 0x04B3, "threatsightdelayenabled" }, 
    { 0x04B4, "threatsightdelayfalloff" }, 
    { 0x04B5, "threshold" }, 
    { 0x04B6, "throwingknife" }, 
    { 0x04B7, "time" }, 
    { 0x04B8, "timeplayedtotal" }, 
    { 0x04B9, "titlenew" }, 
    { 0x04BA, "titleunlocked" }, 
    { 0x04BB, "top" }, 
    { 0x04BC, "toparc" }, 
    { 0x04BD, "totalxp" }, 
    { 0x04BE, "touch" }, 
    { 0x04BF, "touching_platform" }, 
    { 0x04C0, "traverse_complete" }, 
    { 0x04C1, "traverse_soon" }, 
    { 0x04C2, "traversecost" }, 
    { 0x04C3, "traversesoonnotifydist" }, 
    { 0x04C4, "trend" }, 
    { 0x04C5, "trigger" },
    { 0x04C6, "trigger_damage" },
    { 0x04C7, "trigger_use" },
    { 0x04C8, "trigger_use_touch" },
    { 0x04C9, "truck_cam" },
//	{ 0x04CA, "turnanim_unknown" },
    { 0x04CB, "turnrate" },
    { 0x04CC, "turret_deactivate" },
    { 0x04CD, "turret_fire" },
    { 0x04CE, "turret_no_vis" },
    { 0x04CF, "turret_not_on_target" },
    { 0x04D0, "turret_on_target" },
    { 0x04D1, "turret_on_vistarget" },
    { 0x04D2, "turret_pitch_clamped" },
    { 0x04D3, "turret_rotate_stopped" },
    { 0x04D4, "turret_yaw_clamped" },
    { 0x04D5, "turretinvulnerability" },
//	{ 0x04D6, "turretignore_unknown" },
    { 0x04D7, "turretownerchange" },
    { 0x04D8, "turretstatechange" },
    { 0x04D9, "type" }, 
    { 0x04DA, "ucdidhigh" }, 
    { 0x04DB, "ucdidlow" }, 
    { 0x04DC, "unlockedcamo" }, 
    { 0x04DD, "unlockedreticles" }, 
    { 0x04DE, "unlockpoints" }, 
    { 0x04DF, "unresolved_collision" }, 
    { 0x04E0, "up" }, 
    { 0x04E1, "upaimlimit" }, 
    { 0x04E2, "upgradechallengeprogress" }, 
    { 0x04E3, "upgradechallengestage" }, 
    { 0x04E4, "upgradepoints" }, 
    { 0x04E5, "upgradepurchased" }, 
    { 0x04E6, "useable" }, 
    { 0x04E7, "usechokepoints" }, 
    { 0x04E8, "usecombatscriptatcover" }, 
    { 0x04E9, "usedemblemslots" }, 
    { 0x04EA, "useorcaavoidance" }, 
    { 0x04EB, "usepathsmoothingvalues" }, 
    { 0x04EC, "veh_boatbounce" }, 
    { 0x04ED, "veh_boost_activated" }, 
    { 0x04EE, "veh_boost_deactivated" }, 
    { 0x04EF, "veh_brake" }, 
    { 0x04F0, "veh_collision" }, 
    { 0x04F1, "veh_contact" }, 
    { 0x04F2, "veh_jolt" }, 
    { 0x04F3, "veh_landed" }, 
    { 0x04F4, "veh_leftground" }, 
    { 0x04F5, "veh_pathdir" }, 
    { 0x04F6, "veh_pathspeed" }, 
    { 0x04F7, "veh_pathtype" }, 
    { 0x04F8, "veh_predictedcollision" }, 
    { 0x04F9, "veh_speed" }, 
    { 0x04FA, "veh_throttle" }, 
    { 0x04FB, "veh_topspeed" }, 
    { 0x04FC, "veh_transmission" }, 
    { 0x04FD, "vehicle_dismount" }, 
    { 0x04FE, "vehicle_mount" }, 
    { 0x04FF, "vehicletype" }, 
    { 0x0500, "velocity" },
    { 0x0501, "vertalign" }, 
    { 0x0502, "visionsetmissilecam" }, 
    { 0x0503, "visionsetmissilecamduration" }, 
    { 0x0504, "visionsetnaked" }, 
    { 0x0505, "visionsetnakedduration" }, 
    { 0x0506, "visionsetnight" }, 
    { 0x0507, "visionsetnightduration" }, 
    { 0x0508, "visionsetpain" }, 
    { 0x0509, "visionsetpainduration" }, 
    { 0x050A, "visionsetthermal" }, 
    { 0x050B, "visionsetthermalduration" }, 
    { 0x050C, "vote" }, 
    { 0x050D, "wait" }, 
    { 0x050E, "walk" }, 
    { 0x050F, "walkdist" }, 
    { 0x0510, "walkdistfacingmotion" }, 
    { 0x0511, "wastacticalinsertion" }, 
    { 0x0512, "waypoint_reached" }, 
    { 0x0513, "weapon" }, 
    { 0x0514, "weapon_change" }, 
    { 0x0515, "weapon_dropped" }, 
    { 0x0516, "weapon_fired" }, 
    { 0x0517, "weapon_model_change" }, 
    { 0x0518, "weapon_switch_invalid" }, 
    { 0x0519, "weapon_switch_started" }, 
    { 0x051A, "weapon_taken" }, 
    { 0x051B, "weaponchange" }, 
    { 0x051C, "weaponclassrestricted" }, 
    { 0x051D, "weaponinfo" }, 
    { 0x051E, "weaponrank" }, 
    { 0x051F, "weaponrestricted" }, 
    { 0x0520, "weaponsetups" }, 
    { 0x0521, "weaponstats" }, 
    { 0x0522, "weeklychallengeid" }, 
    { 0x0523, "weight" }, 
    { 0x0524, "width" }, 
    { 0x0525, "wildcard1" }, 
    { 0x0526, "wildcard2" }, 
    { 0x0527, "wildcard3" }, 
    { 0x0528, "wildcardslots" }, 
    { 0x0529, "win_streak" }, 
    { 0x052A, "winlossratio" }, 
    { 0x052B, "wins" }, 
    { 0x052C, "won_match" }, 
    { 0x052D, "world" }, 
    { 0x052E, "worldmodel" }, 
    { 0x052F, "worldspawn" }, 
    { 0x0530, "x" }, 
    { 0x0531, "xb3" }, 
    { 0x0532, "xenon" }, 
    { 0x0533, "xp" }, 
    { 0x0534, "xp_multiplier" }, 
    { 0x0535, "xpmaxmultipliertimeplayed" }, 
    { 0x0536, "xpmultiplier" }, 
    { 0x0537, "xuid" }, 
    { 0x0538, "y" }, 
    { 0x0539, "yawconvergencetime" }, 
    { 0x053A, "your_score" }, 
    { 0x053B, "z" }, 
    { 0x053C, "zonly_physics" }, 
    { 0x053D, "codescripts/delete" },
    { 0x053E, "codescripts/struct" },
    { 0x053F, "codescripts/message" },
    { 0x0540, "maps/mp/gametypes/_callbacksetup" },
    { 0x0541, "__smangles" },
    { 0x0542, "__smid" },
    { 0x0543, "__smname" },
    { 0x0544, "__smorigin" },
    { 0x0545, "_abortdefendlocation" },
    { 0x0546, "_adddropmarkerinternal" },
    { 0x0547, "_adjustcamerayawpitchrate" },
    { 0x0548, "_advancetogoal" },
    { 0x0549, "_ai_delete" },
    { 0x054A, "_ai_group" },
    { 0x054B, "_ai_health" },
    { 0x054C, "_aliveplayers" },
    { 0x054D, "_allowalternatemelee" },
    { 0x054E, "_allowweaponpickup" },
    { 0x054F, "_ams" },
    { 0x0550, "_animactive" },
    { 0x0551, "_anime" },
    { 0x0552, "_animmode" },
    { 0x0553, "_animname" },
    { 0x0554, "_anims" },
    { 0x0555, "_anims_drone" },
    { 0x0556, "_anims_player" },
    { 0x0557, "_anims_proxy" },
    { 0x0558, "_array_wait" },
    { 0x0559, "_assignnewvehicleturretuser" },
    { 0x055A, "_attachfanclip" },
    { 0x055B, "_audio" },
    { 0x055C, "_autosave_game_now" },
    { 0x055D, "_autosave_game_now_nochecks" },
    { 0x055E, "_autosave_game_now_notrestart" },
    { 0x055F, "_autosave_stealthcheck" },
    { 0x0560, "_beginlocationselection" },
    { 0x0561, "_bootup_static" },
    { 0x0562, "_cangiveability" },
    { 0x0563, "_caralarmfx" },
    { 0x0564, "_caralarmstop" },
    { 0x0565, "_cleanupshootinglocationondeath" },
    { 0x0566, "_clearabilities" },
    { 0x0567, "_clearalltextafterhudelem" },
    { 0x0568, "_clearcharacterdialogondeath" },
    { 0x0569, "_clearcharacterdialogonnotify" },
    { 0x056A, "_clearentitytarget" },
    { 0x056B, "_clearperks" },
    { 0x056C, "_clearradiodialogondeath" },
    { 0x056D, "_clearworlddialogonnotify" },
    { 0x056E, "_cloak_enemy_array" },
    { 0x056F, "_cloak_enemy_state" },
    { 0x0570, "_cloak_toggle_internal" },
    { 0x0571, "_cloaked_stealth_settings" },
    { 0x0572, "_closingdistancecheck" },
    { 0x0573, "_color" },
    { 0x0574, "_colors_go_line" },
    { 0x0575, "_createfx" },
    { 0x0576, "_createhudline" },
    { 0x0577, "_custom_anim" },
    { 0x0578, "_custom_anim_loop" },
    { 0x0579, "_custom_anim_thread" },
    { 0x057A, "_debug_vector_to_string" },
    { 0x057B, "_defendlocation" },
    { 0x057C, "_delaygrenadethrow" },
    { 0x057D, "_delete" },
    { 0x057E, "_destroyprojectileafterdelay" },
    { 0x057F, "_destructible_preanims" },
    { 0x0580, "_destructible_preanimtree" },
    { 0x0581, "_detachall" },
    { 0x0582, "_determineallynodescore" },
    { 0x0583, "_determineshotgunnodescore" },
    { 0x0584, "_dialogtablelookup" },
    { 0x0585, "_disableoffhandweapons" },
    { 0x0586, "_disableusability" },
    { 0x0587, "_disableweapon" },
    { 0x0588, "_disableweaponswitch" },
    { 0x0589, "_displayhelpertext" },
    { 0x058A, "_displayrechargehelpertext" },
    { 0x058B, "_dmg" },
    { 0x058C, "_do_a_lil_damage_and_heal" },
    { 0x058D, "_drawdebug" },
    { 0x058E, "_earthquake" },
    { 0x058F, "_effect" },
    { 0x0590, "_effect_keys" },
    { 0x0591, "_enabledetonate" },
    { 0x0592, "_enableexplosivedeath" },
    { 0x0593, "_enableoffhandweapons" },
    { 0x0594, "_enableusability" },
    { 0x0595, "_enableweapon" },
    { 0x0596, "_enableweaponswitch" },
    { 0x0597, "_ensure_player_is_decloaked" },
    { 0x0598, "_evaluatebuddycovernodes" },
    { 0x0599, "_evaluatenodeattackradius" },
    { 0x059A, "_evaluatenodeinplayerfov" },
    { 0x059B, "_evaluatenodeiscover" },
    { 0x059C, "_evaluatenodeisexposed" },
    { 0x059D, "_evaluatenodeknownenemyinradius" },
    { 0x059E, "_evaluatenodelostoplayer" },
    { 0x059F, "_evaluatenodeothershotgunnersbest" },
    { 0x05A0, "_evaluatenodeplayerinradius" },
    { 0x05A1, "_evaluatenodeplayervisibility" },
    { 0x05A2, "_evaluatenoderangetoplayer" },
    { 0x05A3, "_evaluateshotgunnercovernodes" },
    { 0x05A4, "_exit" },
    { 0x05A5, "_exit_menu" },
    { 0x05A6, "_extended_patrol_idle_animation_list_func" },
    { 0x05A7, "_extra_autosave_checks" },
    { 0x05A8, "_facility" },
    { 0x05A9, "_fastopen" },
    { 0x05AA, "_findfleelocation" },
    { 0x05AB, "_findnewvehicleturretuser" },
    { 0x05AC, "_fire" },
    { 0x05AD, "_first_frame_anim" },
    { 0x05AE, "_flag_wait_trigger" },
    { 0x05AF, "_force_kill" },
    { 0x05B0, "_freevehicle" },
    { 0x05B1, "_frozen_controls" },
    { 0x05B2, "_fx" },
    { 0x05B3, "_get_dummy" },
    { 0x05B4, "_get_if_defined_or_default" },
    { 0x05B5, "_getindex" },
    { 0x05B6, "_getmodulekillstreakweapon" },
    { 0x05B7, "_getpaintoutline" },
    { 0x05B8, "_getplayerscore" },
    { 0x05B9, "_getradarstrength" },
    { 0x05BA, "_getrandomorginfrontofplayer" },
    { 0x05BB, "_getscrambletypeidforstring" },
    { 0x05BC, "_getteampaintoutline" },
    { 0x05BD, "_getteamscore" },
    { 0x05BE, "_getvehiclespawnerarray" },
    { 0x05BF, "_getvehiclespawnerarray_by_spawngroup" },
    { 0x05C0, "_giveweapon" },
    { 0x05C1, "_glass_physics_wakeup" },
    { 0x05C2, "_glass_physics_wakeup_update" },
    { 0x05C3, "_global_fx_ents" },
    { 0x05C4, "_goalblockedbyai" },
    { 0x05C5, "_goalblockedbyplayer" },
    { 0x05C6, "_gopath" },
    { 0x05C7, "_group" },
    { 0x05C8, "_handle_triggers_on" },
    { 0x05C9, "_handlebreachgrenade" },
    { 0x05CA, "_hasability" },
    { 0x05CB, "_hasperk" },
    { 0x05CC, "_hint_stick_get_config_suffix" },
    { 0x05CD, "_hint_stick_update_breakfunc" },
    { 0x05CE, "_hint_stick_update_string" },
    { 0x05CF, "_ignore_settings_old" },
    { 0x05D0, "_initalliedaialleycombatbehavior" },
    { 0x05D1, "_initsafehouseexitkvabehavior" },
    { 0x05D2, "_insertintoglobalusablelist" },
    { 0x05D3, "_interactive" },
    { 0x05D4, "_investigate_last_known_position_with_endons" },
    { 0x05D5, "_investigate_last_known_position_wrapper" },
    { 0x05D6, "_is_godmode" },
    { 0x05D7, "_isairplane" },
    { 0x05D8, "_ishelicopter" },
    { 0x05D9, "_kill" },
    { 0x05DA, "_kill_fx" },
    { 0x05DB, "_lastanimtime" },
    { 0x05DC, "_lastwave" },
    { 0x05DD, "_lc" },
    { 0x05DE, "_lc_persists" },
    { 0x05DF, "_leaderdialogwait" },
    { 0x05E0, "_light" },
    { 0x05E1, "_linkto" },
    { 0x05E2, "_listen_drone_input" },
    { 0x05E3, "_listen_for_hold_to_exit" },
    { 0x05E4, "_listen_for_hold_to_exit_set_flags" },
    { 0x05E5, "_loadstarted" },
    { 0x05E6, "_make_overlay" },
    { 0x05E7, "_manage_timer" },
    { 0x05E8, "_mark_newlyspawned" },
    { 0x05E9, "_max_script_health" },
    { 0x05EA, "_mb" },
    { 0x05EB, "_mech_globals" },
    { 0x05EC, "_mech_hunt_baghdad" },
    { 0x05ED, "_mech_node" },
    { 0x05EE, "_mech_occupied" },
    { 0x05EF, "_mgoff" },
    { 0x05F0, "_mgon" },
    { 0x05F1, "_missile_strike_setting" },
    { 0x05F2, "_missilemissedtargetcheck" },
    { 0x05F3, "_missing_fx" },
    { 0x05F4, "_monitor_controls" },
    { 0x05F5, "_monitor_damage" },
    { 0x05F6, "_monitor_health" },
    { 0x05F7, "_monitor_regen" },
    { 0x05F8, "_monitor_static" },
    { 0x05F9, "_monitor_threat_count" },
    { 0x05FA, "_monitor_touch" },
    { 0x05FB, "_monitor_volume_array" },
    { 0x05FC, "_mount_snowmobile" },
    { 0x05FD, "_newhudelem" },
    { 0x05FE, "_nextcoverprint" },
    { 0x05FF, "_nextmission" },
    { 0x0600, "_normalbehavior" },
    { 0x0601, "_notetrackfx" },
    { 0x0602, "_obituary" },
    { 0x0603, "_objective_delete" },
    { 0x0604, "_offset_position_from_tag" },
    { 0x0605, "_old_visionset" },
    { 0x0606, "_orbital_care_pod" },
    { 0x0607, "_orbital_strike_setting" },
    { 0x0608, "_patrol_endon_spotted_flag" },
    { 0x0609, "_pdrone_player_exit_return_control" },
    { 0x060A, "_pdrone_player_proxy" },
    { 0x060B, "_pdrone_player_proxy_clear" },
    { 0x060C, "_pdrone_player_proxy_delicate_flower" },
    { 0x060D, "_pdrone_stop_use_anim" },
    { 0x060E, "_pipe_fx_time" },
    { 0x060F, "_pipe_methods" },
    { 0x0610, "_pipes" },
    { 0x0611, "_play_view_model_cloak_toggle_anim" },
    { 0x0612, "_playerallow" },
    { 0x0613, "_playercleanupscrambleevents" },
    { 0x0614, "_playergetnextevent" },
    { 0x0615, "_playergetscrambleevent" },
    { 0x0616, "_playergetuniquescrambleid" },
    { 0x0617, "_playermonitorscrambleevents" },
    { 0x0618, "_playlocalsound" },
    { 0x0619, "_popopen" },
    { 0x061A, "_precache" },
    { 0x061B, "_pursueenemy" },
    { 0x061C, "_radio_queue" },
    { 0x061D, "_radiusdamage" },
    { 0x061E, "_randommissilemovement" },
    { 0x061F, "_reactionanimation" },
    { 0x0620, "_reduce_hud_target_count_on_death" },
    { 0x0621, "_remove_drone_control" },
    { 0x0622, "_remove_hud" },
    { 0x0623, "_remove_hud_on_death" },
    { 0x0624, "_remove_hudoutline_on_enemies" },
    { 0x0625, "_remove_overlay_static" },
    { 0x0626, "_remove_shield" },
    { 0x0627, "_reset_dvars" },
    { 0x0628, "_restorepreviousnameplatematerial" },
    { 0x0629, "_returnanimorigin" },
    { 0x062A, "_rotateprop" },
    { 0x062B, "_rotateyaw" },
    { 0x062C, "_s2walk" },
    { 0x062D, "_save_dvars" },
    { 0x062E, "_script_exploders" },
    { 0x062F, "_scripted_spawn" },
    { 0x0630, "_set_dvars" },
    { 0x0631, "_set_hudoutline_on_enemies" },
    { 0x0632, "_set_overlay_static_alpha" },
    { 0x0633, "_setability" },
    { 0x0634, "_setactionslot" },
    { 0x0635, "_setentitytarget" },
    { 0x0636, "_sethighestmissionifnotcheating" },
    { 0x0637, "_sethudoutline" },
    { 0x0638, "_sethudoutline_on_spawn" },
    { 0x0639, "_setlightintensity" },
    { 0x063A, "_setmissiondiffstringifnotcheating" },
    { 0x063B, "_setnameplatematerial" },
    { 0x063C, "_setperk" },
    { 0x063D, "_setplayerscore" },
    { 0x063E, "_setsaveddvar" },
    { 0x063F, "_setswitchnode" },
    { 0x0640, "_setteamscore" },
    { 0x0641, "_settext" },
    { 0x0642, "_setup_hud" },
    { 0x0643, "_setup_overlay_static" },
    { 0x0644, "_setupdooranimstyle" },
    { 0x0645, "_setvehgoalpos" },
    { 0x0646, "_setvehgoalpos_wrap" },
    { 0x0647, "_shotgunneradvance" },
    { 0x0648, "_shotgunnerambience" },
    { 0x0649, "_shotgunnerdamagefunction" },
    { 0x064A, "_shotgunnerdeath" },
    { 0x064B, "_show_contols" },
    { 0x064C, "_slomo_breach_blowback_guy" },
    { 0x064D, "_slomo_breach_c4_hostage" },
    { 0x064E, "_slomo_breach_chair_guy_animated" },
    { 0x064F, "_slomo_breach_chair_guy_normal" },
    { 0x0650, "_slomo_breach_desk_guy" },
    { 0x0651, "_slomo_breach_executed_guy" },
    { 0x0652, "_slomo_breach_executed_guy_pushed_to_floor" },
    { 0x0653, "_slomo_breach_executioner_knife" },
    { 0x0654, "_slomo_breach_executioner_pistol" },
    { 0x0655, "_slomo_breach_fightback_guy" },
    { 0x0656, "_slomo_breach_hostage_react" },
    { 0x0657, "_slomo_breach_knife_charger" },
    { 0x0658, "_slomo_breach_knife_hostage_death" },
    { 0x0659, "_slomo_breach_pistol_guy" },
    { 0x065A, "_slowmo_breach_funcs" },
    { 0x065B, "_slowmo_functions" },
    { 0x065C, "_slowopen" },
    { 0x065D, "_snd" },
    { 0x065E, "_snd_update_soundcontextoverride" },
    { 0x065F, "_sonicaoeanim" },
    { 0x0660, "_sonicaoenotready" },
    { 0x0661, "_sortbyscore" },
    { 0x0662, "_sound" },
    { 0x0663, "_spawner_mg42_think" },
    { 0x0664, "_spawner_stealth_default" },
    { 0x0665, "_spawntargetnamegotogoal" },
    { 0x0666, "_squaddoorbreach" },
    { 0x0667, "_startdooropen" },
    { 0x0668, "_state_init" },
    { 0x0669, "_stealth" },
    { 0x066A, "_stealth_move_detection_cap" },
    { 0x066B, "_stop_mech_hunt_baghdad" },
    { 0x066C, "_stunassaultdrones" },
    { 0x066D, "_stuncivilians" },
    { 0x066E, "_stunenemies" },
    { 0x066F, "_suicide" },
    { 0x0670, "_tag_entity" },
    { 0x0671, "_takeweaponsexcept" },
    { 0x0672, "_teleportleashbehavior" },
    { 0x0673, "_tff_sync_trigger_think" },
    { 0x0674, "_tff_sync_triggers" },
    { 0x0675, "_threatdetection" },
    { 0x0676, "_timeout" },
    { 0x0677, "_timeout_pause_on_death_and_prematch" },
    { 0x0678, "_trigger_handle_triggering" },
    { 0x0679, "_unlink" },
    { 0x067A, "_unsetability" },
    { 0x067B, "_unsetperk" },
    { 0x067C, "_updatebuddycovernodes" },
    { 0x067D, "_updateenemygroupdirection" },
    { 0x067E, "_updateenemyusable" },
    { 0x067F, "_updatepainamount" },
    { 0x0680, "_updateshotgunnercovernodes" },
    { 0x0681, "_updateteamusable" },
    { 0x0682, "_useperkenabled" },
    { 0x0683, "_validateattacker" },
    { 0x0684, "_vehicle_badplace" },
    { 0x0685, "_vehicle_effect" },
    { 0x0686, "_vehicle_effect_custom_param" },
    { 0x0687, "_vehicle_is_crashing" },
    { 0x0688, "_vehicle_landvehicle" },
    { 0x0689, "_vehicle_paths" },
    { 0x068A, "_vehicle_resume_named" },
    { 0x068B, "_vehicle_spawn" },
    { 0x068C, "_vehicle_stop_named" },
    { 0x068D, "_vehicle_unload" },
    { 0x068E, "_vehicleturretreenable" },
    { 0x068F, "_vmodel_anims" },
    { 0x0690, "_vmodel_enter" },
    { 0x0691, "_vmodel_exit" },
    { 0x0692, "_vmodel_sway" },
    { 0x0693, "_vol" },
    { 0x0694, "_wait" },
    { 0x0695, "_waittillgoalornewgoal" },
    { 0x0696, "_waittillmatch" },
    { 0x0697, "_waittillmatch_notify" },
    { 0x0698, "_walk" },
    { 0x0699, "_wavedelay" },
    { 0x069A, "_waveplayerspawnindex" },
    { 0x069B, "a10_30mm_fire" },
    { 0x069C, "a10_fire_missiles" },
    { 0x069D, "a10_gun_dives" },
    { 0x069E, "a10_missile_dives" },
    { 0x069F, "a10_missile_set_target" },
    { 0x06A0, "a10_precache" },
    { 0x06A1, "a10_spawn_funcs" },
    { 0x06A2, "a10_wait_fire_missile" },
    { 0x06A3, "a10_wait_start_firing" },
    { 0x06A4, "a10_wait_stop_firing" },
    { 0x06A5, "aa_add_event" },
    { 0x06A6, "aa_add_event_float" },
    { 0x06A7, "aa_ai_functions" },
    { 0x06A8, "aa_door_functions" },
    { 0x06A9, "aa_explosion" },
    { 0x06AA, "aa_init_stats" },
    { 0x06AB, "aa_player_ads_tracking" },
    { 0x06AC, "aa_player_attacks_enemy_with_ads" },
    { 0x06AD, "aa_player_health_tracking" },
    { 0x06AE, "aa_print_vals" },
    { 0x06AF, "aa_should_start_fresh" },
    { 0x06B0, "aa_spawning_functions" },
    { 0x06B1, "aa_time_tracking" },
    { 0x06B2, "aa_update_flags" },
    { 0x06B3, "abandon_mission_warning_hint" },
    { 0x06B4, "abanglecutoff" },
    { 0x06B5, "abilities" },
    { 0x06B6, "abilitycansetfuncs" },
    { 0x06B7, "abilitychosen" },
    { 0x06B8, "abilitysetfuncs" },
    { 0x06B9, "abilityunsetfuncs" },
    { 0x06BA, "abort" },
    { 0x06BB, "abort_count" },
    { 0x06BC, "abort_drones" },
    { 0x06BD, "abort_wait_any_func_array" },
    { 0x06BE, "abortapproachifthreatened" },
    { 0x06BF, "abortlevel" },
    { 0x06C0, "abortreloadwhencanshoot" },
    { 0x06C1, "about_to_stop" },
    { 0x06C2, "about_to_unload" },
    { 0x06C3, "abouttobebreached" },
    { 0x06C4, "absangleclamp180" },
    { 0x06C5, "absyawtoangles" },
    { 0x06C6, "absyawtoenemy" },
    { 0x06C7, "absyawtoenemy2d" },
    { 0x06C8, "absyawtoorigin" },
    { 0x06C9, "absz" },
    { 0x06CA, "abyss_player_kill" },
    { 0x06CB, "ac_duct" },
    { 0x06CC, "ac_duct_01" },
    { 0x06CD, "ac_duct_02" },
    { 0x06CE, "ac130" },
    { 0x06CF, "ac130_flood_respawn" },
    { 0x06D0, "ac130gunner" },
    { 0x06D1, "ac130player" },
    { 0x06D2, "accaracy_mod" },
    { 0x06D3, "accel" },
    { 0x06D4, "accel_watcher" },
    { 0x06D5, "accelerating" },
    { 0x06D6, "acceltime" },
    { 0x06D7, "accessallmarkers" },
    { 0x06D8, "accumulated_restore" },
    { 0x06D9, "accumulateplayerpingdata" },
    { 0x06DA, "accuracy_fake_function" },
    { 0x06DB, "accuracygrowthmultiplier" },
    { 0x06DC, "accuracystationarymod" },
    { 0x06DD, "achieve_downed_kills" },
    { 0x06DE, "achieve_slowmo_breach_kills" },
    { 0x06DF, "achievement" },
    { 0x06E0, "achievement_attacker" },
    { 0x06E1, "achievementsniperdronetriplekill" },
    { 0x06E2, "acquire_target" },
    { 0x06E3, "acquired_animation" },
    { 0x06E4, "acquiring_dogfight_target" },
    { 0x06E5, "acquiring_lock_target" },
    { 0x06E6, "action_back" },
    { 0x06E7, "action_func" },
    { 0x06E8, "action_gears" },
    { 0x06E9, "action_killstreak" },
    { 0x06EA, "action_leaderboards" },
    { 0x06EB, "action_slot_num" },
    { 0x06EC, "action_slot_whistle" },
    { 0x06ED, "action_thread" },
    { 0x06EE, "action_weapons_primary" },
    { 0x06EF, "action_weapons_secondary" },
    { 0x06F0, "actionnotify" },
    { 0x06F1, "actionnotifymessage" },
    { 0x06F2, "actionslotenabled" },
    { 0x06F3, "actionslots" },
    { 0x06F4, "activate_betrayal_exo_abilities" },
    { 0x06F5, "activate_clientside_exploder" },
    { 0x06F6, "activate_color_code_internal" },
    { 0x06F7, "activate_destructibles_in_volume" },
    { 0x06F8, "activate_exo_ping" },
    { 0x06F9, "activate_exploder" },
    { 0x06FA, "activate_exploders_in_volume" },
    { 0x06FB, "activate_guy" },
    { 0x06FC, "activate_heater" },
    { 0x06FD, "activate_individual_exploder" },
    { 0x06FE, "activate_individual_exploder_proc" },
    { 0x06FF, "activate_interactives_in_volume" },
    { 0x0700, "activate_mute_volume" },
    { 0x0701, "activate_security_drone" },
    { 0x0702, "activate_splashes" },
    { 0x0703, "activate_takedown_world_prompt_on_enemy" },
    { 0x0704, "activate_takedown_world_prompt_on_truck_enemy" },
    { 0x0705, "activate_targets" },
    { 0x0706, "activate_trigger" },
    { 0x0707, "activate_trigger_process" },
    { 0x0708, "activate_trigger_when_player_jumps" },
    { 0x0709, "activate_trigger_with_noteworthy" },
    { 0x070A, "activate_trigger_with_targetname" },
    { 0x070B, "activateagent" },
    { 0x070C, "activategroupedtridrones" },
    { 0x070D, "activateplayerhud" },
    { 0x070E, "activateratio" },
    { 0x070F, "activatethermal" },
    { 0x0710, "activation_cost" },
    { 0x0711, "active_boats" },
    { 0x0712, "active_button" },
    { 0x0713, "active_civilians" },
    { 0x0714, "active_cloaking_disable" },
    { 0x0715, "active_cloaking_enable" },
    { 0x0716, "active_drones" },
    { 0x0717, "active_events" },
    { 0x0718, "active_events_axis" },
    { 0x0719, "active_ffa_players" },
    { 0x071A, "active_objective" },
    { 0x071B, "active_vo_lockouts" },
    { 0x071C, "active_wait_spread" },
    { 0x071D, "activecounteruavs" },
    { 0x071E, "activefriendlyspawn" },
    { 0x071F, "activegrenadetimer" },
    { 0x0720, "activehordedefendlocs" },
    { 0x0721, "activenodes" },
    { 0x0722, "activeplayers" },
    { 0x0723, "activestyle" },
    { 0x0724, "activetarget" },
    { 0x0725, "activeuavs" },
    { 0x0726, "activeweapon" },
    { 0x0727, "actor_alarm_guard" },
    { 0x0728, "actor_anims" },
    { 0x0729, "actor_playscene_walker_stepover_cormack" },
    { 0x072A, "actor_playscene_walker_stepover_jackson" },
    { 0x072B, "actor_playscene_walker_stepover_will" },
    { 0x072C, "actual_spawn" },
    { 0x072D, "ad_offset_position_from_tag" },
    { 0x072E, "add_abort" },
    { 0x072F, "add_agents_to_game" },
    { 0x0730, "add_ai_to_colors" },
    { 0x0731, "add_and_select_entity" },
    { 0x0732, "add_animation" },
    { 0x0733, "add_animsound" },
    { 0x0734, "add_array_to_destructible" },
    { 0x0735, "add_avatar" },
    { 0x0736, "add_basement_enemy_flashlight" },
    { 0x0737, "add_bcs_location_mapping" },
    { 0x0738, "add_breach_func" },
    { 0x0739, "add_burke_flashlight" },
    { 0x073A, "add_button" },
    { 0x073B, "add_c4_glow" },
    { 0x073C, "add_call" },
    { 0x073D, "add_capture_enemy_momentum" },
    { 0x073E, "add_capture_friendly_momentum" },
    { 0x073F, "add_cellphone_notetracks" },
    { 0x0740, "add_cheap_flashlight" },
    { 0x0741, "add_cleanup_ent" },
    { 0x0742, "add_collision_offsets_to_path_ent" },
    { 0x0743, "add_collision_to_path" },
    { 0x0744, "add_collision_to_path_node" },
    { 0x0745, "add_contrail" },
    { 0x0746, "add_control_based_hint_strings" },
    { 0x0747, "add_coop_scene_models" },
    { 0x0748, "add_cover_node" },
    { 0x0749, "add_damage_function" },
    { 0x074A, "add_damage_fx" },
    { 0x074B, "add_damage_owner_recorder" },
    { 0x074C, "add_damagefeedback" },
    { 0x074D, "add_dds_category" },
    { 0x074E, "add_dds_category_axis" },
    { 0x074F, "add_dds_category_group" },
    { 0x0750, "add_dds_category_group_axis" },
    { 0x0751, "add_dds_countryid" },
    { 0x0752, "add_debug_element" },
    { 0x0753, "add_destructible_fx" },
    { 0x0754, "add_destructible_to_frame_queue" },
    { 0x0755, "add_destructible_type_function" },
    { 0x0756, "add_destructible_type_transient" },
    { 0x0757, "add_dialogue_line" },
    { 0x0758, "add_doc_civ_walla" },
    { 0x0759, "add_drone_to_squad" },
    { 0x075A, "add_earthquake" },
    { 0x075B, "add_endon" },
    { 0x075C, "add_enemy_flashlight" },
    { 0x075D, "add_extra_autosave_check" },
    { 0x075E, "add_fractional_data_point" },
    { 0x075F, "add_func" },
    { 0x0760, "add_fx" },
    { 0x0761, "add_global_spawn_function" },
    { 0x0762, "add_greece_starts" },
    { 0x0763, "add_hint_background" },
    { 0x0764, "add_hint_string" },
    { 0x0765, "add_hovertank_turret" },
    { 0x0766, "add_hud_line" },
    { 0x0767, "add_hudelm_position_internal" },
    { 0x0768, "add_humanoid_agent" },
    { 0x0769, "add_idle_control" },
    { 0x076A, "add_jav_glow" },
    { 0x076B, "add_kb_button" },
    { 0x076C, "add_key" },
    { 0x076D, "add_key_to_destructible" },
    { 0x076E, "add_keypairs_to_destructible" },
    { 0x076F, "add_kill_enemy_minion_momentum" },
    { 0x0770, "add_kill_enemy_momentum" },
    { 0x0771, "add_kill_friendly_minion_momentum" },
    { 0x0772, "add_kill_friendly_momentum" },
    { 0x0773, "add_lock_target" },
    { 0x0774, "add_mag_move_notetracks" },
    { 0x0775, "add_momentum" },
    { 0x0776, "add_moving_obstacle" },
    { 0x0777, "add_moving_vol_to_node" },
    { 0x0778, "add_name" },
    { 0x0779, "add_no_game_starts" },
    { 0x077A, "add_node_to_global_arrays" },
    { 0x077B, "add_noself_call" },
    { 0x077C, "add_note_track_data" },
    { 0x077D, "add_notetrack_and_get_index" },
    { 0x077E, "add_notetrack_array" },
    { 0x077F, "add_object_to_tactics_system" },
    { 0x0780, "add_objective" },
    { 0x0781, "add_option_to_selected_entities" },
    { 0x0782, "add_party_member_class_change" },
    { 0x0783, "add_passenger_to_player_pitbull" },
    { 0x0784, "add_path_node" },
    { 0x0785, "add_path_weights" },
    { 0x0786, "add_phrase_to_history" },
    { 0x0787, "add_player_flashlight" },
    { 0x0788, "add_proccess_trigger" },
    { 0x0789, "add_random_killspawner_to_spawngroup" },
    { 0x078A, "add_reactive_fx" },
    { 0x078B, "add_replace_after_load_done" },
    { 0x078C, "add_reverb" },
    { 0x078D, "add_rpg_to_tactics_system" },
    { 0x078E, "add_scene_model" },
    { 0x078F, "add_script_car" },
    { 0x0790, "add_shake_and_rumble_notetracks" },
    { 0x0791, "add_shake_and_rumble_notetracks_for_grab" },
    { 0x0792, "add_shake_and_rumble_notetracks_for_jump" },
    { 0x0793, "add_sit_load_ak_notetracks" },
    { 0x0794, "add_slowmo_breach_custom_function" },
    { 0x0795, "add_slowmo_breacher" },
    { 0x0796, "add_smoking_notetracks" },
    { 0x0797, "add_spawn_behavior" },
    { 0x0798, "add_spawn_function" },
    { 0x0799, "add_spawn_function_to_noteworthy" },
    { 0x079A, "add_spawn_function_to_targetname" },
    { 0x079B, "add_spawner_to_global_arrays" },
    { 0x079C, "add_start" },
    { 0x079D, "add_start_assert" },
    { 0x079E, "add_start_construct" },
    { 0x079F, "add_struct_to_global_array" },
    { 0x07A0, "add_swarm_repulsor_for_ally" },
    { 0x07A1, "add_target_on_dot" },
    { 0x07A2, "add_target_on_los" },
    { 0x07A3, "add_target_pivot" },
    { 0x07A4, "add_to_animsound" },
    { 0x07A5, "add_to_array" },
    { 0x07A6, "add_to_bot_damage_targets" },
    { 0x07A7, "add_to_bot_use_targets" },
    { 0x07A8, "add_to_destroyed_count" },
    { 0x07A9, "add_to_dialogue" },
    { 0x07AA, "add_to_dialogue_generic" },
    { 0x07AB, "add_to_flock" },
    { 0x07AC, "add_to_group_civilian" },
    { 0x07AD, "add_to_group_enemy" },
    { 0x07AE, "add_to_javelin_targeting" },
    { 0x07AF, "add_to_radio" },
    { 0x07B0, "add_to_spawngroup" },
    { 0x07B1, "add_to_threat_bias" },
    { 0x07B2, "add_tokens_to_trigger_flags" },
    { 0x07B3, "add_trace_fx" },
    { 0x07B4, "add_trace_fx_proc" },
    { 0x07B5, "add_trigger_func_thread" },
    { 0x07B6, "add_trigger_function" },
    { 0x07B7, "add_turret_on_dismount" },
    { 0x07B8, "add_vehicle_anim" },
    { 0x07B9, "add_vehicle_player_anim" },
    { 0x07BA, "add_vision_set" },
    { 0x07BB, "add_vision_sets_from_triggers" },
    { 0x07BC, "add_vol_to_node" },
    { 0x07BD, "add_volume_to_global_arrays" },
    { 0x07BE, "add_wait" },
    { 0x07BF, "add_wait_asserter" },
    { 0x07C0, "add_warbird_cargo" },
    { 0x07C1, "add_weapon" },
    { 0x07C2, "add_z" },
    { 0x07C3, "addactioncovermealiasex" },
    { 0x07C4, "addactivecounteruav" },
    { 0x07C5, "addactiveuav" },
    { 0x07C6, "addaieventlistener_func" },
    { 0x07C7, "addairexplosion" },
    { 0x07C8, "addallowedthreatcallout" },
    { 0x07C9, "addalternatespawnpoint" },
    { 0x07CA, "addarmorypoints" },
    { 0x07CB, "addattachments" },
    { 0x07CC, "addattacker" },
    { 0x07CD, "addautomaticattachments" },
    { 0x07CE, "addcalloutresponseevent" },
    { 0x07CF, "addcastname" },
    { 0x07D0, "addcenterdual" },
    { 0x07D1, "addcenterheading" },
    { 0x07D2, "addcenterimage" },
    { 0x07D3, "addcentername" },
    { 0x07D4, "addcenternamedouble" },
    { 0x07D5, "addcentersubtitle" },
    { 0x07D6, "addcentertriple" },
    { 0x07D7, "addcheckfirealias" },
    { 0x07D8, "addchild" },
    { 0x07D9, "addcollisiontopool" },
    { 0x07DA, "addconcatdirectionalias" },
    { 0x07DB, "addconcattargetalias" },
    { 0x07DC, "addcratetype" },
    { 0x07DD, "addcratetypes_standard" },
    { 0x07DE, "adddeathicon" },
    { 0x07DF, "adddropmarker" },
    { 0x07E0, "added_aerial_links" },
    { 0x07E1, "addedtowave" },
    { 0x07E2, "addgap" },
    { 0x07E3, "addgrenadethrowanimoffset" },
    { 0x07E4, "addhinttrigger" },
    { 0x07E5, "addhostileburstalias" },
    { 0x07E6, "addinformalias" },
    { 0x07E7, "addinformevent" },
    { 0x07E8, "addinformreloadingaliasex" },
    { 0x07E9, "additional_delete_cars" },
    { 0x07EA, "additional_geo" },
    { 0x07EB, "additional_tactical_logic_func" },
    { 0x07EC, "additional_unlink_nodes" },
    { 0x07ED, "additionalassets" },
    { 0x07EE, "additionalsighttraceentities" },
    { 0x07EF, "additionalvo" },
    { 0x07F0, "additive_pain" },
    { 0x07F1, "additive_pull_weight" },
    { 0x07F2, "additiverotateroot" },
    { 0x07F3, "additiveturretdriveidle" },
    { 0x07F4, "additiveturretfire" },
    { 0x07F5, "additiveturretidle" },
    { 0x07F6, "additiveturretrotateleft" },
    { 0x07F7, "additiveturretrotateright" },
    { 0x07F8, "additiveusegunroot" },
    { 0x07F9, "addlastperks" },
    { 0x07FA, "addlaunchers" },
    { 0x07FB, "addleftname" },
    { 0x07FC, "addlefttitle" },
    { 0x07FD, "addlevel" },
    { 0x07FE, "addlightningexploder" },
    { 0x07FF, "addlowermessage" },
    { 0x0800, "addmovecombataliasex" },
    { 0x0801, "addmovenoncombataliasex" },
    { 0x0802, "addnamealias" },
    { 0x0803, "addnamealiasex" },
    { 0x0804, "addnodestobechecked" },
    { 0x0805, "addnotetrack_animsound" },
    { 0x0806, "addnotetrack_attach" },
    { 0x0807, "addnotetrack_customfunction" },
    { 0x0808, "addnotetrack_detach" },
    { 0x0809, "addnotetrack_detach_gun" },
    { 0x080A, "addnotetrack_df" },
    { 0x080B, "addnotetrack_dialogue" },
    { 0x080C, "addnotetrack_flag" },
    { 0x080D, "addnotetrack_flag_clear" },
    { 0x080E, "addnotetrack_lui_notify" },
    { 0x080F, "addnotetrack_notify" },
    { 0x0810, "addnotetrack_playersound" },
    { 0x0811, "addnotetrack_set_omnvar" },
    { 0x0812, "addnotetrack_sound" },
    { 0x0813, "addnotetrack_startfxontag" },
    { 0x0814, "addnotetrack_stopfxontag" },
    { 0x0815, "addnotetrack_swapparttoefx" },
    { 0x0816, "addnotetrack_tracepartforefx" },
    { 0x0817, "addofficertosquad" },
    { 0x0818, "addonstart_animsound" },
    { 0x0819, "addoption" },
    { 0x081A, "addorderalias" },
    { 0x081B, "addorderevent" },
    { 0x081C, "addplanetolist" },
    { 0x081D, "addplayernamealias" },
    { 0x081E, "addplayertosquad" },
    { 0x081F, "addpossiblethreatcallout" },
    { 0x0820, "addposteventgeotocratebadplacearray" },
    { 0x0821, "addprereq" },
    { 0x0822, "addrankalias" },
    { 0x0823, "addreactionalias" },
    { 0x0824, "addreactionevent" },
    { 0x0825, "addresponsealias" },
    { 0x0826, "addresponseevent" },
    { 0x0827, "addresponseevent_internal" },
    { 0x0828, "addrightname" },
    { 0x0829, "addrighttitle" },
    { 0x082A, "addsafetyhealth" },
    { 0x082B, "addsituationalcombatorder" },
    { 0x082C, "addsituationalorder" },
    { 0x082D, "addspace" },
    { 0x082E, "addspacesmall" },
    { 0x082F, "addspawnpoints" },
    { 0x0830, "addspeaker" },
    { 0x0831, "addstartspawnpoints" },
    { 0x0832, "addstreaksupportprompt" },
    { 0x0833, "addsubleftname" },
    { 0x0834, "addsublefttitle" },
    { 0x0835, "addtakingfirealias" },
    { 0x0836, "addtauntalias" },
    { 0x0837, "addthreatalias" },
    { 0x0838, "addthreatcalloutalias" },
    { 0x0839, "addthreatcalloutecho" },
    { 0x083A, "addthreatcalloutlandmarkalias" },
    { 0x083B, "addthreatcalloutlocationalias" },
    { 0x083C, "addthreatcalloutqa_nextline" },
    { 0x083D, "addthreatcalloutresponsealias" },
    { 0x083E, "addthreatdistancealias" },
    { 0x083F, "addthreatelevationalias" },
    { 0x0840, "addthreatevent" },
    { 0x0841, "addthreatexposedalias" },
    { 0x0842, "addthreatobviousalias" },
    { 0x0843, "addtime" },
    { 0x0844, "addtoalivecount" },
    { 0x0845, "addtobaseangle" },
    { 0x0846, "addtobattlebuddywaitlist" },
    { 0x0847, "addtocarepackagedronelist" },
    { 0x0848, "addtocharactersarray" },
    { 0x0849, "addtodeletespike" },
    { 0x084A, "addtoexplosivedronelist" },
    { 0x084B, "addtohelilist" },
    { 0x084C, "addtolittlebirdlist" },
    { 0x084D, "addtolivescount" },
    { 0x084E, "addtoparticipantsarray" },
    { 0x084F, "addtosquad" },
    { 0x0850, "addtosystem" },
    { 0x0851, "addtoteam" },
    { 0x0852, "addtoteamcount" },
    { 0x0853, "addtototalspawned" },
    { 0x0854, "addtotrackingdronelist" },
    { 0x0855, "addtoturretlist" },
    { 0x0856, "addtowavespawner" },
    { 0x0857, "addturret" },
    { 0x0858, "adduavmodel" },
    { 0x0859, "aden_key_fr" },
    { 0x085A, "adjust_angles_to_player" },
    { 0x085B, "adjust_bounce_lookahead" },
    { 0x085C, "adjust_gravity" },
    { 0x085D, "adjust_model_speed_to_node" },
    { 0x085E, "adjust_pitbull_add_idle" },
    { 0x085F, "adjustallyaccuracyovertime" },
    { 0x0860, "adjustfov" },
    { 0x0861, "adjustlink" },
    { 0x0862, "adjustmissileoverlay" },
    { 0x0863, "adjustshadowcenter" },
    { 0x0864, "adjuststaticoverlay" },
    { 0x0865, "adrenaline" },
    { 0x0866, "adrenaline_col" },
    { 0x0867, "adrenaline_speed_scalar" },
    { 0x0868, "adrenalineinit" },
    { 0x0869, "adrenalinesettings" },
    { 0x086A, "adrenalinesupport" },
    { 0x086B, "adrone_condition_callback_to_state_deathspin" },
    { 0x086C, "adrone_condition_callback_to_state_destruct" },
    { 0x086D, "adrone_condition_callback_to_state_distant" },
    { 0x086E, "adrone_condition_callback_to_state_flyby" },
    { 0x086F, "adrone_condition_callback_to_state_flying" },
    { 0x0870, "adrone_condition_callback_to_state_flyover" },
    { 0x0871, "adrone_condition_callback_to_state_hover" },
    { 0x0872, "adrone_condition_callback_to_state_off" },
    { 0x0873, "ads" },
    { 0x0874, "ads_hint" },
    { 0x0875, "ads_hint_breakout" },
    { 0x0876, "ads_hint_breakout_think" },
    { 0x0877, "ads_hint_clear" },
    { 0x0878, "ads_hint_display" },
    { 0x0879, "ads_on" },
    { 0x087A, "adsmonitor" },
    { 0x087B, "adstime" },
    { 0x087C, "advance_bones_and_joker_intro" },
    { 0x087D, "advance_gideon_if_player_ahead" },
    { 0x087E, "advance_regardless_of_numbers" },
    { 0x087F, "advancedtraverse" },
    { 0x0880, "advancedtraverse2" },
    { 0x0881, "advancedwindowtraverse" },
    { 0x0882, "advanceonhidingenemy" },
    { 0x0883, "advancetoenemygroup" },
    { 0x0884, "advancetoenemygroupmax" },
    { 0x0885, "advancetoenemyinterval" },
    { 0x0886, "aerial_danger_exists_for" },
    { 0x0887, "aerial_dangers_monitoring" },
    { 0x0888, "aerial_group" },
    { 0x0889, "aerial_neighbors" },
    { 0x088A, "aerial_pathnode_group_connect_dist" },
    { 0x088B, "aerial_pathnode_offset" },
    { 0x088C, "aerial_pathnodes" },
    { 0x088D, "aerial_pathnodes_force_connect" },
    { 0x088E, "aerialdrone" },
    { 0x088F, "aerialkillstreakmarker" },
    { 0x0890, "affected" },
    { 0x0891, "afk" },
    { 0x0892, "after_collpase_ents" },
    { 0x0893, "afterlandanim" },
    { 0x0894, "afterlandanimconnected" },
    { 0x0895, "aftermath_anims" },
    { 0x0896, "agent_damage_finished" },
    { 0x0897, "agent_funcs" },
    { 0x0898, "agent_gameparticipant" },
    { 0x0899, "agent_override_difficulty" },
    { 0x089A, "agent_player_conf_think" },
    { 0x089B, "agent_player_dom_think" },
    { 0x089C, "agent_player_sd_think" },
    { 0x089D, "agent_squadmember_conf_think" },
    { 0x089E, "agent_squadmember_dom_think" },
    { 0x089F, "agent_teamparticipant" },
    { 0x08A0, "agent_type" },
    { 0x08A1, "agentarray" },
    { 0x08A2, "agentbody" },
    { 0x08A3, "agentcostumetablename" },
    { 0x08A4, "agentdogbark" },
    { 0x08A5, "agentdogthink" },
    { 0x08A6, "agentfunc" },
    { 0x08A7, "aggresivelookat" },
    { 0x08A8, "aggressivemode" },
    { 0x08A9, "aggro_target" },
    { 0x08AA, "ah_delay_playerseek" },
    { 0x08AB, "ah_fast_body_cleanup" },
    { 0x08AC, "ah_init_track_block" },
    { 0x08AD, "ah_init_track_doors" },
    { 0x08AE, "ah_morgue_doors" },
    { 0x08AF, "ah_morgue_threat_proc" },
    { 0x08B0, "ah_move_track_block" },
    { 0x08B1, "ah_player_bodybag_slowdown" },
    { 0x08B2, "ah_track_door_open" },
    { 0x08B3, "ah_tranistion_doors" },
    { 0x08B4, "ai" },
    { 0x08B5, "ai_3d_sighting_model" },
    { 0x08B6, "ai_add_player_only_damage" },
    { 0x08B7, "ai_add_twenty_percent_damage" },
    { 0x08B8, "ai_ally_mb_intro_anim" },
    { 0x08B9, "ai_animate_props_on_death" },
    { 0x08BA, "ai_array" },
    { 0x08BB, "ai_array_killcount_flag_set" },
    { 0x08BC, "ai_boat_bow_splash_fx" },
    { 0x08BD, "ai_boat_water_foamfx" },
    { 0x08BE, "ai_canal_combat_01_accuracy_think" },
    { 0x08BF, "ai_canal_combat_02_accuracy_think" },
    { 0x08C0, "ai_canal_combat_03_accuracy_think" },
    { 0x08C1, "ai_canal_combat_04_accuracy_think" },
    { 0x08C2, "ai_canal_combat_05_accuracy_think" },
    { 0x08C3, "ai_charged_shot_wait_for_death" },
    { 0x08C4, "ai_classname_in_level" },
    { 0x08C5, "ai_classname_in_level_keys" },
    { 0x08C6, "ai_clear_custom_animation_reaction" },
    { 0x08C7, "ai_clear_custom_animation_reaction_and_idle" },
    { 0x08C8, "ai_cond_player_at_ambient_battle" },
    { 0x08C9, "ai_cond_player_at_escape_battle" },
    { 0x08CA, "ai_cond_player_at_pitbull_battle" },
    { 0x08CB, "ai_cond_player_at_police_battle" },
    { 0x08CC, "ai_cond_player_at_standoff_battle" },
    { 0x08CD, "ai_cond_player_at_standoff_battle_or_danger_zone" },
    { 0x08CE, "ai_cond_player_at_tanker_battle" },
    { 0x08CF, "ai_cond_player_at_van" },
    { 0x08D0, "ai_cond_reached_goal" },
    { 0x08D1, "ai_cond_reached_path_end" },
    { 0x08D2, "ai_create_behavior_function" },
    { 0x08D3, "ai_damage_think" },
    { 0x08D4, "ai_deathflag" },
    { 0x08D5, "ai_delete_self" },
    { 0x08D6, "ai_delete_when_out_of_sight" },
    { 0x08D7, "ai_detect_charged_damage" },
    { 0x08D8, "ai_detection" },
    { 0x08D9, "ai_detection_timeout" },
    { 0x08DA, "ai_disable_swim_or_underwater_walk" },
    { 0x08DB, "ai_diveboat_foam_trail" },
    { 0x08DC, "ai_diveboats_chase_trail" },
    { 0x08DD, "ai_dont_glow_in_thermal" },
    { 0x08DE, "ai_empty" },
    { 0x08DF, "ai_enable_swim_or_underwater_walk" },
    { 0x08E0, "ai_end_fixed_node" },
    { 0x08E1, "ai_end_ignore_all" },
    { 0x08E2, "ai_end_ignore_me" },
    { 0x08E3, "ai_end_magic_bullet_shield" },
    { 0x08E4, "ai_flee_from_microwave" },
    { 0x08E5, "ai_func_override" },
    { 0x08E6, "ai_functions" },
    { 0x08E7, "ai_game_mode" },
    { 0x08E8, "ai_gd" },
    { 0x08E9, "ai_get_behavior_function" },
    { 0x08EA, "ai_go_to_goal_before_colors" },
    { 0x08EB, "ai_ignore_everything" },
    { 0x08EC, "ai_ignore_foliage_for_time" },
    { 0x08ED, "ai_init" },
    { 0x08EE, "ai_jump_over_40_down_88" },
    { 0x08EF, "ai_kill" },
    { 0x08F0, "ai_kill_no_ragdoll" },
    { 0x08F1, "ai_kill_when_out_of_sight" },
    { 0x08F2, "ai_lasers" },
    { 0x08F3, "ai_lobby_think" },
    { 0x08F4, "ai_mantle_over_low_cover_40" },
    { 0x08F5, "ai_mb1" },
    { 0x08F6, "ai_mb1_allywarp" },
    { 0x08F7, "ai_mb1_drones" },
    { 0x08F8, "ai_mb1_first_guard_fallback" },
    { 0x08F9, "ai_mb1_jumpdown_guards" },
    { 0x08FA, "ai_mb1_script_end" },
    { 0x08FB, "ai_mb2" },
    { 0x08FC, "ai_mb2_drones" },
    { 0x08FD, "ai_mb2_enemies_run" },
    { 0x08FE, "ai_mb2_enemyrun" },
    { 0x08FF, "ai_mb2_gate" },
    { 0x0900, "ai_mb2_mech_watcher" },
    { 0x0901, "ai_mb2_remove_stencils" },
    { 0x0902, "ai_mb2_script_end" },
    { 0x0903, "ai_message_handler_hidden" },
    { 0x0904, "ai_message_handler_spotted" },
    { 0x0905, "ai_mode" },
    { 0x0906, "ai_motorpool_animation" },
    { 0x0907, "ai_notify" },
    { 0x0908, "ai_number" },
    { 0x0909, "ai_player_only_damage_func" },
    { 0x090A, "ai_remove_outline_waiter" },
    { 0x090B, "ai_remove_player_only_damage" },
    { 0x090C, "ai_remove_twenty_percent_damage" },
    { 0x090D, "ai_restore_ignore_setting" },
    { 0x090E, "ai_run_behavior_until_condition" },
    { 0x090F, "ai_save_ignore_setting" },
    { 0x0910, "ai_set_custom_animation_reaction" },
    { 0x0911, "ai_set_goback_override_function" },
    { 0x0912, "ai_sets_goal" },
    { 0x0913, "ai_shoot_missile" },
    { 0x0914, "ai_shoot_missile_salvo" },
    { 0x0915, "ai_shot_by_player_team_notify" },
    { 0x0916, "ai_should_be_added" },
    { 0x0917, "ai_silo_floor_01_balcony" },
    { 0x0918, "ai_silo_floor_01_wave_2_think" },
    { 0x0919, "ai_silo_floor_01_wave_3_think" },
    { 0x091A, "ai_silo_think" },
    { 0x091B, "ai_slide_across_car" },
    { 0x091C, "ai_special_retreat_watcher" },
    { 0x091D, "ai_start_balcony_death" },
    { 0x091E, "ai_start_ignore_all" },
    { 0x091F, "ai_start_ignore_me" },
    { 0x0920, "ai_start_magic_bullet_shield" },
    { 0x0921, "ai_start_pacifist" },
    { 0x0922, "ai_start_respawn_death" },
    { 0x0923, "ai_stealth_pause_handler" },
    { 0x0924, "ai_step_up_32" },
    { 0x0925, "ai_stop_death_function" },
    { 0x0926, "ai_stun" },
    { 0x0927, "ai_swim_death" },
    { 0x0928, "ai_swim_pain" },
    { 0x0929, "ai_target" },
    { 0x092A, "ai_target_force" },
    { 0x092B, "ai_target_force_damaged" },
    { 0x092C, "ai_target_force_scripted" },
    { 0x092D, "ai_thermal" },
    { 0x092E, "ai_toggle_cloak" },
    { 0x092F, "ai_toggle_cloak_animate" },
    { 0x0930, "ai_toggle_cloak_complete_vo" },
    { 0x0931, "ai_toggle_cloak_start_vo" },
    { 0x0932, "ai_twenty_percent_damage_func" },
    { 0x0933, "ai_unignore_everything" },
    { 0x0934, "ai_wading_footsteps" },
    { 0x0935, "ai_wait_go" },
    { 0x0936, "ai_water_footstep" },
    { 0x0937, "ai_water_set_depth" },
    { 0x0938, "ai_wave_monitor_retreat" },
    { 0x0939, "ai_wave_monitor_threshold" },
    { 0x093A, "ai_wave_setgoalvolume" },
    { 0x093B, "ai_wave_spawn" },
    { 0x093C, "ai_wave_spawn_volume" },
    { 0x093D, "ai_wave_spawn_volume_threshold" },
    { 0x093E, "ai_wave_spawn_volume_threshold_retreat" },
    { 0x093F, "aianim_simple" },
    { 0x0940, "aianim_simple_vehicle" },
    { 0x0941, "aiareintheroom" },
    { 0x0942, "aiarraydeleteonflag" },
    { 0x0943, "aiarrayfallbackonflag" },
    { 0x0944, "aiarrayidleloop" },
    { 0x0945, "aiarraymovetonewidlepos" },
    { 0x0946, "aiarrayoverridemodelrandom" },
    { 0x0947, "aiattack" },
    { 0x0948, "aibattlechatterloop" },
    { 0x0949, "aicount" },
    { 0x094A, "aideathenemy" },
    { 0x094B, "aideatheventthread" },
    { 0x094C, "aideathfriendly" },
    { 0x094D, "aideleteonflag" },
    { 0x094E, "aidisablestealthcombat" },
    { 0x094F, "aidisplacewaiter" },
    { 0x0950, "aienablestealthcombat" },
    { 0x0951, "aienabletotalcombat" },
    { 0x0952, "aifallbackonflag" },
    { 0x0953, "aifollow" },
    { 0x0954, "aifolloworderwaiter" },
    { 0x0955, "aigrenadedangerwaiter" },
    { 0x0956, "aigroup_create" },
    { 0x0957, "aigroup_soldierthink" },
    { 0x0958, "aigroup_spawnerdeath" },
    { 0x0959, "aigroup_spawnerempty" },
    { 0x095A, "aigroup_spawnerthink" },
    { 0x095B, "aihasweapon" },
    { 0x095C, "aihostileburstloop" },
    { 0x095D, "aiidleloop" },
    { 0x095E, "aiidleloopdisable" },
    { 0x095F, "aiinwater" },
    { 0x0960, "aikilleventthread" },
    { 0x0961, "aikills" },
    { 0x0962, "aim_accel_turnrate_lerp" },
    { 0x0963, "aim_additives_think" },
    { 0x0964, "aim_assist_bmodel" },
    { 0x0965, "aim_assist_using_bmodels_init" },
    { 0x0966, "aim_assist_with_bmodels" },
    { 0x0967, "aim_at_my_attacker" },
    { 0x0968, "aim_axis_of_selected_ents" },
    { 0x0969, "aim_burke_at_angles" },
    { 0x096A, "aim_hud" },
    { 0x096B, "aim_hud_on" },
    { 0x096C, "aim_test" },
    { 0x096D, "aim_turnrate_pitch" },
    { 0x096E, "aim_turnrate_pitch_ads" },
    { 0x096F, "aim_turnrate_yaw" },
    { 0x0970, "aim_turnrate_yaw_ads" },
    { 0x0971, "aim_turret_at_ambush_point_or_visible_enemy" },
    { 0x0972, "aim_while_moving_thread" },
    { 0x0973, "aimassist_target" },
    { 0x0974, "aimblendtime" },
    { 0x0975, "aimbutdontshoot" },
    { 0x0976, "aimedatshootentorpos" },
    { 0x0977, "aimedsomewhatatenemy" },
    { 0x0978, "aimfaryawtolerance" },
    { 0x0979, "aimidlethread" },
    { 0x097A, "aimovetonewidlepos" },
    { 0x097B, "aimpitchdifftolerance" },
    { 0x097C, "aimsetupblendtime" },
    { 0x097D, "aimtarget" },
    { 0x097E, "aimweight" },
    { 0x097F, "aimweight_end" },
    { 0x0980, "aimweight_start" },
    { 0x0981, "aimweight_t" },
    { 0x0982, "aimweight_transframes" },
    { 0x0983, "aimyawdiffclosedistsq" },
    { 0x0984, "aimyawdiffclosetolerance" },
    { 0x0985, "aimyawdifffartolerance" },
    { 0x0986, "ainame" },
    { 0x0987, "ainameandrankwaiter" },
    { 0x0988, "aiofficerorders" },
    { 0x0989, "aioverridemodel" },
    { 0x098A, "aioverridemodelrandom" },
    { 0x098B, "aiowner" },
    { 0x098C, "air_strip_ambient_a10_gun_dive_1" },
    { 0x098D, "air_strip_ambient_a10_gun_dive_2" },
    { 0x098E, "air_strip_ambient_a10_gun_dive_3" },
    { 0x098F, "air_strip_ambient_dogfight_1" },
    { 0x0990, "air_strip_ambient_dogfight_2" },
    { 0x0991, "air_strip_ambient_dogfight_3" },
    { 0x0992, "airank" },
    { 0x0993, "airbrake_hint" },
    { 0x0994, "aircraft_wash" },
    { 0x0995, "aircraft_wash_thread" },
    { 0x0996, "airdropcratecollision" },
    { 0x0997, "airplane_list" },
    { 0x0998, "airstrike_drones" },
    { 0x0999, "airstrike_earthquake" },
    { 0x099A, "airstrike_flares_monitor" },
    { 0x099B, "airstrikefx" },
    { 0x099C, "airstrikeinprogress" },
    { 0x099D, "airstrikeoverrides" },
    { 0x099E, "airstriketype" },
    { 0x099F, "airtoairevent" },
    { 0x09A0, "airtogroundevent" },
    { 0x09A1, "aistartusingassaultvehicle" },
    { 0x09A2, "aispread" },
    { 0x09A3, "aistate" },
    { 0x09A4, "aistealthcombatenemygotocover" },
    { 0x09A5, "aisuppressai" },
    { 0x09A6, "aithreadthreader" },
    { 0x09A7, "aiturnnotifies" },
    { 0x09A8, "aitype_check" },
    { 0x09A9, "aiupdateanimstate" },
    { 0x09AA, "aiupdatecombat" },
    { 0x09AB, "aiupdatesuppressed" },
    { 0x09AC, "aiweapon" },
    { 0x09AD, "ajani" },
    { 0x09AE, "akimboweaponent" },
    { 0x09AF, "alarm_annoyance" },
    { 0x09B0, "alarm_create_loops" },
    { 0x09B1, "alarm_enable" },
    { 0x09B2, "alarm_guid" },
    { 0x09B3, "alarm_interval" },
    { 0x09B4, "alarm_is_playing" },
    { 0x09B5, "alarm_monitor_cleanup" },
    { 0x09B6, "alarm_on" },
    { 0x09B7, "alarm_playing" },
    { 0x09B8, "alarm_reverb_distance_mix" },
    { 0x09B9, "alarm_start" },
    { 0x09BA, "alarm_start_loops" },
    { 0x09BB, "alarm_stop_loops" },
    { 0x09BC, "alarm_update_loops" },
    { 0x09BD, "alarm_validate_damage" },
    { 0x09BE, "alarmfx" },
    { 0x09BF, "alarmfx01" },
    { 0x09C0, "alarmsoundent" },
    { 0x09C1, "alarmsystem" },
    { 0x09C2, "alcove_clips" },
    { 0x09C3, "alert_check_function" },
    { 0x09C4, "alert_level" },
    { 0x09C5, "alert_level_table" },
    { 0x09C6, "alert_sound" },
    { 0x09C7, "alert_stop_animating" },
    { 0x09C8, "alert_when_another_is_hurt" },
    { 0x09C9, "alertai" },
    { 0x09CA, "alertaigroup" },
    { 0x09CB, "alertallpoolguards" },
    { 0x09CC, "alerted" },
    { 0x09CD, "alerted_amount" },
    { 0x09CE, "alerted_by_corpse" },
    { 0x09CF, "alertedenemies" },
    { 0x09D0, "alertedentity" },
    { 0x09D1, "alertedinfo" },
    { 0x09D2, "alertface" },
    { 0x09D3, "alertgroup" },
    { 0x09D4, "alerthighlighthudeffect" },
    { 0x09D5, "alerttimedelay" },
    { 0x09D6, "alias" },
    { 0x09D7, "alias_data" },
    { 0x09D8, "alias_name" },
    { 0x09D9, "aliens_make_entity_sentient_func" },
    { 0x09DA, "align_hint_think" },
    { 0x09DB, "alignment_factor" },
    { 0x09DC, "alive" },
    { 0x09DD, "alivecount" },
    { 0x09DE, "aliveplayers" },
    { 0x09DF, "all_avatars_scheduled_for_delete" },
    { 0x09E0, "all_dom_flags" },
    { 0x09E1, "all_exopush_enemies_dead" },
    { 0x09E2, "all_hp_zones" },
    { 0x09E3, "all_players_istouching" },
    { 0x09E4, "all_team_streak_col" },
    { 0x09E5, "all3duiscreens" },
    { 0x09E6, "allboothdisplays" },
    { 0x09E7, "allenemyambushers" },
    { 0x09E8, "allenemypatrollers" },
    { 0x09E9, "allenemyvehicles" },
    { 0x09EA, "allenvarray" },
    { 0x09EB, "alley_1_big_metal_gate" },
    { 0x09EC, "alley_1_complete_dialogue" },
    { 0x09ED, "alley_a_dialogue" },
    { 0x09EE, "alley_b_dialogue" },
    { 0x09EF, "alley_beckon" },
    { 0x09F0, "alley_combat_dialogue" },
    { 0x09F1, "alley_dialogue" },
    { 0x09F2, "alley_ending_point_trigger" },
    { 0x09F3, "alley_fail_dialogue" },
    { 0x09F4, "alley_flank_dialogue" },
    { 0x09F5, "alley_flank_dialogue_nag" },
    { 0x09F6, "alley_gideon_slide" },
    { 0x09F7, "alley_meetup_dialogue" },
    { 0x09F8, "alley_oncoming_dialogue" },
    { 0x09F9, "alley_setup" },
    { 0x09FA, "alley_veh_god_on" },
    { 0x09FB, "alley1_combat" },
    { 0x09FC, "alley1_force_deaths" },
    { 0x09FD, "alley1_kva" },
    { 0x09FE, "alley1_oncoming" },
    { 0x09FF, "alley1_oncoming_burke_alley_enter" },
    { 0x0A00, "alley1_oncoming_goto" },
    { 0x0A01, "alley1_oncoming_grenade_awareness" },
    { 0x0A02, "alley1_oncoming_truck_anims" },
    { 0x0A03, "alley1_oncoming_truck_seq" },
    { 0x0A04, "alley1_oncoming_truck_sweeper_monitor" },
    { 0x0A05, "alley1_oncoming_turret_fire" },
    { 0x0A06, "alley1_oncoming_turret_think" },
    { 0x0A07, "alley1_stage1_combat" },
    { 0x0A08, "alley1_stage1_rooftop_movedown" },
    { 0x0A09, "alley1_stage2_combat" },
    { 0x0A0A, "alley1_stage2_combat_flag" },
    { 0x0A0B, "alley1_stage3_combat" },
    { 0x0A0C, "alley1_stage3_combat_flag" },
    { 0x0A0D, "alley1_stage3_refill_think" },
    { 0x0A0E, "alley1_veh_destro" },
    { 0x0A0F, "alley2_combat" },
    { 0x0A10, "alley2_combat_enemy_vol_assign" },
    { 0x0A11, "alley2_combat_player_monitor" },
    { 0x0A12, "alley2_combat_vol_assign" },
    { 0x0A13, "alley2_jumpers" },
    { 0x0A14, "alley2_jumpers_setup" },
    { 0x0A15, "alley2_kva" },
    { 0x0A16, "alley2_spawner_locator" },
    { 0x0A17, "alley2_stage1_combat" },
    { 0x0A18, "alley2_stage2_combat" },
    { 0x0A19, "alley2_stage3_combat" },
    { 0x0A1A, "alleys_distant_emergency_siren_blasts" },
    { 0x0A1B, "alleys_distant_euro_siren_loop" },
    { 0x0A1C, "alleys_distant_standard_siren_loop" },
    { 0x0A1D, "alleys_end_music" },
    { 0x0A1E, "alleys_music_end" },
    { 0x0A1F, "alleys_rpg_fight_music" },
    { 0x0A20, "alleys_rpg_music" },
    { 0x0A21, "alleys_rpg_music_backup_trigger" },
    { 0x0A22, "alleysallymovement" },
    { 0x0A23, "alleysbegin" },
    { 0x0A24, "alleysbegincombatdialog" },
    { 0x0A25, "alleyscafeanims" },
    { 0x0A26, "alleyscheckifplayerretreated" },
    { 0x0A27, "alleyscombat" },
    { 0x0A28, "alleyscombatbacklinefloodspawns" },
    { 0x0A29, "alleyscombatbacklineleftinteriorfloor1" },
    { 0x0A2A, "alleyscombatbacklineleftside" },
    { 0x0A2B, "alleyscombatbacklinerightinteriorfloor1" },
    { 0x0A2C, "alleyscombatbacklinerightinteriorfloor2" },
    { 0x0A2D, "alleyscombatbacklinerightside" },
    { 0x0A2E, "alleyscombatenemycountmonitor" },
    { 0x0A2F, "alleyscombatenemyorders" },
    { 0x0A30, "alleyscombatenemyretreat" },
    { 0x0A31, "alleyscombatenemysetup" },
    { 0x0A32, "alleyscombatenterbuilding" },
    { 0x0A33, "alleyscombatfinalbldgfloodspawns" },
    { 0x0A34, "alleyscombatfinalbuilding" },
    { 0x0A35, "alleyscombatfinalbuildinginterior" },
    { 0x0A36, "alleyscombatfinalbuildingshotgunners" },
    { 0x0A37, "alleyscombatfrontlinefloodspawns" },
    { 0x0A38, "alleyscombatfrontlineleftbackstairs" },
    { 0x0A39, "alleyscombatfrontlineleftside" },
    { 0x0A3A, "alleyscombatfrontlineleftsideinteriorfloor1" },
    { 0x0A3B, "alleyscombatfrontlinerightbackatm" },
    { 0x0A3C, "alleyscombatfrontlinerightside" },
    { 0x0A3D, "alleyscombatinteriorfakebulletsactivate" },
    { 0x0A3E, "alleyscombatinteriorfakebulletssetup" },
    { 0x0A3F, "alleyscombatmidlineleftside" },
    { 0x0A40, "alleyscombatmidlinerightside" },
    { 0x0A41, "alleyscombatmidlinerightsideinterior" },
    { 0x0A42, "alleyscombattriggertoggles" },
    { 0x0A43, "alleysdialogtimer" },
    { 0x0A44, "alleysdronecivilians" },
    { 0x0A45, "alleysdronegawker" },
    { 0x0A46, "alleysenemyretreat" },
    { 0x0A47, "alleysenemyrpg" },
    { 0x0A48, "alleysenemyspawns" },
    { 0x0A49, "alleysflaginit" },
    { 0x0A4A, "alleysgatebash" },
    { 0x0A4B, "alleysgatebashrumblelight" },
    { 0x0A4C, "alleysgateriprumbleheavy" },
    { 0x0A4D, "alleysgateripunblockpath" },
    { 0x0A4E, "alleysglobalsetup" },
    { 0x0A4F, "alleysglobalvars" },
    { 0x0A50, "alleysilanaleadstheway" },
    { 0x0A51, "alleysintroanims" },
    { 0x0A52, "alleysintrotransitiondialogue" },
    { 0x0A53, "alleyskvaintrodialogue" },
    { 0x0A54, "alleysmidpointreminder" },
    { 0x0A55, "alleysmonitorgateriphint" },
    { 0x0A56, "alleysobjectivesetup" },
    { 0x0A57, "alleysprecache" },
    { 0x0A58, "alleysremainingenemies" },
    { 0x0A59, "alleysrpgguyshootfirst" },
    { 0x0A5A, "alleyssetcompletedobjflags" },
    { 0x0A5B, "alleyssniperpip" },
    { 0x0A5C, "alleysspawnrpgenemies" },
    { 0x0A5D, "alleysstartpoints" },
    { 0x0A5E, "alleysstreettransitiondialogue" },
    { 0x0A5F, "alleysvehicleexplodeondeath" },
    { 0x0A60, "alleysvehiclemonitor" },
    { 0x0A61, "alleysvideolog" },
    { 0x0A62, "alleysvisitorcentergate" },
    { 0x0A63, "alleysvisitorcentergatereminder" },
    { 0x0A64, "alleyway_fight_enemies" },
    { 0x0A65, "allfloorpannels" },
    { 0x0A66, "allies_bunker" },
    { 0x0A67, "allies_careful" },
    { 0x0A68, "allies_check_cloak_state" },
    { 0x0A69, "allies_cover_michell" },
    { 0x0A6A, "allies_dialog_col" },
    { 0x0A6B, "allies_inert" },
    { 0x0A6C, "allies_plane" },
    { 0x0A6D, "allies_rally_init" },
    { 0x0A6E, "allies_s1" },
    { 0x0A6F, "allies_s2" },
    { 0x0A70, "allies_start_spawn_name" },
    { 0x0A71, "allies_to_building_exit" },
    { 0x0A72, "allies_to_drone_swarm" },
    { 0x0A73, "allies_to_first_land_assist" },
    { 0x0A74, "allies_to_first_land_assist_debug" },
    { 0x0A75, "allies_to_fob" },
    { 0x0A76, "allies_to_fob_think" },
    { 0x0A77, "allies_to_hill" },
    { 0x0A78, "allies_to_truck_jump" },
    { 0x0A79, "allies_to_weapons_platform_video_log" },
    { 0x0A7A, "alliesbreachatrium" },
    { 0x0A7B, "alliesbreachatriumonalarm" },
    { 0x0A7C, "alliesbreachconfroom" },
    { 0x0A7D, "alliescapturing" },
    { 0x0A7E, "allieschopper" },
    { 0x0A7F, "alliesdrivein" },
    { 0x0A80, "alliesexitatrium" },
    { 0x0A81, "alliesexitconfroom" },
    { 0x0A82, "alliesexittruck" },
    { 0x0A83, "alliesflagcarrierclientnum" },
    { 0x0A84, "alliesflagstatus" },
    { 0x0A85, "alliesparkingdefend" },
    { 0x0A86, "alliesparkingkill" },
    { 0x0A87, "alliesparkingkillalt" },
    { 0x0A88, "alliesparkingkillvictim" },
    { 0x0A89, "alliesparkingsetup" },
    { 0x0A8A, "alliesredirect" },
    { 0x0A8B, "alliesshootpooltargets" },
    { 0x0A8C, "alliesvulnerabletime" },
    { 0x0A8D, "allieswarningtime" },
    { 0x0A8E, "allow_backstabbers" },
    { 0x0A8F, "allow_boost_jump" },
    { 0x0A90, "allow_death_delay" },
    { 0x0A91, "allow_death_during_zipline" },
    { 0x0A92, "allow_death_timer" },
    { 0x0A93, "allow_dog_paired_melee_vs_ai" },
    { 0x0A94, "allow_early_back_out" },
    { 0x0A95, "allow_exo_climb" },
    { 0x0A96, "allow_fake_shooting" },
    { 0x0A97, "allow_pipe_damage" },
    { 0x0A98, "allow_player_hovertank_mount" },
    { 0x0A99, "allow_player_input_1" },
    { 0x0A9A, "allow_player_input_2" },
    { 0x0A9B, "allow_player_zip" },
    { 0x0A9C, "allow_random_killers" },
    { 0x0A9D, "allow_swimming" },
    { 0x0A9E, "allow_threat_paint" },
    { 0x0A9F, "allowable_double_attachments" },
    { 0x0AA0, "allowboostingabovetriggerradius" },
    { 0x0AA1, "allowcarry" },
    { 0x0AA2, "allowclasschoice" },
    { 0x0AA3, "allowdronedelivery" },
    { 0x0AA4, "allowedcallouts" },
    { 0x0AA5, "allowedpartialreloadontheruntime" },
    { 0x0AA6, "allowempdamage" },
    { 0x0AA7, "allowenemyspectate" },
    { 0x0AA8, "allowfauxdeath" },
    { 0x0AA9, "allowfreespectate" },
    { 0x0AAA, "allowlaststandai" },
    { 0x0AAB, "allowlatecomers" },
    { 0x0AAC, "allowmeleedamage" },
    { 0x0AAD, "allowneutral" },
    { 0x0AAE, "allowplayerscore" },
    { 0x0AAF, "allowshoot" },
    { 0x0AB0, "allowteamchoice" },
    { 0x0AB1, "allowtelefrag" },
    { 0x0AB2, "allowuse" },
    { 0x0AB3, "allowvehicledamage" },
    { 0x0AB4, "allowvote" },
    { 0x0AB5, "allowweapons" },
    { 0x0AB6, "alltargetlogicarray" },
    { 0x0AB7, "alltargetmax" },
    { 0x0AB8, "alltargetmin" },
    { 0x0AB9, "alltargetsarray" },
    { 0x0ABA, "alltriggerarray" },
    { 0x0ABB, "allvfx_struct" },
    { 0x0ABC, "ally" },
    { 0x0ABD, "ally_advance_ahead_upon_killing_group" },
    { 0x0ABE, "ally_ai_active" },
    { 0x0ABF, "ally_alert_vol" },
    { 0x0AC0, "ally_anims" },
    { 0x0AC1, "ally_determine_move_speed" },
    { 0x0AC2, "ally_dynamic_run_set" },
    { 0x0AC3, "ally_enable_boost_traversals" },
    { 0x0AC4, "ally_fire_on_dam" },
    { 0x0AC5, "ally_grapple" },
    { 0x0AC6, "ally_jet_shoot_think" },
    { 0x0AC7, "ally_move_dynamic_speed" },
    { 0x0AC8, "ally_mover" },
    { 0x0AC9, "ally_one_handed_grenade_proc" },
    { 0x0ACA, "ally_redirect_goto_node" },
    { 0x0ACB, "ally_reset_dynamic_speed" },
    { 0x0ACC, "ally_s2_squad_member_1" },
    { 0x0ACD, "ally_s2_squad_member_2" },
    { 0x0ACE, "ally_s2_squad_member_3" },
    { 0x0ACF, "ally_s2_squad_member_4" },
    { 0x0AD0, "ally_shoot_rpg_at_drones" },
    { 0x0AD1, "ally_squad_member_1" },
    { 0x0AD2, "ally_squad_member_2" },
    { 0x0AD3, "ally_squad_member_3" },
    { 0x0AD4, "ally_squad_member_4" },
    { 0x0AD5, "ally_stop_dynamic_speed" },
    { 0x0AD6, "ally_vo_controller" },
    { 0x0AD7, "ally_vo_org" },
    { 0x0AD8, "allyagentthink" },
    { 0x0AD9, "allybreachconfroomanddie" },
    { 0x0ADA, "allyburkeparkingsetup" },
    { 0x0ADB, "allyclaimedtarget" },
    { 0x0ADC, "allyclearforcegoalonend" },
    { 0x0ADD, "allyconfroomdeath" },
    { 0x0ADE, "allyexithandlevictim" },
    { 0x0ADF, "allyexitpool" },
    { 0x0AE0, "allyexittruck" },
    { 0x0AE1, "allyinfiltrators" },
    { 0x0AE2, "allypoolclimb" },
    { 0x0AE3, "allypoolkill" },
    { 0x0AE4, "allypoolsetup" },
    { 0x0AE5, "allyredirect" },
    { 0x0AE6, "allyredirectgotonode" },
    { 0x0AE7, "allyredirectnoteworthy" },
    { 0x0AE8, "allyscrambleanimations" },
    { 0x0AE9, "allysetupconfroom" },
    { 0x0AEA, "allysetupstruggle" },
    { 0x0AEB, "allyshootpooltarget" },
    { 0x0AEC, "allyshootwalkwaytarget" },
    { 0x0AED, "allysquad" },
    { 0x0AEE, "allystealthanimations" },
    { 0x0AEF, "allystruggleslomo" },
    { 0x0AF0, "allystrugglesuccess" },
    { 0x0AF1, "allytanks" },
    { 0x0AF2, "allywalkwaykill" },
    { 0x0AF3, "allywalkwaykillvictim" },
    { 0x0AF4, "almost_dead" },
    { 0x0AF5, "alpha_leader" },
    { 0x0AF6, "alpha_leader_think" },
    { 0x0AF7, "alpha_squad" },
    { 0x0AF8, "alpha_squad_and_player" },
    { 0x0AF9, "alphabetize" },
    { 0x0AFA, "alphabetize_localized_string" },
    { 0x0AFB, "already_dumpped" },
    { 0x0AFC, "already_got_end_level_notetrack" },
    { 0x0AFD, "already_ran_function" },
    { 0x0AFE, "already_set" },
    { 0x0AFF, "already_used" },
    { 0x0B00, "alreadyaddedtoalivecount" },
    { 0x0B01, "alt_rspns_random_test" },
    { 0x0B02, "alt_rspns_test_func" },
    { 0x0B03, "alternates" },
    { 0x0B04, "altmeleedeath" },
    { 0x0B05, "altmeleevictimorientation" },
    { 0x0B06, "always_loop_ents" },
    { 0x0B07, "always_pain" },
    { 0x0B08, "always_sprint" },
    { 0x0B09, "always_wake_drones" },
    { 0x0B0A, "alwaysdrawfriendlynames" },
    { 0x0B0B, "alwayslookatfirsttarget" },
    { 0x0B0C, "alwaysrocketdeath" },
    { 0x0B0D, "alwaysrunforward" },
    { 0x0B0E, "alwaysstaticout" },
    { 0x0B0F, "alwaysusepistol" },
    { 0x0B10, "am_i_hit" },
    { 0x0B11, "am_i_moving" },
    { 0x0B12, "amb_push_oneshots" },
    { 0x0B13, "amb_pushing" },
    { 0x0B14, "amb_sky_combat" },
    { 0x0B15, "amb_sky_combat_setup" },
    { 0x0B16, "ambience" },
    { 0x0B17, "ambience_inner" },
    { 0x0B18, "ambience_outer" },
    { 0x0B19, "ambient_animate" },
    { 0x0B1A, "ambient_battle_deployable_cover" },
    { 0x0B1B, "ambient_building_fires_fob_drone_swarm" },
    { 0x0B1C, "ambient_combat" },
    { 0x0B1D, "ambient_combat_allies" },
    { 0x0B1E, "ambient_combat_axis" },
    { 0x0B1F, "ambient_combat_vo" },
    { 0x0B20, "ambient_deck" },
    { 0x0B21, "ambient_dialogue_manager" },
    { 0x0B22, "ambient_drones" },
    { 0x0B23, "ambient_eq" },
    { 0x0B24, "ambient_explosion_before_landing" },
    { 0x0B25, "ambient_explosion_courtyard" },
    { 0x0B26, "ambient_explosion_dirt_cooling_towers" },
    { 0x0B27, "ambient_explosion_fireball_cooling_towers" },
    { 0x0B28, "ambient_explosion_play" },
    { 0x0B29, "ambient_explosions" },
    { 0x0B2A, "ambient_fan_rotate" },
    { 0x0B2B, "ambient_fires_inside_building" },
    { 0x0B2C, "ambient_flare_fx" },
    { 0x0B2D, "ambient_gas_explosion_loading_zone" },
    { 0x0B2E, "ambient_hangar" },
    { 0x0B2F, "ambient_hangar_fan_blade_rotate" },
    { 0x0B30, "ambient_hangar_fan_blades_setup" },
    { 0x0B31, "ambient_hangar_workers" },
    { 0x0B32, "ambient_hangar_workers_spawn_settings" },
    { 0x0B33, "ambient_large_pipe_effects_courtyard" },
    { 0x0B34, "ambient_mb1_crane" },
    { 0x0B35, "ambient_mb2_claw_platform" },
    { 0x0B36, "ambient_mb2_crane" },
    { 0x0B37, "ambient_mb2_cranes" },
    { 0x0B38, "ambient_mb2_tanks" },
    { 0x0B39, "ambient_model_fix" },
    { 0x0B3A, "ambient_modifier" },
    { 0x0B3B, "ambient_police_drone_vo" },
    { 0x0B3C, "ambient_police_drones" },
    { 0x0B3D, "ambient_reverb" },
    { 0x0B3E, "ambient_shrike_flyby" },
    { 0x0B3F, "ambient_smk_walkway" },
    { 0x0B40, "ambient_sniper_rockets" },
    { 0x0B41, "ambient_soldier_vo_01" },
    { 0x0B42, "ambient_soldier_vo_02" },
    { 0x0B43, "ambient_soldier_vo_03" },
    { 0x0B44, "ambient_soldier_vo_04" },
    { 0x0B45, "ambient_soldier_vo_05" },
    { 0x0B46, "ambient_soldier_vo_06" },
    { 0x0B47, "ambient_track" },
    { 0x0B48, "ambient_underwater_effects_rescue" },
    { 0x0B49, "ambient_warbird_fire" },
    { 0x0B4A, "ambient_warbird_shooting_think" },
    { 0x0B4B, "ambient_warbird_wait_to_fire" },
    { 0x0B4C, "ambientanimation" },
    { 0x0B4D, "ambientcloudskill" },
    { 0x0B4E, "ambientcloudsloadin" },
    { 0x0B4F, "ambientdelay" },
    { 0x0B50, "ambientevent" },
    { 0x0B51, "ambienteventstart" },
    { 0x0B52, "ambientexp" },
    { 0x0B53, "ambienthdr" },
    { 0x0B54, "ambulance_damage_part" },
    { 0x0B55, "ambulance_firstframe_function" },
    { 0x0B56, "ambulance_max_health" },
    { 0x0B57, "ambulance_objective_update" },
    { 0x0B58, "ambulance_part_monitor" },
    { 0x0B59, "ambulance_push_active" },
    { 0x0B5A, "ambulance_push_attach" },
    { 0x0B5B, "ambulance_push_idle" },
    { 0x0B5C, "ambulance_push_sequence_end" },
    { 0x0B5D, "ambulance_push_step_away" },
    { 0x0B5E, "ambush_ambushed_vo" },
    { 0x0B5F, "ambush_breakout" },
    { 0x0B60, "ambush_duration" },
    { 0x0B61, "ambush_end" },
    { 0x0B62, "ambush_entrances" },
    { 0x0B63, "ambush_events" },
    { 0x0B64, "ambush_heli_explosion" },
    { 0x0B65, "ambush_player_if_alive_exopush" },
    { 0x0B66, "ambush_trap_ent" },
    { 0x0B67, "ambush_wait" },
    { 0x0B68, "ambush_yaw" },
    { 0x0B69, "ambushendtime" },
    { 0x0B6A, "ambushnode" },
    { 0x0B6B, "ambushtimer" },
    { 0x0B6C, "americans" },
    { 0x0B6D, "americans_setup" },
    { 0x0B6E, "ammo" },
    { 0x0B6F, "ammo_cache_think_global" },
    { 0x0B70, "ammo_icon" },
    { 0x0B71, "ammo_icon_fade_in" },
    { 0x0B72, "ammo_icon_fade_out" },
    { 0x0B73, "ammo_icon_think" },
    { 0x0B74, "ammo_icon_trig" },
    { 0x0B75, "ammo_max" },
    { 0x0B76, "ammo_pickup" },
    { 0x0B77, "ammocheatinterval" },
    { 0x0B78, "ammocheattime" },
    { 0x0B79, "ammofeeder" },
    { 0x0B7A, "ammopickup" },
    { 0x0B7B, "ammopickup_scalar" },
    { 0x0B7C, "ammopickupfunc" },
    { 0x0B7D, "ammopickupmodel" },
    { 0x0B7E, "ammorefillprimary" },
    { 0x0B7F, "ammorefillsecondary" },
    { 0x0B80, "amount" },
    { 0x0B81, "amount_in_sights" },
    { 0x0B82, "amplify_vfx" },
    { 0x0B83, "ams_enabled" },
    { 0x0B84, "ams_get_state" },
    { 0x0B85, "ams_init" },
    { 0x0B86, "ams_intensity" },
    { 0x0B87, "ams_player_health" },
    { 0x0B88, "ams_proxy_vehicle_speed" },
    { 0x0B89, "ams_set_intensity" },
    { 0x0B8A, "ams_set_proxy_vehicle" },
    { 0x0B8B, "ams_set_state" },
    { 0x0B8C, "ams_start" },
    { 0x0B8D, "ams_stop" },
    { 0x0B8E, "amsx_get" },
    { 0x0B8F, "amsx_get_proxy" },
    { 0x0B90, "amsx_get_proxy_vehicle_ent" },
    { 0x0B91, "amv_jetbike_height_time" },
    { 0x0B92, "amv_jetbike_height_val" },
    { 0x0B93, "angle" },
    { 0x0B94, "angle_interpolate" },
    { 0x0B95, "angle_lerp" },
    { 0x0B96, "angle_offset" },
    { 0x0B97, "angleaccel" },
    { 0x0B98, "anglelimit" },
    { 0x0B99, "anglerangethread" },
    { 0x0B9A, "angles_and_origin" },
    { 0x0B9B, "angles_clamp_180" },
    { 0x0B9C, "angles_lerp" },
    { 0x0B9D, "angles_origin" },
    { 0x0B9E, "anglescheck" },
    { 0x0B9F, "anglesclamp180" },
    { 0x0BA0, "anglesondeath" },
    { 0x0BA1, "anglesonkill" },
    { 0x0BA2, "anglessubtract" },
    { 0x0BA3, "anglevalid" },
    { 0x0BA4, "angspeed" },
    { 0x0BA5, "anim_1" },
    { 0x0BA6, "anim_2" },
    { 0x0BA7, "anim_3" },
    { 0x0BA8, "anim_addmodel" },
    { 0x0BA9, "anim_animationendnotify" },
    { 0x0BAA, "anim_array" },
    { 0x0BAB, "anim_at_entity" },
    { 0x0BAC, "anim_at_self" },
    { 0x0BAD, "anim_blend_time_override" },
    { 0x0BAE, "anim_burke_boost_lets_go" },
    { 0x0BAF, "anim_burke_crawl" },
    { 0x0BB0, "anim_changes_pushplayer" },
    { 0x0BB1, "anim_custom_animmode" },
    { 0x0BB2, "anim_custom_animmode_loop" },
    { 0x0BB3, "anim_custom_animmode_loop_solo" },
    { 0x0BB4, "anim_custom_animmode_on_guy" },
    { 0x0BB5, "anim_custom_animmode_solo" },
    { 0x0BB6, "anim_deathnotify" },
    { 0x0BB7, "anim_debug" },
    { 0x0BB8, "anim_dialogueendnotify" },
    { 0x0BB9, "anim_disablepain" },
    { 0x0BBA, "anim_dontpushplayer" },
    { 0x0BBB, "anim_down" },
    { 0x0BBC, "anim_end_early" },
    { 0x0BBD, "anim_end_early_animationendnotify" },
    { 0x0BBE, "anim_end_early_deathnotify" },
    { 0x0BBF, "anim_end_early_dialogueendnotify" },
    { 0x0BC0, "anim_end_early_facialendnotify" },
    { 0x0BC1, "anim_exists" },
    { 0x0BC2, "anim_facialanim" },
    { 0x0BC3, "anim_facialendnotify" },
    { 0x0BC4, "anim_facialfiller" },
    { 0x0BC5, "anim_first_frame" },
    { 0x0BC6, "anim_first_frame_on_guy" },
    { 0x0BC7, "anim_first_frame_solo" },
    { 0x0BC8, "anim_first_frame_with_finale_gameplay" },
    { 0x0BC9, "anim_generic" },
    { 0x0BCA, "anim_generic_custom_animmode" },
    { 0x0BCB, "anim_generic_custom_animmode_loop" },
    { 0x0BCC, "anim_generic_first_frame" },
    { 0x0BCD, "anim_generic_gravity" },
    { 0x0BCE, "anim_generic_loop" },
    { 0x0BCF, "anim_generic_queue" },
    { 0x0BD0, "anim_generic_reach" },
    { 0x0BD1, "anim_generic_reach_and_arrive" },
    { 0x0BD2, "anim_generic_run" },
    { 0x0BD3, "anim_generic_teleport" },
    { 0x0BD4, "anim_gunhand" },
    { 0x0BD5, "anim_guninhand" },
    { 0x0BD6, "anim_handle_notetrack" },
    { 0x0BD7, "anim_idle_down" },
    { 0x0BD8, "anim_idle_up" },
    { 0x0BD9, "anim_is_death" },
    { 0x0BDA, "anim_laserbuoy" },
    { 0x0BDB, "anim_last_frame_solo" },
    { 0x0BDC, "anim_link_tag_model" },
    { 0x0BDD, "anim_loop" },
    { 0x0BDE, "anim_loop_hatch_anims_solo" },
    { 0x0BDF, "anim_loop_packet" },
    { 0x0BE0, "anim_loop_packet_solo" },
    { 0x0BE1, "anim_loop_solo" },
    { 0x0BE2, "anim_loop_solo_vm" },
    { 0x0BE3, "anim_loop_vm" },
    { 0x0BE4, "anim_moveto" },
    { 0x0BE5, "anim_node" },
    { 0x0BE6, "anim_org" },
    { 0x0BE7, "anim_org_ajani_post_breach" },
    { 0x0BE8, "anim_playsound_func" },
    { 0x0BE9, "anim_pos" },
    { 0x0BEA, "anim_prep" },
    { 0x0BEB, "anim_prop_init_threads" },
    { 0x0BEC, "anim_prop_models" },
    { 0x0BED, "anim_prop_models_animtree" },
    { 0x0BEE, "anim_props" },
    { 0x0BEF, "anim_props_animated" },
    { 0x0BF0, "anim_pushplayer" },
    { 0x0BF1, "anim_rate_to_speed" },
    { 0x0BF2, "anim_reach" },
    { 0x0BF3, "anim_reach_and_approach" },
    { 0x0BF4, "anim_reach_and_approach_node_solo" },
    { 0x0BF5, "anim_reach_and_approach_solo" },
    { 0x0BF6, "anim_reach_and_idle" },
    { 0x0BF7, "anim_reach_and_idle_solo" },
    { 0x0BF8, "anim_reach_and_plant" },
    { 0x0BF9, "anim_reach_and_plant_and_arrive" },
    { 0x0BFA, "anim_reach_cleanup" },
    { 0x0BFB, "anim_reach_cleanup_solo" },
    { 0x0BFC, "anim_reach_failsafe" },
    { 0x0BFD, "anim_reach_fix" },
    { 0x0BFE, "anim_reach_idle" },
    { 0x0BFF, "anim_reach_solo" },
    { 0x0C00, "anim_reach_success" },
    { 0x0C01, "anim_reach_together" },
    { 0x0C02, "anim_reach_together_with_overrides" },
    { 0x0C03, "anim_reach_with_funcs" },
    { 0x0C04, "anim_relative" },
    { 0x0C05, "anim_removemodel" },
    { 0x0C06, "anim_roundabout_rappel_1" },
    { 0x0C07, "anim_roundabout_rappel_2" },
    { 0x0C08, "anim_scene_building_exit_cormack" },
    { 0x0C09, "anim_scene_building_exit_will" },
    { 0x0C0A, "anim_scene_building_jump" },
    { 0x0C0B, "anim_scene_walker_stepover" },
    { 0x0C0C, "anim_scene_will_grabs_car_door" },
    { 0x0C0D, "anim_scene_will_grabs_car_door_post_cherrypicker" },
    { 0x0C0E, "anim_self_set_real_time" },
    { 0x0C0F, "anim_self_set_time" },
    { 0x0C10, "anim_sequence" },
    { 0x0C11, "anim_set_rate" },
    { 0x0C12, "anim_set_rate_internal" },
    { 0x0C13, "anim_set_rate_single" },
    { 0x0C14, "anim_set_real_time" },
    { 0x0C15, "anim_set_time" },
    { 0x0C16, "anim_simple" },
    { 0x0C17, "anim_simple_notify" },
    { 0x0C18, "anim_single" },
    { 0x0C19, "anim_single_droppod_custom" },
    { 0x0C1A, "anim_single_end_early" },
    { 0x0C1B, "anim_single_failsafe" },
    { 0x0C1C, "anim_single_failsafeonguy" },
    { 0x0C1D, "anim_single_internal" },
    { 0x0C1E, "anim_single_mech" },
    { 0x0C1F, "anim_single_qte_middle" },
    { 0x0C20, "anim_single_qte_middle_fail" },
    { 0x0C21, "anim_single_queue" },
    { 0x0C22, "anim_single_run" },
    { 0x0C23, "anim_single_run_solo" },
    { 0x0C24, "anim_single_solo" },
    { 0x0C25, "anim_single_solo_custom" },
    { 0x0C26, "anim_single_solo_d" },
    { 0x0C27, "anim_single_solo_in_place" },
    { 0x0C28, "anim_single_solo_internal_vm" },
    { 0x0C29, "anim_single_solo_run" },
    { 0x0C2A, "anim_single_solo_vm" },
    { 0x0C2B, "anim_single_solo_with_lerp" },
    { 0x0C2C, "anim_single_solo_with_special_walk" },
    { 0x0C2D, "anim_single_solo_with_wait_flag" },
    { 0x0C2E, "anim_single_to_delete" },
    { 0x0C2F, "anim_single_to_delete_solo" },
    { 0x0C30, "anim_single_to_loop" },
    { 0x0C31, "anim_single_to_loop_solo" },
    { 0x0C32, "anim_single_with_gameplay" },
    { 0x0C33, "anim_spawn_generic_model" },
    { 0x0C34, "anim_spawn_model" },
    { 0x0C35, "anim_spawn_tag_model" },
    { 0x0C36, "anim_spawner_teleport" },
    { 0x0C37, "anim_speed" },
    { 0x0C38, "anim_start_at_groundpos" },
    { 0x0C39, "anim_start_pos" },
    { 0x0C3A, "anim_start_pos_solo" },
    { 0x0C3B, "anim_state" },
    { 0x0C3C, "anim_stop" },
    { 0x0C3D, "anim_stopanimscripted" },
    { 0x0C3E, "anim_struct" },
    { 0x0C3F, "anim_struct_exfil" },
    { 0x0C40, "anim_struct2" },
    { 0x0C41, "anim_tag" },
    { 0x0C42, "anim_teleport" },
    { 0x0C43, "anim_teleport_solo" },
    { 0x0C44, "anim_time" },
    { 0x0C45, "anim_up" },
    { 0x0C46, "anim_van_intro" },
    { 0x0C47, "anim_wait_func" },
    { 0x0C48, "anim_weight" },
    { 0x0C49, "anim_with_teleport" },
    { 0x0C4A, "animal_anims" },
    { 0x0C4B, "animalanimations" },
    { 0x0C4C, "animalias" },
    { 0x0C4D, "animarchetype" },
    { 0x0C4E, "animarray" },
    { 0x0C4F, "animarrayanyexist" },
    { 0x0C50, "animarrayfuncs" },
    { 0x0C51, "animarraypickrandom" },
    { 0x0C52, "animate_collapse_ent" },
    { 0x0C53, "animate_dead_body" },
    { 0x0C54, "animate_drills" },
    { 0x0C55, "animate_drive_idle" },
    { 0x0C56, "animate_drive_idle_on_dummies" },
    { 0x0C57, "animate_guys" },
    { 0x0C58, "animate_on_goal" },
    { 0x0C59, "animate_player_on_rig_simple" },
    { 0x0C5A, "animate_props_on_death" },
    { 0x0C5B, "animate_script_origin" },
    { 0x0C5C, "animate_the_other_guys" },
    { 0x0C5D, "animate_turret_with_viewmodel" },
    { 0x0C5E, "animated_gun" },
    { 0x0C5F, "animated_lights" },
    { 0x0C60, "animated_pod_function" },
    { 0x0C61, "animated_prop_anims" },
    { 0x0C62, "animateddeath" },
    { 0x0C63, "animatedpalmtrees" },
    { 0x0C64, "animatemodel" },
    { 0x0C65, "animatemoveintoplace" },
    { 0x0C66, "animatetreewind" },
    { 0x0C67, "animation_process" },
    { 0x0C68, "animation_think" },
    { 0x0C69, "animcbs" },
    { 0x0C6A, "animdodgeobstaclelistener" },
    { 0x0C6B, "animdown" },
    { 0x0C6C, "anime" },
    { 0x0C6D, "animent" },
    { 0x0C6E, "animflagnameindex" },
    { 0x0C6F, "animhasfacialoverride" },
    { 0x0C70, "animidledown" },
    { 0x0C71, "animidleup" },
    { 0x0C72, "animname" },
    { 0x0C73, "animnode" },
    { 0x0C74, "animontag" },
    { 0x0C75, "animontag_ragdoll_death" },
    { 0x0C76, "animontag_ragdoll_death_fall" },
    { 0x0C77, "animontag_unloading_vehicle_explosion" },
    { 0x0C78, "animplaybackrate" },
    { 0x0C79, "animref" },
    { 0x0C7A, "anims" },
    { 0x0C7B, "animsapplied" },
    { 0x0C7C, "animscript_sittag" },
    { 0x0C7D, "animscript_target" },
    { 0x0C7E, "animscriptdonotetracksthread" },
    { 0x0C7F, "animsequence" },
    { 0x0C80, "animset" },
    { 0x0C81, "animsets" },
    { 0x0C82, "animsound_aliases" },
    { 0x0C83, "animsound_exists" },
    { 0x0C84, "animsound_hud_extralines" },
    { 0x0C85, "animsound_hudlimit" },
    { 0x0C86, "animsound_start_tracker" },
    { 0x0C87, "animsound_start_tracker_loop" },
    { 0x0C88, "animsound_tagged" },
    { 0x0C89, "animsound_tracker" },
    { 0x0C8A, "animsounds" },
    { 0x0C8B, "animsounds_thisframe" },
    { 0x0C8C, "animstate" },
    { 0x0C8D, "animsubstate" },
    { 0x0C8E, "animtree" },
    { 0x0C8F, "animup" },
    { 0x0C90, "anml_doberman" },
    { 0x0C91, "announcerdisabled" },
    { 0x0C92, "annoyance_tracker" },
    { 0x0C93, "antiintrusion" },
    { 0x0C94, "any_enemy_is_able_to_attack" },
    { 0x0C95, "any_players_istouching" },
    { 0x0C96, "any_wheel_on_ground" },
    { 0x0C97, "anyattachmentisscope" },
    { 0x0C98, "anyplayersinkillcam" },
    { 0x0C99, "anystingermissilelockedon" },
    { 0x0C9A, "anythingistouching" },
    { 0x0C9B, "anythingtouchingtrigger" },
    { 0x0C9C, "apex" },
    { 0x0C9D, "apm_mine_deletekillcament" },
    { 0x0C9E, "applied_reverb" },
    { 0x0C9F, "apply_difficulty_frac_with_func" },
    { 0x0CA0, "apply_difficulty_step_with_func" },
    { 0x0CA1, "apply_end_fog" },
    { 0x0CA2, "apply_fog" },
    { 0x0CA3, "apply_friendly_fire_damage_modifier" },
    { 0x0CA4, "apply_jump_fx" },
    { 0x0CA5, "apply_option_to_selected_fx" },
    { 0x0CA6, "apply_reinforcement_perk" },
    { 0x0CA7, "apply_reverb" },
    { 0x0CA8, "apply_truckjunk" },
    { 0x0CA9, "apply_whizby" },
    { 0x0CAA, "applybombcarrierclass" },
    { 0x0CAB, "applyemp" },
    { 0x0CAC, "applyflagcarrierclass" },
    { 0x0CAD, "applyflash" },
    { 0x0CAE, "applyloadout" },
    { 0x0CAF, "applyperks" },
    { 0x0CB0, "applyprisonturretradararrow" },
    { 0x0CB1, "approach_barracks_combat_setup" },
    { 0x0CB2, "approach_handle_murica_movement_left" },
    { 0x0CB3, "approach_idle_ents" },
    { 0x0CB4, "approach_scene_ents" },
    { 0x0CB5, "approach_spawn_functions" },
    { 0x0CB6, "approach_types" },
    { 0x0CB7, "approachconditioncheckfunc" },
    { 0x0CB8, "approaching" },
    { 0x0CB9, "approaching_roundabout_dialogue" },
    { 0x0CBA, "approaching_standoff" },
    { 0x0CBB, "approachnumber" },
    { 0x0CBC, "approachtype" },
    { 0x0CBD, "approachtypefunc" },
    { 0x0CBE, "approachwaittillclose" },
    { 0x0CBF, "aquiring_targets_think" },
    { 0x0CC0, "ar_moment" },
    { 0x0CC1, "arc_point" },
    { 0x0CC2, "arcade_plane_controls" },
    { 0x0CC3, "arcademode" },
    { 0x0CC4, "arcademode_hud_timer" },
    { 0x0CC5, "arcademode_stop_timer" },
    { 0x0CC6, "arcademode_stoptime" },
    { 0x0CC7, "archetype_exists" },
    { 0x0CC8, "archetypechanged" },
    { 0x0CC9, "archetypeexists" },
    { 0x0CCA, "archetypes" },
    { 0x0CCB, "archive" },
    { 0x0CCC, "are_we_close" },
    { 0x0CCD, "aredifferent" },
    { 0x0CCE, "arm_repair_attempt" },
    { 0x0CCF, "armada_intro_screen" },
    { 0x0CD0, "armed" },
    { 0x0CD1, "armordamagehints" },
    { 0x0CD2, "armorpiercingmod" },
    { 0x0CD3, "armorvestmod" },
    { 0x0CD4, "armorygiveexoability" },
    { 0x0CD5, "armorypoints" },
    { 0x0CD6, "armorypurchasefail" },
    { 0x0CD7, "armorythink" },
    { 0x0CD8, "array" },
    { 0x0CD9, "array_2dadd" },
    { 0x0CDA, "array_add" },
    { 0x0CDB, "array_call" },
    { 0x0CDC, "array_checkaddattachment" },
    { 0x0CDD, "array_combine" },
    { 0x0CDE, "array_combine_all" },
    { 0x0CDF, "array_combine_keys" },
    { 0x0CE0, "array_combine_multiple" },
    { 0x0CE1, "array_combine_non_integer_indices" },
    { 0x0CE2, "array_combine_unique" },
    { 0x0CE3, "array_compare" },
    { 0x0CE4, "array_contains" },
    { 0x0CE5, "array_delete" },
    { 0x0CE6, "array_delete_evenly" },
    { 0x0CE7, "array_exclude" },
    { 0x0CE8, "array_find" },
    { 0x0CE9, "array_first" },
    { 0x0CEA, "array_index_by_classname" },
    { 0x0CEB, "array_index_by_parameters" },
    { 0x0CEC, "array_index_by_script_index" },
    { 0x0CED, "array_insert" },
    { 0x0CEE, "array_kill" },
    { 0x0CEF, "array_levelcall" },
    { 0x0CF0, "array_levelthread" },
    { 0x0CF1, "array_levelthread_safe" },
    { 0x0CF2, "array_merge" },
    { 0x0CF3, "array_merge_links" },
    { 0x0CF4, "array_notify" },
    { 0x0CF5, "array_randomize" },
    { 0x0CF6, "array_remove" },
    { 0x0CF7, "array_remove_array" },
    { 0x0CF8, "array_remove_dead" },
    { 0x0CF9, "array_remove_duplicates" },
    { 0x0CFA, "array_remove_index" },
    { 0x0CFB, "array_remove_nokeys" },
    { 0x0CFC, "array_removeclaimedtargets" },
    { 0x0CFD, "array_removedead" },
    { 0x0CFE, "array_removedead_keepkeys" },
    { 0x0CFF, "array_removedead_or_dying" },
    { 0x0D00, "array_removefirstinqueue" },
    { 0x0D01, "array_removeundefined" },
    { 0x0D02, "array_reverse" },
    { 0x0D03, "array_safe_delete" },
    { 0x0D04, "array_setgoalvolume" },
    { 0x0D05, "array_sort_by_handler" },
    { 0x0D06, "array_sort_with_func" },
    { 0x0D07, "array_sound_start" },
    { 0x0D08, "array_spawn" },
    { 0x0D09, "array_spawn_allow_fail" },
    { 0x0D0A, "array_spawn_cg" },
    { 0x0D0B, "array_spawn_function" },
    { 0x0D0C, "array_spawn_function_noteworthy" },
    { 0x0D0D, "array_spawn_function_targetname" },
    { 0x0D0E, "array_spawn_noteworthy" },
    { 0x0D0F, "array_spawn_targetname" },
    { 0x0D10, "array_spawn_targetname_allow_fail" },
    { 0x0D11, "array_spawn_targetname_cg" },
    { 0x0D12, "array_spawn_targetname_stagger" },
    { 0x0D13, "array_thread" },
    { 0x0D14, "array_thread_mod_delayed" },
    { 0x0D15, "array_thread_safe" },
    { 0x0D16, "array_thread4" },
    { 0x0D17, "array_thread5" },
    { 0x0D18, "array_wait" },
    { 0x0D19, "array_waitlogic1" },
    { 0x0D1A, "array_waitlogic2" },
    { 0x0D1B, "array_waittill_player_lookat" },
    { 0x0D1C, "array_waittill_player_lookat_proc" },
    { 0x0D1D, "arrayinsertion" },
    { 0x0D1E, "arrayremovevalue" },
    { 0x0D1F, "arrays_color_spawners" },
    { 0x0D20, "arrays_of_colorcoded_nodes" },
    { 0x0D21, "arrays_of_colorcoded_volumes" },
    { 0x0D22, "arrays_of_colorforced_ai" },
    { 0x0D23, "arrivalanim" },
    { 0x0D24, "arrivalendstance" },
    { 0x0D25, "arrivalnodetype" },
    { 0x0D26, "arrivalpathgoalpos" },
    { 0x0D27, "arrivalstance" },
    { 0x0D28, "arrivalstartdist" },
    { 0x0D29, "arrivaltype" },
    { 0x0D2A, "arrive" },
    { 0x0D2B, "art_print_fog" },
    { 0x0D2C, "artendfogfileexport" },
    { 0x0D2D, "artendvisionfileexport" },
    { 0x0D2E, "artfxprintlnfog" },
    { 0x0D2F, "artifact_pulse" },
    { 0x0D30, "artifacts" },
    { 0x0D31, "artifacts_fade" },
    { 0x0D32, "artillery_earthquake" },
    { 0x0D33, "artillerydangercenters" },
    { 0x0D34, "artilleryshellshock" },
    { 0x0D35, "artstartfogfileexport" },
    { 0x0D36, "artstartvisionfileexport" },
    { 0x0D37, "assault_drone_stinger_target_pos" },
    { 0x0D38, "assault_vehicle_ai_aerial_follow_path_outside" },
    { 0x0D39, "assault_vehicle_ai_aerial_movement" },
    { 0x0D3A, "assault_vehicle_ai_aerial_pathing_c4" },
    { 0x0D3B, "assault_vehicle_ai_aerial_pathing_turret" },
    { 0x0D3C, "assault_vehicle_ai_air_movement_func" },
    { 0x0D3D, "assault_vehicle_ai_can_see_living_enemy" },
    { 0x0D3E, "assault_vehicle_ai_end_on_owner_disconnect" },
    { 0x0D3F, "assault_vehicle_ai_enemy_exists_and_is_alive" },
    { 0x0D40, "assault_vehicle_ai_enemy_moved_air" },
    { 0x0D41, "assault_vehicle_ai_enemy_moved_ground" },
    { 0x0D42, "assault_vehicle_ai_follow_path" },
    { 0x0D43, "assault_vehicle_ai_get_camera_position" },
    { 0x0D44, "assault_vehicle_ai_get_nearest_node" },
    { 0x0D45, "assault_vehicle_ai_ground_movement" },
    { 0x0D46, "assault_vehicle_ai_ground_movement_loop" },
    { 0x0D47, "assault_vehicle_ai_init" },
    { 0x0D48, "assault_vehicle_ai_move_to_aerial_node" },
    { 0x0D49, "assault_vehicle_ai_path_timeout_time" },
    { 0x0D4A, "assault_vehicle_ai_pick_aerial_node" },
    { 0x0D4B, "assault_vehicle_ai_threat" },
    { 0x0D4C, "assault_vehicle_ai_weapons" },
    { 0x0D4D, "assaultfullstaticondeath" },
    { 0x0D4E, "assaulthandledeath" },
    { 0x0D4F, "assaulthandletimeoutwarning" },
    { 0x0D50, "assaulthudremove" },
    { 0x0D51, "assaulthudsetup" },
    { 0x0D52, "assaultobjectiveevent" },
    { 0x0D53, "assaultplayerexit" },
    { 0x0D54, "assaultsetinactivity" },
    { 0x0D55, "assaultvehiclemonitorweapons" },
    { 0x0D56, "assert_existance_of_anim" },
    { 0x0D57, "assert_existance_of_anim_vm" },
    { 0x0D58, "assert_existance_of_looping_anim" },
    { 0x0D59, "assert_if_anim_not_defined" },
    { 0x0D5A, "assert_if_identical_origins" },
    { 0x0D5B, "assertdisplayed" },
    { 0x0D5C, "assertdisplayed_b" },
    { 0x0D5D, "asset_name" },
    { 0x0D5E, "asset_names" },
    { 0x0D5F, "asset_type" },
    { 0x0D60, "assign_animals_tree" },
    { 0x0D61, "assign_animtree" },
    { 0x0D62, "assign_cloak_model" },
    { 0x0D63, "assign_drone_tree" },
    { 0x0D64, "assign_fx_to_trigger" },
    { 0x0D65, "assign_generic_human_tree" },
    { 0x0D66, "assign_goal_node" },
    { 0x0D67, "assign_goal_vol" },
    { 0x0D68, "assign_model" },
    { 0x0D69, "assign_nodes_to_zipline_guys" },
    { 0x0D6A, "assign_npcid" },
    { 0x0D6B, "assign_script_breachgroup_to_ents" },
    { 0x0D6C, "assign_spawns" },
    { 0x0D6D, "assign_spawns_version_2" },
    { 0x0D6E, "assign_spawns_version_3" },
    { 0x0D6F, "assign_unique_id" },
    { 0x0D70, "assignawards" },
    { 0x0D71, "assigned_brush" },
    { 0x0D72, "assigned_model" },
    { 0x0D73, "assigned_model_b" },
    { 0x0D74, "assigned_parent" },
    { 0x0D75, "assignpracticeroundclasses" },
    { 0x0D76, "assignteamspawns" },
    { 0x0D77, "assistedsuicide" },
    { 0x0D78, "assistedsuicideevent" },
    { 0x0D79, "assistplayer" },
    { 0x0D7A, "assistpoints" },
    { 0x0D7B, "assists_disabled" },
    { 0x0D7C, "ast_mus_on" },
    { 0x0D7D, "at_goal" },
    { 0x0D7E, "at_path_end" },
    { 0x0D7F, "at_rest" },
    { 0x0D80, "at_start" },
    { 0x0D81, "at_van_enemy_cleanup" },
    { 0x0D82, "atbrinkofdeath" },
    { 0x0D83, "atconcealmentnode" },
    { 0x0D84, "atk_bomber" },
    { 0x0D85, "atk_bomber_no_path_to_bomb_count" },
    { 0x0D86, "atk_bomber_update" },
    { 0x0D87, "atlas_base_weapon_manager" },
    { 0x0D88, "atlas_base_weapon_manager_elevator" },
    { 0x0D89, "atlas_building_roof_walla" },
    { 0x0D8A, "atlas_drone_damage_function" },
    { 0x0D8B, "atlas_guard" },
    { 0x0D8C, "atlas_guard_dialogue_line1" },
    { 0x0D8D, "atlas_guard1" },
    { 0x0D8E, "atlas_guard2" },
    { 0x0D8F, "atlas_guard3" },
    { 0x0D90, "atlas_guard4" },
    { 0x0D91, "atlas_guard5" },
    { 0x0D92, "atlas_guard6" },
    { 0x0D93, "atlas_guard7" },
    { 0x0D94, "atlas_intercepts" },
    { 0x0D95, "atlas_sign_flicker" },
    { 0x0D96, "atlas_suv_impact_fx" },
    { 0x0D97, "atlas_suv_rider_no_react" },
    { 0x0D98, "atlas_suv_rider_react" },
    { 0x0D99, "atlas_suv_rider_think" },
    { 0x0D9A, "atlas_van_explode" },
    { 0x0D9B, "atlas1" },
    { 0x0D9C, "atlas2" },
    { 0x0D9D, "atlascard_cormack_walk" },
    { 0x0D9E, "atlascard_irons_grab_card" },
    { 0x0D9F, "atlascard_irons_handshake" },
    { 0x0DA0, "atlascard_irons_leave" },
    { 0x0DA1, "atlascard_irons_place_hand" },
    { 0x0DA2, "atlascard_irons_tap" },
    { 0x0DA3, "atlascard_irons_turn" },
    { 0x0DA4, "atlascard_irons_walk" },
    { 0x0DA5, "atlasdrn_condition_callback_to_state_deathspin" },
    { 0x0DA6, "atlasdrn_condition_callback_to_state_destruct" },
    { 0x0DA7, "atlasdrn_condition_callback_to_state_distant" },
    { 0x0DA8, "atlasdrn_condition_callback_to_state_flyby" },
    { 0x0DA9, "atlasdrn_condition_callback_to_state_flying" },
    { 0x0DAA, "atlasdrn_condition_callback_to_state_flyover" },
    { 0x0DAB, "atlasdrn_condition_callback_to_state_hover" },
    { 0x0DAC, "atlasdrn_condition_callback_to_state_off" },
    { 0x0DAD, "atlasdrn_lens_focus" },
    { 0x0DAE, "atm_is_muted" },
    { 0x0DAF, "atm_max_off_time" },
    { 0x0DB0, "atm_max_on_time" },
    { 0x0DB1, "atm_mute_time" },
    { 0x0DB2, "atm_off_time" },
    { 0x0DB3, "atmosfogdistancescale" },
    { 0x0DB4, "atmosfogenabled" },
    { 0x0DB5, "atmosfogextinctionstrength" },
    { 0x0DB6, "atmosfoghalfplanedistance" },
    { 0x0DB7, "atmosfoghazecolor" },
    { 0x0DB8, "atmosfoghazespread" },
    { 0x0DB9, "atmosfoghazestrength" },
    { 0x0DBA, "atmosfogheightfogbaseheight" },
    { 0x0DBB, "atmosfogheightfogenabled" },
    { 0x0DBC, "atmosfogheightfoghalfplanedistance" },
    { 0x0DBD, "atmosfoginscatterstrength" },
    { 0x0DBE, "atmosfogskyangularfalloffenabled" },
    { 0x0DBF, "atmosfogskydistance" },
    { 0x0DC0, "atmosfogskyfalloffanglerange" },
    { 0x0DC1, "atmosfogskyfalloffstartangle" },
    { 0x0DC2, "atmosfogstartdistance" },
    { 0x0DC3, "atmosfogsundirection" },
    { 0x0DC4, "atmosfogsunfogcolor" },
    { 0x0DC5, "atrium_breach_signal_start" },
    { 0x0DC6, "atrium_timer_expire" },
    { 0x0DC7, "atriumanimations" },
    { 0x0DC8, "atriumboostjump" },
    { 0x0DC9, "atriumboostjumpguy" },
    { 0x0DCA, "atriumbreachexplosionnotetrack" },
    { 0x0DCB, "atriumbreachidle" },
    { 0x0DCC, "atriumbreachidleburke" },
    { 0x0DCD, "atriumbreachidleinfiltrators" },
    { 0x0DCE, "atriumbreachmonitoralliesinposition" },
    { 0x0DCF, "atriumdoorbreachdamage" },
    { 0x0DD0, "atriumdoorsopen" },
    { 0x0DD1, "atriumdoorsopenonalarm" },
    { 0x0DD2, "atriumlookatdialogue" },
    { 0x0DD3, "atriumreminderdialogue" },
    { 0x0DD4, "atriumsetupdialogue" },
    { 0x0DD5, "atriumshootfirstdialogue" },
    { 0x0DD6, "atriumtimer" },
    { 0x0DD7, "atriumtimewindow" },
    { 0x0DD8, "atrrestoremech" },
    { 0x0DD9, "attach_assault_drone_lights" },
    { 0x0DDA, "attach_bone" },
    { 0x0DDB, "attach_cig" },
    { 0x0DDC, "attach_cig_self" },
    { 0x0DDD, "attach_clip" },
    { 0x0DDE, "attach_ent" },
    { 0x0DDF, "attach_fixed_scanner" },
    { 0x0DE0, "attach_flashlight_in_hand" },
    { 0x0DE1, "attach_flashlight_on_gun" },
    { 0x0DE2, "attach_flashlight_on_vehicle_unload" },
    { 0x0DE3, "attach_fx_to_mechanism" },
    { 0x0DE4, "attach_housing" },
    { 0x0DE5, "attach_light_to_face" },
    { 0x0DE6, "attach_light_to_police_car" },
    { 0x0DE7, "attach_littlebird_parts" },
    { 0x0DE8, "attach_model_override" },
    { 0x0DE9, "attach_or_link" },
    { 0x0DEA, "attach_phone" },
    { 0x0DEB, "attach_player_current_weapon_to_anim_tag" },
    { 0x0DEC, "attach_player_current_weapon_to_rig" },
    { 0x0DED, "attach_pointlight_to_beam" },
    { 0x0DEE, "attach_scanner" },
    { 0x0DEF, "attach_scanner_turret" },
    { 0x0DF0, "attach_tag" },
    { 0x0DF1, "attach_wakefx" },
    { 0x0DF2, "attach_weapon_to_tag_sync" },
    { 0x0DF3, "attachdistortionfx" },
    { 0x0DF4, "attachedguys" },
    { 0x0DF5, "attachedmodels" },
    { 0x0DF6, "attachedpath" },
    { 0x0DF7, "attachedpropmodel" },
    { 0x0DF8, "attachedproptag" },
    { 0x0DF9, "attachedusemodel" },
    { 0x0DFA, "attachflag" },
    { 0x0DFB, "attachgrenademodel" },
    { 0x0DFC, "attachhat" },
    { 0x0DFD, "attachhead" },
    { 0x0DFE, "attachmentdeath" },
    { 0x0DFF, "attachmentexplode" },
    { 0x0E00, "attachmentmap_attachtoperk" },
    { 0x0E01, "attachmentmap_basetounique" },
    { 0x0E02, "attachmentmap_tobase" },
    { 0x0E03, "attachmentmap_tounique" },
    { 0x0E04, "attachmentmap_uniquetobase" },
    { 0x0E05, "attachmentperkmap" },
    { 0x0E06, "attachmenttype" },
    { 0x0E07, "attachmissiles" },
    { 0x0E08, "attachmodelti" },
    { 0x0E09, "attachprops" },
    { 0x0E0A, "attachpropsfunction" },
    { 0x0E0B, "attachusemodel" },
    { 0x0E0C, "attachweapon" },
    { 0x0E0D, "attack_accuracy" },
    { 0x0E0E, "attack_available" },
    { 0x0E0F, "attack_behavior" },
    { 0x0E10, "attack_damage_trigger" },
    { 0x0E11, "attack_delay" },
    { 0x0E12, "attack_drone_audio_handler" },
    { 0x0E13, "attack_drone_flybys_audio" },
    { 0x0E14, "attack_drone_formation_init" },
    { 0x0E15, "attack_drone_init" },
    { 0x0E16, "attack_drone_kamikaze_audio" },
    { 0x0E17, "attack_drone_kamikaze_flying_fx" },
    { 0x0E18, "attack_drone_queen_1shot_handler" },
    { 0x0E19, "attack_drone_queen_audio" },
    { 0x0E1A, "attack_drone_queen_flybys_audio" },
    { 0x0E1B, "attack_drone_queen_flying_fx" },
    { 0x0E1C, "attack_drones_nofly_zone_radius" },
    { 0x0E1D, "attack_drones_num_drones_per_queen" },
    { 0x0E1E, "attack_drones_num_queens" },
    { 0x0E1F, "attack_heli_cleanup" },
    { 0x0E20, "attack_heli_fx" },
    { 0x0E21, "attack_heli_safe_volumes" },
    { 0x0E22, "attack_hint_display" },
    { 0x0E23, "attack_if_buddy_killed" },
    { 0x0E24, "attack_origin_condition_threadd" },
    { 0x0E25, "attack_player_for_time" },
    { 0x0E26, "attack_sight_required" },
    { 0x0E27, "attackback" },
    { 0x0E28, "attacked_by_dog" },
    { 0x0E29, "attacker_isonmyteam" },
    { 0x0E2A, "attacker_troop_isonmyteam" },
    { 0x0E2B, "attackercandamageitem" },
    { 0x0E2C, "attackerdata" },
    { 0x0E2D, "attackerent" },
    { 0x0E2E, "attackerinlaststand" },
    { 0x0E2F, "attackerinremotekillstreak" },
    { 0x0E30, "attackerishittingteam" },
    { 0x0E31, "attackerlist" },
    { 0x0E32, "attackeronground" },
    { 0x0E33, "attackerposition" },
    { 0x0E34, "attackers" },
    { 0x0E35, "attackerstance" },
    { 0x0E36, "attackertable" },
    { 0x0E37, "attackheliaiburstsize" },
    { 0x0E38, "attackheliexcluders" },
    { 0x0E39, "attackhelifov" },
    { 0x0E3A, "attackheligraceperiod" },
    { 0x0E3B, "attackhelikillsai" },
    { 0x0E3C, "attackhelimemory" },
    { 0x0E3D, "attackhelimovetime" },
    { 0x0E3E, "attackheliplayerbreak" },
    { 0x0E3F, "attackhelirange" },
    { 0x0E40, "attackhelitargetreaquire" },
    { 0x0E41, "attackhelitimeout" },
    { 0x0E42, "attacking_player" },
    { 0x0E43, "attackmiss" },
    { 0x0E44, "attackmisstracktargetthread" },
    { 0x0E45, "attacknode" },
    { 0x0E46, "attacknothingtodo" },
    { 0x0E47, "attackoffset" },
    { 0x0E48, "attackradius" },
    { 0x0E49, "attackradiussq" },
    { 0x0E4A, "attackstate" },
    { 0x0E4B, "attacksuppressableenemy" },
    { 0x0E4C, "attackteleportthread" },
    { 0x0E4D, "attackvisibleenemy" },
    { 0x0E4E, "attackzheight" },
    { 0x0E4F, "attackzheightdown" },
    { 0x0E50, "attempt_execute" },
    { 0x0E51, "attempt_mark_enemy" },
    { 0x0E52, "attract_range" },
    { 0x0E53, "attract_strength" },
    { 0x0E54, "attractor" },
    { 0x0E55, "attractor2" },
    { 0x0E56, "attractornumber" },
    { 0x0E57, "aud" },
    { 0x0E58, "aud_2b_missile_final" },
    { 0x0E59, "aud_2b_missile1" },
    { 0x0E5A, "aud_2b_missile2" },
    { 0x0E5B, "aud_2b_missile3" },
    { 0x0E5C, "aud_ac_units" },
    { 0x0E5D, "aud_add_progress_map" },
    { 0x0E5E, "aud_alarm_submix" },
    { 0x0E5F, "aud_ally_card_accept" },
    { 0x0E60, "aud_ally_card_error" },
    { 0x0E61, "aud_ally_card_swipe" },
    { 0x0E62, "aud_ambient_animations" },
    { 0x0E63, "aud_ambient_helicopter" },
    { 0x0E64, "aud_approaching_poolhouse" },
    { 0x0E65, "aud_ascent_final_warbird" },
    { 0x0E66, "aud_atlas_suv_explo" },
    { 0x0E67, "aud_autopsy_entrance" },
    { 0x0E68, "aud_autopsy_entrance_vo" },
    { 0x0E69, "aud_autopsy_knife_pry_door" },
    { 0x0E6A, "aud_avs_enemy_warbird" },
    { 0x0E6B, "aud_avs_enemy_warbird_2" },
    { 0x0E6C, "aud_avs_enemy_warbird_grapple" },
    { 0x0E6D, "aud_avs_intro_allies_1" },
    { 0x0E6E, "aud_avs_intro_allies_2" },
    { 0x0E6F, "aud_background_chatter" },
    { 0x0E70, "aud_background_chatter_gate" },
    { 0x0E71, "aud_balcony_aircraft_wait" },
    { 0x0E72, "aud_ball_fountain" },
    { 0x0E73, "aud_bet_exo_climb_gear_lt" },
    { 0x0E74, "aud_bet_exo_climb_gear_rt" },
    { 0x0E75, "aud_bet_exo_climb_hit_lt" },
    { 0x0E76, "aud_bet_exo_climb_hit_rt" },
    { 0x0E77, "aud_bet_exo_climb_settle_lt" },
    { 0x0E78, "aud_bet_exo_climb_settle_rt" },
    { 0x0E79, "aud_bet_exo_climb_windup_lt" },
    { 0x0E7A, "aud_bet_exo_climb_windup_rt" },
    { 0x0E7B, "aud_big_gate_open_stage_1" },
    { 0x0E7C, "aud_big_gate_open_stage_2" },
    { 0x0E7D, "aud_big_gate_pre_open" },
    { 0x0E7E, "aud_big_gate_stop_stage_1" },
    { 0x0E7F, "aud_big_gate_stop_stage_2" },
    { 0x0E80, "aud_briefing" },
    { 0x0E81, "aud_building_drop" },
    { 0x0E82, "aud_building_pre_drop" },
    { 0x0E83, "aud_burke_bus1_land" },
    { 0x0E84, "aud_burke_hill_slide_stump" },
    { 0x0E85, "aud_burke_intro_anim" },
    { 0x0E86, "aud_burke_ledge_jump" },
    { 0x0E87, "aud_burke_nearing_cliff" },
    { 0x0E88, "aud_burke_open_door" },
    { 0x0E89, "aud_burke_river_over_log" },
    { 0x0E8A, "aud_burke_riverbank_footstep_left" },
    { 0x0E8B, "aud_burke_riverbank_footstep_right" },
    { 0x0E8C, "aud_burke_riverbank_slide" },
    { 0x0E8D, "aud_burke_step_over_log" },
    { 0x0E8E, "aud_burke_stumble_knee" },
    { 0x0E8F, "aud_burke_stumble_run" },
    { 0x0E90, "aud_burke_takedown" },
    { 0x0E91, "aud_burke_tree_cover_01" },
    { 0x0E92, "aud_burke_wall_climb" },
    { 0x0E93, "aud_burke_water_deep_step" },
    { 0x0E94, "aud_burke_water_enter" },
    { 0x0E95, "aud_burke_water_exit" },
    { 0x0E96, "aud_burke_water_fall_forward" },
    { 0x0E97, "aud_burke_water_footstep_left" },
    { 0x0E98, "aud_burke_water_footstep_right" },
    { 0x0E99, "aud_burke_water_jump" },
    { 0x0E9A, "aud_burke_water_shallow_step" },
    { 0x0E9B, "aud_burke_water_slip" },
    { 0x0E9C, "aud_cap_45_onearm_toss" },
    { 0x0E9D, "aud_cap_escape_to_heli_truck_1" },
    { 0x0E9E, "aud_cap_escape_to_heli_truck_2" },
    { 0x0E9F, "aud_cap_heli_sfx_01" },
    { 0x0EA0, "aud_cap_heli_sfx_02" },
    { 0x0EA1, "aud_cap_heli_sfx_03" },
    { 0x0EA2, "aud_cap_heli_sfx_04" },
    { 0x0EA3, "aud_cap_heli_sfx_05" },
    { 0x0EA4, "aud_cap_heli_sfx_06" },
    { 0x0EA5, "aud_cap_interrogation_transition_vo" },
    { 0x0EA6, "aud_cap_s2_trolley_sfx_01" },
    { 0x0EA7, "aud_cap_s2_trolley_sfx_02" },
    { 0x0EA8, "aud_cap_s2_trolley_sfx_03" },
    { 0x0EA9, "aud_cap_s2_trolley_sfx_03_crk" },
    { 0x0EAA, "aud_cap_s2_trolley_sfx_04" },
    { 0x0EAB, "aud_cap_s2_trolley_sfx_05" },
    { 0x0EAC, "aud_cap_s2_trolley_sfx_06" },
    { 0x0EAD, "aud_cap_s2_trolley_sfx_07" },
    { 0x0EAE, "aud_cap_s2_trolley_sfx_08" },
    { 0x0EAF, "aud_cap_s2_trolley_sfx_09" },
    { 0x0EB0, "aud_cap_s2_trolley_sfx_10" },
    { 0x0EB1, "aud_cap_sml_onearm_toss" },
    { 0x0EB2, "aud_captured_foley_override_handler" },
    { 0x0EB3, "aud_captured_setup_anims" },
    { 0x0EB4, "aud_cave_ambience" },
    { 0x0EB5, "aud_cave_cascade" },
    { 0x0EB6, "aud_check_sound_done" },
    { 0x0EB7, "aud_chopper_sniper_bullet" },
    { 0x0EB8, "aud_chopper_sniper_whizby" },
    { 0x0EB9, "aud_clamp" },
    { 0x0EBA, "aud_clear_sticky_threat" },
    { 0x0EBB, "aud_close_sounds" },
    { 0x0EBC, "aud_combat_clearing_1_warbird" },
    { 0x0EBD, "aud_combat_clearing_2_littlebird_1" },
    { 0x0EBE, "aud_combat_clearing_2_littlebird_2" },
    { 0x0EBF, "aud_combat_clearing_3_littlebird_1" },
    { 0x0EC0, "aud_combat_clearing_3_littlebird_2" },
    { 0x0EC1, "aud_conduit_smash" },
    { 0x0EC2, "aud_copy_vector" },
    { 0x0EC3, "aud_cormack_approach" },
    { 0x0EC4, "aud_cormack_final_monitor_smash" },
    { 0x0EC5, "aud_cormack_final_smash_promo" },
    { 0x0EC6, "aud_cormack_grapple_kill" },
    { 0x0EC7, "aud_cormack_monitor_smash_promo" },
    { 0x0EC8, "aud_cormack_rappel_cable" },
    { 0x0EC9, "aud_courtyard_hangar_door_close" },
    { 0x0ECA, "aud_courtyard_hangar_door_hack" },
    { 0x0ECB, "aud_courtyard_hangar_door_hack_idle" },
    { 0x0ECC, "aud_courtyard_hangar_door_open" },
    { 0x0ECD, "aud_crane_mount_crouch_jump" },
    { 0x0ECE, "aud_crane_mount_lt_hand_hit" },
    { 0x0ECF, "aud_crane_mount_lt_hand_rest" },
    { 0x0ED0, "aud_crane_mount_rt_hand_hit" },
    { 0x0ED1, "aud_crane_mount_rt_hand_rest" },
    { 0x0ED2, "aud_crash_wakeup_sfx" },
    { 0x0ED3, "aud_create_drive_envs" },
    { 0x0ED4, "aud_create_entity" },
    { 0x0ED5, "aud_create_linked_entity" },
    { 0x0ED6, "aud_ctyard_vrap01" },
    { 0x0ED7, "aud_ctyard_vrap02" },
    { 0x0ED8, "aud_ctyard_vrap04" },
    { 0x0ED9, "aud_ctyard_vrap05" },
    { 0x0EDA, "aud_delete_on_sounddone" },
    { 0x0EDB, "aud_destroy_deployed_pod" },
    { 0x0EDC, "aud_det_foley_override_handler" },
    { 0x0EDD, "aud_detach_from_vtol" },
    { 0x0EDE, "aud_disable_deathsdoor_audio" },
    { 0x0EDF, "aud_dna_bomb_01" },
    { 0x0EE0, "aud_dna_bomb_02" },
    { 0x0EE1, "aud_door" },
    { 0x0EE2, "aud_door_takedown_mix_handler" },
    { 0x0EE3, "aud_door_takedown_scream" },
    { 0x0EE4, "aud_drone_attack" },
    { 0x0EE5, "aud_drone_investigating" },
    { 0x0EE6, "aud_drone_start_jets" },
    { 0x0EE7, "aud_drone_view_intro_start" },
    { 0x0EE8, "aud_drone_view_intro_target" },
    { 0x0EE9, "aud_drop_pod_fire" },
    { 0x0EEA, "aud_drop_pod_land_fail" },
    { 0x0EEB, "aud_drop_pod_land_success" },
    { 0x0EEC, "aud_drop_pod_trophy_kill" },
    { 0x0EED, "aud_duck" },
    { 0x0EEE, "aud_dyanmic_event" },
    { 0x0EEF, "aud_dynamic_event_startup" },
    { 0x0EF0, "aud_enable_deathsdoor_audio" },
    { 0x0EF1, "aud_engine_disable" },
    { 0x0EF2, "aud_engine_throttle_amount" },
    { 0x0EF3, "aud_engine_wait" },
    { 0x0EF4, "aud_enter_vtol" },
    { 0x0EF5, "aud_escape_doctor_bodybag" },
    { 0x0EF6, "aud_escape_give_gun_exo" },
    { 0x0EF7, "aud_escape_guard_takedown_door" },
    { 0x0EF8, "aud_escape_keycard" },
    { 0x0EF9, "aud_estate_grounds_ambience" },
    { 0x0EFA, "aud_estate_grounds_emitters" },
    { 0x0EFB, "aud_estate_living_ambience" },
    { 0x0EFC, "aud_estate_security_ambience" },
    { 0x0EFD, "aud_exfil_door_1" },
    { 0x0EFE, "aud_exfil_door_2a" },
    { 0x0EFF, "aud_exfil_door_2b" },
    { 0x0F00, "aud_exfil_vtol_ascend" },
    { 0x0F01, "aud_exfil_vtol_grapple" },
    { 0x0F02, "aud_exfil_vtol_start" },
    { 0x0F03, "aud_exfil_vtol_wind" },
    { 0x0F04, "aud_exit_vtol" },
    { 0x0F05, "aud_exo_climb_burke" },
    { 0x0F06, "aud_exo_climb_flank_land" },
    { 0x0F07, "aud_exo_climb_flank_over" },
    { 0x0F08, "aud_exo_climb_gear_lt" },
    { 0x0F09, "aud_exo_climb_gear_rt" },
    { 0x0F0A, "aud_exo_climb_gideon_land" },
    { 0x0F0B, "aud_exo_climb_hit_lt" },
    { 0x0F0C, "aud_exo_climb_hit_rt" },
    { 0x0F0D, "aud_exo_climb_mount_jump" },
    { 0x0F0E, "aud_exo_climb_mount_land" },
    { 0x0F0F, "aud_exo_climb_rest_lt" },
    { 0x0F10, "aud_exo_climb_rest_rt" },
    { 0x0F11, "aud_exo_climb_slide_push" },
    { 0x0F12, "aud_exo_climb_slide_start" },
    { 0x0F13, "aud_exo_climb_slide_stop" },
    { 0x0F14, "aud_exo_climb_windup_lt" },
    { 0x0F15, "aud_exo_climb_windup_rt" },
    { 0x0F16, "aud_facility_breach_start" },
    { 0x0F17, "aud_fade_in" },
    { 0x0F18, "aud_fade_in_music" },
    { 0x0F19, "aud_fade_loop_out_and_delete" },
    { 0x0F1A, "aud_fade_loop_out_and_delete_temp" },
    { 0x0F1B, "aud_fade_out" },
    { 0x0F1C, "aud_fade_out_and_delete" },
    { 0x0F1D, "aud_fadeup_intro_loop" },
    { 0x0F1E, "aud_fall_scream" },
    { 0x0F1F, "aud_falls_climbing" },
    { 0x0F20, "aud_fin_rocket_damage_vfx" },
    { 0x0F21, "aud_find_exploder" },
    { 0x0F22, "aud_flag_handler" },
    { 0x0F23, "aud_foam_room_emitters" },
    { 0x0F24, "aud_foliage_insects" },
    { 0x0F25, "aud_foliage_mix" },
    { 0x0F26, "aud_foliage_movement" },
    { 0x0F27, "aud_forest_ambience" },
    { 0x0F28, "aud_forest_ambient_loops" },
    { 0x0F29, "aud_fountains" },
    { 0x0F2A, "aud_garage_hyd_wrench" },
    { 0x0F2B, "aud_garage_lift" },
    { 0x0F2C, "aud_gas_sfx" },
    { 0x0F2D, "aud_get_ambi_submix" },
    { 0x0F2E, "aud_get_envelope_domain" },
    { 0x0F2F, "aud_get_music_submix" },
    { 0x0F30, "aud_get_optional_param" },
    { 0x0F31, "aud_get_player_locamote_state" },
    { 0x0F32, "aud_get_progress_map" },
    { 0x0F33, "aud_get_sticky_threat" },
    { 0x0F34, "aud_get_threat_level" },
    { 0x0F35, "aud_gideon_autopsy_halls_start" },
    { 0x0F36, "aud_gideon_heli_runout_kick" },
    { 0x0F37, "aud_gideon_heli_runout_start" },
    { 0x0F38, "aud_gideon_test_chamber_ascend_start" },
    { 0x0F39, "aud_gideon_test_chamber_bodybag_1" },
    { 0x0F3A, "aud_gideon_test_chamber_bodybag_2" },
    { 0x0F3B, "aud_gideon_test_chamber_climb_stairs_1" },
    { 0x0F3C, "aud_gideon_test_chamber_climb_stairs_2" },
    { 0x0F3D, "aud_gideon_test_chamber_descend_stairs" },
    { 0x0F3E, "aud_gideon_test_chamber_descend_stairs_2" },
    { 0x0F3F, "aud_gideon_test_chamber_door_kick" },
    { 0x0F40, "aud_gideon_test_chamber_security" },
    { 0x0F41, "aud_gideon_test_chamber_stair_door" },
    { 0x0F42, "aud_grapple_from_foliage" },
    { 0x0F43, "aud_grapple_infil" },
    { 0x0F44, "aud_grapple_kill_foliage" },
    { 0x0F45, "aud_grapple_land_debris" },
    { 0x0F46, "aud_grapple_launch" },
    { 0x0F47, "aud_grapple_monitor" },
    { 0x0F48, "aud_grates" },
    { 0x0F49, "aud_ground_veh_deathwatch" },
    { 0x0F4A, "aud_ground_veh_loops" },
    { 0x0F4B, "aud_ground_veh_speed_mapping" },
    { 0x0F4C, "aud_guard_station_ambience" },
    { 0x0F4D, "aud_guard_station_main_door" },
    { 0x0F4E, "aud_guardhouse_foley_cormack" },
    { 0x0F4F, "aud_gun_throw_logic" },
    { 0x0F50, "aud_handle_alarms" },
    { 0x0F51, "aud_handle_buoy_sfx" },
    { 0x0F52, "aud_handle_clearing_dambs" },
    { 0x0F53, "aud_handle_earthquake" },
    { 0x0F54, "aud_handle_gangam_jets" },
    { 0x0F55, "aud_handle_incoming" },
    { 0x0F56, "aud_handle_map_setups" },
    { 0x0F57, "aud_handle_river_progress_flags" },
    { 0x0F58, "aud_handle_river_sfx" },
    { 0x0F59, "aud_handle_river_shallow_flag" },
    { 0x0F5A, "aud_handle_so_missile" },
    { 0x0F5B, "aud_handle_vista_jets" },
    { 0x0F5C, "aud_handle_warning_vo" },
    { 0x0F5D, "aud_handle_wave_incoming" },
    { 0x0F5E, "aud_handle_waves_crash" },
    { 0x0F5F, "aud_hangar_ambience" },
    { 0x0F60, "aud_hangar_car_door_exit" },
    { 0x0F61, "aud_hangar_door_exit" },
    { 0x0F62, "aud_hangar_door_open" },
    { 0x0F63, "aud_hangar_walla" },
    { 0x0F64, "aud_hatch_gideon" },
    { 0x0F65, "aud_hatch_plr" },
    { 0x0F66, "aud_hazmat_guy_foley" },
    { 0x0F67, "aud_hazmat_guy_pushes_alarm" },
    { 0x0F68, "aud_heli_battle_flyover" },
    { 0x0F69, "aud_heli_crash_pos" },
    { 0x0F6A, "aud_heli_escape_idle_sfx" },
    { 0x0F6B, "aud_heli_manticore_flyover" },
    { 0x0F6C, "aud_helicopter_deathwatch" },
    { 0x0F6D, "aud_helo_spotlight_spawn" },
    { 0x0F6E, "aud_hostage_truck_hits_water" },
    { 0x0F6F, "aud_hostage_truck_over_curb" },
    { 0x0F70, "aud_hostage_truck_over_edge" },
    { 0x0F71, "aud_hostage_truck_tbone" },
    { 0x0F72, "aud_human_activity_streams" },
    { 0x0F73, "aud_ilana_carmack_escape_controlroom" },
    { 0x0F74, "aud_ilana_carmack_escape_controlroom_attack" },
    { 0x0F75, "aud_ilana_carmack_escape_hallway" },
    { 0x0F76, "aud_ilana_carmack_escape_hallway_end" },
    { 0x0F77, "aud_ilana_carmack_escape_takedown" },
    { 0x0F78, "aud_ilana_carmack_rescue_01" },
    { 0x0F79, "aud_impact_monitor" },
    { 0x0F7A, "aud_impact_system_diveboat" },
    { 0x0F7B, "aud_impact_system_hovertank" },
    { 0x0F7C, "aud_impact_system_jetbike" },
    { 0x0F7D, "aud_in_zone" },
    { 0x0F7E, "aud_incin_after" },
    { 0x0F7F, "aud_incin_after_loop1" },
    { 0x0F80, "aud_incin_amb_kill" },
    { 0x0F81, "aud_incin_blackout" },
    { 0x0F82, "aud_incin_cart_done" },
    { 0x0F83, "aud_incin_cart_push" },
    { 0x0F84, "aud_incin_cart_push_stop" },
    { 0x0F85, "aud_incin_cart_start" },
    { 0x0F86, "aud_incin_flame_logic_first_burst" },
    { 0x0F87, "aud_incin_flame_loop" },
    { 0x0F88, "aud_incin_flame_loop_2" },
    { 0x0F89, "aud_incin_pilot_light" },
    { 0x0F8A, "aud_incin_pilot_light1" },
    { 0x0F8B, "aud_incin_pilot_light2" },
    { 0x0F8C, "aud_incin_pilot_light3" },
    { 0x0F8D, "aud_incin_pilot_light4" },
    { 0x0F8E, "aud_incin_pilot_light5" },
    { 0x0F8F, "aud_incin_pipe_burst" },
    { 0x0F90, "aud_incin_pipe_grab" },
    { 0x0F91, "aud_init" },
    { 0x0F92, "aud_insect_sound" },
    { 0x0F93, "aud_intel" },
    { 0x0F94, "aud_interrogation_music_pt1" },
    { 0x0F95, "aud_interrogation_music_pt2" },
    { 0x0F96, "aud_interrogation_scene" },
    { 0x0F97, "aud_into_mech_missle" },
    { 0x0F98, "aud_intro_caravan_mute" },
    { 0x0F99, "aud_intro_caravan_passby" },
    { 0x0F9A, "aud_intro_caravan_unmute" },
    { 0x0F9B, "aud_intro_drone" },
    { 0x0F9C, "aud_intro_foley" },
    { 0x0F9D, "aud_intro_heli_flyover" },
    { 0x0F9E, "aud_intro_to_elev_walla" },
    { 0x0F9F, "aud_intro_truck_gate" },
    { 0x0FA0, "aud_intro_truck_passby_01" },
    { 0x0FA1, "aud_intro_truck_passby_02" },
    { 0x0FA2, "aud_intro_truck_stop" },
    { 0x0FA3, "aud_introblack_bullet" },
    { 0x0FA4, "aud_irons_reveal_bomb_shake" },
    { 0x0FA5, "aud_irons_reveal_bomb_shake_02" },
    { 0x0FA6, "aud_irons_reveal_star_trek_door" },
    { 0x0FA7, "aud_irons_says_hello" },
    { 0x0FA8, "aud_ironsstealth" },
    { 0x0FA9, "aud_is_even" },
    { 0x0FAA, "aud_is_specops" },
    { 0x0FAB, "aud_jeep_death_listener" },
    { 0x0FAC, "aud_knox_keypad" },
    { 0x0FAD, "aud_knox_thermite" },
    { 0x0FAE, "aud_knox_thermite_promo" },
    { 0x0FAF, "aud_lab_ambient_emitters" },
    { 0x0FB0, "aud_lab_foley_override_handler" },
    { 0x0FB1, "aud_lab_intro_screen" },
    { 0x0FB2, "aud_lab_phone_wait" },
    { 0x0FB3, "aud_lab_tech_chair_startle_1" },
    { 0x0FB4, "aud_lab_tech_chair_startle_2" },
    { 0x0FB5, "aud_lab_tech_desk_bump" },
    { 0x0FB6, "aud_laser_energy_beam_start" },
    { 0x0FB7, "aud_laser_pre_move_down" },
    { 0x0FB8, "aud_last_time" },
    { 0x0FB9, "aud_level_fadein" },
    { 0x0FBA, "aud_limp_exo" },
    { 0x0FBB, "aud_limp_off" },
    { 0x0FBC, "aud_limp_on" },
    { 0x0FBD, "aud_little_bird_hit" },
    { 0x0FBE, "aud_lockdown_alarm" },
    { 0x0FBF, "aud_lowstealth" },
    { 0x0FC0, "aud_manticore_crane" },
    { 0x0FC1, "aud_max" },
    { 0x0FC2, "aud_mech_crush_guy" },
    { 0x0FC3, "aud_mech_grapple_pitch_up" },
    { 0x0FC4, "aud_mech_idle_sfx" },
    { 0x0FC5, "aud_mech_jump" },
    { 0x0FC6, "aud_mech_missile_fire" },
    { 0x0FC7, "aud_mech_obj_move" },
    { 0x0FC8, "aud_mech_obj_move_end" },
    { 0x0FC9, "aud_mech_obj_move_wait" },
    { 0x0FCA, "aud_mech_panic_walla_watcher" },
    { 0x0FCB, "aud_mech_scanner" },
    { 0x0FCC, "aud_mech_trucks_enter" },
    { 0x0FCD, "aud_mech1_bg_truck" },
    { 0x0FCE, "aud_mechkill_catchdude" },
    { 0x0FCF, "aud_median_impact" },
    { 0x0FD0, "aud_meet_atlast_roof_explode" },
    { 0x0FD1, "aud_microwave_grenade" },
    { 0x0FD2, "aud_microwave_grenade_sparks_dude" },
    { 0x0FD3, "aud_microwave_grenade_sparks_env" },
    { 0x0FD4, "aud_min" },
    { 0x0FD5, "aud_monitor_irons" },
    { 0x0FD6, "aud_morgue_bodybag_doors" },
    { 0x0FD7, "aud_morgue_bodybag_line_emt" },
    { 0x0FD8, "aud_morgue_computer_door_entry_sfx" },
    { 0x0FD9, "aud_mus_boost" },
    { 0x0FDA, "aud_music_state" },
    { 0x0FDB, "aud_num_alive_enemies" },
    { 0x0FDC, "aud_observation_guard_radio" },
    { 0x0FDD, "aud_old_music_state" },
    { 0x0FDE, "aud_onearm_weapon_swap" },
    { 0x0FDF, "aud_overrides" },
    { 0x0FE0, "aud_pa_announc_01" },
    { 0x0FE1, "aud_pa_announc_02" },
    { 0x0FE2, "aud_pa_announc_03" },
    { 0x0FE3, "aud_pa_announc_04" },
    { 0x0FE4, "aud_painting_fall" },
    { 0x0FE5, "aud_panic_walla" },
    { 0x0FE6, "aud_patching_in_foley" },
    { 0x0FE7, "aud_patrol_helo_debris_sfx" },
    { 0x0FE8, "aud_penthouse_front_door" },
    { 0x0FE9, "aud_percent_chance" },
    { 0x0FEA, "aud_piston_ent" },
    { 0x0FEB, "aud_pitbull_crash_concussion" },
    { 0x0FEC, "aud_play" },
    { 0x0FED, "aud_play_announcer_warning" },
    { 0x0FEE, "aud_play_distance_attenuated_2d" },
    { 0x0FEF, "aud_play_dust" },
    { 0x0FF0, "aud_play_dynamic_explosion" },
    { 0x0FF1, "aud_play_horror_ambience" },
    { 0x0FF2, "aud_play_laser_move_down" },
    { 0x0FF3, "aud_play_laser_move_up" },
    { 0x0FF4, "aud_play_line_emitter" },
    { 0x0FF5, "aud_play_pcap_vo" },
    { 0x0FF6, "aud_play_pod_impact" },
    { 0x0FF7, "aud_play_point_source_loop" },
    { 0x0FF8, "aud_play_rocket_travel_loops" },
    { 0x0FF9, "aud_play_tank_explosion" },
    { 0x0FFA, "aud_play_trophy_fire" },
    { 0x0FFB, "aud_player_bus_exo_jump" },
    { 0x0FFC, "aud_player_bus_exo_land" },
    { 0x0FFD, "aud_player_bus_jump_handplant" },
    { 0x0FFE, "aud_player_bus_land" },
    { 0x0FFF, "aud_player_bus1_exo_land" },
    { 0x1000, "aud_player_bus1_land" },
    { 0x1001, "aud_player_climb_foley" },
    { 0x1002, "aud_player_climb_to_ledge" },
    { 0x1003, "aud_player_computer" },
    { 0x1004, "aud_player_computer_gl_timing_fix" },
    { 0x1005, "aud_player_computer_promo" },
    { 0x1006, "aud_player_exo_punch_driver" },
    { 0x1007, "aud_player_exo_punch_metal_plate" },
    { 0x1008, "aud_player_gets_in_tank" },
    { 0x1009, "aud_player_grab_mirror" },
    { 0x100A, "aud_player_hill_slide" },
    { 0x100B, "aud_player_jump_back_to_bus" },
    { 0x100C, "aud_player_jump_to_truck" },
    { 0x100D, "aud_player_land_back_on_bus" },
    { 0x100E, "aud_player_land_on_truck" },
    { 0x100F, "aud_player_rappel_complete" },
    { 0x1010, "aud_player_throw_driver" },
    { 0x1011, "aud_player_throw_metal_plate" },
    { 0x1012, "aud_player_wall_climb_01" },
    { 0x1013, "aud_player_wall_climb_02" },
    { 0x1014, "aud_player_wall_climb_03" },
    { 0x1015, "aud_player_wall_climb_04" },
    { 0x1016, "aud_player_wall_climb_05" },
    { 0x1017, "aud_playermech_end" },
    { 0x1018, "aud_playermech_foley_override_handler" },
    { 0x1019, "aud_playermech_start" },
    { 0x101A, "aud_plr_hit" },
    { 0x101B, "aud_plr_hit_vo_line" },
    { 0x101C, "aud_plr_hit_vo_look" },
    { 0x101D, "aud_plr_hit_vo_move_back" },
    { 0x101E, "aud_plr_hit_vo_move_forward" },
    { 0x101F, "aud_plr_inside_mech" },
    { 0x1020, "aud_pod_arm_reach" },
    { 0x1021, "aud_pod_hits_ground" },
    { 0x1022, "aud_pod_hits_ground_corrected" },
    { 0x1023, "aud_pod_scene_begin" },
    { 0x1024, "aud_pod_turbulence_01" },
    { 0x1025, "aud_pod_turbulence_02" },
    { 0x1026, "aud_poolhouse_ambience" },
    { 0x1027, "aud_post_courtyard_emitters" },
    { 0x1028, "aud_print" },
    { 0x1029, "aud_print_3d_on_ent" },
    { 0x102A, "aud_print_debug" },
    { 0x102B, "aud_print_error" },
    { 0x102C, "aud_print_synch" },
    { 0x102D, "aud_print_warning" },
    { 0x102E, "aud_print_zone" },
    { 0x102F, "aud_print_zone_small" },
    { 0x1030, "aud_rappel_player_hookup" },
    { 0x1031, "aud_rappel_player_movement_start" },
    { 0x1032, "aud_rappel_player_movement_stop" },
    { 0x1033, "aud_reached_penthouse" },
    { 0x1034, "aud_ready_hooks" },
    { 0x1035, "aud_recon_foley" },
    { 0x1036, "aud_red_light" },
    { 0x1037, "aud_reinforcements_door1" },
    { 0x1038, "aud_reinforcements_door2" },
    { 0x1039, "aud_rescue_drone" },
    { 0x103A, "aud_rescue_sfx_a" },
    { 0x103B, "aud_rescue_sfx_b" },
    { 0x103C, "aud_rescue_sfx_c" },
    { 0x103D, "aud_rescue_sfx_d" },
    { 0x103E, "aud_rescue_sfx_e" },
    { 0x103F, "aud_rescue_sfx_f" },
    { 0x1040, "aud_rescue_sfx_g" },
    { 0x1041, "aud_rocket_launch_start" },
    { 0x1042, "aud_rocket_stage_01_start" },
    { 0x1043, "aud_rooftop_warbird_departing" },
    { 0x1044, "aud_rooftop_wind_volume" },
    { 0x1045, "aud_rooftops_ambience" },
    { 0x1046, "aud_rotate_vector_yaw" },
    { 0x1047, "aud_run_tank_system" },
    { 0x1048, "aud_s1_elevator_boss_foley" },
    { 0x1049, "aud_s1_elevator_cormack_foley" },
    { 0x104A, "aud_s1_elevator_guard_foley" },
    { 0x104B, "aud_s1_elevator_kick_1" },
    { 0x104C, "aud_s1_elevator_kick_2" },
    { 0x104D, "aud_s2walk_alarm_tone_lp" },
    { 0x104E, "aud_s2walk_cell_prisoners" },
    { 0x104F, "aud_s2walk_cells_foley_mix" },
    { 0x1050, "aud_s2walk_clear_foley_mix" },
    { 0x1051, "aud_s2walk_cormack_punched" },
    { 0x1052, "aud_s2walk_door_close" },
    { 0x1053, "aud_s2walk_door_open" },
    { 0x1054, "aud_s2walk_emitters" },
    { 0x1055, "aud_s2walk_execution_fire" },
    { 0x1056, "aud_s2walk_execution_kneeling_prisoners" },
    { 0x1057, "aud_s2walk_flyby_1" },
    { 0x1058, "aud_s2walk_guard_3_foley_01" },
    { 0x1059, "aud_s2walk_guard_3_foley_02" },
    { 0x105A, "aud_s2walk_guard_hip_radio" },
    { 0x105B, "aud_s2walk_guard_radios" },
    { 0x105C, "aud_s2walk_ilona_push" },
    { 0x105D, "aud_s2walk_loudspeaker2_line1" },
    { 0x105E, "aud_s2walk_loudspeaker2_line2" },
    { 0x105F, "aud_s2walk_prisoner_2_beating" },
    { 0x1060, "aud_s2walk_start_cormack_foley" },
    { 0x1061, "aud_s2walk_start_gideon_bodyfall" },
    { 0x1062, "aud_s2walk_start_gideon_foley" },
    { 0x1063, "aud_s2walk_start_guard_1_foley" },
    { 0x1064, "aud_s2walk_start_guard_1_grabpush" },
    { 0x1065, "aud_s2walk_start_guard_2_foley" },
    { 0x1066, "aud_s2walk_start_guard_2_grab" },
    { 0x1067, "aud_s2walk_start_guard_2_grabpush" },
    { 0x1068, "aud_s2walk_start_guard_2_push" },
    { 0x1069, "aud_s2walk_start_guard_3_foley" },
    { 0x106A, "aud_s2walk_start_guard_3_walkup_foley" },
    { 0x106B, "aud_s2walk_start_ilona_foley" },
    { 0x106C, "aud_s2walk_start_player_foley" },
    { 0x106D, "aud_s2walk_temp_guard_vo" },
    { 0x106E, "aud_s2walk_trigger_start" },
    { 0x106F, "aud_s2walk_yard_prisoners_whimpering" },
    { 0x1070, "aud_s3escape_doctor_radio" },
    { 0x1071, "aud_scale_envelope" },
    { 0x1072, "aud_scale_vector" },
    { 0x1073, "aud_scale_vector_2d" },
    { 0x1074, "aud_scanner_door_open" },
    { 0x1075, "aud_security_alarm" },
    { 0x1076, "aud_security_center_drones_on" },
    { 0x1077, "aud_security_countdown" },
    { 0x1078, "aud_security_hatch_exit" },
    { 0x1079, "aud_security_main_screen" },
    { 0x107A, "aud_security_plant_emp" },
    { 0x107B, "aud_security_prints" },
    { 0x107C, "aud_security_reboot" },
    { 0x107D, "aud_security_vent" },
    { 0x107E, "aud_security_welcome" },
    { 0x107F, "aud_separation_door" },
    { 0x1080, "aud_separation_elevator" },
    { 0x1081, "aud_separation_logic" },
    { 0x1082, "aud_server_room_door_crack" },
    { 0x1083, "aud_server_room_door_enter" },
    { 0x1084, "aud_server_room_door_kick" },
    { 0x1085, "aud_server_room_thermite" },
    { 0x1086, "aud_server_thermite_burn_loop" },
    { 0x1087, "aud_server_thermite_burn_start" },
    { 0x1088, "aud_server_thermite_out" },
    { 0x1089, "aud_set_ambi_submix" },
    { 0x108A, "aud_set_level_fade_time" },
    { 0x108B, "aud_set_mission_failed_music" },
    { 0x108C, "aud_set_music_submix" },
    { 0x108D, "aud_set_point_source_loop_volume" },
    { 0x108E, "aud_set_spec_ops" },
    { 0x108F, "aud_set_sticky_threat" },
    { 0x1090, "aud_set_timescale" },
    { 0x1091, "aud_setup_drop_pod_loop" },
    { 0x1092, "aud_shack_explode" },
    { 0x1093, "aud_shack_explode_whizby" },
    { 0x1094, "aud_slomo_wait" },
    { 0x1095, "aud_smooth" },
    { 0x1096, "aud_sonar_vision_off" },
    { 0x1097, "aud_sonar_vision_on" },
    { 0x1098, "aud_spark_1" },
    { 0x1099, "aud_spark_2" },
    { 0x109A, "aud_spark_3" },
    { 0x109B, "aud_spark_4" },
    { 0x109C, "aud_spark_5" },
    { 0x109D, "aud_sprinklers" },
    { 0x109E, "aud_start_dna_events" },
    { 0x109F, "aud_start_dna_events_cg" },
    { 0x10A0, "aud_start_exfil_foley" },
    { 0x10A1, "aud_start_nyse_fire" },
    { 0x10A2, "aud_start_slow_mo_gunshot_callback" },
    { 0x10A3, "aud_stealth_broken_timer" },
    { 0x10A4, "aud_stealth_melee" },
    { 0x10A5, "aud_stop_and_delete_ent" },
    { 0x10A6, "aud_stop_cormack_foley" },
    { 0x10A7, "aud_stop_headspace_ambience" },
    { 0x10A8, "aud_stop_horror_ambience" },
    { 0x10A9, "aud_stop_line_emitter" },
    { 0x10AA, "aud_stop_mech_panic_walla_watcher" },
    { 0x10AB, "aud_stop_mute_device_for_vo" },
    { 0x10AC, "aud_stop_point_source_loop" },
    { 0x10AD, "aud_stop_slow_mo_gunshot_callback" },
    { 0x10AE, "aud_stop_sound_logic" },
    { 0x10AF, "aud_stop_training_mute_device" },
    { 0x10B0, "aud_stop_vrap_mute_device" },
    { 0x10B1, "aud_table_pulldown" },
    { 0x10B2, "aud_tank_death_listener" },
    { 0x10B3, "aud_tank_field_littlebird" },
    { 0x10B4, "aud_tank_field_warbird" },
    { 0x10B5, "aud_tank_fire_watch" },
    { 0x10B6, "aud_tank_road_littlebird_1" },
    { 0x10B7, "aud_tank_road_littlebird_2" },
    { 0x10B8, "aud_tank_section_vehicles_handler" },
    { 0x10B9, "aud_tank_section_vehicles_spawned" },
    { 0x10BA, "aud_tanker_crash" },
    { 0x10BB, "aud_tanker_fall_down" },
    { 0x10BC, "aud_tennis_court_wakeup" },
    { 0x10BD, "aud_tire_splash" },
    { 0x10BE, "aud_titan_siege_mode_adj_left_side" },
    { 0x10BF, "aud_titan_siege_mode_adj_left_side_back" },
    { 0x10C0, "aud_titan_siege_mode_adj_right_side" },
    { 0x10C1, "aud_titan_siege_mode_adj_right_side_back" },
    { 0x10C2, "aud_training_s2_potus_ziptie_release" },
    { 0x10C3, "aud_transport_chopper" },
    { 0x10C4, "aud_trolley_music" },
    { 0x10C5, "aud_truck_dodge_slowmo_start" },
    { 0x10C6, "aud_truck_dodge_slowmo_whoosh" },
    { 0x10C7, "aud_truck_hits_divider" },
    { 0x10C8, "aud_truck_hits_ground" },
    { 0x10C9, "aud_truck_jump_slowmo" },
    { 0x10CA, "aud_truck_punch_slowmo" },
    { 0x10CB, "aud_truck1_engine_pullup" },
    { 0x10CC, "aud_truck2_engine_drive" },
    { 0x10CD, "aud_truck2_engine_idle" },
    { 0x10CE, "aud_truck2_engine_pullup" },
    { 0x10CF, "aud_trucks_arrive" },
    { 0x10D0, "aud_turret_entry" },
    { 0x10D1, "aud_turrets_activate" },
    { 0x10D2, "aud_use_string_tables" },
    { 0x10D3, "aud_var_nade_type" },
    { 0x10D4, "aud_vector_magnitude_2d" },
    { 0x10D5, "aud_vehicle_ride_data" },
    { 0x10D6, "aud_vrap_mute_start" },
    { 0x10D7, "aud_vtol_excellerate_end" },
    { 0x10D8, "aud_vtol_excellerate_start" },
    { 0x10D9, "aud_vtol_exterior_idle" },
    { 0x10DA, "aud_vtol_land" },
    { 0x10DB, "aud_vtol_passed" },
    { 0x10DC, "aud_wait_delay" },
    { 0x10DD, "aud_wait_for_mission_fail_music" },
    { 0x10DE, "aud_wakeup_amb" },
    { 0x10DF, "aud_wakeup_mech_cooldown_pings" },
    { 0x10E0, "aud_wakeup_mix" },
    { 0x10E1, "aud_warehouse_mech_lift" },
    { 0x10E2, "aud_warehouse_mech_lift_alarm" },
    { 0x10E3, "aud_warehouse_mech_lift_vo" },
    { 0x10E4, "aud_warehouse_roof_machines" },
    { 0x10E5, "aud_warehouse_roof_machines_line" },
    { 0x10E6, "aud_warning_vo" },
    { 0x10E7, "aud_watch_for_anim_end" },
    { 0x10E8, "aud_water_footsteps_foley" },
    { 0x10E9, "aud_water_footsteps_override" },
    { 0x10EA, "aud_water_sound" },
    { 0x10EB, "aud_waterfall_ambience" },
    { 0x10EC, "aud_windmill_sniper_whizby" },
    { 0x10ED, "aud_zap_logic_change" },
    { 0x10EE, "aud_zap_scene" },
    { 0x10EF, "audiblesightplaying" },
    { 0x10F0, "audio" },
    { 0x10F1, "audio_buzzer_struct" },
    { 0x10F2, "audio_jet_counter" },
    { 0x10F3, "audio_monitor_chopper01_death" },
    { 0x10F4, "audio_monitor_chopper02_death" },
    { 0x10F5, "audio_org" },
    { 0x10F6, "audio_presets_music_cue_groups" },
    { 0x10F7, "audio_presets_music_cues" },
    { 0x10F8, "audio_presets_music_moods" },
    { 0x10F9, "audio_presets_vehicle_maps" },
    { 0x10FA, "audio_presets_vehicles" },
    { 0x10FB, "audio_push_1_box_drop" },
    { 0x10FC, "audio_push_1_box_pickup" },
    { 0x10FD, "audio_push_1_box_push" },
    { 0x10FE, "audio_push_1_crane_move_1" },
    { 0x10FF, "audio_push_1_crane_move_2" },
    { 0x1100, "audio_push_1_crane_move_3" },
    { 0x1101, "audio_push_2_box_drop" },
    { 0x1102, "audio_push_2_box_pickup" },
    { 0x1103, "audio_push_2_box_push" },
    { 0x1104, "audio_push_2_crane_move_1" },
    { 0x1105, "audio_push_2_crane_move_2" },
    { 0x1106, "audio_push_2_crane_move_3" },
    { 0x1107, "audio_start_wrestling_exo_guy" },
    { 0x1108, "audio_start_wrestling_guy2" },
    { 0x1109, "audio_start_wrestling_guy3" },
    { 0x110A, "audio_start_wrestling_guy4" },
    { 0x110B, "audio_start_wrestling_guy5" },
    { 0x110C, "audio_stingers_school_bodies_room" },
    { 0x110D, "audio_stringtable_mapname" },
    { 0x110E, "audio_zones" },
    { 0x110F, "audx_attenuate" },
    { 0x1110, "audx_delete_on_sounddone_internal" },
    { 0x1111, "audx_do_dynamic_explosion_math" },
    { 0x1112, "audx_duck" },
    { 0x1113, "audx_fade_in_internal" },
    { 0x1114, "audx_fade_out_internal" },
    { 0x1115, "audx_play_distance_attenuated_2d_internal" },
    { 0x1116, "audx_play_line_emitter_internal" },
    { 0x1117, "audx_print_3d_timer" },
    { 0x1118, "audx_set_spec_ops" },
    { 0x1119, "audx_slomo_wait" },
    { 0x111A, "auto_adjust_difficulty_player_movement_check" },
    { 0x111B, "auto_adjust_difficulty_player_positioner" },
    { 0x111C, "auto_adjust_difficulty_track_player_death" },
    { 0x111D, "auto_adjust_difficulty_track_player_shots" },
    { 0x111E, "auto_adjust_enemy_death_detection" },
    { 0x111F, "auto_adjust_enemy_died" },
    { 0x1120, "auto_adjust_flags" },
    { 0x1121, "auto_adjust_new_zone" },
    { 0x1122, "auto_adjust_results" },
    { 0x1123, "auto_adust_zone_complete" },
    { 0x1124, "auto_combat_music" },
    { 0x1125, "auto_mg42_target" },
    { 0x1126, "auto_mgturretlink" },
    { 0x1127, "auto_occumulator_base" },
    { 0x1128, "auto_recloak" },
    { 0x1129, "autoadjust_playerspots" },
    { 0x112A, "autoassign" },
    { 0x112B, "autoclose" },
    { 0x112C, "autofocus_hipenable" },
    { 0x112D, "autofocus_hipenable_bike" },
    { 0x112E, "autofocus_loop" },
    { 0x112F, "autopsy_cleanup" },
    { 0x1130, "autopsy_create_fodder_techs" },
    { 0x1131, "autopsy_doctor_door_doctor" },
    { 0x1132, "autopsy_doctor_door_enemies" },
    { 0x1133, "autopsy_doctor_door_enemy_ammo" },
    { 0x1134, "autopsy_doctor_door_enemy_think" },
    { 0x1135, "autopsy_doctor_door_fail" },
    { 0x1136, "autopsy_doctor_door_gideon" },
    { 0x1137, "autopsy_doctor_door_no_hint" },
    { 0x1138, "autopsy_doctor_door_player" },
    { 0x1139, "autopsy_door_action" },
    { 0x113A, "autopsy_door_tech" },
    { 0x113B, "autopsy_first_frame_entry_doors" },
    { 0x113C, "autopsy_fodder_tech_animate" },
    { 0x113D, "autopsy_fodder_tech_think" },
    { 0x113E, "autopsy_guard" },
    { 0x113F, "autopsy_guard_player_hit" },
    { 0x1140, "autopsy_main_doctor" },
    { 0x1141, "autopsy_start" },
    { 0x1142, "autoresettime" },
    { 0x1143, "autosave_by_name" },
    { 0x1144, "autosave_by_name_silent" },
    { 0x1145, "autosave_by_name_thread" },
    { 0x1146, "autosave_check_override" },
    { 0x1147, "autosave_check_pitbull_moving" },
    { 0x1148, "autosave_check_pitbull_no_recent_accel" },
    { 0x1149, "autosave_check_pitbull_upright" },
    { 0x114A, "autosave_fly_check" },
    { 0x114B, "autosave_hostile_drone_check" },
    { 0x114C, "autosave_jetbike_check_too_slow" },
    { 0x114D, "autosave_jetbike_check_trailing" },
    { 0x114E, "autosave_now" },
    { 0x114F, "autosave_now_silent" },
    { 0x1150, "autosave_now_trigger" },
    { 0x1151, "autosave_or_timeout" },
    { 0x1152, "autosave_proximity_threat_func" },
    { 0x1153, "autosave_recon" },
    { 0x1154, "autosave_stealth" },
    { 0x1155, "autosave_stealth_meter_check" },
    { 0x1156, "autosave_stealth_silent" },
    { 0x1157, "autosave_stealth_spotted_check" },
    { 0x1158, "autosave_tactical" },
    { 0x1159, "autosave_tactical_grenade_check" },
    { 0x115A, "autosave_tactical_grenade_check_dieout" },
    { 0x115B, "autosave_tactical_player_nades" },
    { 0x115C, "autosave_tactical_proc" },
    { 0x115D, "autosave_tactical_setup" },
    { 0x115E, "autosave_threat_check_enabled" },
    { 0x115F, "autosave_timeout" },
    { 0x1160, "autosaveammocheck" },
    { 0x1161, "autosavecheck" },
    { 0x1162, "autosavecheck_not_picky" },
    { 0x1163, "autosaveconfcentercombatcheck" },
    { 0x1164, "autosaveconfcenterstealthcheck" },
    { 0x1165, "autosavehealthcheck" },
    { 0x1166, "autosavenamethink" },
    { 0x1167, "autosaveplayercheck" },
    { 0x1168, "autosaveprint" },
    { 0x1169, "autosaves_think" },
    { 0x116A, "autosavesniperdronestealth" },
    { 0x116B, "autosavethreatcheck" },
    { 0x116C, "autoshootanimrate" },
    { 0x116D, "autospot_is_close_to_player" },
    { 0x116E, "autospotadswatcher" },
    { 0x116F, "autospotdeathwatcher" },
    { 0x1170, "autotarget" },
    { 0x1171, "auxillary_hud" },
    { 0x1172, "available" },
    { 0x1173, "available_crash_paths" },
    { 0x1174, "availablepositions" },
    { 0x1175, "avalanche_environment" },
    { 0x1176, "avalanche_falling_death" },
    { 0x1177, "avatar" },
    { 0x1178, "avatar_after_spawn" },
    { 0x1179, "avatar_scheduled_for_removal" },
    { 0x117A, "avatar_spawnpoint" },
    { 0x117B, "avatarinfo" },
    { 0x117C, "avengedplayerevent" },
    { 0x117D, "avm_add_envelope" },
    { 0x117E, "avm_add_in_state_callback" },
    { 0x117F, "avm_add_init_state_callback" },
    { 0x1180, "avm_add_loops" },
    { 0x1181, "avm_add_oneshot" },
    { 0x1182, "avm_add_oneshots" },
    { 0x1183, "avm_add_param_map_env" },
    { 0x1184, "avm_add_state_transition" },
    { 0x1185, "avm_begin_behavior_data" },
    { 0x1186, "avm_begin_behavior_def" },
    { 0x1187, "avm_begin_loop_data" },
    { 0x1188, "avm_begin_loop_def" },
    { 0x1189, "avm_begin_oneshot_data" },
    { 0x118A, "avm_begin_oneshot_def" },
    { 0x118B, "avm_begin_param_map" },
    { 0x118C, "avm_begin_preset_def" },
    { 0x118D, "avm_begin_state_data" },
    { 0x118E, "avm_begin_state_def" },
    { 0x118F, "avm_begin_state_group" },
    { 0x1190, "avm_change_smoothing_rate" },
    { 0x1191, "avm_compute_alpha_from_rc" },
    { 0x1192, "avm_compute_doppler_pitch" },
    { 0x1193, "avm_compute_smoothing_rc_from_alpha" },
    { 0x1194, "avm_create_vehicle_proxy" },
    { 0x1195, "avm_end_behavior_data" },
    { 0x1196, "avm_end_behavior_def" },
    { 0x1197, "avm_end_loop_data" },
    { 0x1198, "avm_end_loop_def" },
    { 0x1199, "avm_end_oneshot_data" },
    { 0x119A, "avm_end_oneshot_def" },
    { 0x119B, "avm_end_param_map" },
    { 0x119C, "avm_end_preset_def" },
    { 0x119D, "avm_end_state_data" },
    { 0x119E, "avm_end_state_def" },
    { 0x119F, "avm_end_state_group" },
    { 0x11A0, "avm_get_running_instance_count" },
    { 0x11A1, "avm_get_update_rate" },
    { 0x11A2, "avm_init" },
    { 0x11A3, "avm_register_callback" },
    { 0x11A4, "avm_set_instance_master_volume" },
    { 0x11A5, "avm_set_loop_mute_state" },
    { 0x11A6, "avmx_add_behavior_shortcut_param_maps" },
    { 0x11A7, "avmx_add_instance" },
    { 0x11A8, "avmx_add_oneshot_ducking_scalar" },
    { 0x11A9, "avmx_add_preset" },
    { 0x11AA, "avmx_are_all_defined" },
    { 0x11AB, "avmx_continuously_update_snd_ent" },
    { 0x11AC, "avmx_create_instance_struct" },
    { 0x11AD, "avmx_create_param_io_struct" },
    { 0x11AE, "avmx_create_preset" },
    { 0x11AF, "avmx_fade_stop_and_delete_sound_obj" },
    { 0x11B0, "avmx_generate_instance_name" },
    { 0x11B1, "avmx_get" },
    { 0x11B2, "avmx_get_behavior_instance_struct" },
    { 0x11B3, "avmx_get_behavior_preset_struct" },
    { 0x11B4, "avmx_get_behavior_restricted_oneshots" },
    { 0x11B5, "avmx_get_callback" },
    { 0x11B6, "avmx_get_current_instance_sound_item_input" },
    { 0x11B7, "avmx_get_envelope" },
    { 0x11B8, "avmx_get_fadein_time" },
    { 0x11B9, "avmx_get_fadeout_time" },
    { 0x11BA, "avmx_get_instance" },
    { 0x11BB, "avmx_get_instance_name" },
    { 0x11BC, "avmx_get_instance_preset" },
    { 0x11BD, "avmx_get_instance_preset_name" },
    { 0x11BE, "avmx_get_instance_sound_item_output" },
    { 0x11BF, "avmx_get_instance_sound_item_volume" },
    { 0x11C0, "avmx_get_instance_state_struct" },
    { 0x11C1, "avmx_get_master_volume" },
    { 0x11C2, "avmx_get_oneshot_poly_mode" },
    { 0x11C3, "avmx_get_oneshot_update_mode" },
    { 0x11C4, "avmx_get_preset" },
    { 0x11C5, "avmx_get_preset_name" },
    { 0x11C6, "avmx_get_sound_alias" },
    { 0x11C7, "avmx_get_sound_alias_count" },
    { 0x11C8, "avmx_get_sound_instance" },
    { 0x11C9, "avmx_get_state_preset_struct" },
    { 0x11CA, "avmx_get_vehicle_entity" },
    { 0x11CB, "avmx_handle_oneshot_ducking" },
    { 0x11CC, "avmx_is_player_mode" },
    { 0x11CD, "avmx_is_vehicle_proxy" },
    { 0x11CE, "avmx_launch_state_machines" },
    { 0x11CF, "avmx_map_input" },
    { 0x11D0, "avmx_map_io" },
    { 0x11D1, "avmx_monitor_death" },
    { 0x11D2, "avmx_monitor_oneshot_done" },
    { 0x11D3, "avmx_normalize_ranged_value" },
    { 0x11D4, "avmx_preset_determine_param_map_env_owner" },
    { 0x11D5, "avmx_preset_determine_param_map_owner" },
    { 0x11D6, "avmx_preset_set_param_map_defaults" },
    { 0x11D7, "avmx_remove_instance" },
    { 0x11D8, "avmx_remove_oneshot_ducking_scalar" },
    { 0x11D9, "avmx_set_behavior_oneshot_overrides" },
    { 0x11DA, "avmx_set_instance_init_callback" },
    { 0x11DB, "avmx_set_instance_master_volume" },
    { 0x11DC, "avmx_set_loop_play_state" },
    { 0x11DD, "avmx_set_loop_volume" },
    { 0x11DE, "avmx_set_oneshot_ducking_scalar" },
    { 0x11DF, "avmx_set_oneshot_update_mode" },
    { 0x11E0, "avmx_set_preset_name" },
    { 0x11E1, "avmx_start_instance" },
    { 0x11E2, "avmx_start_loop" },
    { 0x11E3, "avmx_start_oneshot_alias" },
    { 0x11E4, "avmx_state_condition_function" },
    { 0x11E5, "avmx_state_enter_action_function" },
    { 0x11E6, "avmx_state_enter_action_init_data" },
    { 0x11E7, "avmx_state_enter_action_play_loops" },
    { 0x11E8, "avmx_state_enter_action_play_oneshots" },
    { 0x11E9, "avmx_state_exit_action_function" },
    { 0x11EA, "avmx_stop_instance" },
    { 0x11EB, "avmx_stop_loop" },
    { 0x11EC, "avmx_stop_snd_ent" },
    { 0x11ED, "avmx_update_instance_loop_assets" },
    { 0x11EE, "avmx_update_loop_ducking_scalar" },
    { 0x11EF, "avmx_update_loops" },
    { 0x11F0, "avmx_update_oneshot_duck_scalar" },
    { 0x11F1, "avmx_update_sound_ent_output_param" },
    { 0x11F2, "avmx_vehicle_getspeed" },
    { 0x11F3, "avoid_players" },
    { 0x11F4, "avoidairstrikelocations" },
    { 0x11F5, "avoidcarepackages" },
    { 0x11F6, "avoidcornervisibleenemies" },
    { 0x11F7, "avoidenemiesbydistance" },
    { 0x11F8, "avoidenemyspawn" },
    { 0x11F9, "avoidfullvisibleenemies" },
    { 0x11FA, "avoidgasclouds" },
    { 0x11FB, "avoidgrenades" },
    { 0x11FC, "avoidkillstreakonspawntimer" },
    { 0x11FD, "avoidlastattackerlocation" },
    { 0x11FE, "avoidlastdeathlocation" },
    { 0x11FF, "avoidmines" },
    { 0x1200, "avoidrecentlyused" },
    { 0x1201, "avoidsamespawn" },
    { 0x1202, "avoidspawninhp" },
    { 0x1203, "avoidtelefrag" },
    { 0x1204, "award_intel" },
    { 0x1205, "award_player_exo_challenge_kill_for_scene" },
    { 0x1206, "awardcapturepoints" },
    { 0x1207, "awardedfinalsurvivor" },
    { 0x1208, "awardgameevent" },
    { 0x1209, "awardhordeheadshots" },
    { 0x120A, "awardhordekill" },
    { 0x120B, "awardhorderevive" },
    { 0x120C, "awardhorderoundnumber" },
    { 0x120D, "awardhordweaponlevel" },
    { 0x120E, "awardpoints" },
    { 0x120F, "awardxp" },
    { 0x1210, "aware_aievents" },
    { 0x1211, "awareness_meter_fail" },
    { 0x1212, "awareness_param" },
    { 0x1213, "axis_check_cloak_state" },
    { 0x1214, "axis_global_accuracy_mod" },
    { 0x1215, "axis_start_spawn_name" },
    { 0x1216, "axiscapturing" },
    { 0x1217, "axischopper" },
    { 0x1218, "axisflagcarrierclientnum" },
    { 0x1219, "axisflagstatus" },
    { 0x121A, "axismode" },
    { 0x121B, "azm_get_current_zone" },
    { 0x121C, "azm_get_damb_enable" },
    { 0x121D, "azm_get_filter_bypass" },
    { 0x121E, "azm_get_filter_enable" },
    { 0x121F, "azm_get_mix_bypass" },
    { 0x1220, "azm_get_mix_enable" },
    { 0x1221, "azm_get_occlusion_bypass" },
    { 0x1222, "azm_get_occlusion_enable" },
    { 0x1223, "azm_get_quad_enable" },
    { 0x1224, "azm_get_reverb_bypass" },
    { 0x1225, "azm_get_reverb_enable" },
    { 0x1226, "azm_init" },
    { 0x1227, "azm_print_enter_blend" },
    { 0x1228, "azm_print_exit_blend" },
    { 0x1229, "azm_print_progress" },
    { 0x122A, "azm_set_current_zone" },
    { 0x122B, "azm_set_damb_enable" },
    { 0x122C, "azm_set_filter_bypass" },
    { 0x122D, "azm_set_filter_enable" },
    { 0x122E, "azm_set_mix_bypass" },
    { 0x122F, "azm_set_mix_enable" },
    { 0x1230, "azm_set_occlusion_bypass" },
    { 0x1231, "azm_set_occlusion_enable" },
    { 0x1232, "azm_set_quad_enable" },
    { 0x1233, "azm_set_reverb_bypass" },
    { 0x1234, "azm_set_reverb_enable" },
    { 0x1235, "azm_set_zone_dynamic_ambience" },
    { 0x1236, "azm_set_zone_mix" },
    { 0x1237, "azm_set_zone_occlusion" },
    { 0x1238, "azm_set_zone_reverb" },
    { 0x1239, "azm_set_zone_streamed_ambience" },
    { 0x123A, "azm_start_zone" },
    { 0x123B, "azm_stop_zone" },
    { 0x123C, "azm_stop_zones" },
    { 0x123D, "azm_use_string_table" },
    { 0x123E, "azmx_blend_zones" },
    { 0x123F, "azmx_get_blend_args" },
    { 0x1240, "azmx_get_preset_from_string_table" },
    { 0x1241, "azmx_get_zone_preset_from_stringtable_internal" },
    { 0x1242, "azmx_is_valid_damb_blend_request" },
    { 0x1243, "azmx_is_valid_mix_blend_request" },
    { 0x1244, "azmx_is_valid_samb_blend_request" },
    { 0x1245, "azmx_load_zone" },
    { 0x1246, "azmx_restart_damb" },
    { 0x1247, "azmx_restart_mix" },
    { 0x1248, "azmx_restart_occlusion" },
    { 0x1249, "azmx_restart_reverb" },
    { 0x124A, "azmx_restart_stream" },
    { 0x124B, "azmx_set_param_internal" },
    { 0x124C, "azmx_wait_till_fade_done_and_remove_zone" },
    { 0x124D, "back_fake_bullets" },
    { 0x124E, "back_gunfire_timer" },
    { 0x124F, "back_line_of_fire" },
    { 0x1250, "background_block" },
    { 0x1251, "background_drop_pods" },
    { 0x1252, "background_explosion" },
    { 0x1253, "background_org" },
    { 0x1254, "backline_alive_check" },
    { 0x1255, "backline_flee_check" },
    { 0x1256, "backlineguys_total" },
    { 0x1257, "backlineguysalive" },
    { 0x1258, "backoff_count" },
    { 0x1259, "backshieldmodel" },
    { 0x125A, "backstabber_stage" },
    { 0x125B, "backstabber_update" },
    { 0x125C, "backstabevent" },
    { 0x125D, "backup_drop_pod_function" },
    { 0x125E, "bad_guys_die" },
    { 0x125F, "bad_perch_logic" },
    { 0x1260, "badmofo" },
    { 0x1261, "badplace" },
    { 0x1262, "badplace_cylinder_func" },
    { 0x1263, "badplace_delete_func" },
    { 0x1264, "badplace_on_entity" },
    { 0x1265, "badplace_remove" },
    { 0x1266, "badplace_think" },
    { 0x1267, "badplaceint" },
    { 0x1268, "badplacemodifier" },
    { 0x1269, "badplacer" },
    { 0x126A, "badplaces" },
    { 0x126B, "badshot" },
    { 0x126C, "badshotcount" },
    { 0x126D, "badspawn" },
    { 0x126E, "bagh_end_turretpull_mix" },
    { 0x126F, "bagh_grab_gunner" },
    { 0x1270, "bagh_punch_turret" },
    { 0x1271, "bagh_start_turretpull_mix" },
    { 0x1272, "bagh_throw_gunner" },
    { 0x1273, "bail_out_of_turret_dialogue" },
    { 0x1274, "balanceteams" },
    { 0x1275, "balarmon" },
    { 0x1276, "balcony_death_anims" },
    { 0x1277, "balcony_drone_foliage" },
    { 0x1278, "balcony_entrance_doors" },
    { 0x1279, "balcony_finale_end_camera_control" },
    { 0x127A, "balcony_lighting" },
    { 0x127B, "balcony_siren" },
    { 0x127C, "balcony_sniper_drone_idle" },
    { 0x127D, "balcony_sniper_drone_idle_cleanup" },
    { 0x127E, "ball_add_start" },
    { 0x127F, "ball_assign_random_start" },
    { 0x1280, "ball_assign_start" },
    { 0x1281, "ball_assign_team_spawns" },
    { 0x1282, "ball_at_rest" },
    { 0x1283, "ball_can_pass_ally" },
    { 0x1284, "ball_can_pass_enemy" },
    { 0x1285, "ball_can_pickup" },
    { 0x1286, "ball_can_throw" },
    { 0x1287, "ball_carried" },
    { 0x1288, "ball_carrier_cleanup" },
    { 0x1289, "ball_carrier_is_almost_visible" },
    { 0x128A, "ball_carrier_touched_goal" },
    { 0x128B, "ball_check_assist" },
    { 0x128C, "ball_check_pass_kill_pickup" },
    { 0x128D, "ball_clear_contents" },
    { 0x128E, "ball_connect_watch" },
    { 0x128F, "ball_create_ball_starts" },
    { 0x1290, "ball_create_killcam_ent" },
    { 0x1291, "ball_create_team_goal" },
    { 0x1292, "ball_default_origins" },
    { 0x1293, "ball_dont_interpolate" },
    { 0x1294, "ball_download_fx" },
    { 0x1295, "ball_download_wait" },
    { 0x1296, "ball_find_ground" },
    { 0x1297, "ball_fx_active" },
    { 0x1298, "ball_fx_start" },
    { 0x1299, "ball_fx_start_player" },
    { 0x129A, "ball_fx_stop" },
    { 0x129B, "ball_get_path_dist" },
    { 0x129C, "ball_get_view_team" },
    { 0x129D, "ball_give_score" },
    { 0x129E, "ball_goal_can_use" },
    { 0x129F, "ball_goal_fx" },
    { 0x12A0, "ball_goal_fx_for_player" },
    { 0x12A1, "ball_goal_useobject" },
    { 0x12A2, "ball_goals" },
    { 0x12A3, "ball_goals_post_event" },
    { 0x12A4, "ball_in_goal" },
    { 0x12A5, "ball_init_map_min_max" },
    { 0x12A6, "ball_joint_angles_rate" },
    { 0x12A7, "ball_joint_last_angles" },
    { 0x12A8, "ball_joint_last_update_msec" },
    { 0x12A9, "ball_jump_nodes" },
    { 0x12AA, "ball_location_hud" },
    { 0x12AB, "ball_maxs" },
    { 0x12AC, "ball_mins" },
    { 0x12AD, "ball_on_connect" },
    { 0x12AE, "ball_on_pickup" },
    { 0x12AF, "ball_on_projectile_death" },
    { 0x12B0, "ball_on_projectile_hit_client" },
    { 0x12B1, "ball_on_reset" },
    { 0x12B2, "ball_overridemovingplatformdeath" },
    { 0x12B3, "ball_pass_or_shoot" },
    { 0x12B4, "ball_pass_or_throw_active" },
    { 0x12B5, "ball_pass_projectile" },
    { 0x12B6, "ball_pass_touch_goal" },
    { 0x12B7, "ball_pass_watch" },
    { 0x12B8, "ball_physics_bad_trigger_at_rest" },
    { 0x12B9, "ball_physics_bad_trigger_watch" },
    { 0x12BA, "ball_physics_fake_bounce" },
    { 0x12BB, "ball_physics_launch" },
    { 0x12BC, "ball_physics_launch_drop" },
    { 0x12BD, "ball_physics_out_of_level" },
    { 0x12BE, "ball_physics_timeout" },
    { 0x12BF, "ball_physics_touch_cant_pickup_player" },
    { 0x12C0, "ball_physics_touch_goal" },
    { 0x12C1, "ball_play_fx_joined_team" },
    { 0x12C2, "ball_play_local_team_sound" },
    { 0x12C3, "ball_play_score_fx" },
    { 0x12C4, "ball_player_on_connect" },
    { 0x12C5, "ball_restore_contents" },
    { 0x12C6, "ball_return_home" },
    { 0x12C7, "ball_score_event" },
    { 0x12C8, "ball_score_sound" },
    { 0x12C9, "ball_set_dropped" },
    { 0x12CA, "ball_shoot_watch" },
    { 0x12CB, "ball_spawn" },
    { 0x12CC, "ball_starts" },
    { 0x12CD, "ball_starts_post_event" },
    { 0x12CE, "ball_touch_goal_watch" },
    { 0x12CF, "ball_touched_goal" },
    { 0x12D0, "ball_touching_ground" },
    { 0x12D1, "ball_update_extrascore0" },
    { 0x12D2, "ball_waypoint_download" },
    { 0x12D3, "ball_waypoint_held" },
    { 0x12D4, "ball_waypoint_neutral" },
    { 0x12D5, "ball_waypoint_upload" },
    { 0x12D6, "balldrone" },
    { 0x12D7, "balldronetype" },
    { 0x12D8, "balliesintruck" },
    { 0x12D9, "balls" },
    { 0x12DA, "ballscoreassistevent" },
    { 0x12DB, "bar" },
    { 0x12DC, "bar_guy_check_function" },
    { 0x12DD, "bar_guys_waiting" },
    { 0x12DE, "bar_setup" },
    { 0x12DF, "barfighters_notify" },
    { 0x12E0, "barking_sound" },
    { 0x12E1, "barracks_approach_handle_dialogue" },
    { 0x12E2, "barracks_defense_guys" },
    { 0x12E3, "barracks_objectives" },
    { 0x12E4, "barrel" },
    { 0x12E5, "barrel_earthquake" },
    { 0x12E6, "barrel_heat_glow_fx" },
    { 0x12E7, "barrel_overheat_fx" },
    { 0x12E8, "barrelexpsound" },
    { 0x12E9, "barrellinker" },
    { 0x12EA, "barrelrollacceleration" },
    { 0x12EB, "barrelviewmodel" },
    { 0x12EC, "barrelviewmodeloffset" },
    { 0x12ED, "barrier_scene_ents" },
    { 0x12EE, "barrivalsenabled" },
    { 0x12EF, "bars" },
    { 0x12F0, "base" },
    { 0x12F1, "base_agl" },
    { 0x12F2, "base_angles" },
    { 0x12F3, "base_array_ambient_a10_gun_dive_1" },
    { 0x12F4, "base_array_ambient_a10_gun_dive_2" },
    { 0x12F5, "base_array_ambient_a10_gun_dive_3" },
    { 0x12F6, "base_array_ambient_a10_gun_dive_4" },
    { 0x12F7, "base_array_ambient_dogfight_1" },
    { 0x12F8, "base_array_ambient_dogfight_2" },
    { 0x12F9, "base_array_ambient_dogfight_3" },
    { 0x12FA, "base_array_ambient_dogfight_4" },
    { 0x12FB, "base_clip" },
    { 0x12FC, "base_intensity" },
    { 0x12FD, "base_origin" },
    { 0x12FE, "base_target_offset_angles" },
    { 0x12FF, "base_target_offset_length" },
    { 0x1300, "baseaccuracy" },
    { 0x1301, "basealpha" },
    { 0x1302, "baseangles" },
    { 0x1303, "basedangle" },
    { 0x1304, "basedelta" },
    { 0x1305, "baseeffect" },
    { 0x1306, "baseeffectforward" },
    { 0x1307, "baseeffectpos" },
    { 0x1308, "baseeffectright" },
    { 0x1309, "basefontscale" },
    { 0x130A, "baseheight" },
    { 0x130B, "baseignorerandombulletdamage" },
    { 0x130C, "basement_door_clip_function" },
    { 0x130D, "basement_door_school_anim" },
    { 0x130E, "basement_enemy_flashlight_setup" },
    { 0x130F, "basement_fog_checkpoint" },
    { 0x1310, "basement_hide_setup" },
    { 0x1311, "basement_investigate" },
    { 0x1312, "basement_jump_awareness" },
    { 0x1313, "basement_troop_2" },
    { 0x1314, "basement_valve_and_door_stop_early" },
    { 0x1315, "baseorigin" },
    { 0x1316, "baseowner" },
    { 0x1317, "baseplayermovescale" },
    { 0x1318, "basetime" },
    { 0x1319, "basewidth" },
    { 0x131A, "baseyaw" },
    { 0x131B, "basic" },
    { 0x131C, "battery_cost" },
    { 0x131D, "battery_hud_is_visible" },
    { 0x131E, "battery_min" },
    { 0x131F, "batteryfillmax" },
    { 0x1320, "batteryinit" },
    { 0x1321, "batterymetervisible" },
    { 0x1322, "batterysetlevel" },
    { 0x1323, "batteryspend" },
    { 0x1324, "batteryupdatemeter" },
    { 0x1325, "battle_chatter_check_alley" },
    { 0x1326, "battle_chatter_off_both" },
    { 0x1327, "battle_chatter_on_both" },
    { 0x1328, "battle_deployable_cover_setup" },
    { 0x1329, "battle_exterior_sunflare" },
    { 0x132A, "battlebuddy" },
    { 0x132B, "battlebuddyrespawntimestamp" },
    { 0x132C, "battlebuddywaitlist" },
    { 0x132D, "battlechatter" },
    { 0x132E, "battlechatter_canprint" },
    { 0x132F, "battlechatter_canprintdump" },
    { 0x1330, "battlechatter_debugprint" },
    { 0x1331, "battlechatter_dist_check" },
    { 0x1332, "battlechatter_off" },
    { 0x1333, "battlechatter_on" },
    { 0x1334, "battlechatter_on_thread" },
    { 0x1335, "battlechatter_print" },
    { 0x1336, "battlechatter_printdump" },
    { 0x1337, "battlechatter_printdumpline" },
    { 0x1338, "bays_open" },
    { 0x1339, "bc_explosion_vision" },
    { 0x133A, "bc_initial_blur" },
    { 0x133B, "bc_shadow_tweak" },
    { 0x133C, "bcdisabled" },
    { 0x133D, "bcdrawobjects" },
    { 0x133E, "bcgetclaimednode" },
    { 0x133F, "bcinfo" },
    { 0x1340, "bcissniper" },
    { 0x1341, "bclearstrafeturnrate" },
    { 0x1342, "bcname" },
    { 0x1343, "bcnameid" },
    { 0x1344, "bcprintfailprefix" },
    { 0x1345, "bcprintwarnprefix" },
    { 0x1346, "bcrank" },
    { 0x1347, "bcs_location_mappings" },
    { 0x1348, "bcs_location_trigger_mapping" },
    { 0x1349, "bcs_location_trigs_init" },
    { 0x134A, "bcs_locations" },
    { 0x134B, "bcs_maxtalkingdistsqrdfromplayer" },
    { 0x134C, "bcs_maxthreatdistsqrdfromplayer" },
    { 0x134D, "bcs_minpriority" },
    { 0x134E, "bcs_scripted_dialogue_start" },
    { 0x134F, "bcs_setup_chatter_toggle_array" },
    { 0x1350, "bcs_setup_countryids" },
    { 0x1351, "bcs_setup_flavorburst_toggle_array" },
    { 0x1352, "bcs_setup_teams_array" },
    { 0x1353, "bcs_setup_voice" },
    { 0x1354, "bcs_threatresettime" },
    { 0x1355, "bcs_trigs_assign_aliases" },
    { 0x1356, "bcsdebugwaiter" },
    { 0x1357, "bcsenabled" },
    { 0x1358, "bcsounds" },
    { 0x1359, "bdisabledefaultfacialanims" },
    { 0x135A, "bdisablegearsounds" },
    { 0x135B, "bdisablemovetwitch" },
    { 0x135C, "bdoturnandmove" },
    { 0x135D, "beach_guy_monitor" },
    { 0x135E, "beacon" },
    { 0x135F, "beam_clip_disable_function" },
    { 0x1360, "beamgetgroundfx" },
    { 0x1361, "beamgroundfx" },
    { 0x1362, "beamminimap" },
    { 0x1363, "beams" },
    { 0x1364, "beamsounds" },
    { 0x1365, "beamstartfires" },
    { 0x1366, "become_aware_on_goal" },
    { 0x1367, "become_aware_when_player_is_in_volume" },
    { 0x1368, "bedroom_begin" },
    { 0x1369, "bedroom_main" },
    { 0x136A, "bedroom_start" },
    { 0x136B, "beffectlooping" },
    { 0x136C, "beforestairanim" },
    { 0x136D, "begin_anim_reach" },
    { 0x136E, "begin_attack_heli_behavior" },
    { 0x136F, "begin_barracks" },
    { 0x1370, "begin_big_cave" },
    { 0x1371, "begin_canyon" },
    { 0x1372, "begin_canyon_dam" },
    { 0x1373, "begin_canyon_exit" },
    { 0x1374, "begin_canyon_intro" },
    { 0x1375, "begin_canyon2" },
    { 0x1376, "begin_canyon3" },
    { 0x1377, "begin_capture" },
    { 0x1378, "begin_cave_entry" },
    { 0x1379, "begin_cave_hallway" },
    { 0x137A, "begin_combat_cave" },
    { 0x137B, "begin_concussion_grenade_tracking" },
    { 0x137C, "begin_courtyard_combat" },
    { 0x137D, "begin_crash_site" },
    { 0x137E, "begin_dnabomb" },
    { 0x137F, "begin_exo_push" },
    { 0x1380, "begin_ice_bridge" },
    { 0x1381, "begin_intro" },
    { 0x1382, "begin_intro_conversation" },
    { 0x1383, "begin_kill_hades_sequence" },
    { 0x1384, "begin_lake" },
    { 0x1385, "begin_lake_cinema" },
    { 0x1386, "begin_narrow_cave" },
    { 0x1387, "begin_on_foot_segment" },
    { 0x1388, "begin_overlook" },
    { 0x1389, "begin_pcap_vo_lab_serverroom_cormack" },
    { 0x138A, "begin_post_tower" },
    { 0x138B, "begin_refugee_walk" },
    { 0x138C, "begin_rooftop_combat" },
    { 0x138D, "begin_semtex_grenade_tracking" },
    { 0x138E, "begin_skyjack" },
    { 0x138F, "begin_snipers" },
    { 0x1390, "begin_spawnning_exo_spawners" },
    { 0x1391, "begin_stealth_walk" },
    { 0x1392, "begin_tank" },
    { 0x1393, "begin_the_shimmey_for_burke" },
    { 0x1394, "begin_the_street_fight" },
    { 0x1395, "begin_vtol_takedown" },
    { 0x1396, "begin_wallpull_slowmo" },
    { 0x1397, "beginc4tracking" },
    { 0x1398, "beginclasschoice" },
    { 0x1399, "begincourtyarddialogue" },
    { 0x139A, "begincustomevent" },
    { 0x139B, "beginflashgrenadetracking" },
    { 0x139C, "begingrenadetracking" },
    { 0x139D, "beginning_idle_cine_turret" },
    { 0x139E, "beginningoflevelsave" },
    { 0x139F, "beginsliding" },
    { 0x13A0, "beginsmokegrenadetracking" },
    { 0x13A1, "beginteamchoice" },
    { 0x13A2, "behavior" },
    { 0x13A3, "behavior_data" },
    { 0x13A4, "behavior_list" },
    { 0x13A5, "behavior_under_construction" },
    { 0x13A6, "behaviors" },
    { 0x13A7, "behind_punish_dist" },
    { 0x13A8, "being_careful" },
    { 0x13A9, "beingartilleryshellshocked" },
    { 0x13AA, "beingdestroyed" },
    { 0x13AB, "beingrevived" },
    { 0x13AC, "bell_run" },
    { 0x13AD, "best_dodge_car" },
    { 0x13AE, "best_pr_kills" },
    { 0x13AF, "bestcovernode" },
    { 0x13B0, "bestmissilespawn" },
    { 0x13B1, "bestmissilespawnabove" },
    { 0x13B2, "bestspawnflag" },
    { 0x13B3, "bet_betrayal_pt1_gideon" },
    { 0x13B4, "bet_betrayal_pt1_ilona" },
    { 0x13B5, "bet_betrayal_pt1_irons" },
    { 0x13B6, "bet_betrayal_pt1_tech" },
    { 0x13B7, "bet_betrayal_pt2_gideon" },
    { 0x13B8, "bet_betrayal_pt2_ilona" },
    { 0x13B9, "bet_betrayal_pt2_irons" },
    { 0x13BA, "bet_boat_crash_audio_handler" },
    { 0x13BB, "bet_boat_crash_bldg_impact" },
    { 0x13BC, "bet_boat_dive_watcher" },
    { 0x13BD, "bet_boat_end_watcher" },
    { 0x13BE, "bet_boat_enter_plr_exo_arm" },
    { 0x13BF, "bet_boat_enter_plr_grab_wheel" },
    { 0x13C0, "bet_boat_enter_plr_jump_into_boat" },
    { 0x13C1, "bet_boat_enter_plr_power_on" },
    { 0x13C2, "bet_boat_enter_plr_sit" },
    { 0x13C3, "bet_boat_enter_plr_start" },
    { 0x13C4, "bet_boat_exit_ilona" },
    { 0x13C5, "bet_boat_exit_ilona_pickup_wpn" },
    { 0x13C6, "bet_boat_exit_ilona_stand" },
    { 0x13C7, "bet_boat_exit_jump_out" },
    { 0x13C8, "bet_boat_exit_stand_up" },
    { 0x13C9, "bet_boat_exit_start" },
    { 0x13CA, "bet_conf_door_opens" },
    { 0x13CB, "bet_conf_escape_guard_1_punched" },
    { 0x13CC, "bet_conf_escape_guard_1_react" },
    { 0x13CD, "bet_conf_escape_guard_1_tripped" },
    { 0x13CE, "bet_conf_escape_guard_2_punch" },
    { 0x13CF, "bet_conf_escape_guard_2_shot" },
    { 0x13D0, "bet_conf_escape_plr_foot_sweep" },
    { 0x13D1, "bet_conf_escape_plr_punch" },
    { 0x13D2, "bet_conf_escape_plr_wpn" },
    { 0x13D3, "bet_conf_fire_suppression" },
    { 0x13D4, "bet_conf_flash_bang_exp" },
    { 0x13D5, "bet_conf_gideon_exits" },
    { 0x13D6, "bet_conf_gideon_reacts" },
    { 0x13D7, "bet_conf_gideon_turns_to_leave" },
    { 0x13D8, "bet_conf_guard_1_enter" },
    { 0x13D9, "bet_conf_guard_1_swing_wpn" },
    { 0x13DA, "bet_conf_guard_2_push_down_ilona" },
    { 0x13DB, "bet_conf_guard_wpn_trained" },
    { 0x13DC, "bet_conf_ilona_punched" },
    { 0x13DD, "bet_conf_irons_enters" },
    { 0x13DE, "bet_conf_irons_exits" },
    { 0x13DF, "bet_conf_irons_turns_to_leave" },
    { 0x13E0, "bet_conf_irons_walks_to_ilona" },
    { 0x13E1, "bet_conf_kill_guard" },
    { 0x13E2, "bet_conf_plr_knock_back" },
    { 0x13E3, "bet_conf_plr_lean" },
    { 0x13E4, "bet_conf_plr_pull_wpn" },
    { 0x13E5, "bet_conf_plr_punched" },
    { 0x13E6, "bet_conf_plr_sit_back" },
    { 0x13E7, "bet_conf_slo_mo_kick_start" },
    { 0x13E8, "bet_conf_slo_mo_kick_stop" },
    { 0x13E9, "bet_conf_slo_mo_shoot_start" },
    { 0x13EA, "bet_conf_slo_mo_shoot_stop" },
    { 0x13EB, "bet_conf_sprinkler" },
    { 0x13EC, "bet_conf_steam_lp" },
    { 0x13ED, "bet_elevator_exoclimb_dismount" },
    { 0x13EE, "bet_elevator_exoclimb_dismount_foot" },
    { 0x13EF, "bet_ending_cormack" },
    { 0x13F0, "bet_ending_gideon" },
    { 0x13F1, "bet_ending_ilona" },
    { 0x13F2, "bet_ending_joker" },
    { 0x13F3, "bet_escape_additional_sprinklers" },
    { 0x13F4, "bet_escape_additional_steam" },
    { 0x13F5, "bet_escape_alarms" },
    { 0x13F6, "bet_escape_ilona" },
    { 0x13F7, "bet_escape_roof_slide" },
    { 0x13F8, "bet_escape_roof_slomo_end" },
    { 0x13F9, "bet_escape_roof_slomo_start" },
    { 0x13FA, "bet_foley_override_handler" },
    { 0x13FB, "bet_gideon_arm_scanner" },
    { 0x13FC, "bet_holo_glitches_1" },
    { 0x13FD, "bet_holo_glitches_2" },
    { 0x13FE, "bet_holo_glitches_3" },
    { 0x13FF, "bet_holo_glitches_4" },
    { 0x1400, "bet_holo_irons_shoot_pistol" },
    { 0x1401, "bet_holo_irons_stand_and_walk" },
    { 0x1402, "bet_hologram_start" },
    { 0x1403, "bet_ilona_swim_end" },
    { 0x1404, "bet_ilona_swim_start" },
    { 0x1405, "bet_intro_done" },
    { 0x1406, "bet_intro_gideon" },
    { 0x1407, "bet_roof_glass_hit" },
    { 0x1408, "bet_roof_lower_blast_doors" },
    { 0x1409, "bet_roof_raise_blast_doors" },
    { 0x140A, "bet_roof_slide_start" },
    { 0x140B, "bet_roof_slo_mo_start" },
    { 0x140C, "bet_roof_slo_mo_stop" },
    { 0x140D, "bet_roof_water_hit" },
    { 0x140E, "bet_swim_boat_explo" },
    { 0x140F, "bet_swim_boat_hit_bottom" },
    { 0x1410, "bet_swim_boat_sink" },
    { 0x1411, "bet_swim_bullet_trails" },
    { 0x1412, "bet_swim_dock_debris_blocker" },
    { 0x1413, "bet_swim_dock_explode" },
    { 0x1414, "bet_walla_intro_patio" },
    { 0x1415, "betrayal_boat_vision_set_fog_changes" },
    { 0x1416, "betrayal_finale_player_jump" },
    { 0x1417, "betrayal_interior_clut" },
    { 0x1418, "betrayal_interior_darker_fog" },
    { 0x1419, "betrayal_intro_screen" },
    { 0x141A, "betrayal_locations" },
    { 0x141B, "betrayal_roof_transition" },
    { 0x141C, "bfirstmoveanim" },
    { 0x141D, "bg" },
    { 0x141E, "bg_falldamagemaxheight_old" },
    { 0x141F, "bg_falldamagemaxheight_orig" },
    { 0x1420, "bg_falldamageminheight_old" },
    { 0x1421, "bg_falldamageminheight_orig" },
    { 0x1422, "bg_guys" },
    { 0x1423, "bh_attacker_accuracy_increaser" },
    { 0x1424, "bh_cleanup" },
    { 0x1425, "bh_heli_enemy_killer" },
    { 0x1426, "bh_helo_flyby" },
    { 0x1427, "bh_intro" },
    { 0x1428, "bh_intro_autosave" },
    { 0x1429, "bh_pit" },
    { 0x142A, "bh_pit_cleanup" },
    { 0x142B, "bh_pit_exit" },
    { 0x142C, "bh_pit_yard_visblock" },
    { 0x142D, "bh_run_civilians" },
    { 0x142E, "bh_run_mechs" },
    { 0x142F, "bh_yard" },
    { 0x1430, "bh_yard_doors" },
    { 0x1431, "bh_yard_exit" },
    { 0x1432, "bhasbadpath" },
    { 0x1433, "bhasgunwhileriding" },
    { 0x1434, "bhasnopath" },
    { 0x1435, "biasgroup_think" },
    { 0x1436, "bidlehitreaction" },
    { 0x1437, "bidlelooking" },
    { 0x1438, "big_cave_abyss_death" },
    { 0x1439, "big_cave_autosave" },
    { 0x143A, "big_cave_cleanup" },
    { 0x143B, "big_fire_door_close" },
    { 0x143C, "big_fire_door_open" },
    { 0x143D, "big_kamikaze_death" },
    { 0x143E, "big_moment_ending_vfx" },
    { 0x143F, "big_moment_ending_vfx_ash_fall" },
    { 0x1440, "big_moment_ending_vfx_bouncing_rocks" },
    { 0x1441, "big_moment_ending_vfx_donut_smk" },
    { 0x1442, "big_moment_ending_vfx_falling_debris" },
    { 0x1443, "big_moment_ending_vfx_falling_debris_tower" },
    { 0x1444, "big_moment_ending_vfx_falling_rock" },
    { 0x1445, "big_moment_ending_vfx_ground_buckling" },
    { 0x1446, "big_moment_ending_vfx_ground_splinter_up" },
    { 0x1447, "big_moment_ending_vfx_rolling_smk" },
    { 0x1448, "big_moment_ending_vfx_shockwave" },
    { 0x1449, "big_moment_ending_vfx_thick_smk_vm" },
    { 0x144A, "big_moment_ending_vfx_tower_base_smk_looping" },
    { 0x144B, "big_moment_ending_vfx_tower_chunk_trailing_smk" },
    { 0x144C, "big_moment_ending_vfx_tower_explode" },
    { 0x144D, "big_moment_ending_vfx_tower_fall_camshake" },
    { 0x144E, "big_moment_ending_vfx_tower_initial_crack" },
    { 0x144F, "big_moment_ending_vfx_tower_lower_left_burst" },
    { 0x1450, "big_moment_ending_vfx_tower_lower_right_burst" },
    { 0x1451, "big_moment_ending_vfx_tower_middle_top_burst" },
    { 0x1452, "big_moment_ending_vfx_tower_pillar_left_burst" },
    { 0x1453, "big_moment_ending_vfx_tower_pillar_right_burst" },
    { 0x1454, "big_moment_ending_vfx_tower_smoke_up" },
    { 0x1455, "big_moment_ending_vfx_tower_smoke_up_tall" },
    { 0x1456, "big_moment_ending_vfx_tower_top_left_burst" },
    { 0x1457, "big_moment_ending_vfx_trailing_dust" },
    { 0x1458, "big_moment_ending_vfx_warbird_dust" },
    { 0x1459, "big_pipe_explosion_vfx_after_hangar" },
    { 0x145A, "bigfinale" },
    { 0x145B, "bigfinaleblockknife" },
    { 0x145C, "bigfinaleenemytruckdamagesetup" },
    { 0x145D, "bigfinalehadesknife" },
    { 0x145E, "bigfinalehitflash" },
    { 0x145F, "bigfinaleilanagun" },
    { 0x1460, "bigfinaleilanakickcar" },
    { 0x1461, "bigfinaleilanamagicshoot" },
    { 0x1462, "bigfinaleilanapunchcar" },
    { 0x1463, "bigfinaleilanashoot" },
    { 0x1464, "bigfinaleilanaslamcar" },
    { 0x1465, "bigfinaleplayergrabgun" },
    { 0x1466, "bigfinaleplayerhitbyveh" },
    { 0x1467, "bigfinaleplayerhitwall" },
    { 0x1468, "bigfinaleplayerknife" },
    { 0x1469, "bigfinaleplayerlosegun" },
    { 0x146A, "bigfinaleplayerripdoor" },
    { 0x146B, "bigfinaleplayershoot" },
    { 0x146C, "bigfinaleplayerstab" },
    { 0x146D, "bigfinaleplayerstabfail" },
    { 0x146E, "bigfinalepunchhades" },
    { 0x146F, "bigfinaleswitchhadeshead" },
    { 0x1470, "bike_mount_dof" },
    { 0x1471, "bike_reach_function" },
    { 0x1472, "bike_rider" },
    { 0x1473, "bike_riders" },
    { 0x1474, "binoc_hint_breakout" },
    { 0x1475, "binoc_overlay" },
    { 0x1476, "binocdidpan" },
    { 0x1477, "binocdidzoom" },
    { 0x1478, "binocs_put_away" },
    { 0x1479, "binocular_dof" },
    { 0x147A, "binocular_mwp_rim_flicker" },
    { 0x147B, "binocular_vision" },
    { 0x147C, "biometrichud" },
    { 0x147D, "bird_flyaway" },
    { 0x147E, "bird_shadow_after_sewer" },
    { 0x147F, "bird_startle" },
    { 0x1480, "birds_after_sewer" },
    { 0x1481, "birds_scatter_cliff_rappel" },
    { 0x1482, "birthnode" },
    { 0x1483, "bisactivated" },
    { 0x1484, "bisgunner" },
    { 0x1485, "biskillstreak" },
    { 0x1486, "bissuppressingsniper" },
    { 0x1487, "bistargeted" },
    { 0x1488, "bkillplayer" },
    { 0x1489, "black_distance" },
    { 0x148A, "black_overlay" },
    { 0x148B, "black_screen" },
    { 0x148C, "blackout" },
    { 0x148D, "blackoutoverlay" },
    { 0x148E, "blank" },
    { 0x148F, "blast_anim_set" },
    { 0x1490, "blast_door_compare" },
    { 0x1491, "blast_doors_mr_x" },
    { 0x1492, "blastdoor_hideents" },
    { 0x1493, "blastdoor_showents" },
    { 0x1494, "blastpursuitfailedposbad" },
    { 0x1495, "blastradius" },
    { 0x1496, "blastshieldusetracker" },
    { 0x1497, "blend" },
    { 0x1498, "blend_dof_presets" },
    { 0x1499, "blend_dof_viewmodel_presets" },
    { 0x149A, "blend_droppitch" },
    { 0x149B, "blend_movespeedscale" },
    { 0x149C, "blend_movespeedscale_default" },
    { 0x149D, "blend_movespeedscale_percent" },
    { 0x149E, "blend_out_fake_speed_blend_ms" },
    { 0x149F, "blend_out_fake_speed_start_ms" },
    { 0x14A0, "blend_viewmodel_dof" },
    { 0x14A1, "blenddelete" },
    { 0x14A2, "blendintocrouchrun" },
    { 0x14A3, "blendintocrouchwalk" },
    { 0x14A4, "blendintostandrun" },
    { 0x14A5, "blendintostandwalk" },
    { 0x14A6, "blendtreeanims" },
    { 0x14A7, "blimp" },
    { 0x14A8, "blimp_animation" },
    { 0x14A9, "blimp_run" },
    { 0x14AA, "blimp_scripted_lights" },
    { 0x14AB, "blindfire" },
    { 0x14AC, "blink_flashlight" },
    { 0x14AD, "blink_lights" },
    { 0x14AE, "blink_lights_flicker" },
    { 0x14AF, "block_from_going_back" },
    { 0x14B0, "blockage_lighting" },
    { 0x14B1, "blockarea" },
    { 0x14B2, "blockentsinarea" },
    { 0x14B3, "blockgoalpos" },
    { 0x14B4, "blockingpain" },
    { 0x14B5, "blockweapondrops" },
    { 0x14B6, "blood_splat_on_screen" },
    { 0x14B7, "blood_splatter_simple" },
    { 0x14B8, "bloodeffect" },
    { 0x14B9, "bloodmeleeeffect" },
    { 0x14BA, "bloodsplateffect" },
    { 0x14BB, "bloodsprayexitwoundtrace" },
    { 0x14BC, "bloody_death" },
    { 0x14BD, "bloody_death_all_survivors" },
    { 0x14BE, "bloody_death_fx" },
    { 0x14BF, "blow_door" },
    { 0x14C0, "blowitup" },
    { 0x14C1, "blowout_goalradius_on_pathend" },
    { 0x14C2, "blowupatendoftrackingtime" },
    { 0x14C3, "blowupdronesequence" },
    { 0x14C4, "blowupdronesequenceexplosive" },
    { 0x14C5, "blue" },
    { 0x14C6, "blur_sine" },
    { 0x14C7, "blurry_rotors_on" },
    { 0x14C8, "blurview" },
    { 0x14C9, "bmarkallies" },
    { 0x14CA, "bmcd_debug_loop" },
    { 0x14CB, "bnoanimunload" },
    { 0x14CC, "boarderfx" },
    { 0x14CD, "boarderfxid" },
    { 0x14CE, "boat_bobbing_think" },
    { 0x14CF, "boat_canal" },
    { 0x14D0, "boat_crash_break_glass" },
    { 0x14D1, "boat_death_think" },
    { 0x14D2, "boat_end" },
    { 0x14D3, "boat_large_static_foam" },
    { 0x14D4, "boat_portal_tigger_on" },
    { 0x14D5, "boat_rock_check_triggers" },
    { 0x14D6, "boat_rocking_hangar" },
    { 0x14D7, "boat_rocking_jet_moment" },
    { 0x14D8, "boat_scene_big_bob_settings" },
    { 0x14D9, "boat_scene_boat_warning_system" },
    { 0x14DA, "boat_scene_bobbing_obstacle" },
    { 0x14DB, "boat_scene_bridge_collapse" },
    { 0x14DC, "boat_scene_cleanup" },
    { 0x14DD, "boat_scene_cleanup_warning_elem_on_crash" },
    { 0x14DE, "boat_scene_crash_moment" },
    { 0x14DF, "boat_scene_crash_moment_whiteout" },
    { 0x14E0, "boat_scene_disable_dive" },
    { 0x14E1, "boat_scene_dive_tutorial" },
    { 0x14E2, "boat_scene_dive_tutorial_trigger_hit" },
    { 0x14E3, "boat_scene_drive_gas_tutorial" },
    { 0x14E4, "boat_scene_drive_tutorial" },
    { 0x14E5, "boat_scene_early_setup" },
    { 0x14E6, "boat_scene_early_setup_start_bobbing_boats" },
    { 0x14E7, "boat_scene_fail_path" },
    { 0x14E8, "boat_scene_fire_missile_at_boat" },
    { 0x14E9, "boat_scene_handle_boat_collisions" },
    { 0x14EA, "boat_scene_handle_boat_damage" },
    { 0x14EB, "boat_scene_handle_fail_state" },
    { 0x14EC, "boat_scene_heli_change_paths" },
    { 0x14ED, "boat_scene_heli_change_paths_on_trigger" },
    { 0x14EE, "boat_scene_hide_warning_elem" },
    { 0x14EF, "boat_scene_master_handler" },
    { 0x14F0, "boat_scene_missile_dive_warning" },
    { 0x14F1, "boat_scene_missile_flight" },
    { 0x14F2, "boat_scene_missile_impact_damage_boat" },
    { 0x14F3, "boat_scene_missile_launch_volley" },
    { 0x14F4, "boat_scene_missile_wait_for_player_to_surface" },
    { 0x14F5, "boat_scene_monitor_boat_params" },
    { 0x14F6, "boat_scene_moving_obstacle" },
    { 0x14F7, "boat_scene_moving_obstacle_delete_boat_on_spawner_death" },
    { 0x14F8, "boat_scene_moving_obstacle_spawn_boat_in_radius" },
    { 0x14F9, "boat_scene_play_target_lock_sound_loop" },
    { 0x14FA, "boat_scene_prep_drones" },
    { 0x14FB, "boat_scene_prep_water_impacts" },
    { 0x14FC, "boat_scene_raise_canal_blocker" },
    { 0x14FD, "boat_scene_remove_water_impact" },
    { 0x14FE, "boat_scene_setup" },
    { 0x14FF, "boat_scene_setup_spawn_swarm" },
    { 0x1500, "boat_scene_show_warning_elem" },
    { 0x1501, "boat_scene_small_bob_settings" },
    { 0x1502, "boat_scene_spawn_water_impact" },
    { 0x1503, "boat_scene_swap_to_grapple_body" },
    { 0x1504, "boat_scene_target_lock_sound" },
    { 0x1505, "boat_scene_trigger_fail_path" },
    { 0x1506, "boat_scene_vig_civ_setup" },
    { 0x1507, "boat_small_static_foam" },
    { 0x1508, "boats" },
    { 0x1509, "bob_mask" },
    { 0x150A, "bobbing_fnc" },
    { 0x150B, "bobbing_objects" },
    { 0x150C, "bobbing_settings" },
    { 0x150D, "bobbing_underwater" },
    { 0x150E, "bobbingbuoyangles" },
    { 0x150F, "bobbingobject" },
    { 0x1510, "bobobjectparam" },
    { 0x1511, "bobobjectto" },
    { 0x1512, "bodies_gag_door_trigger" },
    { 0x1513, "body_room_exit" },
    { 0x1514, "body_temp" },
    { 0x1515, "bodygasfx" },
    { 0x1516, "bodyrollvelocity" },
    { 0x1517, "bodyroom_gag_ghost_function" },
    { 0x1518, "bodyroom_gag_support_function" },
    { 0x1519, "bodystashguardalertwatch" },
    { 0x151A, "bodystashguardapproach" },
    { 0x151B, "bodystashguarddeath" },
    { 0x151C, "bodystashguardkillwatch" },
    { 0x151D, "bodystashguardnofeedback" },
    { 0x151E, "boid_add_vehicle_to_targets" },
    { 0x151F, "boid_cheap_death" },
    { 0x1520, "boid_cloud_spawned" },
    { 0x1521, "boid_flock_think" },
    { 0x1522, "boid_settings" },
    { 0x1523, "boid_settings_presets" },
    { 0x1524, "boid_vehicle_targets" },
    { 0x1525, "boids" },
    { 0x1526, "bollards_clips" },
    { 0x1527, "bollards_move" },
    { 0x1528, "bolthit" },
    { 0x1529, "bomb" },
    { 0x152A, "bomb_defuser" },
    { 0x152B, "bomb_defuser_update" },
    { 0x152C, "bomb_light" },
    { 0x152D, "bomb_plant_dof" },
    { 0x152E, "bomb_plant_dof_bokeh" },
    { 0x152F, "bomb_plant_lighting" },
    { 0x1530, "bomb_shakes" },
    { 0x1531, "bomb_tag" },
    { 0x1532, "bomb_tag_left" },
    { 0x1533, "bomb_tag_right" },
    { 0x1534, "bomb_target" },
    { 0x1535, "bomb_zone_assaulting" },
    { 0x1536, "bombdefused" },
    { 0x1537, "bombdefuseevent" },
    { 0x1538, "bombdefusetrig" },
    { 0x1539, "bombdetonateevent" },
    { 0x153A, "bomber_disable_movement_for_time" },
    { 0x153B, "bomber_monitor_no_path" },
    { 0x153C, "bomber_wait_for_bomb_reset" },
    { 0x153D, "bomber_wait_for_death" },
    { 0x153E, "bomberdropbombs" },
    { 0x153F, "bomberdropcarepackges" },
    { 0x1540, "bombexploded" },
    { 0x1541, "bomblet_camera_waiter" },
    { 0x1542, "bomblet_camera_waiter_complete" },
    { 0x1543, "bomblet_explosion_waiter" },
    { 0x1544, "bombowner" },
    { 0x1545, "bombplanted" },
    { 0x1546, "bombplantedanim" },
    { 0x1547, "bombplantedtime" },
    { 0x1548, "bombplantevent" },
    { 0x1549, "bombs" },
    { 0x154A, "bombshake_interval" },
    { 0x154B, "bombshake_interval_rand" },
    { 0x154C, "bombsquadicons" },
    { 0x154D, "bombsquadids" },
    { 0x154E, "bombsquadmodel" },
    { 0x154F, "bombsquadvisibilityupdater" },
    { 0x1550, "bombsquadwaiter" },
    { 0x1551, "bombtimer" },
    { 0x1552, "bombtimerwait" },
    { 0x1553, "bombzone_num_picked" },
    { 0x1554, "bombzonegoal" },
    { 0x1555, "bombzones" },
    { 0x1556, "bone" },
    { 0x1557, "bones" },
    { 0x1558, "bones_advance_hospital" },
    { 0x1559, "bones_bike" },
    { 0x155A, "bones_bike_idle_wait" },
    { 0x155B, "bones_dismount" },
    { 0x155C, "bones_fence" },
    { 0x155D, "bones_gate_jtbk_land" },
    { 0x155E, "bones_gate_jtbk_lift" },
    { 0x155F, "bones_high_five" },
    { 0x1560, "bones_onbike" },
    { 0x1561, "bones_rollout_manager" },
    { 0x1562, "boneyard_fire_at_targets" },
    { 0x1563, "boneyard_style_heli_missile_attack" },
    { 0x1564, "boneyard_style_heli_missile_attack_linked" },
    { 0x1565, "boobytrapcratethink" },
    { 0x1566, "bool_norecharge" },
    { 0x1567, "boost" },
    { 0x1568, "boost_attack" },
    { 0x1569, "boost_attack_deal_damage" },
    { 0x156A, "boost_dash" },
    { 0x156B, "boost_dash_think" },
    { 0x156C, "boost_dash_track_player_movement" },
    { 0x156D, "boost_dash_track_player_velocity" },
    { 0x156E, "boost_dodge_activate_plr" },
    { 0x156F, "boost_down_in_order" },
    { 0x1570, "boost_hint" },
    { 0x1571, "boost_hint_breakout" },
    { 0x1572, "boost_jump" },
    { 0x1573, "boost_jump_disable" },
    { 0x1574, "boost_jump_disable_npc" },
    { 0x1575, "boost_jump_enable" },
    { 0x1576, "boost_jump_enabled" },
    { 0x1577, "boost_jump_hint" },
    { 0x1578, "boost_jump_npc" },
    { 0x1579, "boost_jump_player" },
    { 0x157A, "boost_jump_to_heli" },
    { 0x157B, "boost_jump_toggle" },
    { 0x157C, "boost_jump_wrapper" },
    { 0x157D, "boost_land_anims" },
    { 0x157E, "boost_land_assist_npc" },
    { 0x157F, "boost_land_assist_npc_ground" },
    { 0x1580, "boost_land_first_shot" },
    { 0x1581, "boost_land_hud_disable" },
    { 0x1582, "boost_land_hud_enable" },
    { 0x1583, "boost_land_max_locked_out" },
    { 0x1584, "boost_land_max_shot_timer" },
    { 0x1585, "boost_land_npc" },
    { 0x1586, "boost_land_on" },
    { 0x1587, "boost_land_out_of_fuel" },
    { 0x1588, "boost_land_play_oneshot" },
    { 0x1589, "boost_land_player" },
    { 0x158A, "boost_land_release_locked_out" },
    { 0x158B, "boost_land_release_shot_timer" },
    { 0x158C, "boost_land_release_start_time" },
    { 0x158D, "boost_land_use_fuel" },
    { 0x158E, "boost_land_velocity_finder" },
    { 0x158F, "boost_lets_go" },
    { 0x1590, "boost_plane_controls" },
    { 0x1591, "boost_script_ender" },
    { 0x1592, "boost_setup_desat" },
    { 0x1593, "boost_slam_hint" },
    { 0x1594, "boost_slam_history" },
    { 0x1595, "boost_slam_use_hint" },
    { 0x1596, "boost_slam_use_monitor" },
    { 0x1597, "boost_timer" },
    { 0x1598, "boost_use_hint" },
    { 0x1599, "booster_distance_checker" },
    { 0x159A, "boosters_off_anim" },
    { 0x159B, "boostslamkillevent" },
    { 0x159C, "border_drone_fail" },
    { 0x159D, "bored_patrol_anims" },
    { 0x159E, "bot" },
    { 0x159F, "bot_3d_sighting_model" },
    { 0x15A0, "bot_3d_sighting_model_thread" },
    { 0x15A1, "bot_abort_tactical_goal" },
    { 0x15A2, "bot_add_ambush_time_delayed" },
    { 0x15A3, "bot_add_missing_nodes" },
    { 0x15A4, "bot_add_scavenger_bag" },
    { 0x15A5, "bot_add_to_bot_damage_targets" },
    { 0x15A6, "bot_add_to_bot_level_targets" },
    { 0x15A7, "bot_add_to_bot_use_targets" },
    { 0x15A8, "bot_allow_to_capture_flag" },
    { 0x15A9, "bot_allowed_to_3_cap" },
    { 0x15AA, "bot_allowed_to_switch_teams" },
    { 0x15AB, "bot_allowed_to_use_killstreaks" },
    { 0x15AC, "bot_ambush_end" },
    { 0x15AD, "bot_assign_personality_functions" },
    { 0x15AE, "bot_attachment_reticle" },
    { 0x15AF, "bot_attachmenttable" },
    { 0x15B0, "bot_balance_personality" },
    { 0x15B1, "bot_ball_attacker_limit_for_team" },
    { 0x15B2, "bot_ball_defender_limit_for_team" },
    { 0x15B3, "bot_ball_get_balls_carried_by_team" },
    { 0x15B4, "bot_ball_get_closest_ball" },
    { 0x15B5, "bot_ball_get_free_balls" },
    { 0x15B6, "bot_ball_get_origin" },
    { 0x15B7, "bot_ball_is_resetting" },
    { 0x15B8, "bot_ball_origin_can_see_goal" },
    { 0x15B9, "bot_ball_think" },
    { 0x15BA, "bot_ball_trace_to_origin" },
    { 0x15BB, "bot_body_is_dead" },
    { 0x15BC, "bot_bots_enabled_or_added" },
    { 0x15BD, "bot_cache_entrances" },
    { 0x15BE, "bot_cache_entrances_to_bombzones" },
    { 0x15BF, "bot_cache_entrances_to_gametype_array" },
    { 0x15C0, "bot_cache_entrances_to_hardpoints" },
    { 0x15C1, "bot_cache_flag_distances" },
    { 0x15C2, "bot_camotable" },
    { 0x15C3, "bot_camp_tag" },
    { 0x15C4, "bot_camping" },
    { 0x15C5, "bot_can_join_team" },
    { 0x15C6, "bot_can_revive" },
    { 0x15C7, "bot_can_use_assault_ugv" },
    { 0x15C8, "bot_can_use_assault_ugv_only_ai_version" },
    { 0x15C9, "bot_can_use_box_by_type" },
    { 0x15CA, "bot_can_use_emp" },
    { 0x15CB, "bot_can_use_point_in_defend" },
    { 0x15CC, "bot_can_use_sentry_only_ai_version" },
    { 0x15CD, "bot_can_use_strafing_run" },
    { 0x15CE, "bot_can_use_warbird" },
    { 0x15CF, "bot_can_use_warbird_only_ai_version" },
    { 0x15D0, "bot_capture_hp_zone" },
    { 0x15D1, "bot_capture_point" },
    { 0x15D2, "bot_capture_zone" },
    { 0x15D3, "bot_capture_zone_get_furthest_distance" },
    { 0x15D4, "bot_check_tag_above_head" },
    { 0x15D5, "bot_check_team_is_using_position" },
    { 0x15D6, "bot_choose_difficulty_for_default" },
    { 0x15D7, "bot_choose_flag" },
    { 0x15D8, "bot_class" },
    { 0x15D9, "bot_client_counts" },
    { 0x15DA, "bot_cm_human_picked" },
    { 0x15DB, "bot_cm_spawned_bots" },
    { 0x15DC, "bot_cm_waited_players_time" },
    { 0x15DD, "bot_combine_tag_seen_arrays" },
    { 0x15DE, "bot_conf_think" },
    { 0x15DF, "bot_connect_monitor" },
    { 0x15E0, "bot_control_heli" },
    { 0x15E1, "bot_control_heli_main_move_loop" },
    { 0x15E2, "bot_crate_is_command_goal" },
    { 0x15E3, "bot_crate_valid" },
    { 0x15E4, "bot_ctf_ai_director_update" },
    { 0x15E5, "bot_ctf_get_node_chance" },
    { 0x15E6, "bot_ctf_think" },
    { 0x15E7, "bot_cur_loadout_num" },
    { 0x15E8, "bot_custom_classes_allowed" },
    { 0x15E9, "bot_damage_callback" },
    { 0x15EA, "bot_default_class_random" },
    { 0x15EB, "bot_default_sd_role_behavior" },
    { 0x15EC, "bot_defend_get_precalc_entrances_for_current_area" },
    { 0x15ED, "bot_defend_get_random_entrance_point_for_current_area" },
    { 0x15EE, "bot_defend_player_guarding" },
    { 0x15EF, "bot_defend_stop" },
    { 0x15F0, "bot_defend_think" },
    { 0x15F1, "bot_defending" },
    { 0x15F2, "bot_defending_center" },
    { 0x15F3, "bot_defending_nodes" },
    { 0x15F4, "bot_defending_override_origin_node" },
    { 0x15F5, "bot_defending_radius" },
    { 0x15F6, "bot_defending_trigger" },
    { 0x15F7, "bot_defending_type" },
    { 0x15F8, "bot_difficulty_defaults" },
    { 0x15F9, "bot_disable_tactical_goals" },
    { 0x15FA, "bot_dom_debug_should_capture_all" },
    { 0x15FB, "bot_dom_debug_should_protect_all" },
    { 0x15FC, "bot_dom_get_node_chance" },
    { 0x15FD, "bot_dom_leader_dialog" },
    { 0x15FE, "bot_dom_override_flag_targets" },
    { 0x15FF, "bot_dom_think" },
    { 0x1600, "bot_draw_circle" },
    { 0x1601, "bot_draw_cylinder" },
    { 0x1602, "bot_draw_cylinder_think" },
    { 0x1603, "bot_drop" },
    { 0x1604, "bot_enable_tactical_goals" },
    { 0x1605, "bot_end_control_on_respawn" },
    { 0x1606, "bot_end_control_on_vehicle_death" },
    { 0x1607, "bot_end_control_watcher" },
    { 0x1608, "bot_ent_is_anonymous_mine" },
    { 0x1609, "bot_fallback_personality" },
    { 0x160A, "bot_fallback_weapon" },
    { 0x160B, "bot_filter_ambush_inuse" },
    { 0x160C, "bot_filter_ambush_vicinity" },
    { 0x160D, "bot_find_1_loadout_option" },
    { 0x160E, "bot_find_2_loadout_options" },
    { 0x160F, "bot_find_ambush_entrances" },
    { 0x1610, "bot_find_best_tag_from_array" },
    { 0x1611, "bot_find_defend_node_func" },
    { 0x1612, "bot_find_node_that_protects_point" },
    { 0x1613, "bot_find_node_to_capture_point" },
    { 0x1614, "bot_find_node_to_capture_zone" },
    { 0x1615, "bot_find_node_to_guard_player" },
    { 0x1616, "bot_find_random_midpoint" },
    { 0x1617, "bot_find_visible_tags" },
    { 0x1618, "bot_flag_trigger" },
    { 0x1619, "bot_flag_trigger_clear" },
    { 0x161A, "bot_force_stance_for_time" },
    { 0x161B, "bot_funcs" },
    { 0x161C, "bot_gametype_allied_attackers_for_team" },
    { 0x161D, "bot_gametype_allied_defenders_for_team" },
    { 0x161E, "bot_gametype_attacker_defender_ai_director_update" },
    { 0x161F, "bot_gametype_attacker_limit_for_team" },
    { 0x1620, "bot_gametype_chooses_class" },
    { 0x1621, "bot_gametype_chooses_team" },
    { 0x1622, "bot_gametype_defender_limit_for_team" },
    { 0x1623, "bot_gametype_get_allied_attackers_for_team" },
    { 0x1624, "bot_gametype_get_allied_defenders_for_team" },
    { 0x1625, "bot_gametype_get_num_players_on_team" },
    { 0x1626, "bot_gametype_get_players_by_role" },
    { 0x1627, "bot_gametype_initialize_attacker_defender_role" },
    { 0x1628, "bot_gametype_precaching_done" },
    { 0x1629, "bot_gametype_set_role" },
    { 0x162A, "bot_get_all_possible_flags" },
    { 0x162B, "bot_get_ambush_trap_item" },
    { 0x162C, "bot_get_client_limit" },
    { 0x162D, "bot_get_entrances_for_stance_and_index" },
    { 0x162E, "bot_get_grenade_ammo" },
    { 0x162F, "bot_get_grenade_for_purpose" },
    { 0x1630, "bot_get_heli_goal_dist_sq" },
    { 0x1631, "bot_get_heli_slowdown_dist_sq" },
    { 0x1632, "bot_get_host_team" },
    { 0x1633, "bot_get_human_picked_team" },
    { 0x1634, "bot_get_known_attacker" },
    { 0x1635, "bot_get_low_on_ammo" },
    { 0x1636, "bot_get_max_players_on_team" },
    { 0x1637, "bot_get_nodes_in_cone" },
    { 0x1638, "bot_get_num_teammates_capturing_zone" },
    { 0x1639, "bot_get_pick_13_count" },
    { 0x163A, "bot_get_player_team" },
    { 0x163B, "bot_get_rank_xp_and_prestige" },
    { 0x163C, "bot_get_string_index_for_integer" },
    { 0x163D, "bot_get_team_limit" },
    { 0x163E, "bot_get_teammates_capturing_zone" },
    { 0x163F, "bot_get_teammates_currently_defending_point" },
    { 0x1640, "bot_get_teammates_in_radius" },
    { 0x1641, "bot_get_total_gun_ammo" },
    { 0x1642, "bot_get_zones_within_dist" },
    { 0x1643, "bot_get_zones_within_dist_recurs" },
    { 0x1644, "bot_goal_can_override" },
    { 0x1645, "bot_grenade_matches_purpose" },
    { 0x1646, "bot_guard_player" },
    { 0x1647, "bot_gun_think" },
    { 0x1648, "bot_handle_no_valid_defense_node" },
    { 0x1649, "bot_has_tactical_goal" },
    { 0x164A, "bot_heli_find_unvisited_nodes" },
    { 0x164B, "bot_heli_nodes" },
    { 0x164C, "bot_heli_pilot_traceoffset" },
    { 0x164D, "bot_hp_allow_predictive_capping" },
    { 0x164E, "bot_hp_think" },
    { 0x164F, "bot_ignore_precalc_paths" },
    { 0x1650, "bot_in_combat" },
    { 0x1651, "bot_infect_ai_director_update" },
    { 0x1652, "bot_infect_angle_too_steep_for_knife_throw" },
    { 0x1653, "bot_infect_find_node_can_see_ent" },
    { 0x1654, "bot_infect_retrieve_knife" },
    { 0x1655, "bot_infect_think" },
    { 0x1656, "bot_initialized_remote_vehicles" },
    { 0x1657, "bot_interaction_type" },
    { 0x1658, "bot_invalid_attachment_combos" },
    { 0x1659, "bot_is_bodyguarding" },
    { 0x165A, "bot_is_capturing" },
    { 0x165B, "bot_is_capturing_flag" },
    { 0x165C, "bot_is_capturing_zone" },
    { 0x165D, "bot_is_defending" },
    { 0x165E, "bot_is_defending_point" },
    { 0x165F, "bot_is_guarding_player" },
    { 0x1660, "bot_is_monitoring_aerial_danger" },
    { 0x1661, "bot_is_patrolling" },
    { 0x1662, "bot_is_protecting" },
    { 0x1663, "bot_is_protecting_flag" },
    { 0x1664, "bot_is_remote_or_linked" },
    { 0x1665, "bot_is_tag_visible" },
    { 0x1666, "bot_is_valid_killstreak" },
    { 0x1667, "bot_israndom" },
    { 0x1668, "bot_jump_for_tag" },
    { 0x1669, "bot_killstreak_can_use_weapon_version" },
    { 0x166A, "bot_killstreak_choose_loc_enemies" },
    { 0x166B, "bot_killstreak_do_not_use" },
    { 0x166C, "bot_killstreak_drop" },
    { 0x166D, "bot_killstreak_drop_anywhere" },
    { 0x166E, "bot_killstreak_drop_hidden" },
    { 0x166F, "bot_killstreak_drop_outside" },
    { 0x1670, "bot_killstreak_get_all_outside_allies" },
    { 0x1671, "bot_killstreak_get_all_outside_enemies" },
    { 0x1672, "bot_killstreak_get_outside_players" },
    { 0x1673, "bot_killstreak_get_zone_allies_outside" },
    { 0x1674, "bot_killstreak_get_zone_enemies_outside" },
    { 0x1675, "bot_killstreak_is_valid_internal" },
    { 0x1676, "bot_killstreak_is_valid_single" },
    { 0x1677, "bot_killstreak_never_use" },
    { 0x1678, "bot_killstreak_remote_control" },
    { 0x1679, "bot_killstreak_sentry" },
    { 0x167A, "bot_killstreak_setup" },
    { 0x167B, "bot_killstreak_simple_use" },
    { 0x167C, "bot_killstreak_wait" },
    { 0x167D, "bot_know_enemies_on_start" },
    { 0x167E, "bot_ks_funcs" },
    { 0x167F, "bot_ks_heli_offset" },
    { 0x1680, "bot_last_loadout_num" },
    { 0x1681, "bot_leader_dialog" },
    { 0x1682, "bot_loadout_choose_fallback_primary" },
    { 0x1683, "bot_loadout_choose_from_attachmenttable" },
    { 0x1684, "bot_loadout_choose_from_camotable" },
    { 0x1685, "bot_loadout_choose_from_custom_default_class" },
    { 0x1686, "bot_loadout_choose_from_default_class" },
    { 0x1687, "bot_loadout_choose_from_reticletable" },
    { 0x1688, "bot_loadout_choose_from_set" },
    { 0x1689, "bot_loadout_choose_from_statstable" },
    { 0x168A, "bot_loadout_choose_values" },
    { 0x168B, "bot_loadout_class_callback" },
    { 0x168C, "bot_loadout_fields" },
    { 0x168D, "bot_loadout_get_difficulty" },
    { 0x168E, "bot_loadout_item_allowed" },
    { 0x168F, "bot_loadout_item_valid_for_rank" },
    { 0x1690, "bot_loadout_pick" },
    { 0x1691, "bot_loadout_set" },
    { 0x1692, "bot_loadout_set_has_wildcard" },
    { 0x1693, "bot_loadout_team" },
    { 0x1694, "bot_loadout_valid_choice" },
    { 0x1695, "bot_loadouts_initialized" },
    { 0x1696, "bot_lui_convert_team_to_int" },
    { 0x1697, "bot_make_entity_sentient" },
    { 0x1698, "bot_map_center" },
    { 0x1699, "bot_map_max_x" },
    { 0x169A, "bot_map_max_y" },
    { 0x169B, "bot_map_max_z" },
    { 0x169C, "bot_map_min_x" },
    { 0x169D, "bot_map_min_y" },
    { 0x169E, "bot_map_min_z" },
    { 0x169F, "bot_max_players_on_team" },
    { 0x16A0, "bot_melee_tactical_insertion_check" },
    { 0x16A1, "bot_memory_goal" },
    { 0x16A2, "bot_memory_goal_time" },
    { 0x16A3, "bot_min_rank_for_item" },
    { 0x16A4, "bot_monitor_enemy_camp_spots" },
    { 0x16A5, "bot_monitor_team_limits" },
    { 0x16A6, "bot_monitor_watch_entrances_at_goal" },
    { 0x16A7, "bot_monitor_watch_entrances_bodyguard" },
    { 0x16A8, "bot_monitor_watch_entrances_camp" },
    { 0x16A9, "bot_new_tactical_goal" },
    { 0x16AA, "bot_notify_streak_used" },
    { 0x16AB, "bot_out_of_ammo" },
    { 0x16AC, "bot_out_of_combat_time" },
    { 0x16AD, "bot_patrol_area" },
    { 0x16AE, "bot_pers_init" },
    { 0x16AF, "bot_pers_update" },
    { 0x16B0, "bot_personality" },
    { 0x16B1, "bot_personality_list" },
    { 0x16B2, "bot_personality_type" },
    { 0x16B3, "bot_personality_types_desired" },
    { 0x16B4, "bot_pick_new_loadout_next_spawn" },
    { 0x16B5, "bot_pick_personality_from_weapon" },
    { 0x16B6, "bot_pick_random_point_from_set" },
    { 0x16B7, "bot_pick_random_point_in_radius" },
    { 0x16B8, "bot_picking_up" },
    { 0x16B9, "bot_pickup_weapon" },
    { 0x16BA, "bot_player_spawned" },
    { 0x16BB, "bot_point_is_on_pathgrid" },
    { 0x16BC, "bot_post_teleport" },
    { 0x16BD, "bot_post_use_ammo_crate" },
    { 0x16BE, "bot_post_use_box_of_type" },
    { 0x16BF, "bot_pre_use_ammo_crate" },
    { 0x16C0, "bot_pre_use_box_of_type" },
    { 0x16C1, "bot_prematchdonetime" },
    { 0x16C2, "bot_protect_point" },
    { 0x16C3, "bot_queued_process" },
    { 0x16C4, "bot_queued_process_level_thread" },
    { 0x16C5, "bot_queued_process_level_thread_active" },
    { 0x16C6, "bot_queued_process_queue" },
    { 0x16C7, "bot_random_path" },
    { 0x16C8, "bot_random_path_default" },
    { 0x16C9, "bot_random_path_function" },
    { 0x16CA, "bot_random_ranks_for_difficulty" },
    { 0x16CB, "bot_recent_point_of_interest" },
    { 0x16CC, "bot_register_killstreak_func" },
    { 0x16CD, "bot_remove_from_bot_level_targets" },
    { 0x16CE, "bot_remove_invalid_tags" },
    { 0x16CF, "bot_respawn_launcher_name" },
    { 0x16D0, "bot_restart_think_threads" },
    { 0x16D1, "bot_reticletable" },
    { 0x16D2, "bot_rnd_prestige" },
    { 0x16D3, "bot_rnd_rank" },
    { 0x16D4, "bot_scavenger_bags" },
    { 0x16D5, "bot_sd_ai_director_update" },
    { 0x16D6, "bot_sd_override_zone_targets" },
    { 0x16D7, "bot_sd_start" },
    { 0x16D8, "bot_sd_think" },
    { 0x16D9, "bot_seek_dropped_weapon" },
    { 0x16DA, "bot_send_cancel_notify" },
    { 0x16DB, "bot_send_place_notify" },
    { 0x16DC, "bot_sentry_activate" },
    { 0x16DD, "bot_sentry_add_goal" },
    { 0x16DE, "bot_sentry_cancel" },
    { 0x16DF, "bot_sentry_cancel_failsafe" },
    { 0x16E0, "bot_sentry_carried_obj" },
    { 0x16E1, "bot_sentry_choose_placement" },
    { 0x16E2, "bot_sentry_choose_target" },
    { 0x16E3, "bot_sentry_ensure_exit" },
    { 0x16E4, "bot_sentry_force_cancel" },
    { 0x16E5, "bot_sentry_path_start" },
    { 0x16E6, "bot_sentry_path_thread" },
    { 0x16E7, "bot_sentry_should_abort" },
    { 0x16E8, "bot_set_ambush_trap" },
    { 0x16E9, "bot_set_ambush_trap_wait_fire" },
    { 0x16EA, "bot_set_bombzone_bottargets" },
    { 0x16EB, "bot_set_difficulty" },
    { 0x16EC, "bot_set_loadout_class" },
    { 0x16ED, "bot_set_personality" },
    { 0x16EE, "bot_set_role" },
    { 0x16EF, "bot_set_role_delayed" },
    { 0x16F0, "bot_setup_ball_jump_nodes" },
    { 0x16F1, "bot_setup_bombzone_bottargets" },
    { 0x16F2, "bot_setup_bot_targets" },
    { 0x16F3, "bot_setup_callback_class" },
    { 0x16F4, "bot_setup_loadout_callback" },
    { 0x16F5, "bot_setup_map_specific_killstreaks" },
    { 0x16F6, "bot_should_cap_next_zone" },
    { 0x16F7, "bot_should_defend" },
    { 0x16F8, "bot_should_defend_flag" },
    { 0x16F9, "bot_should_do_killcam" },
    { 0x16FA, "bot_should_melee_level_damage_target" },
    { 0x16FB, "bot_should_pickup_weapons" },
    { 0x16FC, "bot_should_pickup_weapons_infect" },
    { 0x16FD, "bot_should_use_ammo_crate" },
    { 0x16FE, "bot_should_use_ballistic_vest_crate" },
    { 0x16FF, "bot_should_use_grenade_crate" },
    { 0x1700, "bot_should_use_juicebox_crate" },
    { 0x1701, "bot_should_use_scavenger_bag" },
    { 0x1702, "bot_spawn_from_devgui_in_progress" },
    { 0x1703, "bot_spawned_before" },
    { 0x1704, "bot_sr_think" },
    { 0x1705, "bot_start_know_enemy" },
    { 0x1706, "bot_start_known_by_enemy" },
    { 0x1707, "bot_supported_killstreaks" },
    { 0x1708, "bot_switch_to_killstreak_weapon" },
    { 0x1709, "bot_tag_allowable_jump_height" },
    { 0x170A, "bot_tag_obj_radius" },
    { 0x170B, "bot_target" },
    { 0x170C, "bot_target_is_flag" },
    { 0x170D, "bot_targets" },
    { 0x170E, "bot_team" },
    { 0x170F, "bot_think" },
    { 0x1710, "bot_think_crate" },
    { 0x1711, "bot_think_crate_blocking_path" },
    { 0x1712, "bot_think_gametype" },
    { 0x1713, "bot_think_killstreak" },
    { 0x1714, "bot_think_level_actions" },
    { 0x1715, "bot_think_revive" },
    { 0x1716, "bot_think_seek_dropped_weapons" },
    { 0x1717, "bot_think_tactical_goals" },
    { 0x1718, "bot_think_watch_aerial_killstreak" },
    { 0x1719, "bot_think_watch_enemy" },
    { 0x171A, "bot_triggers" },
    { 0x171B, "bot_try_trap_follower" },
    { 0x171C, "bot_twar_capture_zone" },
    { 0x171D, "bot_twar_get_node_chance" },
    { 0x171E, "bot_twar_get_zone_label" },
    { 0x171F, "bot_twar_get_zones_for_team" },
    { 0x1720, "bot_twar_is_capturing_zone" },
    { 0x1721, "bot_twar_should_start_cautious_approach" },
    { 0x1722, "bot_twar_think" },
    { 0x1723, "bot_update_camp_assassin" },
    { 0x1724, "bot_usebutton_wait" },
    { 0x1725, "bot_valid_camp_assassin" },
    { 0x1726, "bot_validate_perk" },
    { 0x1727, "bot_validate_reticle" },
    { 0x1728, "bot_validate_weapon" },
    { 0x1729, "bot_variables_initialized" },
    { 0x172A, "bot_vectors_are_equal" },
    { 0x172B, "bot_visited_times" },
    { 0x172C, "bot_wait_for_event_flag_swap" },
    { 0x172D, "bot_waittill_bots_enabled" },
    { 0x172E, "bot_waittill_goal_or_fail" },
    { 0x172F, "bot_waittill_out_of_combat_or_time" },
    { 0x1730, "bot_waittill_using_vehicle" },
    { 0x1731, "bot_war_think" },
    { 0x1732, "bot_watch_entrances_delayed" },
    { 0x1733, "bot_watch_for_death" },
    { 0x1734, "bot_watch_manual_detonate" },
    { 0x1735, "bot_watch_new_tags" },
    { 0x1736, "bot_watch_nodes" },
    { 0x1737, "bot_weap_built_in_attachments" },
    { 0x1738, "bot_weap_personality" },
    { 0x1739, "bot_weap_statstable" },
    { 0x173A, "bothbarrels" },
    { 0x173B, "bothplayerssplitscreen" },
    { 0x173C, "botlastloadout" },
    { 0x173D, "botlastloadoutdifficulty" },
    { 0x173E, "botlastloadoutpersonality" },
    { 0x173F, "botloadoutfavoritecamoprimary" },
    { 0x1740, "botloadoutfavoritecamosecondary" },
    { 0x1741, "botloadoutsets" },
    { 0x1742, "botloadouttemplates" },
    { 0x1743, "bots" },
    { 0x1744, "bots_disable_team_switching" },
    { 0x1745, "bots_exist" },
    { 0x1746, "bots_gametype_handles_class_choice" },
    { 0x1747, "bots_gametype_handles_team_choice" },
    { 0x1748, "bots_ignore_team_balance" },
    { 0x1749, "bots_notify_on_disconnect" },
    { 0x174A, "bots_notify_on_spawn" },
    { 0x174B, "bots_remove_from_array_on_notify" },
    { 0x174C, "bots_update_difficulty" },
    { 0x174D, "bots_used" },
    { 0x174E, "bottarget" },
    { 0x174F, "bottargets" },
    { 0x1750, "bottom" },
    { 0x1751, "boulder_originandangles" },
    { 0x1752, "boulderbarrage" },
    { 0x1753, "bouncegate" },
    { 0x1754, "bouncelight" },
    { 0x1755, "bouncing_betty_animated" },
    { 0x1756, "bouncingbettyarray" },
    { 0x1757, "bounds" },
    { 0x1758, "box_extent" },
    { 0x1759, "boxes" },
    { 0x175A, "boxsettings" },
    { 0x175B, "boxtouchonly" },
    { 0x175C, "boxtruck_explode" },
    { 0x175D, "boxtype" },
    { 0x175E, "bp" },
    { 0x175F, "bplayerisinsidesafehouse" },
    { 0x1760, "bplayerleash" },
    { 0x1761, "bplayerscanon" },
    { 0x1762, "bpm" },
    { 0x1763, "braggingrightsloser" },
    { 0x1764, "brakingcurrenttime" },
    { 0x1765, "bravo" },
    { 0x1766, "bravo_leader" },
    { 0x1767, "breach_abort" },
    { 0x1768, "breach_ai_reset" },
    { 0x1769, "breach_ajani_land" },
    { 0x176A, "breach_anims" },
    { 0x176B, "breach_backtrack_fail" },
    { 0x176C, "breach_bad_guy2_gets_shot" },
    { 0x176D, "breach_bad_weapon_hint" },
    { 0x176E, "breach_charge" },
    { 0x176F, "breach_charge_2" },
    { 0x1770, "breach_cleanup" },
    { 0x1771, "breach_death_anims" },
    { 0x1772, "breach_debug_display_animnames" },
    { 0x1773, "breach_dof" },
    { 0x1774, "breach_dont_fire" },
    { 0x1775, "breach_doors" },
    { 0x1776, "breach_enemies_stunned" },
    { 0x1777, "breach_enemy_6" },
    { 0x1778, "breach_enemy_cancel_ragdoll" },
    { 0x1779, "breach_enemy_catch_exceptions" },
    { 0x177A, "breach_enemy_ignored_by_friendlies" },
    { 0x177B, "breach_enemy_ragdoll_on_death" },
    { 0x177C, "breach_enemy_spawner_think" },
    { 0x177D, "breach_enemy_track_status" },
    { 0x177E, "breach_enemy_waitfor_breach_ending" },
    { 0x177F, "breach_enemy_waitfor_death" },
    { 0x1780, "breach_enemy_waitfor_death_counter" },
    { 0x1781, "breach_explosion" },
    { 0x1782, "breach_failed_to_start" },
    { 0x1783, "breach_fire_straight" },
    { 0x1784, "breach_friendlies_ready_at_other_door" },
    { 0x1785, "breach_friendlies_restore_grenades" },
    { 0x1786, "breach_friendlies_take_grenades" },
    { 0x1787, "breach_friendly_hint" },
    { 0x1788, "breach_functions" },
    { 0x1789, "breach_fx" },
    { 0x178A, "breach_fx_setup" },
    { 0x178B, "breach_gideon_land" },
    { 0x178C, "breach_group_trigger_think" },
    { 0x178D, "breach_groups" },
    { 0x178E, "breach_guy_think" },
    { 0x178F, "breach_guys" },
    { 0x1790, "breach_hint_cleanup" },
    { 0x1791, "breach_hint_create" },
    { 0x1792, "breach_hostage_spawner_think" },
    { 0x1793, "breach_icon_think" },
    { 0x1794, "breach_index" },
    { 0x1795, "breach_joker_land" },
    { 0x1796, "breach_lighting" },
    { 0x1797, "breach_missionfailed" },
    { 0x1798, "breach_near_player" },
    { 0x1799, "breach_no_auto_reload" },
    { 0x179A, "breach_not_ready_hint" },
    { 0x179B, "breach_office_door" },
    { 0x179C, "breach_origin" },
    { 0x179D, "breach_participants_ready_to_proceed" },
    { 0x179E, "breach_passive_player" },
    { 0x179F, "breach_passive_time" },
    { 0x17A0, "breach_play_fx" },
    { 0x17A1, "breach_player_land" },
    { 0x17A2, "breach_reloading_hint" },
    { 0x17A3, "breach_reset_animname" },
    { 0x17A4, "breach_reset_goaladius" },
    { 0x17A5, "breach_rumble" },
    { 0x17A6, "breach_set_animname" },
    { 0x17A7, "breach_set_goaladius" },
    { 0x17A8, "breach_should_be_skipped" },
    { 0x17A9, "breach_signal" },
    { 0x17AA, "breach_slo_mo_exit" },
    { 0x17AB, "breach_slow_down" },
    { 0x17AC, "breach_spawner_setup" },
    { 0x17AD, "breach_think" },
    { 0x17AE, "breach_too_many_enemies_hint" },
    { 0x17AF, "breach_top_off_weapon" },
    { 0x17B0, "breach_trigger_cleanup" },
    { 0x17B1, "breach_trigger_think" },
    { 0x17B2, "breach_use_triggers" },
    { 0x17B3, "breachactors" },
    { 0x17B4, "breachdialogreminders" },
    { 0x17B5, "breachdonotfire" },
    { 0x17B6, "breached" },
    { 0x17B7, "breachenemies" },
    { 0x17B8, "breachenemies_active" },
    { 0x17B9, "breachenemies_alive" },
    { 0x17BA, "breacher_think" },
    { 0x17BB, "breachers" },
    { 0x17BC, "breachersready" },
    { 0x17BD, "breachfailstate" },
    { 0x17BE, "breachfinished" },
    { 0x17BF, "breachfriendlies" },
    { 0x17C0, "breachfriendlies_can_teleport" },
    { 0x17C1, "breachfriendlies_grenades_empty" },
    { 0x17C2, "breachignoreenemy_count" },
    { 0x17C3, "breaching" },
    { 0x17C4, "breaching_shots_fired" },
    { 0x17C5, "breachless_door_opens" },
    { 0x17C6, "breachtargetarraymonitor" },
    { 0x17C7, "breachtargets" },
    { 0x17C8, "breachtrigger" },
    { 0x17C9, "bread_crumbs" },
    { 0x17CA, "break_both_climb_hint" },
    { 0x17CB, "break_detonate_frb_hint" },
    { 0x17CC, "break_exfil_out_bounds" },
    { 0x17CD, "break_exo_cloak_hint" },
    { 0x17CE, "break_from_ignoreall" },
    { 0x17CF, "break_glass" },
    { 0x17D0, "break_glass_when_near" },
    { 0x17D1, "break_hovertank_reload_hint" },
    { 0x17D2, "break_if_flashed_sonic" },
    { 0x17D3, "break_ignore_all_on_damage" },
    { 0x17D4, "break_left_climb_hint" },
    { 0x17D5, "break_me_out_if_player_found" },
    { 0x17D6, "break_nearest_light" },
    { 0x17D7, "break_office_glass_ahead_of_time" },
    { 0x17D8, "break_out_and_fight" },
    { 0x17D9, "break_out_if_damaged" },
    { 0x17DA, "break_prone_hint" },
    { 0x17DB, "break_right_climb_hint" },
    { 0x17DC, "breakable_light" },
    { 0x17DD, "breakables_fx" },
    { 0x17DE, "breaking" },
    { 0x17DF, "breakout_glass" },
    { 0x17E0, "breakout_opfor_cleanup" },
    { 0x17E1, "breakoutofshootingifwanttomoveup" },
    { 0x17E2, "breaks_os" },
    { 0x17E3, "breaktime" },
    { 0x17E4, "breathers" },
    { 0x17E5, "breathingmanager" },
    { 0x17E6, "breathingstoptime" },
    { 0x17E7, "brick" },
    { 0x17E8, "brick_smash_setup" },
    { 0x17E9, "bridge" },
    { 0x17EA, "bridge_atlas_suv_drive_up" },
    { 0x17EB, "bridge_car_explode" },
    { 0x17EC, "bridge_chunks" },
    { 0x17ED, "bridge_civs" },
    { 0x17EE, "bridge_collapse_anim" },
    { 0x17EF, "bridge_collapse_mob_explosion" },
    { 0x17F0, "bridge_collapse_rumble" },
    { 0x17F1, "bridge_collapse_rumble_steady" },
    { 0x17F2, "bridge_collapse_rumble_timed" },
    { 0x17F3, "bridge_collapse_screen_effects" },
    { 0x17F4, "bridge_collapse_sequence" },
    { 0x17F5, "bridge_collapsed" },
    { 0x17F6, "bridge_dialogue" },
    { 0x17F7, "bridge_enemies" },
    { 0x17F8, "bridge_explosion" },
    { 0x17F9, "bridge_fall" },
    { 0x17FA, "bridge_fire_clear" },
    { 0x17FB, "bridge_glows" },
    { 0x17FC, "bridge_idle_anims" },
    { 0x17FD, "bridge_kva_hasmat" },
    { 0x17FE, "bridge_player_notetrack_handler" },
    { 0x17FF, "bridge_post_crash_pitbull_crawl_done" },
    { 0x1800, "bridge_rappel_squad" },
    { 0x1801, "bridge_reso_detonation" },
    { 0x1802, "bridge_screenfx" },
    { 0x1803, "bridge_soot" },
    { 0x1804, "bridge_street_fight" },
    { 0x1805, "bridge_takedown_fail" },
    { 0x1806, "bridge_takedown_fail_fade" },
    { 0x1807, "bridge_takedown_jump_complete" },
    { 0x1808, "bridge_takedown_success" },
    { 0x1809, "bridge_tanker_explode" },
    { 0x180A, "brief_fx" },
    { 0x180B, "briefing_allies" },
    { 0x180C, "briefing_ambient_allies" },
    { 0x180D, "briefing_ambient_ally_setup" },
    { 0x180E, "briefing_anim_struct" },
    { 0x180F, "briefing_begin" },
    { 0x1810, "briefing_foley" },
    { 0x1811, "briefing_main" },
    { 0x1812, "briefing_obj" },
    { 0x1813, "briefing_player" },
    { 0x1814, "briefing_start" },
    { 0x1815, "briefing_vignette_anims" },
    { 0x1816, "briefing_vignette_cleanup" },
    { 0x1817, "briefing_vignettes" },
    { 0x1818, "brinkofdeathkillstreak" },
    { 0x1819, "broken" },
    { 0x181A, "broken_door" },
    { 0x181B, "broken_glass" },
    { 0x181C, "broom_sweep_dust_fx" },
    { 0x181D, "brush" },
    { 0x181E, "brush_delete" },
    { 0x181F, "brush_show" },
    { 0x1820, "brush_shown" },
    { 0x1821, "brush_throw" },
    { 0x1822, "bsaveinprogress" },
    { 0x1823, "bsc_squelched" },
    { 0x1824, "bscripteddeath" },
    { 0x1825, "bsgods_condition_to_state_driving" },
    { 0x1826, "bsgods_condition_to_state_intro" },
    { 0x1827, "bsgods_enter_state_driving" },
    { 0x1828, "bsgods_in_state_driving" },
    { 0x1829, "bsgods_preset_constructor" },
    { 0x182A, "bsgods_preset_instance_init_callback" },
    { 0x182B, "bsharpturnduringsharpturn" },
    { 0x182C, "bshootwhilemoving" },
    { 0x182D, "bsniperenabled" },
    { 0x182E, "bsoundlooping" },
    { 0x182F, "btr_fire_at_target" },
    { 0x1830, "btr_get_target" },
    { 0x1831, "btr_turret_think" },
    { 0x1832, "bubllength" },
    { 0x1833, "buddy" },
    { 0x1834, "buddyjoinedvo" },
    { 0x1835, "buddyjoinwarbirdsetup" },
    { 0x1836, "buddyspawn" },
    { 0x1837, "bufferedchildstats" },
    { 0x1838, "bufferedstats" },
    { 0x1839, "build_aianims" },
    { 0x183A, "build_all_treadfx" },
    { 0x183B, "build_attach_models" },
    { 0x183C, "build_bulletshield" },
    { 0x183D, "build_call_buttons" },
    { 0x183E, "build_cover_death" },
    { 0x183F, "build_death_badplace" },
    { 0x1840, "build_death_jolt_delay" },
    { 0x1841, "build_deathanim" },
    { 0x1842, "build_deathfx" },
    { 0x1843, "build_deathfx_generic_script_model" },
    { 0x1844, "build_deathfx_override" },
    { 0x1845, "build_deathmodel" },
    { 0x1846, "build_deathquake" },
    { 0x1847, "build_deckdust" },
    { 0x1848, "build_destructible" },
    { 0x1849, "build_drive" },
    { 0x184A, "build_elevators" },
    { 0x184B, "build_exhaust" },
    { 0x184C, "build_frontarmor" },
    { 0x184D, "build_fx" },
    { 0x184E, "build_gaz_death" },
    { 0x184F, "build_grenadeshield" },
    { 0x1850, "build_hideparts" },
    { 0x1851, "build_hovertank_death" },
    { 0x1852, "build_humvee_anims" },
    { 0x1853, "build_idle" },
    { 0x1854, "build_is_airplane" },
    { 0x1855, "build_is_helicopter" },
    { 0x1856, "build_life" },
    { 0x1857, "build_light" },
    { 0x1858, "build_light_override" },
    { 0x1859, "build_localinit" },
    { 0x185A, "build_mainturret" },
    { 0x185B, "build_misc_anims" },
    { 0x185C, "build_missile_launcher" },
    { 0x185D, "build_new_view_matrix" },
    { 0x185E, "build_nodes_for_airspace" },
    { 0x185F, "build_path_by_targetname" },
    { 0x1860, "build_path_info" },
    { 0x1861, "build_quake" },
    { 0x1862, "build_radiusdamage" },
    { 0x1863, "build_rider_death_func" },
    { 0x1864, "build_rocket_deathfx" },
    { 0x1865, "build_rumble" },
    { 0x1866, "build_rumble_override" },
    { 0x1867, "build_rumble_unique" },
    { 0x1868, "build_shoot_shock" },
    { 0x1869, "build_single_tread" },
    { 0x186A, "build_team" },
    { 0x186B, "build_technical" },
    { 0x186C, "build_template" },
    { 0x186D, "build_threat_data" },
    { 0x186E, "build_treadfx" },
    { 0x186F, "build_treadfx_override_get_surface_function" },
    { 0x1870, "build_treadfx_override_tags" },
    { 0x1871, "build_treadfx_script_model" },
    { 0x1872, "build_turret" },
    { 0x1873, "build_unload_groups" },
    { 0x1874, "build_vrap_death" },
    { 0x1875, "build_walker_death" },
    { 0x1876, "buildattachmentmaps" },
    { 0x1877, "buildbaseweaponlist" },
    { 0x1878, "buildchallegeinfo" },
    { 0x1879, "buildchallengetableinfo" },
    { 0x187A, "builddot_damage" },
    { 0x187B, "builddot_ontick" },
    { 0x187C, "builddot_startloop" },
    { 0x187D, "builddot_wait" },
    { 0x187E, "building_1" },
    { 0x187F, "building_bone" },
    { 0x1880, "building_exit_arrived" },
    { 0x1881, "building_explode" },
    { 0x1882, "building_explosion_01" },
    { 0x1883, "building_jump_done" },
    { 0x1884, "building_jump_initiate" },
    { 0x1885, "building_research_bridge" },
    { 0x1886, "buildscoreboardtype" },
    { 0x1887, "buildshadowgeomopt" },
    { 0x1888, "buildshadowgeomopt_ng" },
    { 0x1889, "buildshadowmapgeomopt" },
    { 0x188A, "buildvalidflightpaths" },
    { 0x188B, "buildweapondata" },
    { 0x188C, "buildweaponname" },
    { 0x188D, "buildweaponnamecamo" },
    { 0x188E, "buildweaponnamereticle" },
    { 0x188F, "buildweaponsettings" },
    { 0x1890, "bulblength" },
    { 0x1891, "bulbradius" },
    { 0x1892, "bullet_armor" },
    { 0x1893, "bullet_attack" },
    { 0x1894, "bullet_break_glass_gag_timer" },
    { 0x1895, "bullet_cluster_01" },
    { 0x1896, "bullet_cluster_02" },
    { 0x1897, "bullet_cluster_03" },
    { 0x1898, "bullet_cluster_04" },
    { 0x1899, "bullet_cluster_06" },
    { 0x189A, "bullet_cluster_07" },
    { 0x189B, "bullet_cluster_12" },
    { 0x189C, "bullet_cluster_15" },
    { 0x189D, "bullet_cluster_32" },
    { 0x189E, "bullet_cluster_33" },
    { 0x189F, "bullet_cluster_36" },
    { 0x18A0, "bullet_cluster_37" },
    { 0x18A1, "bullet_cluster_40" },
    { 0x18A2, "bullet_cluster_41" },
    { 0x18A3, "bullet_cluster_43" },
    { 0x18A4, "bullet_cluster_45" },
    { 0x18A5, "bullet_deflector_shield" },
    { 0x18A6, "bullet_magnet_shield" },
    { 0x18A7, "bullet_rain_drone_swarm" },
    { 0x18A8, "bullet_resistance" },
    { 0x18A9, "bullet_shield_shield" },
    { 0x18AA, "bullet_thing" },
    { 0x18AB, "bulletdamagemod" },
    { 0x18AC, "bullethitcallback" },
    { 0x18AD, "bulletpenetrationevent" },
    { 0x18AE, "bullets_break_office_glass_gag" },
    { 0x18AF, "bulletshielded" },
    { 0x18B0, "bulletsinclip" },
    { 0x18B1, "bulletstreak" },
    { 0x18B2, "bulletwhizbycheck_whilemoving" },
    { 0x18B3, "bulletwhizbycheckloop" },
    { 0x18B4, "bulletwhizbyreaction" },
    { 0x18B5, "bump_into_awareness" },
    { 0x18B6, "bump_music_for_burke_takedown" },
    { 0x18B7, "bump_nag_vo" },
    { 0x18B8, "bumper_test" },
    { 0x18B9, "bunker_guy01" },
    { 0x18BA, "bunker_guy02" },
    { 0x18BB, "bunker_guy03" },
    { 0x18BC, "bunker_intro_anim" },
    { 0x18BD, "bunker_respawn_handler" },
    { 0x18BE, "bunker_settings" },
    { 0x18BF, "buoys_return_to_bobbing" },
    { 0x18C0, "burke" },
    { 0x18C1, "burke_180_function" },
    { 0x18C2, "burke_advance" },
    { 0x18C3, "burke_advance_hospital" },
    { 0x18C4, "burke_aggression" },
    { 0x18C5, "burke_alert" },
    { 0x18C6, "burke_ask_player_to_use_bike" },
    { 0x18C7, "burke_at_school_door" },
    { 0x18C8, "burke_beam_bend" },
    { 0x18C9, "burke_bike" },
    { 0x18CA, "burke_bike_speed" },
    { 0x18CB, "burke_breach" },
    { 0x18CC, "burke_breach_interrupt" },
    { 0x18CD, "burke_burst_shoot" },
    { 0x18CE, "burke_bus_goal" },
    { 0x18CF, "burke_busted_light" },
    { 0x18D0, "burke_cheap_flashlight_setup" },
    { 0x18D1, "burke_cr_foley_console" },
    { 0x18D2, "burke_cr_foley_enter" },
    { 0x18D3, "burke_cr_foley_idle" },
    { 0x18D4, "burke_cr_foley_start" },
    { 0x18D5, "burke_deadroom_door" },
    { 0x18D6, "burke_disable_cqb" },
    { 0x18D7, "burke_dismount" },
    { 0x18D8, "burke_dismount_timing_fix" },
    { 0x18D9, "burke_drone_warning_dialogue" },
    { 0x18DA, "burke_exfil_approach" },
    { 0x18DB, "burke_exfil_lighting" },
    { 0x18DC, "burke_exit" },
    { 0x18DD, "burke_exo_cloak_on" },
    { 0x18DE, "burke_exo_push_end_early" },
    { 0x18DF, "burke_exo_push_wait" },
    { 0x18E0, "burke_fastzip_aim_turret" },
    { 0x18E1, "burke_fastzip_scene" },
    { 0x18E2, "burke_feet01" },
    { 0x18E3, "burke_forest_stealth_movement" },
    { 0x18E4, "burke_forest_takedown" },
    { 0x18E5, "burke_gate_jtbk_land" },
    { 0x18E6, "burke_gate_jtbk_lift" },
    { 0x18E7, "burke_gets_up" },
    { 0x18E8, "burke_greets_alpha_dialogue" },
    { 0x18E9, "burke_hand_plant_lf_wallclimb" },
    { 0x18EA, "burke_hand_plant_rt_wallclimb" },
    { 0x18EB, "burke_hill_slide" },
    { 0x18EC, "burke_intro_anim" },
    { 0x18ED, "burke_intro_dialogue" },
    { 0x18EE, "burke_intro_lighting" },
    { 0x18EF, "burke_knocked_to_ground" },
    { 0x18F0, "burke_mech_march_movement" },
    { 0x18F1, "burke_middle_takedown" },
    { 0x18F2, "burke_mounts_bike" },
    { 0x18F3, "burke_move_ahead_wait_function" },
    { 0x18F4, "burke_move_into_office" },
    { 0x18F5, "burke_move_through_alley_cover" },
    { 0x18F6, "burke_onbike" },
    { 0x18F7, "burke_path_through_school" },
    { 0x18F8, "burke_path_to_school" },
    { 0x18F9, "burke_patrol_takedown_02" },
    { 0x18FA, "burke_patrol_takedown_02_cleanup" },
    { 0x18FB, "burke_post_breach_move" },
    { 0x18FC, "burke_powers_up_bike" },
    { 0x18FD, "burke_pre_sentinel_kva_reveal" },
    { 0x18FE, "burke_rally_init" },
    { 0x18FF, "burke_rally_street_dialogue" },
    { 0x1900, "burke_rappel" },
    { 0x1901, "burke_rappel_rope_swap" },
    { 0x1902, "burke_red_arm_light" },
    { 0x1903, "burke_red_arm_light_checkpoint" },
    { 0x1904, "burke_reunite_with_player_alley" },
    { 0x1905, "burke_rim_lights" },
    { 0x1906, "burke_river_entry_splash_fx" },
    { 0x1907, "burke_river_looping_splash_fx" },
    { 0x1908, "burke_rooftop_combat" },
    { 0x1909, "burke_rooftop_combat_animscript" },
    { 0x190A, "burke_rope" },
    { 0x190B, "burke_rope_long" },
    { 0x190C, "burke_run_slide" },
    { 0x190D, "burke_school_approach_idle" },
    { 0x190E, "burke_school_approach_idle_skip" },
    { 0x190F, "burke_se_forest_takedown_01" },
    { 0x1910, "burke_sentinel_kva_reveal" },
    { 0x1911, "burke_server_room_se" },
    { 0x1912, "burke_setupanimations" },
    { 0x1913, "burke_shimmey_setup" },
    { 0x1914, "burke_shimmy_1" },
    { 0x1915, "burke_shimmy_2" },
    { 0x1916, "burke_shimmy_2b" },
    { 0x1917, "burke_slide_02" },
    { 0x1918, "burke_solo_takedown" },
    { 0x1919, "burke_spit_blood" },
    { 0x191A, "burke_spot_lighting" },
    { 0x191B, "burke_startle_stairs" },
    { 0x191C, "burke_tree_slide_fx" },
    { 0x191D, "burke_walk_lighting" },
    { 0x191E, "burke_wall_climb_teleport" },
    { 0x191F, "burke_wall_idle" },
    { 0x1920, "burke_wall_idle_skip" },
    { 0x1921, "burkeambushnohitnotetrack" },
    { 0x1922, "burkecourtyardboostjump" },
    { 0x1923, "burkeopenatriumexitdoor" },
    { 0x1924, "burkestruggledeath" },
    { 0x1925, "burn_and_crash" },
    { 0x1926, "burn_on" },
    { 0x1927, "burning" },
    { 0x1928, "burning_trash_fire" },
    { 0x1929, "burnville_paratrooper_hack" },
    { 0x192A, "burnville_paratrooper_hack_loop" },
    { 0x192B, "burst_fire" },
    { 0x192C, "burst_fire_settings" },
    { 0x192D, "burst_fire_unmanned" },
    { 0x192E, "burst_fire_warbird" },
    { 0x192F, "burst_fire_weapon" },
    { 0x1930, "burstdelay" },
    { 0x1931, "burstfirenumshots" },
    { 0x1932, "burstmax" },
    { 0x1933, "burstmin" },
    { 0x1934, "burstshootanimrate" },
    { 0x1935, "burstshot" },
    { 0x1936, "bus_5_hop_blocker_a" },
    { 0x1937, "bus_5_hop_blocker_b" },
    { 0x1938, "bus_chase_suv_explode" },
    { 0x1939, "bus_chase_suv_lose_control" },
    { 0x193A, "bus_chase_suv_oneshots" },
    { 0x193B, "bus_crash" },
    { 0x193C, "bus_crash_at_end" },
    { 0x193D, "bus_crash_hold_on_last_frame" },
    { 0x193E, "bus_crash_setup_backup_collision" },
    { 0x193F, "bus_crash_start" },
    { 0x1940, "bus_jump_count" },
    { 0x1941, "bus_jumping_notetrack_setup" },
    { 0x1942, "bus_kva_impact_sparks" },
    { 0x1943, "bus_skid" },
    { 0x1944, "busereadyidle" },
    { 0x1945, "busted_light_gag" },
    { 0x1946, "butress_animate" },
    { 0x1947, "butress_origin_fix" },
    { 0x1948, "button" },
    { 0x1949, "button_down" },
    { 0x194A, "button_hint_disable" },
    { 0x194B, "button_hint_display" },
    { 0x194C, "button_is_clicked" },
    { 0x194D, "button_is_held" },
    { 0x194E, "button_is_kb" },
    { 0x194F, "button_mash_detection" },
    { 0x1950, "button_mash_dynamic_hint" },
    { 0x1951, "button_mash_level" },
    { 0x1952, "button_mash_success" },
    { 0x1953, "button_pressed" },
    { 0x1954, "button_pressed_think" },
    { 0x1955, "button_presses" },
    { 0x1956, "button_prompt_on_cardoor" },
    { 0x1957, "button_switch" },
    { 0x1958, "buttonclick" },
    { 0x1959, "buttondown" },
    { 0x195A, "buttonisheld" },
    { 0x195B, "buttonmash_add_per_press" },
    { 0x195C, "buttonmash_decay" },
    { 0x195D, "buttonmash_decay_per_frame" },
    { 0x195E, "buttonmash_hint_cleanup" },
    { 0x195F, "buttonmash_max" },
    { 0x1960, "buttonmash_monitor" },
    { 0x1961, "buttonmash_value" },
    { 0x1962, "buttonpressed_internal" },
    { 0x1963, "buttons" },
    { 0x1964, "buttontimer" },
    { 0x1965, "buttontimertotal" },
    { 0x1966, "buttress_function" },
    { 0x1967, "buzzkillevent" },
    { 0x1968, "bypassclasschoice" },
    { 0x1969, "bypassclasschoicefunc" },
    { 0x196A, "bystander_oppression_event_ents" },
    { 0x196B, "c4_earthquake" },
    { 0x196C, "c4_weaponname" },
    { 0x196D, "c4array" },
    { 0x196E, "c4damage" },
    { 0x196F, "c4death" },
    { 0x1970, "c4deathdetonate" },
    { 0x1971, "c4deatheffect" },
    { 0x1972, "c4empdamage" },
    { 0x1973, "c4empkillstreakwait" },
    { 0x1974, "c4explodethisframe" },
    { 0x1975, "cac" },
    { 0x1976, "cac_camera_offset" },
    { 0x1977, "cac_camera_targetoffset" },
    { 0x1978, "cac_camerazoff" },
    { 0x1979, "cac_camerazoff_zoom" },
    { 0x197A, "cac_camoffset_angle_ratio" },
    { 0x197B, "cac_camoffset_ratio" },
    { 0x197C, "cac_dist" },
    { 0x197D, "cac_framedelay" },
    { 0x197E, "cac_getcustomclassloc" },
    { 0x197F, "cac_getequipment" },
    { 0x1980, "cac_getequipmentextra" },
    { 0x1981, "cac_getkillstreak" },
    { 0x1982, "cac_getkillstreakmodule" },
    { 0x1983, "cac_getoffhand" },
    { 0x1984, "cac_getperk" },
    { 0x1985, "cac_getweapon" },
    { 0x1986, "cac_getweaponattachment" },
    { 0x1987, "cac_getweaponattachmentthree" },
    { 0x1988, "cac_getweaponattachmenttwo" },
    { 0x1989, "cac_getweaponcamo" },
    { 0x198A, "cac_getweaponreticle" },
    { 0x198B, "cac_getwildcard" },
    { 0x198C, "cac_has_slam" },
    { 0x198D, "cac_modified_damage" },
    { 0x198E, "cac_ratio_zoom" },
    { 0x198F, "cac_selector" },
    { 0x1990, "cac_targetzoff" },
    { 0x1991, "cac_targetzoff_zoom" },
    { 0x1992, "cac_weap_loot_offset" },
    { 0x1993, "cac_weap_offset" },
    { 0x1994, "cac_weap_screen_offset" },
    { 0x1995, "cac_weap_tuning" },
    { 0x1996, "cac_weap_tuning_camoffset" },
    { 0x1997, "cac_weap_tuning_weap_sideoffset" },
    { 0x1998, "cac_weap_tuning_weap_zoffset" },
    { 0x1999, "cac_weapon" },
    { 0x199A, "cacloadout" },
    { 0x199B, "cafe_irons_speech_bink" },
    { 0x199C, "cafe_market_damb" },
    { 0x199D, "cafe_market_moped_away" },
    { 0x199E, "cafe_market_music_play" },
    { 0x199F, "cafe_market_music_stop" },
    { 0x19A0, "cafe_market_plane_flyover" },
    { 0x19A1, "cafecamerascancounter" },
    { 0x19A2, "cafecameraumbrella" },
    { 0x19A3, "cafecivilianmeetandgreet" },
    { 0x19A4, "cafeendcamerascan" },
    { 0x19A5, "cafegeeseflyinganimation" },
    { 0x19A6, "cafeilanaseat" },
    { 0x19A7, "cafeinitvendorgate" },
    { 0x19A8, "cafeintrodialog" },
    { 0x19A9, "cafeintrofov" },
    { 0x19AA, "cafemarketilanabackyardwait" },
    { 0x19AB, "cafemarketmoveilana" },
    { 0x19AC, "cafemarketplayerfollowtarget" },
    { 0x19AD, "cafemarketslowdownplayermore" },
    { 0x19AE, "cafeoutrositter" },
    { 0x19AF, "cafeplayercameralook" },
    { 0x19B0, "cafesetupilanabackpack" },
    { 0x19B1, "cafesetupplayerseat" },
    { 0x19B2, "cafesetuptouristilana" },
    { 0x19B3, "cafesittingreader" },
    { 0x19B4, "cafesittingreaderchoosenextanim" },
    { 0x19B5, "cafesittingreaderplaynextanim" },
    { 0x19B6, "cafeteasipper" },
    { 0x19B7, "cafeteria_reinforcements" },
    { 0x19B8, "cafeteria_squad_pressure" },
    { 0x19B9, "cafevideolog" },
    { 0x19BA, "cafewaiter" },
    { 0x19BB, "calc_cam_lookat" },
    { 0x19BC, "calc_f" },
    { 0x19BD, "calc_f_from_avatar" },
    { 0x19BE, "calc_f_from_avatar_spawnpoint" },
    { 0x19BF, "calc_f_fromscreen" },
    { 0x19C0, "calc_flock_goal_pos" },
    { 0x19C1, "calc_new_pos" },
    { 0x19C2, "calc_target_dir" },
    { 0x19C3, "calcanimstartpos" },
    { 0x19C4, "calctrackingyaw" },
    { 0x19C5, "calculate_aerial_pathnodes" },
    { 0x19C6, "calculate_aim_offset" },
    { 0x19C7, "calculate_base_target_offset" },
    { 0x19C8, "calculate_break_time" },
    { 0x19C9, "calculate_defend_stance" },
    { 0x19CA, "calculate_dodge_position" },
    { 0x19CB, "calculate_dodge_positions" },
    { 0x19CC, "calculate_flock_goal_positions" },
    { 0x19CD, "calculate_lateral_move_accuracy" },
    { 0x19CE, "calculate_locator_anim_speed" },
    { 0x19CF, "calculate_move_to_goal_yaw" },
    { 0x19D0, "calculate_player_wounded_accuracy" },
    { 0x19D1, "calculate_rope_target" },
    { 0x19D2, "calculate_sprinting_jumping_accuracy" },
    { 0x19D3, "calculate_stance_accuracy" },
    { 0x19D4, "calculate_tactical_score" },
    { 0x19D5, "calculate_tag_on_path_grid" },
    { 0x19D6, "calculate_threat_level" },
    { 0x19D7, "calculate_water_pos" },
    { 0x19D8, "calculate_zone_node_extents" },
    { 0x19D9, "calculated_aerial_nodes_done" },
    { 0x19DA, "calculated_aerial_nodes_in_progress" },
    { 0x19DB, "calculated_nearest_node" },
    { 0x19DC, "calculatedistances" },
    { 0x19DD, "calculatehoverlocation" },
    { 0x19DE, "calculateinitialposition" },
    { 0x19DF, "calculatekd" },
    { 0x19E0, "calculateleftstickdeadzone" },
    { 0x19E1, "calculatematchplaystyle" },
    { 0x19E2, "calculatenewhoverdestination" },
    { 0x19E3, "calculatenodeoffset" },
    { 0x19E4, "calculatenodeoffsetfromanimationdelta" },
    { 0x19E5, "calculatenodetransitionangles" },
    { 0x19E6, "calculatespm" },
    { 0x19E7, "calculations_in_progress" },
    { 0x19E8, "call_elevator" },
    { 0x19E9, "call_for_backup" },
    { 0x19EA, "call_in_assistance" },
    { 0x19EB, "callback" },
    { 0x19EC, "callback_codeendgame" },
    { 0x19ED, "callback_entityoutofworld" },
    { 0x19EE, "callback_hostmigration" },
    { 0x19EF, "callback_killingblow" },
    { 0x19F0, "callback_playerconnect" },
    { 0x19F1, "callback_playerdamage" },
    { 0x19F2, "callback_playerdamage_internal" },
    { 0x19F3, "callback_playerdisconnect" },
    { 0x19F4, "callback_playergrenadesuicide" },
    { 0x19F5, "callback_playerkilled" },
    { 0x19F6, "callback_playerlaststand" },
    { 0x19F7, "callback_playerlaststandhorde" },
    { 0x19F8, "callback_playermigrated" },
    { 0x19F9, "callback_startgametype" },
    { 0x19FA, "callbackcodeendgame" },
    { 0x19FB, "callbackentityoutofworld" },
    { 0x19FC, "callbackhostmigration" },
    { 0x19FD, "callbackplayerconnect" },
    { 0x19FE, "callbackplayerdamage" },
    { 0x19FF, "callbackplayerdisconnect" },
    { 0x1A00, "callbackplayergrenadesuicide" },
    { 0x1A01, "callbackplayerkilled" },
    { 0x1A02, "callbackplayerlaststand" },
    { 0x1A03, "callbackplayermigrated" },
    { 0x1A04, "callbacks" },
    { 0x1A05, "callbackstartgametype" },
    { 0x1A06, "callbackvoid" },
    { 0x1A07, "calledout" },
    { 0x1A08, "caller" },
    { 0x1A09, "calloptionalbehaviorcallback" },
    { 0x1A0A, "callouttypewillrepeat" },
    { 0x1A0B, "callstrike" },
    { 0x1A0C, "callstrike_bomb" },
    { 0x1A0D, "cam_percent_away" },
    { 0x1A0E, "cam_scan_lp" },
    { 0x1A0F, "cam_zoom_in" },
    { 0x1A10, "cam_zoom_out" },
    { 0x1A11, "camdirectionforward" },
    { 0x1A12, "came_from" },
    { 0x1A13, "camera" },
    { 0x1A14, "camera_array" },
    { 0x1A15, "camera_cut" },
    { 0x1A16, "camera_goal" },
    { 0x1A17, "camera_helper" },
    { 0x1A18, "camera_lookat" },
    { 0x1A19, "camera_rotator_begin" },
    { 0x1A1A, "camera_rotator_think" },
    { 0x1A1B, "camera_scan" },
    { 0x1A1C, "camera_scanner_interior_killed" },
    { 0x1A1D, "camera_scanner_interior_spotted" },
    { 0x1A1E, "camera_scanner_interior_trigger_think" },
    { 0x1A1F, "camera_scanner_think" },
    { 0x1A20, "camera_shake" },
    { 0x1A21, "camera_shake_on_turret_fire" },
    { 0x1A22, "camera_sway_tuning" },
    { 0x1A23, "camera_tag" },
    { 0x1A24, "camera_tag_angles" },
    { 0x1A25, "camera_tag_origin" },
    { 0x1A26, "camera_view_tuning" },
    { 0x1A27, "cameradrift" },
    { 0x1A28, "cameralinkpoint" },
    { 0x1A29, "cameralookatescapevehicle" },
    { 0x1A2A, "cameraloop" },
    { 0x1A2B, "camerascanintrodialogue" },
    { 0x1A2C, "camerascanoutrodialog" },
    { 0x1A2D, "cameraview" },
    { 0x1A2E, "camerhelperarray" },
    { 0x1A2F, "camlinkent" },
    { 0x1A30, "cammove" },
    { 0x1A31, "camoffset_ratio_cac" },
    { 0x1A32, "camoffset_ratio_lobby" },
    { 0x1A33, "camoffset_ratio_maxspeed" },
    { 0x1A34, "camoffset_ratio_prelobby" },
    { 0x1A35, "camoffset_ratio_prelobby_loot" },
    { 0x1A36, "camp_bomb_update" },
    { 0x1A37, "camp_david_play_videos" },
    { 0x1A38, "camp_david_reload_malfunction" },
    { 0x1A39, "camp_david_thunder_transition" },
    { 0x1A3A, "camp_david_training_mute_device" },
    { 0x1A3B, "camp_scanner_guy" },
    { 0x1A3C, "camp_security_greeter" },
    { 0x1A3D, "campaign" },
    { 0x1A3E, "camparams" },
    { 0x1A3F, "campdavid_player_arm_reveal" },
    { 0x1A40, "camper_guy" },
    { 0x1A41, "camper_time_started_hunting" },
    { 0x1A42, "camper_trigger_think" },
    { 0x1A43, "camping_needs_fallback_camp_location" },
    { 0x1A44, "camrotate" },
    { 0x1A45, "camzoff" },
    { 0x1A46, "can_be_damaged" },
    { 0x1A47, "can_camp_near_others" },
    { 0x1A48, "can_early_melee" },
    { 0x1A49, "can_fire_turret" },
    { 0x1A4A, "can_melee_enemy_time" },
    { 0x1A4B, "can_pickup_bomb_time" },
    { 0x1A4C, "can_say_friendlyfire" },
    { 0x1A4D, "can_see_attacker_for_a_bit" },
    { 0x1A4E, "can_see_ent" },
    { 0x1A4F, "can_see_origin" },
    { 0x1A50, "can_see_player" },
    { 0x1A51, "can_shoot_enemy" },
    { 0x1A52, "can_shoot_enemy_monitor" },
    { 0x1A53, "can_shoot_guns" },
    { 0x1A54, "can_shoot_missiles" },
    { 0x1A55, "can_shoot_weapons" },
    { 0x1A56, "can_teleport_ai_to_pos" },
    { 0x1A57, "can_tip_think" },
    { 0x1A58, "can_turret_start_play" },
    { 0x1A59, "canal_adssetfovzoomin" },
    { 0x1A5A, "canal_balcony_smoke_and_spawn" },
    { 0x1A5B, "canal_binoc_hint" },
    { 0x1A5C, "canal_binoc_transition_in" },
    { 0x1A5D, "canal_binoc_transition_out" },
    { 0x1A5E, "canal_binocs_stop_zoom_in" },
    { 0x1A5F, "canal_binocs_stop_zoom_out" },
    { 0x1A60, "canal_binocs_zoom_in" },
    { 0x1A61, "canal_binocs_zoom_out" },
    { 0x1A62, "canal_boat_explosion" },
    { 0x1A63, "canal_boat_hit_bottom" },
    { 0x1A64, "canal_breach_logic" },
    { 0x1A65, "canal_bridge_patrol_think" },
    { 0x1A66, "canal_bridge_patrols_spawn" },
    { 0x1A67, "canal_chase_boats" },
    { 0x1A68, "canal_convo_fov_shift_off" },
    { 0x1A69, "canal_convo_fov_shift_on_start" },
    { 0x1A6A, "canal_convo_fov_shift_to_dead" },
    { 0x1A6B, "canal_convo_fov_shift_to_wp" },
    { 0x1A6C, "canal_cormack_move_to_window" },
    { 0x1A6D, "canal_cormack_objective_convo" },
    { 0x1A6E, "canal_delete_dead_demo_team" },
    { 0x1A6F, "canal_dock_destroy" },
    { 0x1A70, "canal_door_button_hint_display" },
    { 0x1A71, "canal_drone_guard_sequence" },
    { 0x1A72, "canal_drone_guard_think" },
    { 0x1A73, "canal_drone_guards_move_to_struct_and_loop_animation" },
    { 0x1A74, "canal_drone_swarm_death_think" },
    { 0x1A75, "canal_drone_swarm_think" },
    { 0x1A76, "canal_emp_wave" },
    { 0x1A77, "canal_enemy_damage_function" },
    { 0x1A78, "canal_enemy_setup_post_explosive_pickup" },
    { 0x1A79, "canal_fight_to_explosives_sequence" },
    { 0x1A7A, "canal_fight_to_weapon_platform" },
    { 0x1A7B, "canal_finale_button_mashing" },
    { 0x1A7C, "canal_finale_fov_shift_off" },
    { 0x1A7D, "canal_finale_fov_shift_on" },
    { 0x1A7E, "canal_finale_rumble" },
    { 0x1A7F, "canal_finale_rumble_sm" },
    { 0x1A80, "canal_finale_sequence" },
    { 0x1A81, "canal_finale_shock" },
    { 0x1A82, "canal_finale_will_prep" },
    { 0x1A83, "canal_guard_player_close_check" },
    { 0x1A84, "canal_handle_bomb_pickup" },
    { 0x1A85, "canal_handle_bomb_plant_button_display" },
    { 0x1A86, "canal_handle_bomb_plant_start" },
    { 0x1A87, "canal_handle_car_door_shields_vis" },
    { 0x1A88, "canal_handle_dead_demo_team" },
    { 0x1A89, "canal_handle_player_binoc_controls" },
    { 0x1A8A, "canal_highlight_dead_team" },
    { 0x1A8B, "canal_irons_open_door" },
    { 0x1A8C, "canal_jet_flyover" },
    { 0x1A8D, "canal_jet_flyover2" },
    { 0x1A8E, "canal_kamikaze_player_check" },
    { 0x1A8F, "canal_laser" },
    { 0x1A90, "canal_logic" },
    { 0x1A91, "canal_middle_weapon_guards" },
    { 0x1A92, "canal_p1" },
    { 0x1A93, "canal_p2" },
    { 0x1A94, "canal_pop_smoke" },
    { 0x1A95, "canal_razorback" },
    { 0x1A96, "canal_razorback_turret_fire" },
    { 0x1A97, "canal_razorback_turret_think" },
    { 0x1A98, "canal_setup_dead_demo_team" },
    { 0x1A99, "canal_setup_pt1" },
    { 0x1A9A, "canal_spawn_dead_demo_team" },
    { 0x1A9B, "canal_spawn_razorback" },
    { 0x1A9C, "canal_spawn_zipline_group1" },
    { 0x1A9D, "canal_spawn_zipline_group2" },
    { 0x1A9E, "canal_turn_player" },
    { 0x1A9F, "canal_turret_vehicle" },
    { 0x1AA0, "canal_turret_vehicle_passenger_think" },
    { 0x1AA1, "canal_turret_vehicle2" },
    { 0x1AA2, "canal_underwater_bullet_trails" },
    { 0x1AA3, "canal_video_board_cycle" },
    { 0x1AA4, "canal_wall_enemy_close_check" },
    { 0x1AA5, "canal_wall_enemy_think" },
    { 0x1AA6, "canal_wall_reinforcements" },
    { 0x1AA7, "canal_waterfall_last_fight" },
    { 0x1AA8, "canal_weapon_guards_spawn_and_think" },
    { 0x1AA9, "canal_weapon_platform_anim" },
    { 0x1AAA, "canal_weapon_platform_firing_loop" },
    { 0x1AAB, "canal_weapon_platform_vis_control" },
    { 0x1AAC, "canal_wmp_key_tweaks" },
    { 0x1AAD, "canals_part_2" },
    { 0x1AAE, "canbeplaced" },
    { 0x1AAF, "canblindfire" },
    { 0x1AB0, "cancalloutlocation" },
    { 0x1AB1, "cancelallbut" },
    { 0x1AB2, "cancelexitbuttonpressmonitor" },
    { 0x1AB3, "cancelkillcam" },
    { 0x1AB4, "cancelkillcamcallback" },
    { 0x1AB5, "cancelkillcamonuse" },
    { 0x1AB6, "cancelkillcamonuse_specificbutton" },
    { 0x1AB7, "cancelkillcamsafespawnbutton" },
    { 0x1AB8, "cancelkillcamsafespawncallback" },
    { 0x1AB9, "cancelkillcamusebutton" },
    { 0x1ABA, "cancelmode" },
    { 0x1ABB, "cancelnukeondeath" },
    { 0x1ABC, "cancelospbuddyexitcommand" },
    { 0x1ABD, "cancelpendingreinforcement" },
    { 0x1ABE, "cancelpossessbuttonpressmonitor" },
    { 0x1ABF, "cancelwarbirdbuddyexitcommand" },
    { 0x1AC0, "canclaim" },
    { 0x1AC1, "cancloak" },
    { 0x1AC2, "canconcat" },
    { 0x1AC3, "cancontestclaim" },
    { 0x1AC4, "candamagedestructible" },
    { 0x1AC5, "candeployjuggernaut" },
    { 0x1AC6, "candocombat" },
    { 0x1AC7, "candoflavorburst" },
    { 0x1AC8, "cangiveability" },
    { 0x1AC9, "canhitsuppressspot" },
    { 0x1ACA, "caninteractwith" },
    { 0x1ACB, "canisterdrips" },
    { 0x1ACC, "canistersteam" },
    { 0x1ACD, "canlean" },
    { 0x1ACE, "canlogclient" },
    { 0x1ACF, "canlogevent" },
    { 0x1AD0, "canlogkillstreak" },
    { 0x1AD1, "canloglife" },
    { 0x1AD2, "canmovepointtopoint" },
    { 0x1AD3, "cannon_effect" },
    { 0x1AD4, "cannotplacestring" },
    { 0x1AD5, "canopy_fade_in_cinematic" },
    { 0x1AD6, "canperformclienttraces" },
    { 0x1AD7, "canpickupobject" },
    { 0x1AD8, "canreact" },
    { 0x1AD9, "canreactagain" },
    { 0x1ADA, "canreadtext" },
    { 0x1ADB, "canreturntocover" },
    { 0x1ADC, "cansave" },
    { 0x1ADD, "cansay" },
    { 0x1ADE, "cansayname" },
    { 0x1ADF, "cansayplayername" },
    { 0x1AE0, "canseeandshootpoint" },
    { 0x1AE1, "canseeenemy" },
    { 0x1AE2, "canseeenemyfromexposed" },
    { 0x1AE3, "canseeplayer" },
    { 0x1AE4, "canseepointfromexposedatcorner" },
    { 0x1AE5, "canseepointfromexposedatnode" },
    { 0x1AE6, "cansetupstance" },
    { 0x1AE7, "canshootwhilerunning" },
    { 0x1AE8, "canshootwhilerunningbackward" },
    { 0x1AE9, "canshootwhilerunningforward" },
    { 0x1AEA, "canshowsplash" },
    { 0x1AEB, "canshufflekillstreaks" },
    { 0x1AEC, "canshufflewithkillstreakweapon" },
    { 0x1AED, "cansmash" },
    { 0x1AEE, "canstoppeeking" },
    { 0x1AEF, "cansuppressenemy" },
    { 0x1AF0, "cansuppressenemyfromexposed" },
    { 0x1AF1, "cansurvivevehicleexplosion" },
    { 0x1AF2, "cantfindanythingtodo" },
    { 0x1AF3, "canthrowgrenade" },
    { 0x1AF4, "cantraceto" },
    { 0x1AF5, "cantseeenemybehavior" },
    { 0x1AF6, "cantseeenemywait" },
    { 0x1AF7, "cantusehintthink" },
    { 0x1AF8, "canuse" },
    { 0x1AF9, "canusecallback" },
    { 0x1AFA, "canuselaser" },
    { 0x1AFB, "canuseobject" },
    { 0x1AFC, "canusesawapproach" },
    { 0x1AFD, "canusewarbird" },
    { 0x1AFE, "canyon_ally_vo" },
    { 0x1AFF, "canyon_ally_vo_dam" },
    { 0x1B00, "canyon_ally_vo2" },
    { 0x1B01, "canyon_ally_vo3" },
    { 0x1B02, "canyon_intro_vo" },
    { 0x1B03, "canyon_no_game_start_setupfunc" },
    { 0x1B04, "canyon_whizby_sound" },
    { 0x1B05, "canyon_whizby_sounds" },
    { 0x1B06, "cao_agent" },
    { 0x1B07, "cao_camera_ratio" },
    { 0x1B08, "cao_camerazoff" },
    { 0x1B09, "cao_camerazoff_zoom" },
    { 0x1B0A, "cao_camoffset_ratio" },
    { 0x1B0B, "cao_fardist" },
    { 0x1B0C, "cao_getactivecostume" },
    { 0x1B0D, "cao_getactivecostumeindex" },
    { 0x1B0E, "cao_getcostumebyindex" },
    { 0x1B0F, "cao_getglobalcostumecategory" },
    { 0x1B10, "cao_getpercostumecategory" },
    { 0x1B11, "cao_isglobalcostumecategory" },
    { 0x1B12, "cao_neardist" },
    { 0x1B13, "cao_ratio_zoom" },
    { 0x1B14, "cao_set_costumes_from_lua" },
    { 0x1B15, "cao_setactivecostume" },
    { 0x1B16, "cao_setcostumebyindex" },
    { 0x1B17, "cao_setglobalcostumecategory" },
    { 0x1B18, "cao_setpercostumecategory" },
    { 0x1B19, "cao_targetzoff" },
    { 0x1B1A, "cao_targetzoff_zoom" },
    { 0x1B1B, "cao_update" },
    { 0x1B1C, "caoavatarposoffset" },
    { 0x1B1D, "cap_bake_chamber_gdn_01" },
    { 0x1B1E, "cap_bake_chamber_gdn_02" },
    { 0x1B1F, "cap_civilian_damage_proc" },
    { 0x1B20, "cap_crash_recovery_gdn" },
    { 0x1B21, "cap_elevator_crk" },
    { 0x1B22, "cap_elevator_gdn" },
    { 0x1B23, "cap_elevator_iln" },
    { 0x1B24, "cap_ending_gdn" },
    { 0x1B25, "cap_ending_gdn_extra" },
    { 0x1B26, "cap_ending_iln" },
    { 0x1B27, "cap_gun_training_gdn" },
    { 0x1B28, "cap_incinerator_crawl_loop_01" },
    { 0x1B29, "cap_incinerator_end_01" },
    { 0x1B2A, "cap_incinerator_end_02" },
    { 0x1B2B, "cap_incinerator_end_03" },
    { 0x1B2C, "cap_incinerator_push_01" },
    { 0x1B2D, "cap_incinerator_push_02" },
    { 0x1B2E, "cap_incinerator_push_03" },
    { 0x1B2F, "cap_incinerator_start_01" },
    { 0x1B30, "cap_incinerator_start_02" },
    { 0x1B31, "cap_incinerator_start_03" },
    { 0x1B32, "cap_interrogation_crk" },
    { 0x1B33, "cap_interrogation_crk_add" },
    { 0x1B34, "cap_interrogation_irn" },
    { 0x1B35, "cap_interrogation_plr" },
    { 0x1B36, "cap_intro_drive_gdn" },
    { 0x1B37, "cap_intro_drive_iln" },
    { 0x1B38, "cap_manticore_window_gdn_01" },
    { 0x1B39, "cap_manticore_window_gdn_02" },
    { 0x1B3A, "cap_observation_gdn_01" },
    { 0x1B3B, "cap_observation_gdn_02" },
    { 0x1B3C, "cap_rescue_crk" },
    { 0x1B3D, "cap_rescue_gdn" },
    { 0x1B3E, "cap_rescue_iln" },
    { 0x1B3F, "cap_separation_iln_01" },
    { 0x1B40, "cap_test_chamber_gdn_01" },
    { 0x1B41, "cap_test_chamber_gdn_02" },
    { 0x1B42, "cap_test_chamber_gdn_03" },
    { 0x1B43, "cap_trolley_gdn" },
    { 0x1B44, "capsperminute" },
    { 0x1B45, "capsule_damage" },
    { 0x1B46, "capture_doctor_scene_start" },
    { 0x1B47, "capture_flag" },
    { 0x1B48, "capture_hack" },
    { 0x1B49, "capture_lighting" },
    { 0x1B4A, "capture_radius" },
    { 0x1B4B, "capturecount" },
    { 0x1B4C, "captured_ambient_animation_function" },
    { 0x1B4D, "captured_ambient_animation_setup" },
    { 0x1B4E, "captured_break_lock" },
    { 0x1B4F, "captured_caravan_spawner" },
    { 0x1B50, "captured_caravan_truck_remover" },
    { 0x1B51, "captured_enter_exo" },
    { 0x1B52, "captured_hint_display" },
    { 0x1B53, "captured_hint_ender_function" },
    { 0x1B54, "captured_hint_radius" },
    { 0x1B55, "captured_hint_range_check" },
    { 0x1B56, "captured_mission_failed" },
    { 0x1B57, "captured_open_door" },
    { 0x1B58, "captured_player_cuffs" },
    { 0x1B59, "captured_push_cart" },
    { 0x1B5A, "captured_take_exo" },
    { 0x1B5B, "captured_use_console" },
    { 0x1B5C, "captured_worker_weapons" },
    { 0x1B5D, "capturetime" },
    { 0x1B5E, "capturezone_reset_base_effects" },
    { 0x1B5F, "capturezoneeffects" },
    { 0x1B60, "capzones" },
    { 0x1B61, "car_alarm_horn_01" },
    { 0x1B62, "car_alarm_main" },
    { 0x1B63, "car_alarm_org" },
    { 0x1B64, "car_alarm_setup" },
    { 0x1B65, "car_alarm_sound" },
    { 0x1B66, "car_alarm_timeout" },
    { 0x1B67, "car_behavior" },
    { 0x1B68, "car_chase_crash" },
    { 0x1B69, "car_damage_owner_recorder" },
    { 0x1B6A, "car_door_broken" },
    { 0x1B6B, "car_door_ripoff_fx" },
    { 0x1B6C, "car_door_snap_player" },
    { 0x1B6D, "car_door_snap_will" },
    { 0x1B6E, "car_hit_blur" },
    { 0x1B6F, "car_hit_shadows" },
    { 0x1B70, "car_lift" },
    { 0x1B71, "car_lift_scene" },
    { 0x1B72, "car_light" },
    { 0x1B73, "car_ride_bink" },
    { 0x1B74, "car_ride_boundary_fail" },
    { 0x1B75, "car_ride_doctor_waits" },
    { 0x1B76, "car_ride_driving_workers_wait" },
    { 0x1B77, "car_ride_driving_workers_waits" },
    { 0x1B78, "car_ride_enter_cormack_waits" },
    { 0x1B79, "car_ride_enter_doctor_waits" },
    { 0x1B7A, "car_ride_gaz_waits" },
    { 0x1B7B, "car_ride_intro_fail" },
    { 0x1B7C, "car_ride_org" },
    { 0x1B7D, "car_ride_player_rig" },
    { 0x1B7E, "car_ride_rumble" },
    { 0x1B7F, "car_ride_view_clamps" },
    { 0x1B80, "carabiner_knox" },
    { 0x1B81, "caralarm" },
    { 0x1B82, "cardfx" },
    { 0x1B83, "cardoor_buttons" },
    { 0x1B84, "cardoor_hint_breakout" },
    { 0x1B85, "cardoor_old_weapon" },
    { 0x1B86, "cardoor_weapon" },
    { 0x1B87, "cardtagnames" },
    { 0x1B88, "cardtagvisible" },
    { 0x1B89, "career_stat_increment" },
    { 0x1B8A, "careful_logic" },
    { 0x1B8B, "carepackageandcarepackagevalid" },
    { 0x1B8C, "carepackageandgoliathvalid" },
    { 0x1B8D, "carepackageandplatformvalid" },
    { 0x1B8E, "carepackagecleanup" },
    { 0x1B8F, "carepackagedrone" },
    { 0x1B90, "carepackagedrone_delete" },
    { 0x1B91, "carepackagedrone_deleteonactivate" },
    { 0x1B92, "carepackagedrone_explode" },
    { 0x1B93, "carepackagedrone_leave" },
    { 0x1B94, "carepackagedrone_remove" },
    { 0x1B95, "carepackagedrone_watchdeath" },
    { 0x1B96, "carepackagedrone_watchownerloss" },
    { 0x1B97, "carepackagedrone_watchroundend" },
    { 0x1B98, "carepackagedronefindowner" },
    { 0x1B99, "carepackagedrones" },
    { 0x1B9A, "carepackagedronewatchcratedeath" },
    { 0x1B9B, "carepackagedronewatchdeath" },
    { 0x1B9C, "carepackages" },
    { 0x1B9D, "carepackagesetupminimap" },
    { 0x1B9E, "carepackagetouchvalid" },
    { 0x1B9F, "carepackagetrace" },
    { 0x1BA0, "cargo" },
    { 0x1BA1, "cargo_recover_fail" },
    { 0x1BA2, "cargo_ship_death_fx" },
    { 0x1BA3, "cargo_ship_fights_back" },
    { 0x1BA4, "cargo_ship_hit_aliases" },
    { 0x1BA5, "cargo_ship_hit_count" },
    { 0x1BA6, "cargo_ship_hit_react" },
    { 0x1BA7, "cargo_ship_missiles" },
    { 0x1BA8, "cargo_ship_rocking" },
    { 0x1BA9, "cargo_total" },
    { 0x1BAA, "carriedby" },
    { 0x1BAB, "carrieditem" },
    { 0x1BAC, "carriedobj" },
    { 0x1BAD, "carriedsentry" },
    { 0x1BAE, "carriedturret" },
    { 0x1BAF, "carrier" },
    { 0x1BB0, "carrierhascarryweaponinloadout" },
    { 0x1BB1, "carriervisible" },
    { 0x1BB2, "carrierweaponcurrent" },
    { 0x1BB3, "carry_first_done" },
    { 0x1BB4, "carryflag" },
    { 0x1BB5, "carryicon" },
    { 0x1BB6, "carryobject" },
    { 0x1BB7, "carryobject_overridemovingplatformdeath" },
    { 0x1BB8, "carryobjectproxthink" },
    { 0x1BB9, "carryobjectproxthinkdelayed" },
    { 0x1BBA, "carryobjectusethink" },
    { 0x1BBB, "carryweapon" },
    { 0x1BBC, "carryweaponthink" },
    { 0x1BBD, "cart" },
    { 0x1BBE, "cart_first_time" },
    { 0x1BBF, "cart_push" },
    { 0x1BC0, "cart_push2" },
    { 0x1BC1, "carter" },
    { 0x1BC2, "carter_cr_foley_idle" },
    { 0x1BC3, "carter_cr_foley_start" },
    { 0x1BC4, "casual_killer" },
    { 0x1BC5, "casualtytracking" },
    { 0x1BC6, "cat_array_add" },
    { 0x1BC7, "cat_array_get" },
    { 0x1BC8, "catch_damage_notify" },
    { 0x1BC9, "catch_death_notify" },
    { 0x1BCA, "catch_got_enemy" },
    { 0x1BCB, "catch_level_notify" },
    { 0x1BCC, "catch_mission_failed" },
    { 0x1BCD, "catch_weapon_switch" },
    { 0x1BCE, "categories" },
    { 0x1BCF, "categories_axis" },
    { 0x1BD0, "category_alias_name" },
    { 0x1BD1, "category_backoff_limit" },
    { 0x1BD2, "category_groups" },
    { 0x1BD3, "category_groups_axis" },
    { 0x1BD4, "category_name" },
    { 0x1BD5, "category_response_name" },
    { 0x1BD6, "cause_is_explosive" },
    { 0x1BD7, "cause_is_grenade" },
    { 0x1BD8, "cautious_approach_till_close" },
    { 0x1BD9, "cave_dialogue_cormack_attack" },
    { 0x1BDA, "cave_dialogue_cormack_contact" },
    { 0x1BDB, "cave_dialogue_cormack_drop_em" },
    { 0x1BDC, "cave_dialogue_cormack_dropping" },
    { 0x1BDD, "cave_dialogue_cormack_push" },
    { 0x1BDE, "cave_dialogue_ilona_down" },
    { 0x1BDF, "cave_dialogue_ilona_exit" },
    { 0x1BE0, "cave_dialogue_ilona_left" },
    { 0x1BE1, "cave_drill_fx" },
    { 0x1BE2, "cave_drill_pounding_fx" },
    { 0x1BE3, "cave_drill_rock_impact_fx" },
    { 0x1BE4, "cave_drills" },
    { 0x1BE5, "cave_drills_inside" },
    { 0x1BE6, "cave_drop_guys" },
    { 0x1BE7, "cave_ender_notify" },
    { 0x1BE8, "cave_entry" },
    { 0x1BE9, "cave_entry_animnode" },
    { 0x1BEA, "cave_entry_bunker_battle" },
    { 0x1BEB, "cave_entry_dialogue" },
    { 0x1BEC, "cave_entry_goliath_attack" },
    { 0x1BED, "cave_entry_goliath_behavior" },
    { 0x1BEE, "cave_entry_goliath_movement" },
    { 0x1BEF, "cave_entry_goliath_show" },
    { 0x1BF0, "cave_entry_goliath_spawn" },
    { 0x1BF1, "cave_entry_goliaths" },
    { 0x1BF2, "cave_entry_player" },
    { 0x1BF3, "cave_entry_scene" },
    { 0x1BF4, "cave_entry_sentinel" },
    { 0x1BF5, "cave_entry_slide_exploders" },
    { 0x1BF6, "cave_entry_surface_cleanup" },
    { 0x1BF7, "cave_entry_tank_missile" },
    { 0x1BF8, "cave_entry_walker_tank" },
    { 0x1BF9, "cave_falling_debris_fx" },
    { 0x1BFA, "cave_in" },
    { 0x1BFB, "cave_intro_anim_moment" },
    { 0x1BFC, "cave_npc_boost_assist" },
    { 0x1BFD, "cave_npc_boost_assist_land" },
    { 0x1BFE, "cave_shake_effects" },
    { 0x1BFF, "cave_start_teleport" },
    { 0x1C00, "cave_temperature" },
    { 0x1C01, "cave_wall_temp_show" },
    { 0x1C02, "cave_water_origin" },
    { 0x1C03, "cb_usedkillstreak" },
    { 0x1C04, "cbdr_missile_think" },
    { 0x1C05, "cc_kva_alerted_walla" },
    { 0x1C06, "cc_technical_turret_fire" },
    { 0x1C07, "ccfire" },
    { 0x1C08, "cd_living_room_blinds" },
    { 0x1C09, "cdrn_auto_unlink" },
    { 0x1C0A, "cdrn_intance_init" },
    { 0x1C0B, "cdrn_servo_oneshot_pch_func" },
    { 0x1C0C, "cdrn_wheel_speed_modifier_callback_linear" },
    { 0x1C0D, "ceiling_fan" },
    { 0x1C0E, "cell_prisoners_trig" },
    { 0x1C0F, "center" },
    { 0x1C10, "center_node" },
    { 0x1C11, "center_screen_line" },
    { 0x1C12, "center_screen_lines" },
    { 0x1C13, "center_screen_text" },
    { 0x1C14, "center_universe" },
    { 0x1C15, "centeraimpoint" },
    { 0x1C16, "centerlinethread" },
    { 0x1C17, "centerorbitalview" },
    { 0x1C18, "centerpodspawnview" },
    { 0x1C19, "cfxprintln" },
    { 0x1C1A, "cfxprintlnend" },
    { 0x1C1B, "cfxprintlnstart" },
    { 0x1C1C, "cg_car_light_shadowstate_on" },
    { 0x1C1D, "cg_car_light_shadowstate_reset" },
    { 0x1C1E, "cg_civ_conversation_gag1" },
    { 0x1C1F, "cg_gate_anim_notetrack_load_stall" },
    { 0x1C20, "cg_helipad_red_fx_lights" },
    { 0x1C21, "cg_kill_entity_on_flag" },
    { 0x1C22, "cg_kill_entity_on_transition" },
    { 0x1C23, "cg_never_delete_setup" },
    { 0x1C24, "cg_noterack_delay_count" },
    { 0x1C25, "cg_open_close_school_entrance_doors" },
    { 0x1C26, "cg_school_entrance_doors_init" },
    { 0x1C27, "cg_sentinel_fx_light" },
    { 0x1C28, "cg_setup_civ_fence_special" },
    { 0x1C29, "cg_setup_civs_baseball" },
    { 0x1C2A, "cg_setup_civs_fence" },
    { 0x1C2B, "cg_setup_civs_foodtruck" },
    { 0x1C2C, "cg_setup_civs_infosign" },
    { 0x1C2D, "cg_setup_hospital_bodies" },
    { 0x1C2E, "cg_setup_refugee_stage_audience" },
    { 0x1C2F, "cg_setup_refugee_stage_speaker" },
    { 0x1C30, "cg_setup_school_entrance_doors_startpoints" },
    { 0x1C31, "cg_setup_social_groups" },
    { 0x1C32, "cg_spawn_perf_monitor" },
    { 0x1C33, "cg_spawn_perf_monitor_setup" },
    { 0x1C34, "cg_spraypaint_gag" },
    { 0x1C35, "cg_spraypaint_runner" },
    { 0x1C36, "cg_subway_turnstyle_open" },
    { 0x1C37, "cg_swap_tank_treads_mat" },
    { 0x1C38, "cg_tff_set_up_transient_meshes" },
    { 0x1C39, "cg_tff_transition_canaloverlook_to_riverwalk" },
    { 0x1C3A, "cg_tff_transition_droneswarmone_blocker" },
    { 0x1C3B, "cg_tff_transition_droneswarmone_to_mall" },
    { 0x1C3C, "cg_tff_transition_eastview_blocker" },
    { 0x1C3D, "cg_tff_transition_eastview_to_fob" },
    { 0x1C3E, "cg_tff_transition_fob_to_droneswarmone" },
    { 0x1C3F, "cg_tff_transition_fob_to_truckpush" },
    { 0x1C40, "cg_tff_transition_mall_to_shinkhole" },
    { 0x1C41, "cg_tff_transition_shinkhole_to_subway" },
    { 0x1C42, "cg_tff_transition_shopping_to_canaloverlook" },
    { 0x1C43, "cg_tff_transition_subway_to_shoppingdistrict" },
    { 0x1C44, "cg_trigger_enter_finale_silo_neutral" },
    { 0x1C45, "cg_trigger_enter_finale_silo_yellow" },
    { 0x1C46, "cg_visibility_proxy_office_interior" },
    { 0x1C47, "ch_assists" },
    { 0x1C48, "ch_bulletdamagecommon" },
    { 0x1C49, "ch_cyl_zoff_far" },
    { 0x1C4A, "ch_cyl_zoff_near" },
    { 0x1C4B, "ch_emp_goliath_think" },
    { 0x1C4C, "ch_getprogress" },
    { 0x1C4D, "ch_getstate" },
    { 0x1C4E, "ch_gettarget" },
    { 0x1C4F, "ch_hardpoints" },
    { 0x1C50, "ch_kills" },
    { 0x1C51, "ch_roundplayed" },
    { 0x1C52, "ch_roundwin" },
    { 0x1C53, "ch_setprogress" },
    { 0x1C54, "ch_setstate" },
    { 0x1C55, "ch_streak_kill" },
    { 0x1C56, "ch_vehicle_killed" },
    { 0x1C57, "ch_vehicle_kills" },
    { 0x1C58, "chaingun" },
    { 0x1C59, "chair_actor_07" },
    { 0x1C5A, "chair_actor_08" },
    { 0x1C5B, "chair_animate" },
    { 0x1C5C, "challenge_parentchallenge" },
    { 0x1C5D, "challenge_point_award" },
    { 0x1C5E, "challenge_point_award_on_damage" },
    { 0x1C5F, "challenge_rewardval" },
    { 0x1C60, "challenge_targetval" },
    { 0x1C61, "challengedata" },
    { 0x1C62, "challengeinfo" },
    { 0x1C63, "challengescompleted" },
    { 0x1C64, "challengesplashnotify" },
    { 0x1C65, "champion" },
    { 0x1C66, "chancetospawndog" },
    { 0x1C67, "chancetospawnpickup" },
    { 0x1C68, "change_camera" },
    { 0x1C69, "change_color_node_quick" },
    { 0x1C6A, "change_color_node_quick_player_close_check" },
    { 0x1C6B, "change_debug_text_hud_color" },
    { 0x1C6C, "change_fall_tollerance" },
    { 0x1C6D, "change_fov_back_to_65" },
    { 0x1C6E, "change_lane" },
    { 0x1C6F, "change_lane_too_close" },
    { 0x1C70, "change_music_to_standoff" },
    { 0x1C71, "change_optimal_flight_distance" },
    { 0x1C72, "change_player_health_packets" },
    { 0x1C73, "change_spawn_chance_highway_path_player_side" },
    { 0x1C74, "change_spawn_dist_highway_path_player_side" },
    { 0x1C75, "change_state" },
    { 0x1C76, "change_threat_detection_style" },
    { 0x1C77, "change_to_original_models" },
    { 0x1C78, "change_to_run_after_time" },
    { 0x1C79, "change_to_run_now" },
    { 0x1C7A, "change_to_tactics_models" },
    { 0x1C7B, "change_weapons" },
    { 0x1C7C, "change_weapons_listener" },
    { 0x1C7D, "changeaiming" },
    { 0x1C7E, "changecrateweight" },
    { 0x1C7F, "changed_team" },
    { 0x1C80, "changelightcolorto" },
    { 0x1C81, "changelightcolortoworkerthread" },
    { 0x1C82, "changestanceforfuntime" },
    { 0x1C83, "changestepoutpos" },
    { 0x1C84, "changethreatstyle" },
    { 0x1C85, "changeweapons" },
    { 0x1C86, "changingcoverpos" },
    { 0x1C87, "changingweapon" },
    { 0x1C88, "char_dialog_add_and_go" },
    { 0x1C89, "character_hat_index" },
    { 0x1C8A, "character_head_index" },
    { 0x1C8B, "character_index_cache" },
    { 0x1C8C, "characterid_count" },
    { 0x1C8D, "characterid_is_talking_currently" },
    { 0x1C8E, "characters" },
    { 0x1C8F, "charge" },
    { 0x1C90, "charge_blink" },
    { 0x1C91, "charge_indicator_hud" },
    { 0x1C92, "chargebattery" },
    { 0x1C93, "charged_shot_reticle" },
    { 0x1C94, "charged_shot_reticle_corners" },
    { 0x1C95, "charged_shot_rumble_ent" },
    { 0x1C96, "charged_shot_soundent" },
    { 0x1C97, "chase_cam_ent" },
    { 0x1C98, "chase_cam_last_num" },
    { 0x1C99, "chase_cam_target" },
    { 0x1C9A, "chase_cleanup_after_player_crash" },
    { 0x1C9B, "chase_heli_fire" },
    { 0x1C9C, "chase_timer_cancel" },
    { 0x1C9D, "chase_timer_countdown" },
    { 0x1C9E, "chase_van" },
    { 0x1C9F, "chase_van_rabbiting_anim" },
    { 0x1CA0, "chase_van_set_close" },
    { 0x1CA1, "chase_van_set_far" },
    { 0x1CA2, "chase_van_set_medium" },
    { 0x1CA3, "chasecam" },
    { 0x1CA4, "chasecam_onent" },
    { 0x1CA5, "chatinitialized" },
    { 0x1CA6, "chatqueue" },
    { 0x1CA7, "chatterdisabled" },
    { 0x1CA8, "cheap_flashlight_hide" },
    { 0x1CA9, "cheap_flashlight_init" },
    { 0x1CAA, "cheap_flashlight_setup" },
    { 0x1CAB, "cheap_flashlight_show" },
    { 0x1CAC, "cheap_vehicles_have_shields" },
    { 0x1CAD, "cheapmagicbullet" },
    { 0x1CAE, "cheatammoifnecessary" },
    { 0x1CAF, "check_allies_in_volume" },
    { 0x1CB0, "check_animation" },
    { 0x1CB1, "check_campaign_completion" },
    { 0x1CB2, "check_class_time" },
    { 0x1CB3, "check_clearroof_early" },
    { 0x1CB4, "check_createfx_limit" },
    { 0x1CB5, "check_death_flag" },
    { 0x1CB6, "check_delete" },
    { 0x1CB7, "check_drone_callback" },
    { 0x1CB8, "check_enemies_for_alert" },
    { 0x1CB9, "check_exploder_platform" },
    { 0x1CBA, "check_failed_spawn_groups" },
    { 0x1CBB, "check_fire_and_forget" },
    { 0x1CBC, "check_flag_for_stat_tracking" },
    { 0x1CBD, "check_flight_distances" },
    { 0x1CBE, "check_for_door" },
    { 0x1CBF, "check_for_npc_weapon_cloak_status_update" },
    { 0x1CC0, "check_force_color" },
    { 0x1CC1, "check_grenade" },
    { 0x1CC2, "check_grenade_dmg" },
    { 0x1CC3, "check_group_at_goal" },
    { 0x1CC4, "check_group_facing_forward" },
    { 0x1CC5, "check_health" },
    { 0x1CC6, "check_hint_condition" },
    { 0x1CC7, "check_if_enemies_marked" },
    { 0x1CC8, "check_if_hurt" },
    { 0x1CC9, "check_if_intersecting_any_script_car" },
    { 0x1CCA, "check_if_multiple_ents_inside" },
    { 0x1CCB, "check_intel_achievements" },
    { 0x1CCC, "check_is_climbing" },
    { 0x1CCD, "check_item_found" },
    { 0x1CCE, "check_kill_damage" },
    { 0x1CCF, "check_kill_traversal" },
    { 0x1CD0, "check_lab_achievement" },
    { 0x1CD1, "check_limit_type" },
    { 0x1CD2, "check_look_both_ways_achievement" },
    { 0x1CD3, "check_los" },
    { 0x1CD4, "check_man_overboard" },
    { 0x1CD5, "check_melee_interaction_active" },
    { 0x1CD6, "check_missile_ammo" },
    { 0x1CD7, "check_missing_animation" },
    { 0x1CD8, "check_move_me_to_maintain_ratio" },
    { 0x1CD9, "check_on_target_process" },
    { 0x1CDA, "check_other_haslevelveteranachievement" },
    { 0x1CDB, "check_player_bunker_position" },
    { 0x1CDC, "check_player_deck_position_1" },
    { 0x1CDD, "check_player_deck_position_2" },
    { 0x1CDE, "check_player_gender" },
    { 0x1CDF, "check_player_in_sniper_zone" },
    { 0x1CE0, "check_player_in_stop_enemy_callout_vo_volume" },
    { 0x1CE1, "check_player_pickedup_sniper" },
    { 0x1CE2, "check_potential_falling_death" },
    { 0x1CE3, "check_restricted_airspace_achievement" },
    { 0x1CE4, "check_script_char_group_ratio" },
    { 0x1CE5, "check_seoul_achievements" },
    { 0x1CE6, "check_sound_tag_dupe" },
    { 0x1CE7, "check_sound_tag_dupe_reset" },
    { 0x1CE8, "check_spawn_group_isspawner" },
    { 0x1CE9, "check_time" },
    { 0x1CEA, "check_to_activate" },
    { 0x1CEB, "check_trigger_flagset" },
    { 0x1CEC, "check_unloadgroup" },
    { 0x1CED, "check_vo_type" },
    { 0x1CEE, "check_wait_on_cg_notetracks" },
    { 0x1CEF, "check_zkey_press" },
    { 0x1CF0, "checkadvanceonenemyconditions" },
    { 0x1CF1, "checkallowspectating" },
    { 0x1CF2, "checkapproachconditions" },
    { 0x1CF3, "checkapproachpreconditions" },
    { 0x1CF4, "checkarrivalenterpositions" },
    { 0x1CF5, "checkbuddyspawn" },
    { 0x1CF6, "checkcamposition" },
    { 0x1CF7, "checkchanged" },
    { 0x1CF8, "checkcombatstate" },
    { 0x1CF9, "checkcoverenterpos" },
    { 0x1CFA, "checkdynamicspawns" },
    { 0x1CFB, "checked" },
    { 0x1CFC, "checkendcombat" },
    { 0x1CFD, "checkexpiretime" },
    { 0x1CFE, "checkforbestweapon" },
    { 0x1CFF, "checkforcebleedout" },
    { 0x1D00, "checkforceragdoll" },
    { 0x1D01, "checkforcrashing" },
    { 0x1D02, "checkforexplosivegoal" },
    { 0x1D03, "checkforexplosivegoalexplosive" },
    { 0x1D04, "checkforpersonalbests" },
    { 0x1D05, "checkforreinforcements" },
    { 0x1D06, "checkforunpause" },
    { 0x1D07, "checkgameendchallenges" },
    { 0x1D08, "checkgamemodemastery" },
    { 0x1D09, "checkgrenadethrowdist" },
    { 0x1D0A, "checkhalftime" },
    { 0x1D0B, "checkhalftimescore" },
    { 0x1D0C, "checkhigherrankkillevents" },
    { 0x1D0D, "checkhighjumpevents" },
    { 0x1D0E, "checkhit" },
    { 0x1D0F, "checkhitsthismag" },
    { 0x1D10, "checking_for_flag" },
    { 0x1D11, "checkkeyobject" },
    { 0x1D12, "checknodeexitpos" },
    { 0x1D13, "checknodestart" },
    { 0x1D14, "checkorbitallaserusage" },
    { 0x1D15, "checkpitchvisibility" },
    { 0x1D16, "checkplayerscorelimitsoon" },
    { 0x1D17, "checkpracticeroundlockout" },
    { 0x1D18, "checkroundswitch" },
    { 0x1D19, "checkroundwin" },
    { 0x1D1A, "checkscorelimit" },
    { 0x1D1B, "checkstreakingevents" },
    { 0x1D1C, "checkstreakreward" },
    { 0x1D1D, "checktargetisinfrontofplayer" },
    { 0x1D1E, "checktargetisinvision" },
    { 0x1D1F, "checkteamscorelimitsoon" },
    { 0x1D20, "checktimelimit" },
    { 0x1D21, "checktoturnoffemp" },
    { 0x1D22, "checktransitionconditions" },
    { 0x1D23, "checktransitionpreconditions" },
    { 0x1D24, "checkvandalismmedal" },
    { 0x1D25, "checkvehicleturretuserstatus" },
    { 0x1D26, "checkwarbirdtargetlos" },
    { 0x1D27, "checkweapchange" },
    { 0x1D28, "checkweaponspecifickill" },
    { 0x1D29, "chemdamagethink" },
    { 0x1D2A, "chemical_rack" },
    { 0x1D2B, "chemical_rackgotosarray" },
    { 0x1D2C, "chemical_rackpausetime" },
    { 0x1D2D, "chemical_racksactive" },
    { 0x1D2E, "cherry_picker" },
    { 0x1D2F, "cherry_picker_damage_alarm" },
    { 0x1D30, "cherry_picker_hud" },
    { 0x1D31, "cherry_picker_hud_bar" },
    { 0x1D32, "cherry_picker_hud_drone" },
    { 0x1D33, "cherry_picker_hud_drone2" },
    { 0x1D34, "cherry_picker_hud_emp" },
    { 0x1D35, "cherry_picker_target_add" },
    { 0x1D36, "cherry_picker_target_remove" },
    { 0x1D37, "cherry_picker_turret_gameplay" },
    { 0x1D38, "cherry_turret" },
    { 0x1D39, "cherry_turret_hud" },
    { 0x1D3A, "chevron" },
    { 0x1D3B, "chevron_right" },
    { 0x1D3C, "childchecktime" },
    { 0x1D3D, "children" },
    { 0x1D3E, "choose_crash_path" },
    { 0x1D3F, "choose_from_weighted_array" },
    { 0x1D40, "choose_vol" },
    { 0x1D41, "chooseanimfromset" },
    { 0x1D42, "chooseattackidle" },
    { 0x1D43, "choosefirstinfected" },
    { 0x1D44, "chooseidlepointreactanimation" },
    { 0x1D45, "choosepose" },
    { 0x1D46, "chooseposefunc" },
    { 0x1D47, "choosesmashnode" },
    { 0x1D48, "chopper" },
    { 0x1D49, "chopper_01_away_by" },
    { 0x1D4A, "chopper_01_by_in" },
    { 0x1D4B, "chopper_01_close_lp" },
    { 0x1D4C, "chopper_01_dist_lp" },
    { 0x1D4D, "chopper_01_wind_up" },
    { 0x1D4E, "chopper_02_away_by" },
    { 0x1D4F, "chopper_02_by_in" },
    { 0x1D50, "chopper_02_close_lp" },
    { 0x1D51, "chopper_02_dist_lp" },
    { 0x1D52, "chopper_02_wind_up" },
    { 0x1D53, "chopper_air_support_activate" },
    { 0x1D54, "chopper_final_explo" },
    { 0x1D55, "chopper_fx" },
    { 0x1D56, "chopper_pilot_death_anim" },
    { 0x1D57, "chopper_shoot_down" },
    { 0x1D58, "chopper_shoot_down_internal" },
    { 0x1D59, "chopper_shoot_straight" },
    { 0x1D5A, "chopper_sniper_shot" },
    { 0x1D5B, "chopper_turret_off" },
    { 0x1D5C, "chopper_turret_on" },
    { 0x1D5D, "chopperattackarrow" },
    { 0x1D5E, "choppersniped" },
    { 0x1D5F, "chopperturretfunc" },
    { 0x1D60, "chopperturretofffunc" },
    { 0x1D61, "chopperturretonfunc" },
    { 0x1D62, "chosen" },
    { 0x1D63, "chosentemplates" },
    { 0x1D64, "chromo_anim2" },
    { 0x1D65, "chromo_offset" },
    { 0x1D66, "chyron" },
    { 0x1D67, "chyron_sound" },
    { 0x1D68, "cig_hide" },
    { 0x1D69, "cig_show" },
    { 0x1D6A, "cig_throwing" },
    { 0x1D6B, "cigar" },
    { 0x1D6C, "cigarette_light" },
    { 0x1D6D, "cine_fire_debris_stumble" },
    { 0x1D6E, "cine_holelight" },
    { 0x1D6F, "cine_left_light" },
    { 0x1D70, "cine_sub_fire_rim" },
    { 0x1D71, "cine_sub_fog" },
    { 0x1D72, "cine_sub_right_irons" },
    { 0x1D73, "cine_sub_will_all_mulitlight" },
    { 0x1D74, "cinematic_rocket_guys" },
    { 0x1D75, "circling" },
    { 0x1D76, "circuit_breaker" },
    { 0x1D77, "city_ambient_fx" },
    { 0x1D78, "civ_ah" },
    { 0x1D79, "civ_armshots" },
    { 0x1D7A, "civ_boat_spawn" },
    { 0x1D7B, "civ_chestshots" },
    { 0x1D7C, "civ_conversation_gag1" },
    { 0x1D7D, "civ_damage_check" },
    { 0x1D7E, "civ_domestic_truck_spawn" },
    { 0x1D7F, "civ_gate_node" },
    { 0x1D80, "civ_headshots" },
    { 0x1D81, "civ_kills" },
    { 0x1D82, "civ_legshots" },
    { 0x1D83, "civ_panic_door_run_in" },
    { 0x1D84, "civ_run_nodes" },
    { 0x1D85, "civ_victims" },
    { 0x1D86, "civ1" },
    { 0x1D87, "civ2" },
    { 0x1D88, "civ3" },
    { 0x1D89, "civ4" },
    { 0x1D8A, "civ5" },
    { 0x1D8B, "civ6" },
    { 0x1D8C, "civ7" },
    { 0x1D8D, "civ8" },
    { 0x1D8E, "civilain_flee_to_goal" },
    { 0x1D8F, "civilian_actor_ai_player_reaction" },
    { 0x1D90, "civilian_actor_behavior_manager" },
    { 0x1D91, "civilian_actor_drone_player_reaction" },
    { 0x1D92, "civilian_actor_play_idle" },
    { 0x1D93, "civilian_actor_play_reaction" },
    { 0x1D94, "civilian_african_male_b" },
    { 0x1D95, "civilian_african_male_c" },
    { 0x1D96, "civilian_african_male_d" },
    { 0x1D97, "civilian_alert_behavior" },
    { 0x1D98, "civilian_alert_behavior_hangar" },
    { 0x1D99, "civilian_alert_sound" },
    { 0x1D9A, "civilian_alert_sound_setup" },
    { 0x1D9B, "civilian_alert_watcher" },
    { 0x1D9C, "civilian_anim_setup" },
    { 0x1D9D, "civilian_anims" },
    { 0x1D9E, "civilian_attach_props" },
    { 0x1D9F, "civilian_below" },
    { 0x1DA0, "civilian_body_and_head_setup" },
    { 0x1DA1, "civilian_check_if_player_blocking" },
    { 0x1DA2, "civilian_clean_up" },
    { 0x1DA3, "civilian_cleanup" },
    { 0x1DA4, "civilian_combathunchedmoveturn" },
    { 0x1DA5, "civilian_combatmoveturn" },
    { 0x1DA6, "civilian_compact_car_constructor" },
    { 0x1DA7, "civilian_compact_car_init" },
    { 0x1DA8, "civilian_detach_props" },
    { 0x1DA9, "civilian_driveway_scene" },
    { 0x1DAA, "civilian_drone_repair_think" },
    { 0x1DAB, "civilian_drone_run_override" },
    { 0x1DAC, "civilian_drone_runner_collision" },
    { 0x1DAD, "civilian_drone_runners_think" },
    { 0x1DAE, "civilian_drone_scan_anim_struct" },
    { 0x1DAF, "civilian_drone_scan_female" },
    { 0x1DB0, "civilian_drone_scan_male" },
    { 0x1DB1, "civilian_drone_scan_scene" },
    { 0x1DB2, "civilian_drone_scan_vo" },
    { 0x1DB3, "civilian_drone_setup" },
    { 0x1DB4, "civilian_drone_stationary_think" },
    { 0x1DB5, "civilian_garage" },
    { 0x1DB6, "civilian_garage_1" },
    { 0x1DB7, "civilian_garage_2" },
    { 0x1DB8, "civilian_garage_spawner_setup" },
    { 0x1DB9, "civilian_garage_vo" },
    { 0x1DBA, "civilian_get_out_of_car_setup" },
    { 0x1DBB, "civilian_get_random_idle" },
    { 0x1DBC, "civilian_get_random_reaction" },
    { 0x1DBD, "civilian_get_random_run" },
    { 0x1DBE, "civilian_get_random_walk" },
    { 0x1DBF, "civilian_group" },
    { 0x1DC0, "civilian_guesthouse" },
    { 0x1DC1, "civilian_guesthouse_1" },
    { 0x1DC2, "civilian_guesthouse_2" },
    { 0x1DC3, "civilian_guesthouse_3" },
    { 0x1DC4, "civilian_guesthouse_spawner_setup" },
    { 0x1DC5, "civilian_guesthouse_vo" },
    { 0x1DC6, "civilian_guesthouse_walkin" },
    { 0x1DC7, "civilian_guesthouse_walkin_spawner_setup" },
    { 0x1DC8, "civilian_guesthouse_walkin_vo" },
    { 0x1DC9, "civilian_head_and_body_setup" },
    { 0x1DCA, "civilian_head_and_body_swap" },
    { 0x1DCB, "civilian_in_car_count" },
    { 0x1DCC, "civilian_in_car_get_out" },
    { 0x1DCD, "civilian_in_running_car" },
    { 0x1DCE, "civilian_in_running_car_setup" },
    { 0x1DCF, "civilian_init" },
    { 0x1DD0, "civilian_init_props" },
    { 0x1DD1, "civilian_jet_flyby" },
    { 0x1DD2, "civilian_killed" },
    { 0x1DD3, "civilian_left" },
    { 0x1DD4, "civilian_loop_setup" },
    { 0x1DD5, "civilian_loop_vo_trigger" },
    { 0x1DD6, "civilian_lost" },
    { 0x1DD7, "civilian_lost_guard" },
    { 0x1DD8, "civilian_lost_guard_setup" },
    { 0x1DD9, "civilian_lost_setup" },
    { 0x1DDA, "civilian_noncombatmoveturn" },
    { 0x1DDB, "civilian_panic_distance_check" },
    { 0x1DDC, "civilian_pool_1" },
    { 0x1DDD, "civilian_pool_2" },
    { 0x1DDE, "civilian_pool_3" },
    { 0x1DDF, "civilian_pool_spawner_setup" },
    { 0x1DE0, "civilian_pool_vo" },
    { 0x1DE1, "civilian_poolhouse_1" },
    { 0x1DE2, "civilian_poolhouse_2" },
    { 0x1DE3, "civilian_poolhouse_3" },
    { 0x1DE4, "civilian_poolhouse_vo" },
    { 0x1DE5, "civilian_right" },
    { 0x1DE6, "civilian_right_side" },
    { 0x1DE7, "civilian_right_side_1" },
    { 0x1DE8, "civilian_right_side_2" },
    { 0x1DE9, "civilian_right_side_3" },
    { 0x1DEA, "civilian_right_side_setup" },
    { 0x1DEB, "civilian_right_side_vo" },
    { 0x1DEC, "civilian_roundabout_vo_1" },
    { 0x1DED, "civilian_roundabout_vo_2" },
    { 0x1DEE, "civilian_roundabout_vo_3" },
    { 0x1DEF, "civilian_setup" },
    { 0x1DF0, "civilian_setup_esc_nodes" },
    { 0x1DF1, "civilian_setupanimations" },
    { 0x1DF2, "civilian_sonic_aoe_thread" },
    { 0x1DF3, "civilian_spawn_single" },
    { 0x1DF4, "civilian_stealth_detect" },
    { 0x1DF5, "civilian_urban_female_a" },
    { 0x1DF6, "civilian_urban_female_b" },
    { 0x1DF7, "civilian_urban_female_c" },
    { 0x1DF8, "civilian_urban_male_b" },
    { 0x1DF9, "civilian_urban_male_c" },
    { 0x1DFA, "civilian_urban_male_d" },
    { 0x1DFB, "civilian_urban_male_e" },
    { 0x1DFC, "civilian_wait_for_reaction" },
    { 0x1DFD, "civilian_walk_animation" },
    { 0x1DFE, "civilian_walker_behavior_manager" },
    { 0x1DFF, "civilian_walker_idle_when_blocked" },
    { 0x1E00, "civilian_walker_phone" },
    { 0x1E01, "civilian_walker_phone_spawner_setup" },
    { 0x1E02, "civilian_walker_play_reaction" },
    { 0x1E03, "civilian_walker_play_walk" },
    { 0x1E04, "civilian_walker_setup" },
    { 0x1E05, "civilian_walker_setup_esc_nodes" },
    { 0x1E06, "civilian_walker_update_current_goal_and_animate_to" },
    { 0x1E07, "civilian_walker_wait_for_walk_signal" },
    { 0x1E08, "civilian_warning_given" },
    { 0x1E09, "civilian_warning_vo" },
    { 0x1E0A, "civilian_watch_player_when_close" },
    { 0x1E0B, "civilian1" },
    { 0x1E0C, "civilian2" },
    { 0x1E0D, "civiliananims" },
    { 0x1E0E, "civilianendinganimations" },
    { 0x1E0F, "civilianflashedarray" },
    { 0x1E10, "civilianjetflyby" },
    { 0x1E11, "civilianjetflyby_timer" },
    { 0x1E12, "civilianmarketanimations" },
    { 0x1E13, "civilianprops" },
    { 0x1E14, "civilians" },
    { 0x1E15, "civilians_below" },
    { 0x1E16, "civilians_flank_alley_react" },
    { 0x1E17, "civilians_left" },
    { 0x1E18, "civilians_right" },
    { 0x1E19, "civkillwhennearplayer" },
    { 0x1E1A, "civscrambleanimations" },
    { 0x1E1B, "civsniperdamagemonitor" },
    { 0x1E1C, "claim_a_node" },
    { 0x1E1D, "claimed" },
    { 0x1E1E, "claimed_drone" },
    { 0x1E1F, "claimed_node" },
    { 0x1E20, "claimed_walker_turret_target" },
    { 0x1E21, "claimplayer" },
    { 0x1E22, "claimteam" },
    { 0x1E23, "claimtrigger" },
    { 0x1E24, "clampedhealth" },
    { 0x1E25, "clamplookangle" },
    { 0x1E26, "clamppositiontolowerbounds" },
    { 0x1E27, "clampreleasefx" },
    { 0x1E28, "clamptobyte" },
    { 0x1E29, "clamptoshort" },
    { 0x1E2A, "clampweaponweightvalue" },
    { 0x1E2B, "clampyaworbitoffset" },
    { 0x1E2C, "clan_profile_update" },
    { 0x1E2D, "clanmemberownerids" },
    { 0x1E2E, "class" },
    { 0x1E2F, "class_num" },
    { 0x1E30, "class_override" },
    { 0x1E31, "classabilityready" },
    { 0x1E32, "classabilitytime" },
    { 0x1E33, "classcallback" },
    { 0x1E34, "classdmgmod" },
    { 0x1E35, "classgrenades" },
    { 0x1E36, "classmap" },
    { 0x1E37, "classmaxhealth" },
    { 0x1E38, "classold" },
    { 0x1E39, "classpickcount" },
    { 0x1E3A, "classsettings" },
    { 0x1E3B, "classswitchwait" },
    { 0x1E3C, "classswitchwaiting" },
    { 0x1E3D, "classtablename" },
    { 0x1E3E, "classtablenum" },
    { 0x1E3F, "classtime" },
    { 0x1E40, "classtweaks" },
    { 0x1E41, "classweaponswait" },
    { 0x1E42, "claymore_pickup_think_global" },
    { 0x1E43, "claymorearray" },
    { 0x1E44, "claymoredetectiondot" },
    { 0x1E45, "claymoredetectiongraceperiod" },
    { 0x1E46, "claymoredetectionmindist" },
    { 0x1E47, "claymoredetonateradius" },
    { 0x1E48, "claymoredetonation" },
    { 0x1E49, "claymoremakesentient" },
    { 0x1E4A, "claymores" },
    { 0x1E4B, "claymoresentientfunc" },
    { 0x1E4C, "clean_kill_vo" },
    { 0x1E4D, "clean_kill_vo_setup" },
    { 0x1E4E, "clean_up_ai" },
    { 0x1E4F, "clean_up_ai_single" },
    { 0x1E50, "clean_up_car" },
    { 0x1E51, "clean_up_hud_entity" },
    { 0x1E52, "clean_up_intro_pilots" },
    { 0x1E53, "clean_up_on_parent_death" },
    { 0x1E54, "clean_up_shadow_tag" },
    { 0x1E55, "clean_up_suv_drivers" },
    { 0x1E56, "clean_up_target_pos_ent" },
    { 0x1E57, "clean_up_traffic_drivers" },
    { 0x1E58, "clean_up_vehicle" },
    { 0x1E59, "clean_up_vehicle_free_path" },
    { 0x1E5A, "clean_up_vehicle_seoul" },
    { 0x1E5B, "clean_up_vehicle_type" },
    { 0x1E5C, "clean_up_vehicles_all" },
    { 0x1E5D, "cleanarray" },
    { 0x1E5E, "cleanout_unneeded_ents_for_createfx" },
    { 0x1E5F, "cleanup" },
    { 0x1E60, "cleanup_ai_logging_road" },
    { 0x1E61, "cleanup_ai_on_trigger" },
    { 0x1E62, "cleanup_ai_think" },
    { 0x1E63, "cleanup_ai_with_script_noteworthy" },
    { 0x1E64, "cleanup_atlas_on_death" },
    { 0x1E65, "cleanup_bobbing" },
    { 0x1E66, "cleanup_courtyard_enemies" },
    { 0x1E67, "cleanup_drone_tags" },
    { 0x1E68, "cleanup_enemies" },
    { 0x1E69, "cleanup_enemy_ai_seoul" },
    { 0x1E6A, "cleanup_ents" },
    { 0x1E6B, "cleanup_ents_removing_bullet_shield" },
    { 0x1E6C, "cleanup_explosion_ents" },
    { 0x1E6D, "cleanup_extra_ai" },
    { 0x1E6E, "cleanup_foam_corridor_enemies" },
    { 0x1E6F, "cleanup_fob_guys" },
    { 0x1E70, "cleanup_hovertank_combat" },
    { 0x1E71, "cleanup_in_aisle3" },
    { 0x1E72, "cleanup_land_assist" },
    { 0x1E73, "cleanup_mech_traversal_elements" },
    { 0x1E74, "cleanup_microwave_on_exit" },
    { 0x1E75, "cleanup_missile" },
    { 0x1E76, "cleanup_on_death" },
    { 0x1E77, "cleanup_on_flag" },
    { 0x1E78, "cleanup_on_goal" },
    { 0x1E79, "cleanup_oncoming_suv" },
    { 0x1E7A, "cleanup_overlay" },
    { 0x1E7B, "cleanup_primer" },
    { 0x1E7C, "cleanup_primer_reload" },
    { 0x1E7D, "cleanup_road_flares" },
    { 0x1E7E, "cleanup_school_cars" },
    { 0x1E7F, "cleanup_snake" },
    { 0x1E80, "cleanup_snake_cloud" },
    { 0x1E81, "cleanup_snake_cloud_on_flag" },
    { 0x1E82, "cleanup_snipers_zone" },
    { 0x1E83, "cleanup_specific_spawns" },
    { 0x1E84, "cleanup_squad_drone" },
    { 0x1E85, "cleanup_sticky" },
    { 0x1E86, "cleanup_sticky_on_death" },
    { 0x1E87, "cleanup_tower_enemies" },
    { 0x1E88, "cleanup_vista" },
    { 0x1E89, "cleanupbuddyspawn" },
    { 0x1E8A, "cleanupcarepackage" },
    { 0x1E8B, "cleanuplasertargetingdevice" },
    { 0x1E8C, "cleanupnodefields" },
    { 0x1E8D, "cleanupondeath" },
    { 0x1E8E, "cleanupospents" },
    { 0x1E8F, "cleanuprockettargeticon" },
    { 0x1E90, "cleanupvars" },
    { 0x1E91, "cleanupweaponsonground" },
    { 0x1E92, "clear_additive_helmet_anim" },
    { 0x1E93, "clear_ai_detection_on_death" },
    { 0x1E94, "clear_alerted_info" },
    { 0x1E95, "clear_all_color_orders" },
    { 0x1E96, "clear_all_loopers" },
    { 0x1E97, "clear_anim_on_death" },
    { 0x1E98, "clear_animation" },
    { 0x1E99, "clear_anims" },
    { 0x1E9A, "clear_anims_on_death" },
    { 0x1E9B, "clear_archetype" },
    { 0x1E9C, "clear_blast_walk_anims" },
    { 0x1E9D, "clear_bot_camping_on_bot_death" },
    { 0x1E9E, "clear_bot_camping_on_reset" },
    { 0x1E9F, "clear_bot_on_bot_death" },
    { 0x1EA0, "clear_bot_on_reset" },
    { 0x1EA1, "clear_breaching_variable" },
    { 0x1EA2, "clear_bulletshield_on_alert" },
    { 0x1EA3, "clear_camper_data" },
    { 0x1EA4, "clear_cars_around_pos" },
    { 0x1EA5, "clear_color_order" },
    { 0x1EA6, "clear_color_order_from_team" },
    { 0x1EA7, "clear_colors" },
    { 0x1EA8, "clear_custom_animset" },
    { 0x1EA9, "clear_custom_gameskill_func" },
    { 0x1EAA, "clear_custom_patrol_anim_set" },
    { 0x1EAB, "clear_deathanim" },
    { 0x1EAC, "clear_defend" },
    { 0x1EAD, "clear_defend_or_goal_if_necessary" },
    { 0x1EAE, "clear_doctor_head" },
    { 0x1EAF, "clear_dodge_positions" },
    { 0x1EB0, "clear_door_effect" },
    { 0x1EB1, "clear_drone_cloud" },
    { 0x1EB2, "clear_dvar" },
    { 0x1EB3, "clear_enemy_outline_on_death" },
    { 0x1EB4, "clear_enemy_passthrough" },
    { 0x1EB5, "clear_entity_selection" },
    { 0x1EB6, "clear_event_on_prob" },
    { 0x1EB7, "clear_exception" },
    { 0x1EB8, "clear_force_color" },
    { 0x1EB9, "clear_fx_hudelements" },
    { 0x1EBA, "clear_generic_idle_anim" },
    { 0x1EBB, "clear_generic_run_anim" },
    { 0x1EBC, "clear_guy_fx" },
    { 0x1EBD, "clear_hint_button" },
    { 0x1EBE, "clear_hints" },
    { 0x1EBF, "clear_hud_on_notify" },
    { 0x1EC0, "clear_ignore_all_on_group" },
    { 0x1EC1, "clear_land_assist" },
    { 0x1EC2, "clear_light_set_for_player" },
    { 0x1EC3, "clear_max_momentum_delayed" },
    { 0x1EC4, "clear_maxed_momentum" },
    { 0x1EC5, "clear_momentum" },
    { 0x1EC6, "clear_npc_anim" },
    { 0x1EC7, "clear_npc_anims" },
    { 0x1EC8, "clear_on_action_success" },
    { 0x1EC9, "clear_overdrive_battery" },
    { 0x1ECA, "clear_path_weights" },
    { 0x1ECB, "clear_player_anim" },
    { 0x1ECC, "clear_player_attacked_by_dog_on_death" },
    { 0x1ECD, "clear_pluggable_move_loop_override" },
    { 0x1ECE, "clear_president_anims" },
    { 0x1ECF, "clear_promotion_order" },
    { 0x1ED0, "clear_refugee_camp_walk_anims" },
    { 0x1ED1, "clear_run_anim" },
    { 0x1ED2, "clear_script_goal_on" },
    { 0x1ED3, "clear_script_goal_on_gas_end" },
    { 0x1ED4, "clear_script_model_anim" },
    { 0x1ED5, "clear_set_goal" },
    { 0x1ED6, "clear_settable_fx" },
    { 0x1ED7, "clear_stencil_on_death" },
    { 0x1ED8, "clear_talking_currently_when_done" },
    { 0x1ED9, "clear_target_zone_update" },
    { 0x1EDA, "clear_team_colors" },
    { 0x1EDB, "clear_tool_hud" },
    { 0x1EDC, "clear_unresolved_collision_count_next_frame" },
    { 0x1EDD, "clear_urgent_walk_anims" },
    { 0x1EDE, "clear_vehicle_anim" },
    { 0x1EDF, "clearafterfade" },
    { 0x1EE0, "clearalertoutline" },
    { 0x1EE1, "clearalertstencilstate" },
    { 0x1EE2, "clearall" },
    { 0x1EE3, "clearammo" },
    { 0x1EE4, "clearbattlebuddy" },
    { 0x1EE5, "clearbuddymessage" },
    { 0x1EE6, "clearcarrier" },
    { 0x1EE7, "clearcopycatloadout" },
    { 0x1EE8, "cleardodgeanims" },
    { 0x1EE9, "cleared" },
    { 0x1EEA, "clearempondeath" },
    { 0x1EEB, "clearfaceanimonanimdone" },
    { 0x1EEC, "clearfirefightdata" },
    { 0x1EED, "clearfirefightshotsoninterval" },
    { 0x1EEE, "clearfxondeath" },
    { 0x1EEF, "clearhudtimer" },
    { 0x1EF0, "clearidshortly" },
    { 0x1EF1, "clearisspeaking" },
    { 0x1EF2, "clearkillcamstate" },
    { 0x1EF3, "clearkillstreaks" },
    { 0x1EF4, "clearlookatthread" },
    { 0x1EF5, "clearlowermessage" },
    { 0x1EF6, "clearlowermessages" },
    { 0x1EF7, "clearmovementparameters" },
    { 0x1EF8, "clearondeath" },
    { 0x1EF9, "clearonvictimdisconnect" },
    { 0x1EFA, "clearplayertargetlist" },
    { 0x1EFB, "clearpracticeroundlockoutdata" },
    { 0x1EFC, "clearprevioustispawnpoint" },
    { 0x1EFD, "clearprogress" },
    { 0x1EFE, "clearragdolldeath" },
    { 0x1EFF, "clearrideintro" },
    { 0x1F00, "clearrideintroonteamchange" },
    { 0x1F01, "clearsightposnear" },
    { 0x1F02, "clearspawnpointdistancedata" },
    { 0x1F03, "clearspawnpointsightdata" },
    { 0x1F04, "clearstencil" },
    { 0x1F05, "clearstencilstate" },
    { 0x1F06, "clearstencilstateondeath" },
    { 0x1F07, "clearsurvivaltime" },
    { 0x1F08, "clearteamspawnpointdistancedata" },
    { 0x1F09, "clearteamspawnpointsightdata" },
    { 0x1F0A, "cleartextmarker" },
    { 0x1F0B, "clearthreatbias" },
    { 0x1F0C, "clearunderwateraudiozone" },
    { 0x1F0D, "clearusingremote" },
    { 0x1F0E, "clearwatervarsonspawn" },
    { 0x1F0F, "clientid" },
    { 0x1F10, "clientmatchdataid" },
    { 0x1F11, "clienttracespawnclass" },
    { 0x1F12, "clienttweakables" },
    { 0x1F13, "cliff_rappel" },
    { 0x1F14, "cliff_rappel_dialogue" },
    { 0x1F15, "cliff_rappel_dialogue_nag" },
    { 0x1F16, "cliff_rappel_landing" },
    { 0x1F17, "cliff_rappel_lerpsun" },
    { 0x1F18, "cliff_rappel_lighting_init" },
    { 0x1F19, "cliff_rappel_lighting_setup" },
    { 0x1F1A, "cliff_rappel_logic" },
    { 0x1F1B, "cliff_rappel_moment" },
    { 0x1F1C, "cliff_rappel_shadow_tweaks" },
    { 0x1F1D, "climb_fence_joker_01" },
    { 0x1F1E, "climb_fence_joker_02" },
    { 0x1F1F, "climb_fence_joker_03" },
    { 0x1F20, "climb_fence_joker_04" },
    { 0x1F21, "climb_fence_joker_05" },
    { 0x1F22, "climb_fence_joker_06" },
    { 0x1F23, "climb_fence_joker_07" },
    { 0x1F24, "climb_fence_joker_08" },
    { 0x1F25, "climb_fence_joker_09" },
    { 0x1F26, "climb_fence_joker_10" },
    { 0x1F27, "climb_fence_torres_01" },
    { 0x1F28, "climb_fence_torres_02" },
    { 0x1F29, "climb_fence_torres_03" },
    { 0x1F2A, "climb_fence_torres_04" },
    { 0x1F2B, "climb_fence_torres_05" },
    { 0x1F2C, "climb_fence_torres_06" },
    { 0x1F2D, "climb_fence_torres_07" },
    { 0x1F2E, "climb_fence_torres_08" },
    { 0x1F2F, "climb_fence_torres_09" },
    { 0x1F30, "climb_fence_torres_10" },
    { 0x1F31, "climb_hint" },
    { 0x1F32, "climb_scene_anim_boat_getout" },
    { 0x1F33, "climb_scene_cleanup" },
    { 0x1F34, "climb_scene_colors_careful_on_arrival" },
    { 0x1F35, "climb_scene_crane_allow_input" },
    { 0x1F36, "climb_scene_crane_dismount_to_wall" },
    { 0x1F37, "climb_scene_crane_glass_break" },
    { 0x1F38, "climb_scene_crane_grab_rumble" },
    { 0x1F39, "climb_scene_crane_grab_shake" },
    { 0x1F3A, "climb_scene_crane_mount" },
    { 0x1F3B, "climb_scene_crane_move" },
    { 0x1F3C, "climb_scene_crane_move_rumble" },
    { 0x1F3D, "climb_scene_crane_move_shake" },
    { 0x1F3E, "climb_scene_fail_fall" },
    { 0x1F3F, "climb_scene_fail_on_ground_notify" },
    { 0x1F40, "climb_scene_finale" },
    { 0x1F41, "climb_scene_finale_setup_anim_ents" },
    { 0x1F42, "climb_scene_finale_setup_people_ents" },
    { 0x1F43, "climb_scene_finale_setup_player_ents" },
    { 0x1F44, "climb_scene_finale_setup_vehicle_ents" },
    { 0x1F45, "climb_scene_first_climb" },
    { 0x1F46, "climb_scene_first_on_foot_warbird_turret" },
    { 0x1F47, "climb_scene_force_dismount" },
    { 0x1F48, "climb_scene_grapple_hint_handler" },
    { 0x1F49, "climb_scene_handle_crane_climb" },
    { 0x1F4A, "climb_scene_handle_crane_climb_movement_input" },
    { 0x1F4B, "climb_scene_handle_finale_walker_civilian_vingette" },
    { 0x1F4C, "climb_scene_handle_walker" },
    { 0x1F4D, "climb_scene_handle_walker_reaction" },
    { 0x1F4E, "climb_scene_ilona_simple_climbing" },
    { 0x1F4F, "climb_scene_master_handler" },
    { 0x1F50, "climb_scene_move_crate_on_path" },
    { 0x1F51, "climb_scene_moving_crates" },
    { 0x1F52, "climb_scene_on_foot" },
    { 0x1F53, "climb_scene_on_foot_crate_death_area" },
    { 0x1F54, "climb_scene_on_foot_ilana_past_crate" },
    { 0x1F55, "climb_scene_on_foot_setup" },
    { 0x1F56, "climb_scene_on_foot_warbird_arrival" },
    { 0x1F57, "climb_scene_preprocess_crate_path" },
    { 0x1F58, "climb_scene_rotate_crate_on_path" },
    { 0x1F59, "climb_scene_second_climb" },
    { 0x1F5A, "climb_scene_second_climb_ilona_no_push" },
    { 0x1F5B, "climb_scene_set_colors_careful_on_arrival_setting" },
    { 0x1F5C, "climb_scene_setup" },
    { 0x1F5D, "climb_scene_setup_droneswarm" },
    { 0x1F5E, "climb_scene_setup_zipliners" },
    { 0x1F5F, "climb_scene_skybridge" },
    { 0x1F60, "climb_scene_skybridge_break_glass" },
    { 0x1F61, "climb_scene_skybridge_teleport_ilona" },
    { 0x1F62, "climb_scene_start_action" },
    { 0x1F63, "climb_scene_start_crane" },
    { 0x1F64, "climb_scene_warbird_setup_rotar_death_trigger" },
    { 0x1F65, "climb_scne_finale_fade_out" },
    { 0x1F66, "climb_scne_finale_hide_body" },
    { 0x1F67, "climb_trigger" },
    { 0x1F68, "climb_wall_nag_dialogue" },
    { 0x1F69, "climb_warbird" },
    { 0x1F6A, "climbing_animation_back_to_side_idle" },
    { 0x1F6B, "climbing_animation_dismount" },
    { 0x1F6C, "climbing_animation_idle_loop" },
    { 0x1F6D, "climbing_animation_idle_to_side_idle" },
    { 0x1F6E, "climbing_animation_side_idle_to_back" },
    { 0x1F6F, "climbing_animation_side_idle_to_idle" },
    { 0x1F70, "climbing_animation_stop_idle" },
    { 0x1F71, "climbing_animation_traverse_move" },
    { 0x1F72, "climbing_crane_allow_input" },
    { 0x1F73, "climbing_crates" },
    { 0x1F74, "climbing_give_player_weapon" },
    { 0x1F75, "climbing_head_sway" },
    { 0x1F76, "climbing_helper_dir_is_blocked" },
    { 0x1F77, "climbing_helper_player_combat_requested" },
    { 0x1F78, "climbing_helper_player_dismount_requested" },
    { 0x1F79, "climbing_helper_player_exit_combat_mode_requested" },
    { 0x1F7A, "climbing_helper_player_in_combat_mode" },
    { 0x1F7B, "climbing_helper_player_input_1_allowed" },
    { 0x1F7C, "climbing_helper_player_input_2_allowed" },
    { 0x1F7D, "climbing_helper_player_jump_requested" },
    { 0x1F7E, "climbing_helper_player_jumping" },
    { 0x1F7F, "climbing_helper_player_mag_moving" },
    { 0x1F80, "climbing_helper_player_moving" },
    { 0x1F81, "climbing_hint_display" },
    { 0x1F82, "climbing_ilona_teleported" },
    { 0x1F83, "climbing_motion_dismount" },
    { 0x1F84, "climbing_motion_player_combat_mode" },
    { 0x1F85, "climbing_motion_player_jump_to_mag" },
    { 0x1F86, "climbing_motion_player_jumping" },
    { 0x1F87, "climbing_motion_player_looking" },
    { 0x1F88, "climbing_motion_player_mag_to_jump" },
    { 0x1F89, "climbing_motion_player_moving_on_magnetic_surface" },
    { 0x1F8A, "climbing_motion_start_player_jump" },
    { 0x1F8B, "climbing_motion_start_player_jump_to_mag" },
    { 0x1F8C, "climbing_motion_start_player_mag_move" },
    { 0x1F8D, "climbing_motion_start_player_mag_to_jump" },
    { 0x1F8E, "climbing_motion_start_player_shooting" },
    { 0x1F8F, "climbing_motion_stop_player_combat_mode" },
    { 0x1F90, "climbing_motion_stop_player_combat_mode_quick" },
    { 0x1F91, "climbing_player_controller" },
    { 0x1F92, "climbing_player_dismounting" },
    { 0x1F93, "climbing_player_mount" },
    { 0x1F94, "climbing_scene_on_foot_no_friendly_damage_in_death_area" },
    { 0x1F95, "climbing_update_available_moving_options" },
    { 0x1F96, "clip" },
    { 0x1F97, "clip_missle_damage_think" },
    { 0x1F98, "clipammol" },
    { 0x1F99, "clipammor" },
    { 0x1F9A, "cloak" },
    { 0x1F9B, "cloak_again" },
    { 0x1F9C, "cloak_battery_hud" },
    { 0x1F9D, "cloak_battery_level" },
    { 0x1F9E, "cloak_device_hit_by_electro_magnetic_pulse" },
    { 0x1F9F, "cloak_disabled" },
    { 0x1FA0, "cloak_enemy_attack_behavior" },
    { 0x1FA1, "cloak_enemy_attack_behavior_mech" },
    { 0x1FA2, "cloak_enemy_default_setup" },
    { 0x1FA3, "cloak_enemy_fast_attack_behavior" },
    { 0x1FA4, "cloak_enemy_investigative_attack_behavior" },
    { 0x1FA5, "cloak_enemy_normal_behavior" },
    { 0x1FA6, "cloak_enemy_normal_behavior_mech" },
    { 0x1FA7, "cloak_enemy_reset_behavior" },
    { 0x1FA8, "cloak_enemy_reset_behavior_mech" },
    { 0x1FA9, "cloak_enemy_state_hidden" },
    { 0x1FAA, "cloak_enemy_state_spotted" },
    { 0x1FAB, "cloak_enemy_warning1_behavior" },
    { 0x1FAC, "cloak_enemy_warning1_behavior_mech" },
    { 0x1FAD, "cloak_enemy_warning2_behavior" },
    { 0x1FAE, "cloak_hud" },
    { 0x1FAF, "cloak_new" },
    { 0x1FB0, "cloak_npc_weapon_instantaneous" },
    { 0x1FB1, "cloak_off" },
    { 0x1FB2, "cloak_off_rope" },
    { 0x1FB3, "cloak_off_server_room" },
    { 0x1FB4, "cloak_on" },
    { 0x1FB5, "cloak_overlay" },
    { 0x1FB6, "cloak_stencil_on" },
    { 0x1FB7, "cloak_vm_weapon_blend" },
    { 0x1FB8, "cloak_vm_weapon_instantaneous" },
    { 0x1FB9, "cloak_warbird" },
    { 0x1FBA, "cloakactivateddialog" },
    { 0x1FBB, "cloakcooldown" },
    { 0x1FBC, "cloakdeactivateddialog" },
    { 0x1FBD, "cloaked_model" },
    { 0x1FBE, "cloaked_stealth_disable_battery_hud" },
    { 0x1FBF, "cloaked_stealth_disable_lab_hud_cinematic" },
    { 0x1FC0, "cloaked_stealth_enable_battery_hud" },
    { 0x1FC1, "cloaked_stealth_enable_lab_hud_cinematic" },
    { 0x1FC2, "cloaked_stealth_player_setup" },
    { 0x1FC3, "cloakedmodel" },
    { 0x1FC4, "cloaking_visual_effect_in_progress" },
    { 0x1FC5, "cloakingtransition" },
    { 0x1FC6, "cloakreadydialog" },
    { 0x1FC7, "cloakstate" },
    { 0x1FC8, "cloakwarbirdexit" },
    { 0x1FC9, "cloakweapon" },
    { 0x1FCA, "cloneloadout" },
    { 0x1FCB, "close" },
    { 0x1FCC, "close_ads_window_on_unlink" },
    { 0x1FCD, "close_all_doors" },
    { 0x1FCE, "close_elevator_doors" },
    { 0x1FCF, "close_enemy_check_on_mt_exit" },
    { 0x1FD0, "close_inner_doors" },
    { 0x1FD1, "close_interior_door" },
    { 0x1FD2, "close_me_when_exopush_over" },
    { 0x1FD3, "close_outer_doors" },
    { 0x1FD4, "close_pos" },
    { 0x1FD5, "close_silo_doors" },
    { 0x1FD6, "closeclassmenu" },
    { 0x1FD7, "closed" },
    { 0x1FD8, "closed_angles" },
    { 0x1FD9, "closeendinggates" },
    { 0x1FDA, "closeendinggatestransition" },
    { 0x1FDB, "closeenoughaimdegrees" },
    { 0x1FDC, "closeflightsound" },
    { 0x1FDD, "closeomamenuondeath" },
    { 0x1FDE, "closer_to_goal_vol" },
    { 0x1FDF, "closerfunc" },
    { 0x1FE0, "closest_drone" },
    { 0x1FE1, "closestai" },
    { 0x1FE2, "cloud_fx" },
    { 0x1FE3, "cloud_queen" },
    { 0x1FE4, "cloud_queen_fly" },
    { 0x1FE5, "cloudfasteffectchange" },
    { 0x1FE6, "cloudfastheavy" },
    { 0x1FE7, "cloudfastinit" },
    { 0x1FE8, "cloudfastlight" },
    { 0x1FE9, "cloudfastmedium" },
    { 0x1FEA, "cloudfastnone" },
    { 0x1FEB, "cloudfastplayer" },
    { 0x1FEC, "cloudpushplayer" },
    { 0x1FED, "cloudrandomizer" },
    { 0x1FEE, "clouds" },
    { 0x1FEF, "clouds_create" },
    { 0x1FF0, "cloudsunflicker" },
    { 0x1FF1, "cloudsunreset" },
    { 0x1FF2, "clusterdeployed" },
    { 0x1FF3, "clusterhellfire" },
    { 0x1FF4, "clustermissile" },
    { 0x1FF5, "clusterspiral" },
    { 0x1FF6, "clut_manage" },
    { 0x1FF7, "clut_manage_school" },
    { 0x1FF8, "clut_previous" },
    { 0x1FF9, "clut_rotate" },
    { 0x1FFA, "clut_trigger_manage" },
    { 0x1FFB, "clut_underwater" },
    { 0x1FFC, "cobra_missile_models" },
    { 0x1FFD, "cobra_weapon_tags" },
    { 0x1FFE, "cobrapilot_difficulty" },
    { 0x1FFF, "cobraweapon" },
    { 0x2000, "codecallback_givekillstreak" },
    { 0x2001, "codescripted" },
    { 0x2002, "cohesion_factor" },
    { 0x2003, "coi_bone" },
    { 0x2004, "coi_ent" },
    { 0x2005, "coi_pos" },
    { 0x2006, "cointoss" },
    { 0x2007, "cointossweighted" },
    { 0x2008, "col" },
    { 0x2009, "col_base" },
    { 0x200A, "col_body" },
    { 0x200B, "col_brush" },
    { 0x200C, "col_gun" },
    { 0x200D, "col_head" },
    { 0x200E, "col_leg_l" },
    { 0x200F, "col_leg_r" },
    { 0x2010, "col_lines" },
    { 0x2011, "col_moving_volumes" },
    { 0x2012, "col_t" },
    { 0x2013, "col_volumes" },
    { 0x2014, "cold_breath" },
    { 0x2015, "cold_burn_lighting_fog" },
    { 0x2016, "coll" },
    { 0x2017, "collapse_animate_lamps" },
    { 0x2018, "collapse_cleanup" },
    { 0x2019, "collapse_cop" },
    { 0x201A, "collapse_fov" },
    { 0x201B, "collapse_friendly_think" },
    { 0x201C, "collapse_player_disable_exo_and_weapons" },
    { 0x201D, "collapse_player_dynamic_speed" },
    { 0x201E, "collapse_player_look_at_tower" },
    { 0x201F, "collapse_scene_ents" },
    { 0x2020, "collapse_scene_ents_long" },
    { 0x2021, "collapse_shellshock" },
    { 0x2022, "collapse_stop_sign_think" },
    { 0x2023, "collapsing_buttress_01" },
    { 0x2024, "collapsing_buttress_02" },
    { 0x2025, "collapsing_buttress_03" },
    { 0x2026, "collapsing_buttress_missile" },
    { 0x2027, "collapsing_buttress_missile_flyby" },
    { 0x2028, "collect_func" },
    { 0x2029, "collectcount" },
    { 0x202A, "collectobjects" },
    { 0x202B, "collectpickup" },
    { 0x202C, "collectpickupfunc" },
    { 0x202D, "collectpickupmodel" },
    { 0x202E, "collision" },
    { 0x202F, "collision_brush_post_explosion" },
    { 0x2030, "collision_brush_pre_explosion" },
    { 0x2031, "collision_prop" },
    { 0x2032, "collision_watcher" },
    { 0x2033, "color_activate_post_burk_rally" },
    { 0x2034, "color_debug" },
    { 0x2035, "color_doesnt_care_about_classname" },
    { 0x2036, "color_doesnt_care_about_heroes" },
    { 0x2037, "color_from_index" },
    { 0x2038, "color_group_enter_lab_trigger" },
    { 0x2039, "color_node" },
    { 0x203A, "color_node_anim_at_node" },
    { 0x203B, "color_node_anim_at_node_animate" },
    { 0x203C, "color_node_arrival_notifies" },
    { 0x203D, "color_node_type_function" },
    { 0x203E, "color_ordered_node_assignment" },
    { 0x203F, "color_priority" },
    { 0x2040, "color_spawners_setup" },
    { 0x2041, "color_system" },
    { 0x2042, "color_teams" },
    { 0x2043, "color_user" },
    { 0x2044, "color0" },
    { 0x2045, "color01" },
    { 0x2046, "color1" },
    { 0x2047, "colorblind" },
    { 0x2048, "colorchecklist" },
    { 0x2049, "colorcode_is_used_in_map" },
    { 0x204A, "colordebug" },
    { 0x204B, "colorindex" },
    { 0x204C, "colorislegit" },
    { 0x204D, "colorlist" },
    { 0x204E, "colornode_clear_promotion_order" },
    { 0x204F, "colornode_func" },
    { 0x2050, "colornode_replace_on_death" },
    { 0x2051, "colornode_set_empty_promotion_order" },
    { 0x2052, "colornode_set_promotion_order" },
    { 0x2053, "colornode_set_respawn_point" },
    { 0x2054, "colornode_setgoal_func" },
    { 0x2055, "colornode_spawn_reinforcement" },
    { 0x2056, "colornode_stop_replace_on_death_group" },
    { 0x2057, "colornodes_debug_array" },
    { 0x2058, "colors" },
    { 0x2059, "colors_player_can_take_nodes" },
    { 0x205A, "cols" },
    { 0x205B, "colvol" },
    { 0x205C, "combat_canal_01" },
    { 0x205D, "combat_cave_cleanup" },
    { 0x205E, "combat_cave_dialogue" },
    { 0x205F, "combat_cave_exit" },
    { 0x2060, "combat_cave_to_lake_follow_dot" },
    { 0x2061, "combat_clearfacialanim" },
    { 0x2062, "combat_courtyard_general_01_think" },
    { 0x2063, "combat_courtyard_jammer" },
    { 0x2064, "combat_courtyard_jammer_complete" },
    { 0x2065, "combat_courtyard_jammer_ladder_left" },
    { 0x2066, "combat_courtyard_jammer_ladder_right" },
    { 0x2067, "combat_courtyard_mech" },
    { 0x2068, "combat_courtyard_path_general" },
    { 0x2069, "combat_courtyard_path_jammer_building" },
    { 0x206A, "combat_courtyard_path_left_00" },
    { 0x206B, "combat_courtyard_path_left_00_think" },
    { 0x206C, "combat_courtyard_path_left_01" },
    { 0x206D, "combat_courtyard_path_left_01_think" },
    { 0x206E, "combat_courtyard_path_left_02" },
    { 0x206F, "combat_courtyard_path_left_02_think" },
    { 0x2070, "combat_courtyard_path_left_03" },
    { 0x2071, "combat_courtyard_path_left_03_think" },
    { 0x2072, "combat_courtyard_path_middle_01" },
    { 0x2073, "combat_courtyard_path_middle_01_think" },
    { 0x2074, "combat_courtyard_path_middle_02" },
    { 0x2075, "combat_courtyard_path_middle_02_think" },
    { 0x2076, "combat_courtyard_path_middle_03" },
    { 0x2077, "combat_courtyard_path_middle_03_think" },
    { 0x2078, "combat_courtyard_path_right_01" },
    { 0x2079, "combat_courtyard_path_right_01_think" },
    { 0x207A, "combat_courtyard_path_right_02" },
    { 0x207B, "combat_courtyard_path_right_02_think" },
    { 0x207C, "combat_courtyard_path_right_03" },
    { 0x207D, "combat_courtyard_path_right_03_think" },
    { 0x207E, "combat_enemy_tank" },
    { 0x207F, "combat_enemy_trans_heli_wave_01" },
    { 0x2080, "combat_flyin_bridge" },
    { 0x2081, "combat_foam_corridor" },
    { 0x2082, "combat_forest_patrols_start" },
    { 0x2083, "combat_gaz_bridge" },
    { 0x2084, "combat_hangar" },
    { 0x2085, "combat_lobby" },
    { 0x2086, "combat_logging_road_end" },
    { 0x2087, "combat_player_in_m_turret" },
    { 0x2088, "combat_playfacialanim" },
    { 0x2089, "combat_post_breach_patrol" },
    { 0x208A, "combat_research_building" },
    { 0x208B, "combat_research_building_bridge" },
    { 0x208C, "combat_research_left_01" },
    { 0x208D, "combat_research_platform_01" },
    { 0x208E, "combat_research_pool_room" },
    { 0x208F, "combat_research_pool_walkway_01" },
    { 0x2090, "combat_research_right_01" },
    { 0x2091, "combat_silo" },
    { 0x2092, "combat_silo_boost" },
    { 0x2093, "combat_silo_complete" },
    { 0x2094, "combat_silo_mech" },
    { 0x2095, "combat_silo_seeker_ai" },
    { 0x2096, "combat_spawn_research_right_flank_02" },
    { 0x2097, "combat_state" },
    { 0x2098, "combat_street_blown_building" },
    { 0x2099, "combat_street_initial" },
    { 0x209A, "combat_street_mid_checkpoint_1" },
    { 0x209B, "combat_street_mid_checkpoint_2" },
    { 0x209C, "combat_street_seeker_ai" },
    { 0x209D, "combat_street_wave_01" },
    { 0x209E, "combat_street_wave_02" },
    { 0x209F, "combat_street_wave_03" },
    { 0x20A0, "combat_street_wave_04" },
    { 0x20A1, "combat_street_wave_rear" },
    { 0x20A2, "combat_tank_courtyard" },
    { 0x20A3, "combat_tank_courtyard_gate_1_guys_think" },
    { 0x20A4, "combat_tank_field_flee_guys_think" },
    { 0x20A5, "combat_tank_road" },
    { 0x20A6, "combat_zip_rooftop" },
    { 0x20A7, "combatbehavior" },
    { 0x20A8, "combatbuttonbuffer" },
    { 0x20A9, "combatcrouchanims" },
    { 0x20AA, "combatendtime" },
    { 0x20AB, "combathigh" },
    { 0x20AC, "combatidle" },
    { 0x20AD, "combatidlepreventoverlappingplayer" },
    { 0x20AE, "combatmemorytimeconst" },
    { 0x20AF, "combatmemorytimerand" },
    { 0x20B0, "combatrecordtie" },
    { 0x20B1, "combatrecordwin" },
    { 0x20B2, "combatreminderdialogue" },
    { 0x20B3, "combatstandanims" },
    { 0x20B4, "combatstate" },
    { 0x20B5, "combattime" },
    { 0x20B6, "comebackcustomkillstreakfunc" },
    { 0x20B7, "comebackcustomospfunc" },
    { 0x20B8, "comebackevent" },
    { 0x20B9, "command_goal" },
    { 0x20BA, "command_used" },
    { 0x20BB, "commander_dialog" },
    { 0x20BC, "commander_speaking" },
    { 0x20BD, "commanding_bot" },
    { 0x20BE, "commit_exo_awards_stage_and_progress" },
    { 0x20BF, "commit_exo_awards_upgrade_points_custom" },
    { 0x20C0, "commit_exo_awards_upon_mission_success" },
    { 0x20C1, "common_canyon_funcs" },
    { 0x20C2, "commonstarttime" },
    { 0x20C3, "compare_killnow_score" },
    { 0x20C4, "compare_player_pass_dot" },
    { 0x20C5, "compare_script_index" },
    { 0x20C6, "compare_time_before_attack" },
    { 0x20C7, "compare_time_before_move" },
    { 0x20C8, "compare_time_since_birth" },
    { 0x20C9, "compareorbitangle" },
    { 0x20CA, "comparescreenpos" },
    { 0x20CB, "comparesizesfx" },
    { 0x20CC, "comparezoneindexes" },
    { 0x20CD, "compass_offsets" },
    { 0x20CE, "compass_text" },
    { 0x20CF, "compass_update_text" },
    { 0x20D0, "compassicons" },
    { 0x20D1, "complete_me" },
    { 0x20D2, "completed_delay" },
    { 0x20D3, "completedanims" },
    { 0x20D4, "completednodes" },
    { 0x20D5, "component_cache" },
    { 0x20D6, "component_weights" },
    { 0x20D7, "compute_best_gun_target" },
    { 0x20D8, "compute_fireweapon_direction" },
    { 0x20D9, "compute_spread" },
    { 0x20DA, "compute_target_lead_origin" },
    { 0x20DB, "compute_threat" },
    { 0x20DC, "computer_door_entry_sfx_notetrack" },
    { 0x20DD, "concealed_kill_tutorial_display" },
    { 0x20DE, "concealed_tutorial_display_hint" },
    { 0x20DF, "concussionendtime" },
    { 0x20E0, "condition_callback" },
    { 0x20E1, "condition_to_moving" },
    { 0x20E2, "condition_to_start_moving" },
    { 0x20E3, "condition_to_state_cruzin" },
    { 0x20E4, "condition_to_state_state_honking" },
    { 0x20E5, "condition_to_stop_moving" },
    { 0x20E6, "cone_length" },
    { 0x20E7, "conf_camper_camp_tags" },
    { 0x20E8, "conf_camping_tag" },
    { 0x20E9, "conf_fx" },
    { 0x20EA, "conf_static" },
    { 0x20EB, "confcenteratriumflashcharge" },
    { 0x20EC, "confcenterbegin" },
    { 0x20ED, "confcenterbossexplode" },
    { 0x20EE, "confcentercombatdialogue" },
    { 0x20EF, "confcenterexplosion" },
    { 0x20F0, "confcenterfailalarmsoundeddialogue" },
    { 0x20F1, "confcenterfailburkekilleddialogue" },
    { 0x20F2, "confcenterfailhadeskilledearlydialogue" },
    { 0x20F3, "confcenterfailinvalidtargetdialogue" },
    { 0x20F4, "confcenterfailtimeoutdialogue" },
    { 0x20F5, "confcenterfailtimerexpiredialogue" },
    { 0x20F6, "confcenterflaginit" },
    { 0x20F7, "confcentergatecharge" },
    { 0x20F8, "confcenterglobalsetup" },
    { 0x20F9, "confcenterglobalvars" },
    { 0x20FA, "confcenterintrodialogue" },
    { 0x20FB, "confcenterkilldialogue" },
    { 0x20FC, "confcenterlightglowfx" },
    { 0x20FD, "confcenterobjectivesetup" },
    { 0x20FE, "confcenteroutrodialogue" },
    { 0x20FF, "confcenterpoolallywaterdrip" },
    { 0x2100, "confcenterpoolsplash" },
    { 0x2101, "confcenterprecache" },
    { 0x2102, "confcenterresidualsmoke" },
    { 0x2103, "confcentersetcompletedobjflags" },
    { 0x2104, "confcenterstartpoints" },
    { 0x2105, "confcentersupportadialogue" },
    { 0x2106, "confcentersupportbdialogue" },
    { 0x2107, "confcentersupportcdialogue" },
    { 0x2108, "confcentertotalcombat" },
    { 0x2109, "confcentervehiclesvulnerable" },
    { 0x210A, "conference_center_explo" },
    { 0x210B, "conference_center_explo_zone" },
    { 0x210C, "conference_center_fire" },
    { 0x210D, "conferenceroomanimations" },
    { 0x210E, "confhades" },
    { 0x210F, "config" },
    { 0x2110, "config_system" },
    { 0x2111, "confrontation_flashbang" },
    { 0x2112, "confrontation_fx_cleanup" },
    { 0x2113, "confrontation_guys" },
    { 0x2114, "confrontation_handle_player_clip" },
    { 0x2115, "confrontation_holo" },
    { 0x2116, "confrontation_hologram_fadeout" },
    { 0x2117, "confrontation_hudoutline_animate" },
    { 0x2118, "confrontation_hudoutline_cleanup" },
    { 0x2119, "confrontation_hudoutline_setup" },
    { 0x211A, "confrontation_irons_gun_shot" },
    { 0x211B, "confrontation_rig" },
    { 0x211C, "confrontation_scene_button_clean_up" },
    { 0x211D, "confrontation_scene_cleanup_confrontation" },
    { 0x211E, "confrontation_scene_cleanup_hologram" },
    { 0x211F, "confrontation_scene_cleaup" },
    { 0x2120, "confrontation_scene_escape" },
    { 0x2121, "confrontation_scene_escape_guard_dies" },
    { 0x2122, "confrontation_scene_escape_player_rise" },
    { 0x2123, "confrontation_scene_escape_qte_fail" },
    { 0x2124, "confrontation_scene_escape_qte_kick" },
    { 0x2125, "confrontation_scene_escape_qte_kick_kill" },
    { 0x2126, "confrontation_scene_escape_qte_raise_gun" },
    { 0x2127, "confrontation_scene_escape_qte_shoot" },
    { 0x2128, "confrontation_scene_flashbang_explode" },
    { 0x2129, "confrontation_scene_gun_swap" },
    { 0x212A, "confrontation_scene_hologram" },
    { 0x212B, "confrontation_scene_irons_lockdown" },
    { 0x212C, "confrontation_scene_irons_no_gun" },
    { 0x212D, "confrontation_scene_master_handler" },
    { 0x212E, "confrontation_scene_open_flashbang_door" },
    { 0x212F, "confrontation_scene_player_rumble_heavy" },
    { 0x2130, "confrontation_scene_player_rumble_light" },
    { 0x2131, "confrontation_scene_qte_kick_slomo_start" },
    { 0x2132, "confrontation_scene_qte_kick_slomo_stop" },
    { 0x2133, "confrontation_scene_qte_shoot_slomo_start" },
    { 0x2134, "confrontation_scene_qte_shoot_slomo_stop" },
    { 0x2135, "confrontation_scene_setup" },
    { 0x2136, "confrontation_static_start" },
    { 0x2137, "confrontation_tech_blood" },
    { 0x2138, "confroombodyscan" },
    { 0x2139, "confroombreachbodyguarddeath" },
    { 0x213A, "confroombreachhadesspeech" },
    { 0x213B, "confroomexplosiondronereaction" },
    { 0x213C, "confroomexplosivetrap" },
    { 0x213D, "confroomflashbang" },
    { 0x213E, "confroomhadessweep" },
    { 0x213F, "confroomragdoll" },
    { 0x2140, "confroomrecovery" },
    { 0x2141, "confroomreminderdialogue" },
    { 0x2142, "confroomsetup" },
    { 0x2143, "confroomstandingidles" },
    { 0x2144, "connect_node" },
    { 0x2145, "connect_nodes" },
    { 0x2146, "connect_paths" },
    { 0x2147, "connectandspawninstinctdogpack" },
    { 0x2148, "connected" },
    { 0x2149, "connectedmenus" },
    { 0x214A, "connectedpostgame" },
    { 0x214B, "connectingplayers" },
    { 0x214C, "connectnewagent" },
    { 0x214D, "connectpaths_ents_by_targetname" },
    { 0x214E, "connectpathsfunction" },
    { 0x214F, "connecttime" },
    { 0x2150, "connecttraverses" },
    { 0x2151, "considerchangingtarget" },
    { 0x2152, "considerthrowgrenade" },
    { 0x2153, "console" },
    { 0x2154, "console_guy" },
    { 0x2155, "consoleguy" },
    { 0x2156, "consolidated_inputs" },
    { 0x2157, "const_cosine_bunched_angle" },
    { 0x2158, "const_cosine_stick_angle" },
    { 0x2159, "constant_quake" },
    { 0x215A, "constrain_vector_to_cone" },
    { 0x215B, "constraingametype" },
    { 0x215C, "construct_vision_ents" },
    { 0x215D, "construct_vision_set" },
    { 0x215E, "construction_heli_shoot" },
    { 0x215F, "contact_watcher" },
    { 0x2160, "container_death_anims" },
    { 0x2161, "contents" },
    { 0x2162, "context_overrides" },
    { 0x2163, "continue_when_player_near_entity" },
    { 0x2164, "continuedrivenmovement" },
    { 0x2165, "continuemovement" },
    { 0x2166, "continuereinforcements" },
    { 0x2167, "control_foam_room_door02_clip" },
    { 0x2168, "control_goliath_usability" },
    { 0x2169, "control_mech_attacks" },
    { 0x216A, "control_mob_fire" },
    { 0x216B, "control_mob_turret" },
    { 0x216C, "control_room" },
    { 0x216D, "control_room_anims" },
    { 0x216E, "control_room_buzzer_started" },
    { 0x216F, "control_room_door_open_lt" },
    { 0x2170, "control_room_door_open_rt" },
    { 0x2171, "control_room_exit" },
    { 0x2172, "control_room_explosion" },
    { 0x2173, "control_room_foley_notetracks" },
    { 0x2174, "control_room_interior_vfx_on" },
    { 0x2175, "control_room_run" },
    { 0x2176, "control_room_run_approach" },
    { 0x2177, "control_room_run_joker" },
    { 0x2178, "control_room_run_player" },
    { 0x2179, "control_room_scene" },
    { 0x217A, "control_room_scene_actors" },
    { 0x217B, "control_room_scene_exit" },
    { 0x217C, "control_room_scene_player" },
    { 0x217D, "control_room_screens" },
    { 0x217E, "control_turret_after_delay" },
    { 0x217F, "controlcheck" },
    { 0x2180, "controllable_cloud_queen" },
    { 0x2181, "controllable_drone_activated" },
    { 0x2182, "controllable_drone_allowed_vols" },
    { 0x2183, "controllable_drone_hud" },
    { 0x2184, "controllable_drone_spawners" },
    { 0x2185, "controllable_drone_swarm_init" },
    { 0x2186, "controllable_drone_swarm_target" },
    { 0x2187, "controllable_drones" },
    { 0x2188, "controllable_fly_think" },
    { 0x2189, "controllable_hud_target_shader" },
    { 0x218A, "controlled_dog" },
    { 0x218B, "controlled_orbitalsupport_turret" },
    { 0x218C, "controller_rumble_heavy" },
    { 0x218D, "controller_rumble_heavy_long" },
    { 0x218E, "controller_rumble_heavy0" },
    { 0x218F, "controller_rumble_heavy1" },
    { 0x2190, "controller_rumble_heavy2" },
    { 0x2191, "controller_rumble_heavy3" },
    { 0x2192, "controller_rumble_light" },
    { 0x2193, "controller_rumble_light_long" },
    { 0x2194, "controller_rumble_light0" },
    { 0x2195, "controller_rumble_light1" },
    { 0x2196, "controller_rumble_light2" },
    { 0x2197, "controller_rumble_light3" },
    { 0x2198, "controlling_dog" },
    { 0x2199, "controllingorbitallaser" },
    { 0x219A, "controllingwarbird" },
    { 0x219B, "controlsfrozen" },
    { 0x219C, "conversation_index" },
    { 0x219D, "conversation_response" },
    { 0x219E, "conversation_start" },
    { 0x219F, "conversation_stop" },
    { 0x21A0, "convert_8bit_color" },
    { 0x21A1, "convert_drones_near_player" },
    { 0x21A2, "convert_guy_to_drone" },
    { 0x21A3, "convert_to_time_string" },
    { 0x21A4, "convertfogtech" },
    { 0x21A5, "convertlegacyfog" },
    { 0x21A6, "convertmillisecondstodecisecondsandclamptoshort" },
    { 0x21A7, "convertoneshot" },
    { 0x21A8, "convertoneshotfx" },
    { 0x21A9, "converts" },
    { 0x21AA, "convoactive" },
    { 0x21AB, "convogate" },
    { 0x21AC, "convos" },
    { 0x21AD, "convoy_barrier" },
    { 0x21AE, "convoy_barrier_setup" },
    { 0x21AF, "convoy_crash_emitters" },
    { 0x21B0, "convoy_truck_explosion" },
    { 0x21B1, "convoydetonateambushinteract" },
    { 0x21B2, "cool_down_duration" },
    { 0x21B3, "cooldownstate" },
    { 0x21B4, "cooldowntime" },
    { 0x21B5, "cooldownwaittime" },
    { 0x21B6, "cooling_tower" },
    { 0x21B7, "cooling_tower_collapse" },
    { 0x21B8, "cooling_tower_collapse_visibility" },
    { 0x21B9, "coop_breached_from_same_door_in_a_muliti_door_room" },
    { 0x21BA, "coop_icon_blinkcrement" },
    { 0x21BB, "coop_icon_blinktime" },
    { 0x21BC, "coop_icon_color_blink" },
    { 0x21BD, "coop_icon_color_damage" },
    { 0x21BE, "coop_icon_color_downed" },
    { 0x21BF, "coop_icon_color_dying" },
    { 0x21C0, "coop_icon_color_normal" },
    { 0x21C1, "coop_icon_color_shoot" },
    { 0x21C2, "coop_icon_state" },
    { 0x21C3, "coop_player_in_special_ops_survival" },
    { 0x21C4, "coop_player_touching_valid_door_volume" },
    { 0x21C5, "coop_revive_nag_hud_refreshtime" },
    { 0x21C6, "coop_with_one_player_downed" },
    { 0x21C7, "coopkillstreaksplashnotify" },
    { 0x21C8, "cooplinker" },
    { 0x21C9, "coopoffensive" },
    { 0x21CA, "coopturret" },
    { 0x21CB, "cop_car_lights_on" },
    { 0x21CC, "cop_car_lights_on_barricade" },
    { 0x21CD, "copgroup" },
    { 0x21CE, "copier" },
    { 0x21CF, "copilot_intro" },
    { 0x21D0, "copy_angles_of_selected_ents" },
    { 0x21D1, "copy_animation_to_cloak_models" },
    { 0x21D2, "copy_animation_to_model" },
    { 0x21D3, "copy_attachments" },
    { 0x21D4, "copy_bar" },
    { 0x21D5, "copy_cat" },
    { 0x21D6, "copy_ents" },
    { 0x21D7, "copy_names" },
    { 0x21D8, "copy_script_model" },
    { 0x21D9, "copycatloadout" },
    { 0x21DA, "copystructarrayvalues" },
    { 0x21DB, "core_snipers_drone_spawners" },
    { 0x21DC, "coredamagetrig" },
    { 0x21DD, "coredeathtrig" },
    { 0x21DE, "coreshellshock" },
    { 0x21DF, "cormack" },
    { 0x21E0, "cormack_anim_rate_change" },
    { 0x21E1, "cormack_anim_scene_fob_meet" },
    { 0x21E2, "cormack_boost_jump" },
    { 0x21E3, "cormack_bridge_intro" },
    { 0x21E4, "cormack_dilate_pupils" },
    { 0x21E5, "cormack_dodge_drones" },
    { 0x21E6, "cormack_exfil_approach" },
    { 0x21E7, "cormack_firing_listener" },
    { 0x21E8, "cormack_flare" },
    { 0x21E9, "cormack_flare_notetrack_handler_flare" },
    { 0x21EA, "cormack_flare_notetrack_handler_ice" },
    { 0x21EB, "cormack_fov_end" },
    { 0x21EC, "cormack_fov_start" },
    { 0x21ED, "cormack_grapple_kill_rope" },
    { 0x21EE, "cormack_grapple_to_vtol" },
    { 0x21EF, "cormack_hall_handler" },
    { 0x21F0, "cormack_hand_on_ilana" },
    { 0x21F1, "cormack_helmet_close" },
    { 0x21F2, "cormack_helmet_open" },
    { 0x21F3, "cormack_ilana_cleanup" },
    { 0x21F4, "cormack_ilana_infil" },
    { 0x21F5, "cormack_intel_foley" },
    { 0x21F6, "cormack_intro" },
    { 0x21F7, "cormack_jetpack_switch" },
    { 0x21F8, "cormack_lake_callout_cargo" },
    { 0x21F9, "cormack_lake_callout_cover" },
    { 0x21FA, "cormack_lake_callout_coverme" },
    { 0x21FB, "cormack_lake_callout_downhere" },
    { 0x21FC, "cormack_lake_callout_goliath" },
    { 0x21FD, "cormack_lake_callout_pin" },
    { 0x21FE, "cormack_lake_callout_rpg" },
    { 0x21FF, "cormack_lake_callout_stop" },
    { 0x2200, "cormack_landing_pad_combat" },
    { 0x2201, "cormack_light_handler" },
    { 0x2202, "cormack_missile" },
    { 0x2203, "cormack_missile_fx" },
    { 0x2204, "cormack_narrow_cave_search" },
    { 0x2205, "cormack_narrow_cave_start" },
    { 0x2206, "cormack_narrowcave_breach_grab_axe" },
    { 0x2207, "cormack_narrowcave_breach_ledge" },
    { 0x2208, "cormack_narrowcave_breach_surface" },
    { 0x2209, "cormack_narrowcave_breach_turn" },
    { 0x220A, "cormack_narrowcave_search_enter" },
    { 0x220B, "cormack_narrowcave_search_exit" },
    { 0x220C, "cormack_narrowcave_search_traverse_sec1" },
    { 0x220D, "cormack_outro" },
    { 0x220E, "cormack_perarts_jump_explosions" },
    { 0x220F, "cormack_pick" },
    { 0x2210, "cormack_pickup_stinger" },
    { 0x2211, "cormack_pod_exit_impact" },
    { 0x2212, "cormack_post_breach_move" },
    { 0x2213, "cormack_rappel" },
    { 0x2214, "cormack_reached" },
    { 0x2215, "cormack_server_room_se" },
    { 0x2216, "cormack_shoot_missile" },
    { 0x2217, "cormack_shoots_bridge_guy" },
    { 0x2218, "cormack_smash_monitor_01" },
    { 0x2219, "cormack_smash_monitor_02" },
    { 0x221A, "cormack_stealth_takedown_guard_sounds" },
    { 0x221B, "cormack_stealth_takedown_guy_waits" },
    { 0x221C, "cormack_stealth_takedown_rope_waits" },
    { 0x221D, "cormack_turkey_shoot" },
    { 0x221E, "cormack_wait" },
    { 0x221F, "corner_clearfacialanim" },
    { 0x2220, "corner_playaimfacialanim" },
    { 0x2221, "corner_playcornerfacialanim" },
    { 0x2222, "corner_think" },
    { 0x2223, "corneraiming" },
    { 0x2224, "cornerdeathreleasegrenade" },
    { 0x2225, "cornerdirection" },
    { 0x2226, "cornerline_height" },
    { 0x2227, "cornermode" },
    { 0x2228, "cornerreload" },
    { 0x2229, "cornerrightgrenadedeath" },
    { 0x222A, "corners" },
    { 0x222B, "cornersights" },
    { 0x222C, "corpse" },
    { 0x222D, "corpse_array" },
    { 0x222E, "corpse_array_time" },
    { 0x222F, "corpse_behavior_doesnt_require_player_sight" },
    { 0x2230, "corpse_cleanup" },
    { 0x2231, "corpse_entity" },
    { 0x2232, "corpse_height" },
    { 0x2233, "corpse_seen_by" },
    { 0x2234, "corpse_trigger_think" },
    { 0x2235, "cosine" },
    { 0x2236, "costume" },
    { 0x2237, "costume_changed" },
    { 0x2238, "costumecat2idx" },
    { 0x2239, "costumecategories" },
    { 0x223A, "costumelogged" },
    { 0x223B, "couldntseeenemypos" },
    { 0x223C, "count_bullet" },
    { 0x223D, "count_rocket" },
    { 0x223E, "count_swarm" },
    { 0x223F, "countdown_missile_launch" },
    { 0x2240, "counted" },
    { 0x2241, "counter" },
    { 0x2242, "countplayers" },
    { 0x2243, "countryid" },
    { 0x2244, "countryids" },
    { 0x2245, "courtyard" },
    { 0x2246, "courtyard_ally_mcd_safeguard" },
    { 0x2247, "courtyard_ally_mcd_safeguard_init" },
    { 0x2248, "courtyard_ambient_bullet_impact" },
    { 0x2249, "courtyard_ambient_bullet_impacts" },
    { 0x224A, "courtyard_ambient_explosions" },
    { 0x224B, "courtyard_burke_defend_squad" },
    { 0x224C, "courtyard_burke_enter_hangar_logic" },
    { 0x224D, "courtyard_burke_rally" },
    { 0x224E, "courtyard_cormack_enter_hangar_logic" },
    { 0x224F, "courtyard_defend_start" },
    { 0x2250, "courtyard_door_hack_complete_dialogue" },
    { 0x2251, "courtyard_door_hack_start_dialogue" },
    { 0x2252, "courtyard_doormen_enemy_think" },
    { 0x2253, "courtyard_end_jammer" },
    { 0x2254, "courtyard_enemy_initial_think" },
    { 0x2255, "courtyard_enemy_sniper_fodder_count" },
    { 0x2256, "courtyard_enemy_sniper_fodder_damage_function" },
    { 0x2257, "courtyard_enemy_sniper_fodder_think" },
    { 0x2258, "courtyard_enemy_sniper_fodder_track" },
    { 0x2259, "courtyard_enemy_think" },
    { 0x225A, "courtyard_entry_dialogue" },
    { 0x225B, "courtyard_gate_take_damage" },
    { 0x225C, "courtyard_gate_think" },
    { 0x225D, "courtyard_gates_think" },
    { 0x225E, "courtyard_glowing_ladders" },
    { 0x225F, "courtyard_goal_volume" },
    { 0x2260, "courtyard_goal_volume_trigger_b_think" },
    { 0x2261, "courtyard_goal_volume_trigger_think" },
    { 0x2262, "courtyard_hangar_door_close" },
    { 0x2263, "courtyard_hangar_door_close_rpg" },
    { 0x2264, "courtyard_hangar_door_hack" },
    { 0x2265, "courtyard_hangar_door_logic" },
    { 0x2266, "courtyard_hangar_door_open" },
    { 0x2267, "courtyard_hangar_mech_01_spawned" },
    { 0x2268, "courtyard_intro_magic_bullets" },
    { 0x2269, "courtyard_jammer" },
    { 0x226A, "courtyard_jammer_complete_dialogue" },
    { 0x226B, "courtyard_jammer_ladder_enemy_think" },
    { 0x226C, "courtyard_jammer_logic" },
    { 0x226D, "courtyard_jammer_plant_dof" },
    { 0x226E, "courtyard_jammer_plant_nag_dialogue" },
    { 0x226F, "courtyard_jammer_rumbles" },
    { 0x2270, "courtyard_jammer_scene" },
    { 0x2271, "courtyard_logic" },
    { 0x2272, "courtyard_mech_01" },
    { 0x2273, "courtyard_mech_02" },
    { 0x2274, "courtyard_mech_03" },
    { 0x2275, "courtyard_mech_04" },
    { 0x2276, "courtyard_mech_start_dialogue" },
    { 0x2277, "courtyard_mi17_spawn_01" },
    { 0x2278, "courtyard_mi17_spawn_02" },
    { 0x2279, "courtyard_mobile_cover_guys" },
    { 0x227A, "courtyard_rappel_preview" },
    { 0x227B, "courtyard_rappel_preview_guys" },
    { 0x227C, "courtyard_rappel_preview_think" },
    { 0x227D, "courtyard_rappel_preview_vehicles" },
    { 0x227E, "courtyard_rpg_drop" },
    { 0x227F, "courtyard_scrambler_rotate" },
    { 0x2280, "courtyard_scripted_props_staged_wakeup" },
    { 0x2281, "courtyard_scripted_props_think" },
    { 0x2282, "courtyard_squad_defend_nag_dialogue" },
    { 0x2283, "courtyard_start_dish" },
    { 0x2284, "courtyard_sun_off" },
    { 0x2285, "courtyard_traversal_hangar" },
    { 0x2286, "courtyard_traversal_initial" },
    { 0x2287, "courtyard_traversal_jammer" },
    { 0x2288, "courtyard_traversal_tank" },
    { 0x2289, "courtyard_vrap01" },
    { 0x228A, "courtyard_vrap02" },
    { 0x228B, "courtyard_vrap03" },
    { 0x228C, "courtyard_vrap04" },
    { 0x228D, "courtyard_vrap05" },
    { 0x228E, "courtyardguardcheckgatedialogue" },
    { 0x228F, "courtyardreminderdialogue" },
    { 0x2290, "courtyardspecialdetection" },
    { 0x2291, "cover_clearfacialanim" },
    { 0x2292, "cover_drone_disable" },
    { 0x2293, "cover_drone_disabled" },
    { 0x2294, "cover_drone_enable" },
    { 0x2295, "cover_drone_wheels" },
    { 0x2296, "cover_fire_missile_repulsor" },
    { 0x2297, "cover_nodes_first" },
    { 0x2298, "cover_nodes_last" },
    { 0x2299, "cover_playfacialanim" },
    { 0x229A, "cover_wall_think" },
    { 0x229B, "cover_warnings_disabled" },
    { 0x229C, "coverapproachlastminutecheck" },
    { 0x229D, "covercrouch" },
    { 0x229E, "covercrouchfail" },
    { 0x229F, "covercrouchgrenade" },
    { 0x22A0, "covercrouchlean_aimmode" },
    { 0x22A1, "covercrouchleanpitch" },
    { 0x22A2, "coverenterpos" },
    { 0x22A3, "coverexit" },
    { 0x22A4, "coverexitangles" },
    { 0x22A5, "coverexitdist" },
    { 0x22A6, "coverexitpos" },
    { 0x22A7, "coverexitpostdist" },
    { 0x22A8, "coverleft45" },
    { 0x22A9, "coverleft90" },
    { 0x22AA, "coverleftgrenade" },
    { 0x22AB, "covermode" },
    { 0x22AC, "covermulti_choosehidestate" },
    { 0x22AD, "covermulti_dotransition" },
    { 0x22AE, "covermulti_enterstate" },
    { 0x22AF, "covermulti_exitstate" },
    { 0x22B0, "covermulti_getanimtransition" },
    { 0x22B1, "covermulti_getbestvaliddir" },
    { 0x22B2, "covermulti_getnonrandomvaliddir" },
    { 0x22B3, "covermulti_getrandomvaliddir" },
    { 0x22B4, "covermulti_getstatefromdir" },
    { 0x22B5, "covermulti_isvaliddir" },
    { 0x22B6, "covermulti_setdir" },
    { 0x22B7, "covermulti_setstate" },
    { 0x22B8, "covermulti_setstateinternal" },
    { 0x22B9, "covermulti_think" },
    { 0x22BA, "covernode" },
    { 0x22BB, "coverpoint" },
    { 0x22BC, "coverposestablishedtime" },
    { 0x22BD, "coverprint" },
    { 0x22BE, "coverreload" },
    { 0x22BF, "coverright45" },
    { 0x22C0, "coverright90" },
    { 0x22C1, "coverrightgrenade" },
    { 0x22C2, "coversetupanim" },
    { 0x22C3, "coverstand" },
    { 0x22C4, "coverstandfail" },
    { 0x22C5, "coverstandgrenade" },
    { 0x22C6, "covertest" },
    { 0x22C7, "covertrans" },
    { 0x22C8, "covertransangles" },
    { 0x22C9, "covertransdist" },
    { 0x22CA, "covertranspredist" },
    { 0x22CB, "covertype" },
    { 0x22CC, "cower_cleanup_civs_on_goal" },
    { 0x22CD, "cpm" },
    { 0x22CE, "cpu_transmission" },
    { 0x22CF, "cqb_aim" },
    { 0x22D0, "cqb_clearfacialanim" },
    { 0x22D1, "cqb_dof_off" },
    { 0x22D2, "cqb_dof_on" },
    { 0x22D3, "cqb_investigate_behavior" },
    { 0x22D4, "cqb_mode" },
    { 0x22D5, "cqb_playfacialanim" },
    { 0x22D6, "cqb_point_of_interest" },
    { 0x22D7, "cqb_reloadinternal" },
    { 0x22D8, "cqb_target" },
    { 0x22D9, "cqb_test" },
    { 0x22DA, "cqb_walk" },
    { 0x22DB, "cqb_wide_poi_track" },
    { 0x22DC, "cqb_wide_target_track" },
    { 0x22DD, "cqbenabled" },
    { 0x22DE, "cqbpointsofinterest" },
    { 0x22DF, "cqbtracking" },
    { 0x22E0, "cqbwalking" },
    { 0x22E1, "cracked_floor_function" },
    { 0x22E2, "cracked_windshield_swap" },
    { 0x22E3, "crane_animated_down" },
    { 0x22E4, "crane_animated_up" },
    { 0x22E5, "crane_cable" },
    { 0x22E6, "crane_cable_down" },
    { 0x22E7, "crane_cable_up" },
    { 0x22E8, "crane_check_for_stop_command" },
    { 0x22E9, "crane_claw_crate_grab" },
    { 0x22EA, "crane_claw_crate_release" },
    { 0x22EB, "crane_claw_drop_start" },
    { 0x22EC, "crane_claw_drop_stop" },
    { 0x22ED, "crane_claw_mvmnt_start" },
    { 0x22EE, "crane_claw_mvmnt_stop" },
    { 0x22EF, "crane_claw_rise_start" },
    { 0x22F0, "crane_claw_rise_stop" },
    { 0x22F1, "crane_force_stop_command" },
    { 0x22F2, "crane_mach_mvmnt_start" },
    { 0x22F3, "crane_mach_mvmnt_stop" },
    { 0x22F4, "cranechemcollision" },
    { 0x22F5, "cranechemcollisiontotal" },
    { 0x22F6, "cranecollision" },
    { 0x22F7, "cranecollisiontotal" },
    { 0x22F8, "cranes" },
    { 0x22F9, "cranesparks" },
    { 0x22FA, "cranethink" },
    { 0x22FB, "crash" },
    { 0x22FC, "crash_blackout" },
    { 0x22FD, "crash_derailed_check" },
    { 0x22FE, "crash_detour_check" },
    { 0x22FF, "crash_dof_presets" },
    { 0x2300, "crash_event" },
    { 0x2301, "crash_fire_light" },
    { 0x2302, "crash_gideon_rescue_cormack" },
    { 0x2303, "crash_gideon_rescue_gideon" },
    { 0x2304, "crash_gideon_rescue_ilona" },
    { 0x2305, "crash_gideon_rescue2_cormack" },
    { 0x2306, "crash_gideon_rescue2_gideon" },
    { 0x2307, "crash_gideon_rescue2_ilona" },
    { 0x2308, "crash_introscreen" },
    { 0x2309, "crash_is_fatal" },
    { 0x230A, "crash_lighting_crash_site" },
    { 0x230B, "crash_lighting_crash_site_dof" },
    { 0x230C, "crash_lighting_drone_hall" },
    { 0x230D, "crash_lighting_engine_lighting" },
    { 0x230E, "crash_lighting_entry" },
    { 0x230F, "crash_lighting_entry_dof" },
    { 0x2310, "crash_lighting_entry_dof_scripted" },
    { 0x2311, "crash_lighting_goliath_dof" },
    { 0x2312, "crash_lighting_ice_caves_01" },
    { 0x2313, "crash_lighting_ice_caves_01_flare" },
    { 0x2314, "crash_lighting_ice_caves_02" },
    { 0x2315, "crash_lighting_lake_cinema" },
    { 0x2316, "crash_lighting_overlook" },
    { 0x2317, "crash_lighting_plane_fire" },
    { 0x2318, "crash_lighting_post_goliath_fall" },
    { 0x2319, "crash_lighting_skyjack_setup" },
    { 0x231A, "crash_lighting_underground_lake" },
    { 0x231B, "crash_logic" },
    { 0x231C, "crash_mechs" },
    { 0x231D, "crash_node" },
    { 0x231E, "crash_open_gate" },
    { 0x231F, "crash_open_left_gate" },
    { 0x2320, "crash_open_right_gate" },
    { 0x2321, "crash_overlay" },
    { 0x2322, "crash_overlook_sunflare" },
    { 0x2323, "crash_overlook_trigger" },
    { 0x2324, "crash_overlook_trigger_sunflare" },
    { 0x2325, "crash_path_check" },
    { 0x2326, "crash_plane_crash_ilona" },
    { 0x2327, "crash_precache" },
    { 0x2328, "crash_rumble" },
    { 0x2329, "crash_set_level_lighting_values" },
    { 0x232A, "crash_site_a10_gun_dive_1" },
    { 0x232B, "crash_site_a10_missile_dive_1" },
    { 0x232C, "crash_site_ally_drones" },
    { 0x232D, "crash_site_animnode" },
    { 0x232E, "crash_site_background_enemies" },
    { 0x232F, "crash_site_battle_chatter_chooser" },
    { 0x2330, "crash_site_battle_chatter_manager" },
    { 0x2331, "crash_site_battle_chatter_north" },
    { 0x2332, "crash_site_battle_chatter_south" },
    { 0x2333, "crash_site_bg_battle_chatter_north" },
    { 0x2334, "crash_site_bg_battle_chatter_south" },
    { 0x2335, "crash_site_bg_warbird_1" },
    { 0x2336, "crash_site_bg_warbird_2" },
    { 0x2337, "crash_site_bg_warbird_3" },
    { 0x2338, "crash_site_bg_warbirds" },
    { 0x2339, "crash_site_bunker_allies" },
    { 0x233A, "crash_site_bunker_sentinels" },
    { 0x233B, "crash_site_chutes" },
    { 0x233C, "crash_site_combat_manager" },
    { 0x233D, "crash_site_cormack" },
    { 0x233E, "crash_site_dead_razorback_guys" },
    { 0x233F, "crash_site_dialogue" },
    { 0x2340, "crash_site_drone" },
    { 0x2341, "crash_site_drones" },
    { 0x2342, "crash_site_drop_pod_enemies" },
    { 0x2343, "crash_site_drop_pod_manager" },
    { 0x2344, "crash_site_ilana" },
    { 0x2345, "crash_site_intro_killer" },
    { 0x2346, "crash_site_intro_killer2" },
    { 0x2347, "crash_site_jump_node_usage_scale" },
    { 0x2348, "crash_site_kill_counter" },
    { 0x2349, "crash_site_plane" },
    { 0x234A, "crash_site_plane_allies" },
    { 0x234B, "crash_site_player" },
    { 0x234C, "crash_site_player_gun" },
    { 0x234D, "crash_site_random_bg_explosion" },
    { 0x234E, "crash_site_random_playspace_explosion" },
    { 0x234F, "crash_site_razorback_allies" },
    { 0x2350, "crash_site_runway" },
    { 0x2351, "crash_speed" },
    { 0x2352, "crash_speed_ips" },
    { 0x2353, "crash_speed_mph" },
    { 0x2354, "crash_squad_take_cover" },
    { 0x2355, "crash_starts" },
    { 0x2356, "crash_struct" },
    { 0x2357, "crash_time" },
    { 0x2358, "crash_wakeup" },
    { 0x2359, "crashed" },
    { 0x235A, "crashed_pod_rotation" },
    { 0x235B, "crashedc17_missile_org" },
    { 0x235C, "crashfx" },
    { 0x235D, "crashing" },
    { 0x235E, "crashing_plane" },
    { 0x235F, "crashplane" },
    { 0x2360, "crashpos" },
    { 0x2361, "crate" },
    { 0x2362, "crate_calculate_on_path_grid" },
    { 0x2363, "crate_can_use" },
    { 0x2364, "crate_can_use_always" },
    { 0x2365, "crate_count" },
    { 0x2366, "crate_get_bot_target" },
    { 0x2367, "crate_get_nearest_valid_nodes" },
    { 0x2368, "crate_has_landed" },
    { 0x2369, "crate_in_range" },
    { 0x236A, "crate_is_on_path_grid" },
    { 0x236B, "crate_landed_and_on_path_grid" },
    { 0x236C, "crate_low_ammo_check" },
    { 0x236D, "crate_monitor_position" },
    { 0x236E, "crate_move_start" },
    { 0x236F, "crate_path_start" },
    { 0x2370, "crate_picked_up" },
    { 0x2371, "crate_should_claim" },
    { 0x2372, "crate_wait_use" },
    { 0x2373, "crateallcapturethinkhorde" },
    { 0x2374, "cratedetectstopphysics" },
    { 0x2375, "cratehandledamagecallback" },
    { 0x2376, "crateimpactcleanup" },
    { 0x2377, "cratemaxval" },
    { 0x2378, "cratemodelplayerupdater" },
    { 0x2379, "cratemodelteamupdater" },
    { 0x237A, "cratenonownerusetime" },
    { 0x237B, "crateothercapturethink" },
    { 0x237C, "crateownercapturethink" },
    { 0x237D, "crateownerdoubletapthink" },
    { 0x237E, "crateownerusetime" },
    { 0x237F, "cratesetupforuse" },
    { 0x2380, "cratesetuphintstrings" },
    { 0x2381, "crateteammodelupdater" },
    { 0x2382, "cratetrapsetupkillcam" },
    { 0x2383, "cratetype" },
    { 0x2384, "cratetypeisexcluded" },
    { 0x2385, "cratetypes" },
    { 0x2386, "crateusejuggernautupdater" },
    { 0x2387, "crateusepostjuggernautupdater" },
    { 0x2388, "crateuseteamupdater" },
    { 0x2389, "crawl_fx" },
    { 0x238A, "crawl_fx_rate" },
    { 0x238B, "crawl_target_and_init_flags" },
    { 0x238C, "crawl_through_targets_to_init_flags" },
    { 0x238D, "crawled" },
    { 0x238E, "crawlingpain" },
    { 0x238F, "crawlingpainanimoverridefunc" },
    { 0x2390, "crawlingpaintransanim" },
    { 0x2391, "crawlingpistol" },
    { 0x2392, "crch_exp_npc_cloak_buttons" },
    { 0x2393, "crch_lft_npc_cloak_buttons" },
    { 0x2394, "crch_rt_npc_cloak_buttons" },
    { 0x2395, "creaky_board" },
    { 0x2396, "create_active_zone" },
    { 0x2397, "create_ads_hint_string" },
    { 0x2398, "create_anim_ent_for_my_position" },
    { 0x2399, "create_anim_scene" },
    { 0x239A, "create_animation_list" },
    { 0x239B, "create_array_of_intel_items" },
    { 0x239C, "create_array_of_origins_from_table" },
    { 0x239D, "create_badplace" },
    { 0x239E, "create_black_screen" },
    { 0x239F, "create_blend" },
    { 0x23A0, "create_bot_badplaces" },
    { 0x23A1, "create_chyron_text" },
    { 0x23A2, "create_client_overlay" },
    { 0x23A3, "create_client_overlay_custom_size" },
    { 0x23A4, "create_client_overlay_fullscreen" },
    { 0x23A5, "create_clientside_water_ents" },
    { 0x23A6, "create_common_envelop_arrays" },
    { 0x23A7, "create_confrontation_static_overlay" },
    { 0x23A8, "create_conversation_arrays" },
    { 0x23A9, "create_debug_text_hud" },
    { 0x23AA, "create_default_vision_set_fog" },
    { 0x23AB, "create_dof_preset" },
    { 0x23AC, "create_dof_viewmodel_preset" },
    { 0x23AD, "create_drone_kamikazes" },
    { 0x23AE, "create_dvar" },
    { 0x23AF, "create_dynamicambience" },
    { 0x23B0, "create_exo_temperature_hud" },
    { 0x23B1, "create_exploders_fromlist" },
    { 0x23B2, "create_flags_and_return_tokens" },
    { 0x23B3, "create_flickerlight_motion_preset" },
    { 0x23B4, "create_flickerlight_preset" },
    { 0x23B5, "create_foam_matrix" },
    { 0x23B6, "create_fog" },
    { 0x23B7, "create_fresh_friendly_icon" },
    { 0x23B8, "create_fx_ent_setup" },
    { 0x23B9, "create_fx_menu" },
    { 0x23BA, "create_fxlighting_object" },
    { 0x23BB, "create_gamemessage_text" },
    { 0x23BC, "create_hud_drone_overlay" },
    { 0x23BD, "create_hud_drone_target" },
    { 0x23BE, "create_hud_laser_crosshair" },
    { 0x23BF, "create_hud_nvg_overlay" },
    { 0x23C0, "create_hud_sonar_overlay" },
    { 0x23C1, "create_hud_static_overlay" },
    { 0x23C2, "create_hud_threat_overlay" },
    { 0x23C3, "create_interval_sound" },
    { 0x23C4, "create_level_envelop_arrays" },
    { 0x23C5, "create_level_misc_arrays" },
    { 0x23C6, "create_light_object" },
    { 0x23C7, "create_light_set" },
    { 0x23C8, "create_lock" },
    { 0x23C9, "create_looper" },
    { 0x23CA, "create_loopsound" },
    { 0x23CB, "create_mantle" },
    { 0x23CC, "create_mg_team" },
    { 0x23CD, "create_missileattractor_on_player_chopper" },
    { 0x23CE, "create_new_spawner_pool" },
    { 0x23CF, "create_nvg_overlay" },
    { 0x23D0, "create_overlay_element" },
    { 0x23D1, "create_path" },
    { 0x23D2, "create_pivot" },
    { 0x23D3, "create_pulselight_preset" },
    { 0x23D4, "create_pulsing_text" },
    { 0x23D5, "create_random_animation" },
    { 0x23D6, "create_reflection_object" },
    { 0x23D7, "create_reflection_objects" },
    { 0x23D8, "create_slowmo_breaches_from_entities" },
    { 0x23D9, "create_start" },
    { 0x23DA, "create_strip" },
    { 0x23DB, "create_sunflare_setting" },
    { 0x23DC, "create_trigger_hint_string" },
    { 0x23DD, "create_triggerfx" },
    { 0x23DE, "create_vehicle_from_spawngroup_and_gopath" },
    { 0x23DF, "create_vision_set_fog" },
    { 0x23E0, "create_vision_set_vision" },
    { 0x23E1, "create_warning_elem" },
    { 0x23E2, "createairdropcrate" },
    { 0x23E3, "createart_transient_thread" },
    { 0x23E4, "createassaultuav" },
    { 0x23E5, "createbar" },
    { 0x23E6, "createbombsquadmodel" },
    { 0x23E7, "createcapzone" },
    { 0x23E8, "createcarriedobject" },
    { 0x23E9, "createcarryobject" },
    { 0x23EA, "createchatevent" },
    { 0x23EB, "createchatphrase" },
    { 0x23EC, "createclientbar" },
    { 0x23ED, "createclientfontstring" },
    { 0x23EE, "createclientfontstring_func" },
    { 0x23EF, "createclienticon" },
    { 0x23F0, "createclientprogressbar" },
    { 0x23F1, "createclienttimer" },
    { 0x23F2, "createcollision" },
    { 0x23F3, "createdefaultbobsettings" },
    { 0x23F4, "createdefaultsmallbobsettings" },
    { 0x23F5, "createdogenemy" },
    { 0x23F6, "createdot" },
    { 0x23F7, "createdot_radius" },
    { 0x23F8, "createdroneenemy" },
    { 0x23F9, "createdynamicambience" },
    { 0x23FA, "createechoalias" },
    { 0x23FB, "createeffect" },
    { 0x23FC, "createempclientbar" },
    { 0x23FD, "createenemy" },
    { 0x23FE, "createexploder" },
    { 0x23FF, "createexploderex" },
    { 0x2400, "createexplosivedrone" },
    { 0x2401, "createfontstring" },
    { 0x2402, "createfx" },
    { 0x2403, "createfx_adjust_array" },
    { 0x2404, "createfx_autosave" },
    { 0x2405, "createfx_centerprint" },
    { 0x2406, "createfx_centerprint_thread" },
    { 0x2407, "createfx_common" },
    { 0x2408, "createfx_draw_enabled" },
    { 0x2409, "createfx_enabled" },
    { 0x240A, "createfx_filter_types" },
    { 0x240B, "createfx_help_active" },
    { 0x240C, "createfx_help_keys" },
    { 0x240D, "createfx_inputlocked" },
    { 0x240E, "createfx_last_movement_timer" },
    { 0x240F, "createfx_loopcounter" },
    { 0x2410, "createfx_menu_list_active" },
    { 0x2411, "createfx_offset" },
    { 0x2412, "createfx_only_triggers" },
    { 0x2413, "createfx_print3d" },
    { 0x2414, "createfx_selecting" },
    { 0x2415, "createfxbyfxid" },
    { 0x2416, "createfxcursor" },
    { 0x2417, "createfxent" },
    { 0x2418, "createfxent_redo" },
    { 0x2419, "createfxent_undo" },
    { 0x241A, "createfxexploders" },
    { 0x241B, "createfxlogic" },
    { 0x241C, "createfxmasks" },
    { 0x241D, "creategastrackingoverlay" },
    { 0x241E, "createhordecrates" },
    { 0x241F, "createhumanoidenemy" },
    { 0x2420, "createicon" },
    { 0x2421, "createicon_hudelem" },
    { 0x2422, "createintervalsound" },
    { 0x2423, "createjuggernautoverlay" },
    { 0x2424, "createkillcamentity" },
    { 0x2425, "createlasertagarray" },
    { 0x2426, "createline" },
    { 0x2427, "createlineconstantly" },
    { 0x2428, "createloopeffect" },
    { 0x2429, "createloopsound" },
    { 0x242A, "createmissileoverlay" },
    { 0x242B, "createmission" },
    { 0x242C, "createmovingbadplace" },
    { 0x242D, "createnewexploder" },
    { 0x242E, "createoneshoteffect" },
    { 0x242F, "createorbitaltimer" },
    { 0x2430, "createoverlay" },
    { 0x2431, "createplaceable" },
    { 0x2432, "createplayerdroppod" },
    { 0x2433, "createplayersegmentstats" },
    { 0x2434, "createplayervariables" },
    { 0x2435, "createprimaryprogressbar" },
    { 0x2436, "createprimaryprogressbartext" },
    { 0x2437, "createprisonturrettrackingoverlay" },
    { 0x2438, "createreactiveent" },
    { 0x2439, "createreconuav" },
    { 0x243A, "createrpgrepulsors" },
    { 0x243B, "createsentryforplayer" },
    { 0x243C, "createserverbar" },
    { 0x243D, "createserverfontstring" },
    { 0x243E, "createservericon" },
    { 0x243F, "createservertimer" },
    { 0x2440, "createsniperimpulse" },
    { 0x2441, "createsquad" },
    { 0x2442, "createteamflag" },
    { 0x2443, "createteamobjpoint" },
    { 0x2444, "createteamprogressbar" },
    { 0x2445, "createteamprogressbartext" },
    { 0x2446, "createthreaticon" },
    { 0x2447, "createtimer" },
    { 0x2448, "createtrackingdrone" },
    { 0x2449, "createturret" },
    { 0x244A, "createturretforplayer" },
    { 0x244B, "createuseent" },
    { 0x244C, "createuseobject" },
    { 0x244D, "credits_active" },
    { 0x244E, "credits_alpha" },
    { 0x244F, "credits_data1" },
    { 0x2450, "credits_data2" },
    { 0x2451, "credits_display_think" },
    { 0x2452, "credits_end" },
    { 0x2453, "credits_spacing" },
    { 0x2454, "credits_speed" },
    { 0x2455, "credits_start" },
    { 0x2456, "crevasse_area_2_special" },
    { 0x2457, "crevasse_combat_wave_1" },
    { 0x2458, "crevasse_impact_ground" },
    { 0x2459, "crevasse_impact_wall" },
    { 0x245A, "crevasse_initial_group" },
    { 0x245B, "crevasse_ledge_adjustment" },
    { 0x245C, "crevasse_player_fall_down" },
    { 0x245D, "crevasse_player_get_up" },
    { 0x245E, "crevasse_player_impact_ground" },
    { 0x245F, "crevasse_player_impact_ground_throttled" },
    { 0x2460, "crevasse_player_impact_wall" },
    { 0x2461, "crevasse_player_slide_end" },
    { 0x2462, "crevasse_player_slide_hands" },
    { 0x2463, "crevasse_slide_end" },
    { 0x2464, "crevasse_slide_hands" },
    { 0x2465, "crevasse_upper" },
    { 0x2466, "crevasse_upper_cancelled" },
    { 0x2467, "crevasse_wave_1_cleaup" },
    { 0x2468, "crevasse_wave_1_drop" },
    { 0x2469, "crevasse_wave_1_left" },
    { 0x246A, "crevasse_wave_1_left_special" },
    { 0x246B, "crevasse_wave_1_mid" },
    { 0x246C, "crevasse_wave_1_right" },
    { 0x246D, "crevasse_wave_2" },
    { 0x246E, "crevasse_wave_3" },
    { 0x246F, "crib_debug" },
    { 0x2470, "critical_factor" },
    { 0x2471, "criticalfactors_awayfromenemies" },
    { 0x2472, "criticalfactors_domination" },
    { 0x2473, "criticalfactors_freeforall" },
    { 0x2474, "criticalfactors_global" },
    { 0x2475, "criticalfactors_safeguard" },
    { 0x2476, "criticalfactors_searchandrescue" },
    { 0x2477, "criticalresult" },
    { 0x2478, "cross2d" },
    { 0x2479, "crossbowstickevent" },
    { 0x247A, "crossing_into_alley" },
    { 0x247B, "crossproduct" },
    { 0x247C, "crouch_button_reset" },
    { 0x247D, "crouch_speed_scalar" },
    { 0x247E, "crouch_until_door_open" },
    { 0x247F, "crouch_until_path_to_door" },
    { 0x2480, "crouch_visible_from" },
    { 0x2481, "crouch_watcher" },
    { 0x2482, "crouchingisok" },
    { 0x2483, "crouchmovementsetspeed" },
    { 0x2484, "crouchrun_begin" },
    { 0x2485, "crouchrun_combatanim" },
    { 0x2486, "crouchrun_runnormal" },
    { 0x2487, "crouchrun_runoverride" },
    { 0x2488, "crouchruntocrouch" },
    { 0x2489, "crouchruntoprone" },
    { 0x248A, "crouchruntopronerun" },
    { 0x248B, "crouchruntopronewalk" },
    { 0x248C, "crouchruntostand" },
    { 0x248D, "crouchstatelistener" },
    { 0x248E, "crouchstop_begin" },
    { 0x248F, "crouchtocrouchrun" },
    { 0x2490, "crouchtocrouchwalk" },
    { 0x2491, "crouchtoprone" },
    { 0x2492, "crouchtopronerun" },
    { 0x2493, "crouchtopronewalk" },
    { 0x2494, "crouchtostand" },
    { 0x2495, "crouchtostandrun" },
    { 0x2496, "crouchtostandwalk" },
    { 0x2497, "crouchwalk_begin" },
    { 0x2498, "crouchwalktocrouch" },
    { 0x2499, "crouchwalktostand" },
    { 0x249A, "crumble_hoodoo_fx" },
    { 0x249B, "crvplrhitground" },
    { 0x249C, "cs_intro_bg_plane_breach" },
    { 0x249D, "cs_intro_cormack_jetpack_off" },
    { 0x249E, "cs_intro_cormack_land" },
    { 0x249F, "cs_intro_cormack_ready_gun" },
    { 0x24A0, "cs_intro_cormack_remove_jetpack" },
    { 0x24A1, "cs_intro_ilona_hand_over_gun" },
    { 0x24A2, "cs_intro_plane_jumper_boost" },
    { 0x24A3, "cs_intro_plane_jumper_drop_to_ground" },
    { 0x24A4, "cs_intro_plane_jumper_land" },
    { 0x24A5, "cs_intro_player_remove_jetpack" },
    { 0x24A6, "csv_include" },
    { 0x24A7, "csv_lines" },
    { 0x24A8, "ct_enemies" },
    { 0x24A9, "ct_enemies_final_runaway_faceplayer" },
    { 0x24AA, "ct_enemies_runaway_faceplayer" },
    { 0x24AB, "ctf" },
    { 0x24AC, "ctf_bot_attacker_limit_for_team" },
    { 0x24AD, "ctf_bot_defender_limit_for_team" },
    { 0x24AE, "ctf_loadouts" },
    { 0x24AF, "ctf_second_zones" },
    { 0x24B0, "cuc_rotation_offset" },
    { 0x24B1, "cuc_scale" },
    { 0x24B2, "cuc_translation" },
    { 0x24B3, "cue_cash" },
    { 0x24B4, "cuff" },
    { 0x24B5, "cull_distance_triggers" },
    { 0x24B6, "cull_spawners_from_killspawner" },
    { 0x24B7, "cull_spawners_leaving_one_set" },
    { 0x24B8, "cur" },
    { 0x24B9, "cur_camoffset_ratio" },
    { 0x24BA, "cur_defend_angle_override" },
    { 0x24BB, "cur_defend_node" },
    { 0x24BC, "cur_defend_point_override" },
    { 0x24BD, "cur_defend_stance" },
    { 0x24BE, "cur_local_angles" },
    { 0x24BF, "cur_node" },
    { 0x24C0, "cur_point" },
    { 0x24C1, "cur_tank_target" },
    { 0x24C2, "curautosave" },
    { 0x24C3, "curclass" },
    { 0x24C4, "curdefvalue" },
    { 0x24C5, "curevent" },
    { 0x24C6, "curmeleetarget" },
    { 0x24C7, "curobjid" },
    { 0x24C8, "curorigin" },
    { 0x24C9, "curprogress" },
    { 0x24CA, "curr" },
    { 0x24CB, "curr_ambi_submix" },
    { 0x24CC, "curr_cue_name" },
    { 0x24CD, "curr_dist" },
    { 0x24CE, "curr_intensity" },
    { 0x24CF, "curr_io" },
    { 0x24D0, "curr_music_submix" },
    { 0x24D1, "curr_preset" },
    { 0x24D2, "curr_state" },
    { 0x24D3, "curr_time" },
    { 0x24D4, "current_aim_offset" },
    { 0x24D5, "current_air_space" },
    { 0x24D6, "current_anim" },
    { 0x24D7, "current_anim_data_scene" },
    { 0x24D8, "current_anim_vm" },
    { 0x24D9, "current_betrayal_boat_vision_fog" },
    { 0x24DA, "current_cam_target" },
    { 0x24DB, "current_cinematic" },
    { 0x24DC, "current_color_order" },
    { 0x24DD, "current_dir" },
    { 0x24DE, "current_elevation" },
    { 0x24DF, "current_enemy" },
    { 0x24E0, "current_ent" },
    { 0x24E1, "current_event" },
    { 0x24E2, "current_exo_guys_alive" },
    { 0x24E3, "current_fallbackers" },
    { 0x24E4, "current_filters" },
    { 0x24E5, "current_flag" },
    { 0x24E6, "current_follow_path" },
    { 0x24E7, "current_fov" },
    { 0x24E8, "current_gen_hangar_door_open" },
    { 0x24E9, "current_global_hint" },
    { 0x24EA, "current_goal_offset" },
    { 0x24EB, "current_goal_position" },
    { 0x24EC, "current_hint" },
    { 0x24ED, "current_hit_count" },
    { 0x24EE, "current_landing_fx" },
    { 0x24EF, "current_median_speed" },
    { 0x24F0, "current_mode_hud" },
    { 0x24F1, "current_objective" },
    { 0x24F2, "current_occlusion" },
    { 0x24F3, "current_pitch" },
    { 0x24F4, "current_point_was_authored" },
    { 0x24F5, "current_pos" },
    { 0x24F6, "current_preset_name" },
    { 0x24F7, "current_projectile" },
    { 0x24F8, "current_reverb" },
    { 0x24F9, "current_speed" },
    { 0x24FA, "current_stance_func" },
    { 0x24FB, "current_start" },
    { 0x24FC, "current_sunflare_setting" },
    { 0x24FD, "current_target" },
    { 0x24FE, "current_target_aim_begin_time_ms" },
    { 0x24FF, "current_traverse_anime" },
    { 0x2500, "current_turret_target" },
    { 0x2501, "current_velocity" },
    { 0x2502, "current_vo" },
    { 0x2503, "current_warbird_weapon" },
    { 0x2504, "current_weapon" },
    { 0x2505, "current_wheel_pos" },
    { 0x2506, "current_yaw" },
    { 0x2507, "current_zone" },
    { 0x2508, "currentactivevehiclecount" },
    { 0x2509, "currentaliveenemycount" },
    { 0x250A, "currentammopickupcount" },
    { 0x250B, "currentcaralarms" },
    { 0x250C, "currentcolorcode" },
    { 0x250D, "currentcolorforced" },
    { 0x250E, "currentcovernode" },
    { 0x250F, "currentdefendloc" },
    { 0x2510, "currentdialogimportance" },
    { 0x2511, "currentdialognotifystring" },
    { 0x2512, "currentdialogsound" },
    { 0x2513, "currentdodgeanim" },
    { 0x2514, "currentenemycount" },
    { 0x2515, "currentfirefightshots" },
    { 0x2516, "currenthealth" },
    { 0x2517, "currentkillstreakindex" },
    { 0x2518, "currentkillstreaks" },
    { 0x2519, "currentleaderdialoggroup" },
    { 0x251A, "currently_anim_reaching" },
    { 0x251B, "currently_burst_firing" },
    { 0x251C, "currently_handling_player_damage" },
    { 0x251D, "currentnode" },
    { 0x251E, "currentpickupcount" },
    { 0x251F, "currentpointtotal" },
    { 0x2520, "currentroundnumber" },
    { 0x2521, "currentscore" },
    { 0x2522, "currentselectedclass" },
    { 0x2523, "currentsessiontime" },
    { 0x2524, "currentshotguncovernode" },
    { 0x2525, "currentstate" },
    { 0x2526, "currenttarget" },
    { 0x2527, "currentteamintelname" },
    { 0x2528, "currenttime" },
    { 0x2529, "currenttracecount" },
    { 0x252A, "currenttrackingyaw" },
    { 0x252B, "currenttrackingyawspeed" },
    { 0x252C, "currentvelocity" },
    { 0x252D, "currentweapon" },
    { 0x252E, "currentweaponatspawn" },
    { 0x252F, "custom_aim_animscript" },
    { 0x2530, "custom_aim_notetracks" },
    { 0x2531, "custom_anim_wait" },
    { 0x2532, "custom_animation" },
    { 0x2533, "custom_animscript" },
    { 0x2534, "custom_battlechatter" },
    { 0x2535, "custom_battlechatter_init_valid_phrases" },
    { 0x2536, "custom_battlechatter_internal" },
    { 0x2537, "custom_battlechatter_validate_phrase" },
    { 0x2538, "custom_callback" },
    { 0x2539, "custom_careful_radius" },
    { 0x253A, "custom_crawl_sound" },
    { 0x253B, "custom_crawling_death_array" },
    { 0x253C, "custom_death_script" },
    { 0x253D, "custom_deathsound" },
    { 0x253E, "custom_dismount_hint_return_when_dismounted" },
    { 0x253F, "custom_distance_along_path_think" },
    { 0x2540, "custom_dof_trace" },
    { 0x2541, "custom_dust_kickup" },
    { 0x2542, "custom_followpath_parameter_func" },
    { 0x2543, "custom_friendly_fire_message" },
    { 0x2544, "custom_friendly_fire_shader" },
    { 0x2545, "custom_gameskill_func" },
    { 0x2546, "custom_giveloadout" },
    { 0x2547, "custom_health_think" },
    { 0x2548, "custom_idle_trans_function" },
    { 0x2549, "custom_landing" },
    { 0x254A, "custom_laser_function" },
    { 0x254B, "custom_linkto_slide" },
    { 0x254C, "custom_no_game_setupfunc" },
    { 0x254D, "custom_player_attacker" },
    { 0x254E, "custom_radius_damage_for_exploders" },
    { 0x254F, "custom_regen_think" },
    { 0x2550, "customangles" },
    { 0x2551, "customanim" },
    { 0x2552, "customarrivalfunc" },
    { 0x2553, "customautosavecheck" },
    { 0x2554, "custombadplacethread" },
    { 0x2555, "custombcs_validphrases" },
    { 0x2556, "custombreathingtime" },
    { 0x2557, "customchatevent" },
    { 0x2558, "customchatphrase" },
    { 0x2559, "customclasspickcount" },
    { 0x255A, "customcratefunc" },
    { 0x255B, "customfunc" },
    { 0x255C, "customhealth" },
    { 0x255D, "customidleanimset" },
    { 0x255E, "customidleanimweights" },
    { 0x255F, "customidlesound" },
    { 0x2560, "customidletransitionfunc" },
    { 0x2561, "customkillstreakcratemodules" },
    { 0x2562, "custommaxhealth" },
    { 0x2563, "custommoveanimset" },
    { 0x2564, "custommovetransition" },
    { 0x2565, "custommovetransitionfunc" },
    { 0x2566, "customnotetrackfx" },
    { 0x2567, "customreactanime" },
    { 0x2568, "customrunningreacttobullets" },
    { 0x2569, "customunloadfunc" },
    { 0x256A, "cut" },
    { 0x256B, "cutoff_distance_current" },
    { 0x256C, "cutoff_distance_goal" },
    { 0x256D, "cutoff_falloff_current" },
    { 0x256E, "cutoff_falloff_goal" },
    { 0x256F, "cutter" },
    { 0x2570, "cvrdrn_paired_anim_explo" },
    { 0x2571, "cvrdrn_paired_anim_start" },
    { 0x2572, "cycle_charging_hud" },
    { 0x2573, "cycle_offhand_grenade" },
    { 0x2574, "dam_destroyed" },
    { 0x2575, "dam_enemies" },
    { 0x2576, "dam_explode" },
    { 0x2577, "dam_objective" },
    { 0x2578, "dam_targ" },
    { 0x2579, "dam_target_death" },
    { 0x257A, "damage_accumulation_clip" },
    { 0x257B, "damage_allowed" },
    { 0x257C, "damage_change_goal" },
    { 0x257D, "damage_feedback_setup" },
    { 0x257E, "damage_functions" },
    { 0x257F, "damage_fx" },
    { 0x2580, "damage_hint_bullet_only" },
    { 0x2581, "damage_hints" },
    { 0x2582, "damage_hints_cleanup" },
    { 0x2583, "damage_info" },
    { 0x2584, "damage_is_explosive" },
    { 0x2585, "damage_is_valid_for_friendlyfire_warning" },
    { 0x2586, "damage_mirror" },
    { 0x2587, "damage_multiplier_mod" },
    { 0x2588, "damage_not" },
    { 0x2589, "damage_part_area" },
    { 0x258A, "damage_scale" },
    { 0x258B, "damage_sound_time" },
    { 0x258C, "damage_type" },
    { 0x258D, "damageattacker" },
    { 0x258E, "damagecallback" },
    { 0x258F, "damagecenter" },
    { 0x2590, "damaged" },
    { 0x2591, "damaged_fire" },
    { 0x2592, "damaged_parts" },
    { 0x2593, "damaged_planter" },
    { 0x2594, "damaged_turbine_1" },
    { 0x2595, "damaged_turbine_2" },
    { 0x2596, "damagedealttoofast" },
    { 0x2597, "damagedlensviewmodel" },
    { 0x2598, "damagedone" },
    { 0x2599, "damagedownertome" },
    { 0x259A, "damagedplayers" },
    { 0x259B, "damageent" },
    { 0x259C, "damagefade" },
    { 0x259D, "damagefeedback" },
    { 0x259E, "damagefeedback_took_damage" },
    { 0x259F, "damagefeedbackhud" },
    { 0x25A0, "damagefeedbacksnd" },
    { 0x25A1, "damagefeedbacktimer" },
    { 0x25A2, "damageinfo" },
    { 0x25A3, "damageinfocolorindex" },
    { 0x25A4, "damageinfovictim" },
    { 0x25A5, "damageisfromplayer" },
    { 0x25A6, "damagelocationisany" },
    { 0x25A7, "damagemodel" },
    { 0x25A8, "damageorigin" },
    { 0x25A9, "damageowner" },
    { 0x25AA, "damagepoint" },
    { 0x25AB, "damageradius" },
    { 0x25AC, "damagereceivedtoofast" },
    { 0x25AD, "damageringsarray" },
    { 0x25AE, "damageshellshockandrumble" },
    { 0x25AF, "damageshieldcounter" },
    { 0x25B0, "damageshieldpain" },
    { 0x25B1, "damagethendestroyriotshield" },
    { 0x25B2, "damagetracking" },
    { 0x25B3, "damb" },
    { 0x25B4, "damb_animal_sfx_offset" },
    { 0x25B5, "damb_enable" },
    { 0x25B6, "damb_init" },
    { 0x25B7, "damb_link_to_damb" },
    { 0x25B8, "damb_make_linked_damb" },
    { 0x25B9, "damb_manual_trigger" },
    { 0x25BA, "damb_pause_damb" },
    { 0x25BB, "damb_prob_mix_damb_presets" },
    { 0x25BC, "damb_set_max_entities" },
    { 0x25BD, "damb_set_oneshot_callback_for_component" },
    { 0x25BE, "damb_set_oneshot_callback_for_dynamic_ambience" },
    { 0x25BF, "damb_start_preset" },
    { 0x25C0, "damb_start_preset_at_point" },
    { 0x25C1, "damb_start_preset_on_entity" },
    { 0x25C2, "damb_stop" },
    { 0x25C3, "damb_stop_preset" },
    { 0x25C4, "damb_stop_preset_at_point" },
    { 0x25C5, "damb_stop_zone" },
    { 0x25C6, "damb_unpause_damb" },
    { 0x25C7, "damb_use_string_table" },
    { 0x25C8, "damb_zone_start_preset" },
    { 0x25C9, "damb_zone_stop_preset" },
    { 0x25CA, "damb1_name" },
    { 0x25CB, "damb2_name" },
    { 0x25CC, "dambinfostruct" },
    { 0x25CD, "dambx_create_damb_event" },
    { 0x25CE, "dambx_fade_out_playing_loop" },
    { 0x25CF, "dambx_fade_out_playing_sound" },
    { 0x25D0, "dambx_get_component_data" },
    { 0x25D1, "dambx_get_component_from_string_table" },
    { 0x25D2, "dambx_get_component_from_string_table_internal" },
    { 0x25D3, "dambx_get_component_preset" },
    { 0x25D4, "dambx_get_damb_preset" },
    { 0x25D5, "dambx_get_list_value_from_string_table" },
    { 0x25D6, "dambx_get_loop_def_from_string_table" },
    { 0x25D7, "dambx_get_loop_def_from_string_table_internal" },
    { 0x25D8, "dambx_get_loop_preset" },
    { 0x25D9, "dambx_get_preset_from_string_table" },
    { 0x25DA, "dambx_get_preset_from_stringtable_internal" },
    { 0x25DB, "dambx_get_two_value_float_array" },
    { 0x25DC, "dambx_make_first_wait" },
    { 0x25DD, "dambx_monitor_damb_point_distance" },
    { 0x25DE, "dambx_monitor_single_loops_on_ent" },
    { 0x25DF, "dambx_perform_loop_event" },
    { 0x25E0, "dambx_perform_oneshot_event" },
    { 0x25E1, "dambx_perform_play_event" },
    { 0x25E2, "dambx_pick_random_alias" },
    { 0x25E3, "dambx_pick_random_component" },
    { 0x25E4, "dambx_play" },
    { 0x25E5, "dambx_play_component_loops" },
    { 0x25E6, "dambx_start_linked_dambs" },
    { 0x25E7, "dambx_start_preset" },
    { 0x25E8, "dambx_stop_preset" },
    { 0x25E9, "dambx_trigger_linked_damb" },
    { 0x25EA, "dambx_update" },
    { 0x25EB, "dambx_update_serially" },
    { 0x25EC, "dambx_wait_till_sound_done_and_remove_handle" },
    { 0x25ED, "dangerforwardpush" },
    { 0x25EE, "dangermaxradius" },
    { 0x25EF, "dangerminradius" },
    { 0x25F0, "dangerovalscale" },
    { 0x25F1, "dangersprinttime" },
    { 0x25F2, "dangerzone_enemy_seek_player" },
    { 0x25F3, "dangle" },
    { 0x25F4, "darkscreenoverlay" },
    { 0x25F5, "dash" },
    { 0x25F6, "data" },
    { 0x25F7, "data_index" },
    { 0x25F8, "dazed_sky_bridge_explosions" },
    { 0x25F9, "dc_old_moveplaybackrate" },
    { 0x25FA, "dds" },
    { 0x25FB, "dds_ai_init" },
    { 0x25FC, "dds_characterid" },
    { 0x25FD, "dds_clear_all_queued_events" },
    { 0x25FE, "dds_clear_all_queued_events_axis" },
    { 0x25FF, "dds_clear_old_expired_events" },
    { 0x2600, "dds_clear_old_expired_events_axis" },
    { 0x2601, "dds_disable" },
    { 0x2602, "dds_dmg_attacker" },
    { 0x2603, "dds_enable" },
    { 0x2604, "dds_event_activate" },
    { 0x2605, "dds_event_activate_play" },
    { 0x2606, "dds_exclude_this_ai" },
    { 0x2607, "dds_find_infantry_threat" },
    { 0x2608, "dds_find_threats" },
    { 0x2609, "dds_get_ai_id" },
    { 0x260A, "dds_get_alias_from_event" },
    { 0x260B, "dds_get_alias_from_name" },
    { 0x260C, "dds_get_non_ai_threats" },
    { 0x260D, "dds_getclock_position" },
    { 0x260E, "dds_init" },
    { 0x260F, "dds_killstreak_timer" },
    { 0x2610, "dds_main_process" },
    { 0x2611, "dds_main_process_axis" },
    { 0x2612, "dds_multikill_tracker" },
    { 0x2613, "dds_notify" },
    { 0x2614, "dds_notify_casualty" },
    { 0x2615, "dds_notify_grenade" },
    { 0x2616, "dds_notify_mod" },
    { 0x2617, "dds_notify_reload" },
    { 0x2618, "dds_notify_response" },
    { 0x2619, "dds_notify_threat" },
    { 0x261A, "dds_notify_threat_unique" },
    { 0x261B, "dds_process_active_events" },
    { 0x261C, "dds_process_active_events_axis" },
    { 0x261D, "dds_reinforcement_think" },
    { 0x261E, "dds_send_team_notify_on_disable" },
    { 0x261F, "dds_set_player_character_name" },
    { 0x2620, "dds_sort_ent_damage" },
    { 0x2621, "dds_sort_ent_dist" },
    { 0x2622, "dds_sort_ent_duration" },
    { 0x2623, "dds_threat_dir_stored" },
    { 0x2624, "dds_threat_guy" },
    { 0x2625, "dds_threat_mypos" },
    { 0x2626, "dds_watch_damage" },
    { 0x2627, "dds_watch_grenade_flee" },
    { 0x2628, "dds_watch_player_health" },
    { 0x2629, "deactivate" },
    { 0x262A, "deactivate_betrayal_exo_abilities" },
    { 0x262B, "deactivate_clientside_exploder" },
    { 0x262C, "deactivate_exo_ping" },
    { 0x262D, "deactivate_heater" },
    { 0x262E, "deactivate_index" },
    { 0x262F, "deactivate_reverb" },
    { 0x2630, "deactivate_targets" },
    { 0x2631, "deactivateagent" },
    { 0x2632, "deactivateagentdelayed" },
    { 0x2633, "deactivatedlaserfx" },
    { 0x2634, "dead_demo_team" },
    { 0x2635, "dead_guy_for_moors" },
    { 0x2636, "dead_mech_enemy" },
    { 0x2637, "dead_razorback_spawn" },
    { 0x2638, "dead_stinger_guy" },
    { 0x2639, "deaddriver" },
    { 0x263A, "deadquote_recently_used" },
    { 0x263B, "death_achievements" },
    { 0x263C, "death_achievements_rappel" },
    { 0x263D, "death_cleanup" },
    { 0x263E, "death_counter" },
    { 0x263F, "death_crash_nearby_player" },
    { 0x2640, "death_delayed_ragdoll" },
    { 0x2641, "death_firesound" },
    { 0x2642, "death_flop_dir" },
    { 0x2643, "death_fx_on_self" },
    { 0x2644, "death_invulnerable_activated" },
    { 0x2645, "death_model_override" },
    { 0x2646, "death_no_ragdoll" },
    { 0x2647, "death_out_of_control" },
    { 0x2648, "death_pit" },
    { 0x2649, "death_plummet" },
    { 0x264A, "death_rocket_out_of_control" },
    { 0x264B, "death_spining" },
    { 0x264C, "death_spiral" },
    { 0x264D, "death_state" },
    { 0x264E, "death_throw" },
    { 0x264F, "death_waiter" },
    { 0x2650, "death_watch" },
    { 0x2651, "death_watcher" },
    { 0x2652, "deathanim" },
    { 0x2653, "deathanimscript" },
    { 0x2654, "deathchain_goalvolume" },
    { 0x2655, "deathchainainotify" },
    { 0x2656, "deathchainspawnerlogic" },
    { 0x2657, "deathcleanup" },
    { 0x2658, "deathdamage_max" },
    { 0x2659, "deathdamage_min" },
    { 0x265A, "deatheffect" },
    { 0x265B, "deathflags" },
    { 0x265C, "deathfunc_rocket" },
    { 0x265D, "deathfunc_vol" },
    { 0x265E, "deathfunc_vrap" },
    { 0x265F, "deathfuncs" },
    { 0x2660, "deathfunction" },
    { 0x2661, "deathfunctions" },
    { 0x2662, "deathfx_ent" },
    { 0x2663, "deathoverridecallback" },
    { 0x2664, "deathposition" },
    { 0x2665, "deathrolloff" },
    { 0x2666, "deathrollon" },
    { 0x2667, "deathscript" },
    { 0x2668, "deathsdoor" },
    { 0x2669, "deathsdoor_enabled" },
    { 0x266A, "deathsoundsandfx" },
    { 0x266B, "deathspawner" },
    { 0x266C, "deathspawnerents" },
    { 0x266D, "deathspawnerpreview" },
    { 0x266E, "deathspin" },
    { 0x266F, "deathstring" },
    { 0x2670, "deathstring_passed" },
    { 0x2671, "deathtime" },
    { 0x2672, "debgugprintdestructiblelist" },
    { 0x2673, "debris" },
    { 0x2674, "debug" },
    { 0x2675, "debug_ai_count" },
    { 0x2676, "debug_all" },
    { 0x2677, "debug_anim_time" },
    { 0x2678, "debug_animsoundtag" },
    { 0x2679, "debug_animsoundtagselected" },
    { 0x267A, "debug_arrival" },
    { 0x267B, "debug_arrivals_on_actor" },
    { 0x267C, "debug_axis" },
    { 0x267D, "debug_bike_line" },
    { 0x267E, "debug_canal_breach_start" },
    { 0x267F, "debug_canal_start" },
    { 0x2680, "debug_character_count" },
    { 0x2681, "debug_check_allies_spawned" },
    { 0x2682, "debug_circle" },
    { 0x2683, "debug_circle_drawlines" },
    { 0x2684, "debug_color" },
    { 0x2685, "debug_color_friendlies" },
    { 0x2686, "debug_color_huds" },
    { 0x2687, "debug_colornodes" },
    { 0x2688, "debug_controls" },
    { 0x2689, "debug_corner" },
    { 0x268A, "debug_door_kick_start" },
    { 0x268B, "debug_draw" },
    { 0x268C, "debug_draw_aim" },
    { 0x268D, "debug_draw_anim_path" },
    { 0x268E, "debug_draw_arrow" },
    { 0x268F, "debug_draw_living_ai" },
    { 0x2690, "debug_draw_obstacles" },
    { 0x2691, "debug_draw_path" },
    { 0x2692, "debug_dumplightshadowstates" },
    { 0x2693, "debug_elements" },
    { 0x2694, "debug_enemy_jets_die" },
    { 0x2695, "debug_enemypos" },
    { 0x2696, "debug_enemyposproc" },
    { 0x2697, "debug_enemyposreplay" },
    { 0x2698, "debug_flashlight_basement_switch" },
    { 0x2699, "debug_fly" },
    { 0x269A, "debug_foam_tag" },
    { 0x269B, "debug_foot_passing" },
    { 0x269C, "debug_free_path" },
    { 0x269D, "debug_friendly_death" },
    { 0x269E, "debug_friendlyfire" },
    { 0x269F, "debug_fxlighting" },
    { 0x26A0, "debug_fxlighting_buttons" },
    { 0x26A1, "debug_graph" },
    { 0x26A2, "debug_graph_draw" },
    { 0x26A3, "debug_graph_init" },
    { 0x26A4, "debug_graph_init_key" },
    { 0x26A5, "debug_grapplep" },
    { 0x26A6, "debug_hero_pathing" },
    { 0x26A7, "debug_hud_elem" },
    { 0x26A8, "debug_hudinfo_landassist" },
    { 0x26A9, "debug_id" },
    { 0x26AA, "debug_irons_chase" },
    { 0x26AB, "debug_line" },
    { 0x26AC, "debug_lobby_start" },
    { 0x26AD, "debug_message" },
    { 0x26AE, "debug_message_ai" },
    { 0x26AF, "debug_message_clear" },
    { 0x26B0, "debug_monitor_for_all_cloaked_stealth_enemies" },
    { 0x26B1, "debug_nuke" },
    { 0x26B2, "debug_out_of_bounds_areas" },
    { 0x26B3, "debug_pathing" },
    { 0x26B4, "debug_player_fall" },
    { 0x26B5, "debug_player_in_post_clip" },
    { 0x26B6, "debug_print_guys_in_volume" },
    { 0x26B7, "debug_radiusdamage_circle" },
    { 0x26B8, "debug_reflection" },
    { 0x26B9, "debug_reflection_buttons" },
    { 0x26BA, "debug_roof_start" },
    { 0x26BB, "debug_seoul_canal_begin_combat" },
    { 0x26BC, "debug_seoul_canal_fight_to_weapon_platform" },
    { 0x26BD, "debug_seoul_canal_start" },
    { 0x26BE, "debug_seoul_finale_scene_start" },
    { 0x26BF, "debug_seoul_shopping_district_flee_swarm" },
    { 0x26C0, "debug_seoul_shopping_district_start" },
    { 0x26C1, "debug_seoul_sinkhole_start" },
    { 0x26C2, "debug_seoul_subway_start" },
    { 0x26C3, "debug_show_org" },
    { 0x26C4, "debug_show_origin" },
    { 0x26C5, "debug_show_pos" },
    { 0x26C6, "debug_show_pos_once" },
    { 0x26C7, "debug_show_vec" },
    { 0x26C8, "debug_show_walker_tank_health" },
    { 0x26C9, "debug_silo_approach_clut" },
    { 0x26CA, "debug_silo_approach_start" },
    { 0x26CB, "debug_silo_door_kick_clut" },
    { 0x26CC, "debug_silo_exhaust_entrance_clut" },
    { 0x26CD, "debug_silo_exhaust_entrance_start" },
    { 0x26CE, "debug_silo_floor_03_clut" },
    { 0x26CF, "debug_silo_floor_03_start" },
    { 0x26D0, "debug_skip_button_press" },
    { 0x26D1, "debug_sky_bridge_start" },
    { 0x26D2, "debug_snake_points" },
    { 0x26D3, "debug_start_alleyway" },
    { 0x26D4, "debug_start_big_cave" },
    { 0x26D5, "debug_start_bike_ride_in" },
    { 0x26D6, "debug_start_cave_entry" },
    { 0x26D7, "debug_start_cave_hallway" },
    { 0x26D8, "debug_start_cliff_rappel" },
    { 0x26D9, "debug_start_combat_cave" },
    { 0x26DA, "debug_start_common" },
    { 0x26DB, "debug_start_courtyard" },
    { 0x26DC, "debug_start_courtyard_jammer" },
    { 0x26DD, "debug_start_crash" },
    { 0x26DE, "debug_start_crash_site" },
    { 0x26DF, "debug_start_demo_with_itiot" },
    { 0x26E0, "debug_start_drive_in" },
    { 0x26E1, "debug_start_equip_player" },
    { 0x26E2, "debug_start_exfil" },
    { 0x26E3, "debug_start_exit_drive" },
    { 0x26E4, "debug_start_exit_drive_end" },
    { 0x26E5, "debug_start_exopush" },
    { 0x26E6, "debug_start_facility_breach" },
    { 0x26E7, "debug_start_foam_room" },
    { 0x26E8, "debug_start_forest_start" },
    { 0x26E9, "debug_start_forest_takedown" },
    { 0x26EA, "debug_start_hospital" },
    { 0x26EB, "debug_start_hospital_capture" },
    { 0x26EC, "debug_start_ice_bridge" },
    { 0x26ED, "debug_start_intro" },
    { 0x26EE, "debug_start_intro_skip" },
    { 0x26EF, "debug_start_lake" },
    { 0x26F0, "debug_start_lake_cinema" },
    { 0x26F1, "debug_start_logging_road" },
    { 0x26F2, "debug_start_mech_march" },
    { 0x26F3, "debug_start_narrow_cave" },
    { 0x26F4, "debug_start_nightclub" },
    { 0x26F5, "debug_start_overlook" },
    { 0x26F6, "debug_start_research_facility_bridge" },
    { 0x26F7, "debug_start_school_basement" },
    { 0x26F8, "debug_start_school_before_fall" },
    { 0x26F9, "debug_start_school_begin" },
    { 0x26FA, "debug_start_school_interior" },
    { 0x26FB, "debug_start_school_wall_grab" },
    { 0x26FC, "debug_start_sentinel_reveal" },
    { 0x26FD, "debug_start_server_room" },
    { 0x26FE, "debug_start_server_room_promo" },
    { 0x26FF, "debug_start_skyjack" },
    { 0x2700, "debug_start_tank_ascent" },
    { 0x2701, "debug_start_tank_board" },
    { 0x2702, "debug_start_tank_field" },
    { 0x2703, "debug_start_tank_field_left_fork" },
    { 0x2704, "debug_start_tank_field_right_fork" },
    { 0x2705, "debug_start_tank_hangar" },
    { 0x2706, "debug_start_tank_road" },
    { 0x2707, "debug_start_vtol_takedown" },
    { 0x2708, "debug_state" },
    { 0x2709, "debug_stealth" },
    { 0x270A, "debug_stealth_type" },
    { 0x270B, "debug_stopenemypos" },
    { 0x270C, "debug_tag" },
    { 0x270D, "debug_tag_camera" },
    { 0x270E, "debug_tag_internal" },
    { 0x270F, "debug_tags" },
    { 0x2710, "debug_test_next_mission" },
    { 0x2711, "debug_text" },
    { 0x2712, "debug_text_hud" },
    { 0x2713, "debug_timer" },
    { 0x2714, "debug_toggle" },
    { 0x2715, "debug_track" },
    { 0x2716, "debug_turrets" },
    { 0x2717, "debug_vehicle_node" },
    { 0x2718, "debug_vehicles" },
    { 0x2719, "debug_watch_dynamicevent_start_now" },
    { 0x271A, "debug_will_exo_breach" },
    { 0x271B, "debug_will_room_start" },
    { 0x271C, "debug_x4walker" },
    { 0x271D, "debugburstprint" },
    { 0x271E, "debugchains" },
    { 0x271F, "debugcircle" },
    { 0x2720, "debugcolorfriendlies" },
    { 0x2721, "debugcriticaldata" },
    { 0x2722, "debugdvars" },
    { 0x2723, "debugging_on" },
    { 0x2724, "debuggoalpos" },
    { 0x2725, "debugheight" },
    { 0x2726, "debughelper" },
    { 0x2727, "debugjump" },
    { 0x2728, "debugleft" },
    { 0x2729, "debugline" },
    { 0x272A, "debugmisstime" },
    { 0x272B, "debugmisstimeoff" },
    { 0x272C, "debugorigin" },
    { 0x272D, "debugplayerteleport" },
    { 0x272E, "debugpos" },
    { 0x272F, "debugposinternal" },
    { 0x2730, "debugpossize" },
    { 0x2731, "debugprint" },
    { 0x2732, "debugprint3dcontinuous" },
    { 0x2733, "debugscoredata" },
    { 0x2734, "debugskip_intro" },
    { 0x2735, "debugspawners" },
    { 0x2736, "debugstart_middle_takedown" },
    { 0x2737, "debugstart_post_middle_takedown" },
    { 0x2738, "debugthreat" },
    { 0x2739, "debugthreatcalc" },
    { 0x273A, "debugtimeout" },
    { 0x273B, "debugvar" },
    { 0x273C, "debugwavecount" },
    { 0x273D, "decel" },
    { 0x273E, "decide_to_change_lane" },
    { 0x273F, "decide_to_dodge" },
    { 0x2740, "decidenumcrawls" },
    { 0x2741, "decidenumshotsforburst" },
    { 0x2742, "decidenumshotsforfull" },
    { 0x2743, "decidewhatandhowtoshoot" },
    { 0x2744, "deck" },
    { 0x2745, "deck_dialog_rail_gun_secure" },
    { 0x2746, "deck_dialogue" },
    { 0x2747, "deck_drones" },
    { 0x2748, "deck_enemies_cleared" },
    { 0x2749, "deck_jammer_rumbles" },
    { 0x274A, "deck_jammers" },
    { 0x274B, "deck_navy_guys" },
    { 0x274C, "deck_reinforcement_ally_think" },
    { 0x274D, "deck_reinforcement_modify_accuracy" },
    { 0x274E, "decloak_intro_helicopter" },
    { 0x274F, "decloak_wait_1" },
    { 0x2750, "decloak_wait_2" },
    { 0x2751, "decloak_wait_3" },
    { 0x2752, "decloaking_model" },
    { 0x2753, "decon_finish" },
    { 0x2754, "decon_guy_walk_away" },
    { 0x2755, "decon_guy_walk_to" },
    { 0x2756, "decon_reverse_blocking" },
    { 0x2757, "decoy_hint_hud" },
    { 0x2758, "decreasegunlevelevent" },
    { 0x2759, "decrement_claimed_refcount" },
    { 0x275A, "decrement_firing_count_if_died_while_firing" },
    { 0x275B, "decrement_help_list_offset" },
    { 0x275C, "decrement_list_offset" },
    { 0x275D, "decrement_ref_count" },
    { 0x275E, "decrementalivecount" },
    { 0x275F, "decrementbulletsinclip" },
    { 0x2760, "decremented" },
    { 0x2761, "decrementfauxvehiclecount" },
    { 0x2762, "deep_array_call" },
    { 0x2763, "deep_array_thread" },
    { 0x2764, "deep_water_weapon" },
    { 0x2765, "deer_leaves_fx" },
    { 0x2766, "deer_sequence" },
    { 0x2767, "def" },
    { 0x2768, "def_asset_type" },
    { 0x2769, "def_fadein_time" },
    { 0x276A, "def_fadeout_time" },
    { 0x276B, "def_fire" },
    { 0x276C, "def_for_cuc_note" },
    { 0x276D, "def_input_name" },
    { 0x276E, "def_neon" },
    { 0x276F, "def_output_name" },
    { 0x2770, "def_output_scalar" },
    { 0x2771, "def_player_mode" },
    { 0x2772, "def_priority" },
    { 0x2773, "def_pulse" },
    { 0x2774, "def_smooth_down" },
    { 0x2775, "def_smooth_up" },
    { 0x2776, "def_sound_offset" },
    { 0x2777, "def_state_min_retrigger_time" },
    { 0x2778, "default_ball_origin" },
    { 0x2779, "default_class_chosen" },
    { 0x277A, "default_door_node_flashbang_frequency" },
    { 0x277B, "default_drop_pitch" },
    { 0x277C, "default_footsteps" },
    { 0x277D, "default_gametype_think" },
    { 0x277E, "default_goal_origins" },
    { 0x277F, "default_goalheight" },
    { 0x2780, "default_goalradius" },
    { 0x2781, "default_health" },
    { 0x2782, "default_hud" },
    { 0x2783, "default_loadout_if_notset" },
    { 0x2784, "default_ondeadevent" },
    { 0x2785, "default_onhalftime" },
    { 0x2786, "default_ononeleftevent" },
    { 0x2787, "default_ontimelimit" },
    { 0x2788, "default_player_dist" },
    { 0x2789, "default_reverb" },
    { 0x278A, "default_run_speed" },
    { 0x278B, "default_start" },
    { 0x278C, "default_start_override" },
    { 0x278D, "default_style" },
    { 0x278E, "default_sun_light" },
    { 0x278F, "default_target_vec" },
    { 0x2790, "default_unresolved_collision_handler" },
    { 0x2791, "default_vid_log_vol" },
    { 0x2792, "default_weapon" },
    { 0x2793, "defaultclass" },
    { 0x2794, "defaultdroppitch" },
    { 0x2795, "defaultdropyaw" },
    { 0x2796, "defaultexception" },
    { 0x2797, "defaultfxlightinglookup" },
    { 0x2798, "defaultidlestateoverride" },
    { 0x2799, "defaultmodel" },
    { 0x279A, "defaultmodellightinglookup" },
    { 0x279B, "defaultonmode" },
    { 0x279C, "defaults" },
    { 0x279D, "defaultstand" },
    { 0x279E, "defaultsundir" },
    { 0x279F, "defaultsunlight" },
    { 0x27A0, "defaultturnthreshold" },
    { 0x27A1, "defaultvalue" },
    { 0x27A2, "defaultweapon" },
    { 0x27A3, "defend_entrance_index" },
    { 0x27A4, "defend_flag" },
    { 0x27A5, "defend_get_ally_bots_at_zone_for_stance" },
    { 0x27A6, "defend_objective_radius" },
    { 0x27A7, "defend_planted_bomb_update" },
    { 0x27A8, "defend_valid_center" },
    { 0x27A9, "defend_zone" },
    { 0x27AA, "defendedplayerevent" },
    { 0x27AB, "defender_damage_func" },
    { 0x27AC, "defender_set_script_pathstyle" },
    { 0x27AD, "defender_update" },
    { 0x27AE, "defendobjectiveevent" },
    { 0x27AF, "defense_cautious_approach" },
    { 0x27B0, "defense_death_monitor" },
    { 0x27B1, "defense_force_next_node_goal" },
    { 0x27B2, "defense_get_initial_entrances" },
    { 0x27B3, "defense_investigate_specific_point" },
    { 0x27B4, "defense_override_entrances" },
    { 0x27B5, "defense_score_flags" },
    { 0x27B6, "defense_watch_entrances_at_goal" },
    { 0x27B7, "defenseless_tank_impact" },
    { 0x27B8, "define_loadout" },
    { 0x27B9, "defrate" },
    { 0x27BA, "defsmooth" },
    { 0x27BB, "defuseendtime" },
    { 0x27BC, "defuser_bad_path_counter" },
    { 0x27BD, "defuser_wait_for_death" },
    { 0x27BE, "defusethink" },
    { 0x27BF, "defusetime" },
    { 0x27C0, "delay" },
    { 0x27C1, "delay_drone_kamikaze_player" },
    { 0x27C2, "delay_from_any_hint_s" },
    { 0x27C3, "delay_from_kill_s" },
    { 0x27C4, "delay_from_same_hint_s" },
    { 0x27C5, "delay_linkto_anim" },
    { 0x27C6, "delay_oncoming_bypass_kill" },
    { 0x27C7, "delay_retreat" },
    { 0x27C8, "delay_script_call" },
    { 0x27C9, "delay_script_call_proc" },
    { 0x27CA, "delay_scripting_if_stealth_broken" },
    { 0x27CB, "delay_set_fall_damage" },
    { 0x27CC, "delay_show_bones" },
    { 0x27CD, "delaycall" },
    { 0x27CE, "delaycall_proc" },
    { 0x27CF, "delaychildthread" },
    { 0x27D0, "delaychildthread_proc" },
    { 0x27D1, "delaycleanupdroppod" },
    { 0x27D2, "delaycontrol" },
    { 0x27D3, "delaydelete" },
    { 0x27D4, "delaydeleteprompt" },
    { 0x27D5, "delaydestroy" },
    { 0x27D6, "delayed_cut" },
    { 0x27D7, "delayed_delete" },
    { 0x27D8, "delayed_delete_light" },
    { 0x27D9, "delayed_earthquake" },
    { 0x27DA, "delayed_exploded_guy_deletion" },
    { 0x27DB, "delayed_luinotifyserver" },
    { 0x27DC, "delayed_player_seek_think" },
    { 0x27DD, "delayed_takeweapon" },
    { 0x27DE, "delayedbadplace" },
    { 0x27DF, "delayeddialogue" },
    { 0x27E0, "delayedexception" },
    { 0x27E1, "delayedleaderdialog" },
    { 0x27E2, "delayedleaderdialogbothteams" },
    { 0x27E3, "delayedlocktargetent" },
    { 0x27E4, "delayedlocktargettag" },
    { 0x27E5, "delayedplayergoal" },
    { 0x27E6, "delayer" },
    { 0x27E7, "delayfade" },
    { 0x27E8, "delayinc" },
    { 0x27E9, "delayminetime" },
    { 0x27EA, "delayplayfx" },
    { 0x27EB, "delayresetdeployedjuggernaut" },
    { 0x27EC, "delaysetweapon" },
    { 0x27ED, "delaystandardmelee" },
    { 0x27EE, "delaystartragdoll" },
    { 0x27EF, "delaythread" },
    { 0x27F0, "delaythread_nuke" },
    { 0x27F1, "delaythread_proc" },
    { 0x27F2, "deletable_magic_bullet_shield" },
    { 0x27F3, "deletable_turret" },
    { 0x27F4, "delete_after_wait" },
    { 0x27F5, "delete_ai" },
    { 0x27F6, "delete_ai_on_flag" },
    { 0x27F7, "delete_ai_on_goal" },
    { 0x27F8, "delete_ai_on_path_end" },
    { 0x27F9, "delete_all_grenades" },
    { 0x27FA, "delete_all_mines" },
    { 0x27FB, "delete_ambient" },
    { 0x27FC, "delete_at_goal" },
    { 0x27FD, "delete_at_path_end" },
    { 0x27FE, "delete_atlas_intercept" },
    { 0x27FF, "delete_atlas_intercepts" },
    { 0x2800, "delete_atlas_van_driver" },
    { 0x2801, "delete_auto" },
    { 0x2802, "delete_bot_badplaces" },
    { 0x2803, "delete_breach" },
    { 0x2804, "delete_civilian_at_trigger" },
    { 0x2805, "delete_cloak_cover" },
    { 0x2806, "delete_collapse_ent" },
    { 0x2807, "delete_corpses_around_vehicle" },
    { 0x2808, "delete_debug_text_hud" },
    { 0x2809, "delete_destructibles_in_volumes" },
    { 0x280A, "delete_drone" },
    { 0x280B, "delete_enemy_on_flag" },
    { 0x280C, "delete_ents_by_targetname" },
    { 0x280D, "delete_exploder" },
    { 0x280E, "delete_exploder_proc" },
    { 0x280F, "delete_exploders_in_volumes" },
    { 0x2810, "delete_guy_on_trigger_stealth" },
    { 0x2811, "delete_guys_in_heli_when_vo_complete" },
    { 0x2812, "delete_hangar_allies_on_goal" },
    { 0x2813, "delete_heartrate_hud" },
    { 0x2814, "delete_highway_player_side" },
    { 0x2815, "delete_interactives_in_volumes" },
    { 0x2816, "delete_lane_cars" },
    { 0x2817, "delete_laser_on_death" },
    { 0x2818, "delete_links_then_self" },
    { 0x2819, "delete_me" },
    { 0x281A, "delete_me_in" },
    { 0x281B, "delete_me_on_flag" },
    { 0x281C, "delete_me_on_goal" },
    { 0x281D, "delete_me_on_goal_special" },
    { 0x281E, "delete_me_on_notify" },
    { 0x281F, "delete_mobile_cover" },
    { 0x2820, "delete_nearest_car_door_vehicle_collision" },
    { 0x2821, "delete_notify" },
    { 0x2822, "delete_ok" },
    { 0x2823, "delete_on_complete" },
    { 0x2824, "delete_on_crash" },
    { 0x2825, "delete_on_death" },
    { 0x2826, "delete_on_death_wait_sound" },
    { 0x2827, "delete_on_goal" },
    { 0x2828, "delete_on_not_defined" },
    { 0x2829, "delete_on_notify" },
    { 0x282A, "delete_on_path_end" },
    { 0x282B, "delete_on_player_unlink" },
    { 0x282C, "delete_on_removed" },
    { 0x282D, "delete_path_end" },
    { 0x282E, "delete_pod_crash_floor" },
    { 0x282F, "delete_pressed" },
    { 0x2830, "delete_primer" },
    { 0x2831, "delete_roadsurface_bridge" },
    { 0x2832, "delete_rooftop_los_blockers" },
    { 0x2833, "delete_selection" },
    { 0x2834, "delete_self_on_death_of" },
    { 0x2835, "delete_spawners" },
    { 0x2836, "delete_specific_navy_ships" },
    { 0x2837, "delete_start" },
    { 0x2838, "delete_subtitle_in" },
    { 0x2839, "delete_this_on_death" },
    { 0x283A, "delete_tower_debris" },
    { 0x283B, "delete_traffic_group" },
    { 0x283C, "delete_traffic_path" },
    { 0x283D, "delete_turret_on_death" },
    { 0x283E, "delete_veh" },
    { 0x283F, "delete_vehicle_at_trigger" },
    { 0x2840, "delete_vehicle_outof_view" },
    { 0x2841, "delete_vehicle_traffic_roundabout_straightways" },
    { 0x2842, "delete_vm_underwater_org" },
    { 0x2843, "delete_weapon_on_notify" },
    { 0x2844, "delete_wills_room_clip" },
    { 0x2845, "deleteaftertime" },
    { 0x2846, "deleteboat" },
    { 0x2847, "deletec4andclaymoresondisconnect" },
    { 0x2848, "deletecrate" },
    { 0x2849, "deletedebughudelem" },
    { 0x284A, "deletedefined" },
    { 0x284B, "deletedelay" },
    { 0x284C, "deletedestructiblekillcament" },
    { 0x284D, "deleteduringreflectionprobegeneration" },
    { 0x284E, "deleteent" },
    { 0x284F, "deleteequipment" },
    { 0x2850, "deleteexplosiontag" },
    { 0x2851, "deleteexplosivedrone" },
    { 0x2852, "deletegoliathpod" },
    { 0x2853, "deleteifnotused" },
    { 0x2854, "deletelasertagarray" },
    { 0x2855, "deletemapremotemissileclip" },
    { 0x2856, "deleteme" },
    { 0x2857, "deletemineonteamswitch" },
    { 0x2858, "deleteobjectwhendone" },
    { 0x2859, "deleteobjpoint" },
    { 0x285A, "deleteondeath" },
    { 0x285B, "deleteonownerdeath" },
    { 0x285C, "deleteonreviveordeathordisconnect" },
    { 0x285D, "deletepickupafterawhile" },
    { 0x285E, "deleteplacedentity" },
    { 0x285F, "deleteplayerdroppod" },
    { 0x2860, "deleteplayerdroppodvfx" },
    { 0x2861, "deletepodtrophyfx" },
    { 0x2862, "deletepodtrophyfxondeath" },
    { 0x2863, "deletepodtrophyfxondisconnect" },
    { 0x2864, "deletepodtrophyfxonteamchange" },
    { 0x2865, "deleteportableradar" },
    { 0x2866, "deleterotationents" },
    { 0x2867, "deletescrambler" },
    { 0x2868, "deleteshieldonplayerdeathordisconnect" },
    { 0x2869, "deleteshieldontriggerdeath" },
    { 0x286A, "deleteshieldontriggerpickup" },
    { 0x286B, "deleteshortly" },
    { 0x286C, "deletesquad" },
    { 0x286D, "deletestruct_ref" },
    { 0x286E, "deletestructarray" },
    { 0x286F, "deletestructarray_ref" },
    { 0x2870, "deleteti" },
    { 0x2871, "deletetrackingdrone" },
    { 0x2872, "deletetransrevmeshes" },
    { 0x2873, "deleteuseent" },
    { 0x2874, "deleteuseobject" },
    { 0x2875, "deletewalkingcivilians" },
    { 0x2876, "deleteweaponmodels" },
    { 0x2877, "delicate_flower" },
    { 0x2878, "deliverytrucksetup" },
    { 0x2879, "delta" },
    { 0x287A, "demo_feed_lines" },
    { 0x287B, "demo_skip_forward" },
    { 0x287C, "depleted" },
    { 0x287D, "deploy_check_player_in_elevator_think" },
    { 0x287E, "deploy_delay" },
    { 0x287F, "deploy_scene_ents" },
    { 0x2880, "deploy_scene_handcuff_ents" },
    { 0x2881, "deploy_sequence" },
    { 0x2882, "deploy_trophy" },
    { 0x2883, "deploy_vo" },
    { 0x2884, "deployable_cover" },
    { 0x2885, "deployable_cover_ai" },
    { 0x2886, "deployable_cover_anims" },
    { 0x2887, "deployable_cover_cleanup" },
    { 0x2888, "deployable_cover_focus_goal" },
    { 0x2889, "deployable_cover_kill" },
    { 0x288A, "deployable_cover_model" },
    { 0x288B, "deployable_cover_think" },
    { 0x288C, "deployable_cover_watch_death" },
    { 0x288D, "deployablecover" },
    { 0x288E, "deployablecoverinuse" },
    { 0x288F, "deployedscrambler" },
    { 0x2890, "deployflares" },
    { 0x2891, "deprecated__audio_msg_handler" },
    { 0x2892, "deprecated_aud_delay_play_2d_sound" },
    { 0x2893, "deprecated_aud_delay_play_2d_sound_internal" },
    { 0x2894, "deprecated_aud_delay_play_linked_sound" },
    { 0x2895, "deprecated_aud_delay_play_linked_sound_internal" },
    { 0x2896, "deprecated_aud_delete_on_sounddone" },
    { 0x2897, "deprecated_aud_fade_sound_in" },
    { 0x2898, "deprecated_aud_handle_flickering_light" },
    { 0x2899, "deprecated_aud_map" },
    { 0x289A, "deprecated_aud_map_range" },
    { 0x289B, "deprecated_aud_map2" },
    { 0x289C, "deprecated_aud_play_2d_sound" },
    { 0x289D, "deprecated_aud_play_conversation" },
    { 0x289E, "deprecated_aud_play_linked_sound" },
    { 0x289F, "deprecated_aud_play_sound_at" },
    { 0x28A0, "deprecated_aud_play_sound_at_internal" },
    { 0x28A1, "deprecated_aud_register_msg_handler" },
    { 0x28A2, "deprecated_aud_send_msg" },
    { 0x28A3, "deprecated_aud_set_filter" },
    { 0x28A4, "deprecated_aud_set_occlusion" },
    { 0x28A5, "deprecated_audio_message" },
    { 0x28A6, "deprecated_audx_dispatch_msg" },
    { 0x28A7, "deprecated_audx_monitor_linked_entity_health" },
    { 0x28A8, "deprecated_audx_play_linked_sound_internal" },
    { 0x28A9, "deprecated_delete_sound_entity" },
    { 0x28AA, "deprecated_play_2d_sound_internal" },
    { 0x28AB, "depth_allow_crouch" },
    { 0x28AC, "depth_allow_prone" },
    { 0x28AD, "depth_allow_stand" },
    { 0x28AE, "derailed" },
    { 0x28AF, "desc_col" },
    { 0x28B0, "describe_start" },
    { 0x28B1, "description" },
    { 0x28B2, "deselect_all_ents" },
    { 0x28B3, "deselect_entity" },
    { 0x28B4, "desired_anim_pose" },
    { 0x28B5, "desired_range" },
    { 0x28B6, "desired_speed" },
    { 0x28B7, "desiredtimeofdeath" },
    { 0x28B8, "desk_animate" },
    { 0x28B9, "despawn_dist_sq" },
    { 0x28BA, "despawn_if_not_in_view" },
    { 0x28BB, "dest" },
    { 0x28BC, "dest_cover" },
    { 0x28BD, "destination2" },
    { 0x28BE, "destinations" },
    { 0x28BF, "destroy_aim_hud" },
    { 0x28C0, "destroy_all_frogger_vehicles_lane" },
    { 0x28C1, "destroy_cine_helicopter" },
    { 0x28C2, "destroy_drones_in_wave" },
    { 0x28C3, "destroy_drones_when_nuked" },
    { 0x28C4, "destroy_hint_on_friendlyfire" },
    { 0x28C5, "destroy_hud_elem_landassist" },
    { 0x28C6, "destroy_mobile_turret" },
    { 0x28C7, "destroy_office_snipe_glass" },
    { 0x28C8, "destroy_on_flag" },
    { 0x28C9, "destroy_radar_hud_elem_early" },
    { 0x28CA, "destroy_screen_pac" },
    { 0x28CB, "destroy_self_when_nuked" },
    { 0x28CC, "destroy_sentinel_drone_hud" },
    { 0x28CD, "destroy_the_window_exit" },
    { 0x28CE, "destroy_tracking_drone_in_water" },
    { 0x28CF, "destroy_truck_01" },
    { 0x28D0, "destroy_turret_when_player_leaves" },
    { 0x28D1, "destroy_walker_tank" },
    { 0x28D2, "destroy_warbird" },
    { 0x28D3, "destroy_warning_elem" },
    { 0x28D4, "destroy_warning_elem_when_hit_again" },
    { 0x28D5, "destroy_warning_elem_when_mission_failed" },
    { 0x28D6, "destroy_windshield" },
    { 0x28D7, "destroyactivedrones" },
    { 0x28D8, "destroyactiveequipmentvehicles" },
    { 0x28D9, "destroyactivehelis" },
    { 0x28DA, "destroyactivelittlebirds" },
    { 0x28DB, "destroyactiveorbitallasers" },
    { 0x28DC, "destroyactiverockets" },
    { 0x28DD, "destroyactivestreakvehicles" },
    { 0x28DE, "destroyactiveturrets" },
    { 0x28DF, "destroyactiveuavs" },
    { 0x28E0, "destroyactiveugvs" },
    { 0x28E1, "destroyactivevehicles" },
    { 0x28E2, "destroyatriumfighttimer" },
    { 0x28E3, "destroydroppedgun" },
    { 0x28E4, "destroyed" },
    { 0x28E5, "destroyedcount" },
    { 0x28E6, "destroyedcounttimeout" },
    { 0x28E7, "destroyedvo" },
    { 0x28E8, "destroyefx" },
    { 0x28E9, "destroyelem" },
    { 0x28EA, "destroyempobjectsinradius" },
    { 0x28EB, "destroyentityheadiconondeath" },
    { 0x28EC, "destroyheadiconsondeath" },
    { 0x28ED, "destroyhudelem" },
    { 0x28EE, "destroyiconsondeath" },
    { 0x28EF, "destroymarkettimer" },
    { 0x28F0, "destroyonownerdisconnect" },
    { 0x28F1, "destroyonreviveentdeath" },
    { 0x28F2, "destroyplayerdroppod" },
    { 0x28F3, "destroyplayericons" },
    { 0x28F4, "destroysetupambushtimer" },
    { 0x28F5, "destroyslowly" },
    { 0x28F6, "destructable_destroyed" },
    { 0x28F7, "destructable_destruct" },
    { 0x28F8, "destructable_think" },
    { 0x28F9, "destructible" },
    { 0x28FA, "destructible_anim" },
    { 0x28FB, "destructible_animation_think" },
    { 0x28FC, "destructible_anims" },
    { 0x28FD, "destructible_attachmodel" },
    { 0x28FE, "destructible_badplace_radius_multiplier" },
    { 0x28FF, "destructible_boxtruck_think" },
    { 0x2900, "destructible_builddot_damage" },
    { 0x2901, "destructible_builddot_ontick" },
    { 0x2902, "destructible_builddot_startloop" },
    { 0x2903, "destructible_builddot_wait" },
    { 0x2904, "destructible_car_alarm" },
    { 0x2905, "destructible_cleans_up_more" },
    { 0x2906, "destructible_create" },
    { 0x2907, "destructible_createdot_predefined" },
    { 0x2908, "destructible_createdot_radius" },
    { 0x2909, "destructible_damage_threshold" },
    { 0x290A, "destructible_death" },
    { 0x290B, "destructible_disable_explosion" },
    { 0x290C, "destructible_dots" },
    { 0x290D, "destructible_explode" },
    { 0x290E, "destructible_explosion_radius_multiplier" },
    { 0x290F, "destructible_force_explosion" },
    { 0x2910, "destructible_function" },
    { 0x2911, "destructible_functions" },
    { 0x2912, "destructible_fx" },
    { 0x2913, "destructible_fx_kill_state_wait" },
    { 0x2914, "destructible_fx_spawn_immediate" },
    { 0x2915, "destructible_fx_spawn_think" },
    { 0x2916, "destructible_fx_spawnimmediate" },
    { 0x2917, "destructible_fx_think" },
    { 0x2918, "destructible_get_my_breakable_light" },
    { 0x2919, "destructible_getinfoindex" },
    { 0x291A, "destructible_gettype" },
    { 0x291B, "destructible_handles_collision_brushes" },
    { 0x291C, "destructible_health_drain_amount_multiplier" },
    { 0x291D, "destructible_healthdrain" },
    { 0x291E, "destructible_info" },
    { 0x291F, "destructible_lights_out" },
    { 0x2920, "destructible_loopfx" },
    { 0x2921, "destructible_loopsound" },
    { 0x2922, "destructible_model" },
    { 0x2923, "destructible_notify" },
    { 0x2924, "destructible_part" },
    { 0x2925, "destructible_parts" },
    { 0x2926, "destructible_physics" },
    { 0x2927, "destructible_protection_func" },
    { 0x2928, "destructible_setdot_ontick" },
    { 0x2929, "destructible_setdot_ontickfunc" },
    { 0x292A, "destructible_sound" },
    { 0x292B, "destructible_sound_think" },
    { 0x292C, "destructible_splash_damage" },
    { 0x292D, "destructible_splash_damage_scaler" },
    { 0x292E, "destructible_splash_rotatation" },
    { 0x292F, "destructible_spotlight" },
    { 0x2930, "destructible_spotlight_think" },
    { 0x2931, "destructible_state" },
    { 0x2932, "destructible_think" },
    { 0x2933, "destructible_trailer_collision_destroy_when_player_close" },
    { 0x2934, "destructible_trailer_collision_think" },
    { 0x2935, "destructible_transient" },
    { 0x2936, "destructible_update_part" },
    { 0x2937, "destructiblecoverwatcher" },
    { 0x2938, "destructibleframequeue" },
    { 0x2939, "destructibleinfo" },
    { 0x293A, "destructibles" },
    { 0x293B, "destructiblespawnedents" },
    { 0x293C, "destructiblespawnedentslimit" },
    { 0x293D, "det_blood_impact_burst01" },
    { 0x293E, "det_blood_impact_burst02" },
    { 0x293F, "det_blood_impact_burst03" },
    { 0x2940, "det_bones_bike_end_fx" },
    { 0x2941, "det_brick_pull_fx" },
    { 0x2942, "det_camp_lookat_trigger_think" },
    { 0x2943, "det_catch_guy_01_ball_drop" },
    { 0x2944, "det_catch_guy_01_pt_02" },
    { 0x2945, "det_catch_guy_01_pt_03" },
    { 0x2946, "det_catch_guy_01_pt_04" },
    { 0x2947, "det_catch_guy_01_pt_05" },
    { 0x2948, "det_catch_guy_02_pt_02" },
    { 0x2949, "det_catch_guy_02_pt_03" },
    { 0x294A, "det_catch_guy_02_pt_04" },
    { 0x294B, "det_catch_guy_02_pt_05" },
    { 0x294C, "det_debris_falling" },
    { 0x294D, "det_doc_cap_doc" },
    { 0x294E, "det_doc_cap_gdn" },
    { 0x294F, "det_doc_cap_jkr" },
    { 0x2950, "det_doc_picked_up" },
    { 0x2951, "det_doc_roll_over" },
    { 0x2952, "det_end_chopper_approach" },
    { 0x2953, "det_end_chopper_crash_start" },
    { 0x2954, "det_end_chopper_tumble" },
    { 0x2955, "det_end_chopper_tumble_2" },
    { 0x2956, "det_end_gate_close" },
    { 0x2957, "det_fall_through_ceiling" },
    { 0x2958, "det_gl_end_logo" },
    { 0x2959, "det_helicopter_explo" },
    { 0x295A, "det_helicopter_shot" },
    { 0x295B, "det_helmet_smash_fx" },
    { 0x295C, "det_hospital_gate_close" },
    { 0x295D, "det_hoverbike_mount_burke" },
    { 0x295E, "det_hoverbike_shutdown_burke" },
    { 0x295F, "det_hoverbike_startup_burke" },
    { 0x2960, "det_intro_gdn" },
    { 0x2961, "det_intro_gideon_foley_pt1" },
    { 0x2962, "det_intro_gideon_foley_pt2" },
    { 0x2963, "det_intro_gideon_foley_pt3" },
    { 0x2964, "det_joker_bike_end_fx" },
    { 0x2965, "det_knife_pull" },
    { 0x2966, "det_knife_stab_fx" },
    { 0x2967, "det_knx_thatsclassifiedmate" },
    { 0x2968, "det_mech_scanner_fx" },
    { 0x2969, "det_scanner_fx" },
    { 0x296A, "det_scanner_fx_bg" },
    { 0x296B, "det_school_fall_plr" },
    { 0x296C, "det_sent_meet_brk" },
    { 0x296D, "det_sent_meet_jkr" },
    { 0x296E, "det_sent_meet_knx" },
    { 0x296F, "det_shelf_papers_fx" },
    { 0x2970, "det_start_doctor_breathing" },
    { 0x2971, "det_stop_doctor_breathing" },
    { 0x2972, "det_vignette" },
    { 0x2973, "det_water_crash_jeep_1" },
    { 0x2974, "det_water_crash_jeep_2" },
    { 0x2975, "detach_attachments_from_weapon_model" },
    { 0x2976, "detach_cig" },
    { 0x2977, "detach_getoutrigs" },
    { 0x2978, "detach_housing" },
    { 0x2979, "detach_idle_clip" },
    { 0x297A, "detach_models_with_substr" },
    { 0x297B, "detach_motion_blur_disable" },
    { 0x297C, "detach_motion_blur_enable" },
    { 0x297D, "detach_phone" },
    { 0x297E, "detachall_on_death" },
    { 0x297F, "detachallweaponmodels" },
    { 0x2980, "detachflag" },
    { 0x2981, "detachgrenadeonscriptchange" },
    { 0x2982, "detachifattached" },
    { 0x2983, "detachprops" },
    { 0x2984, "detachusemodels" },
    { 0x2985, "detachweapon" },
    { 0x2986, "detcord_logic" },
    { 0x2987, "detect_being_pushed" },
    { 0x2988, "detect_cargo_ship_damage" },
    { 0x2989, "detect_cargo_ship_death" },
    { 0x298A, "detect_distsqrd" },
    { 0x298B, "detect_dropping" },
    { 0x298C, "detect_enemies" },
    { 0x298D, "detect_player_death" },
    { 0x298E, "detect_range" },
    { 0x298F, "detect_turret_death" },
    { 0x2990, "detect_when_player_is_in_volume" },
    { 0x2991, "detectedexploit" },
    { 0x2992, "detectexplosives" },
    { 0x2993, "detectfriendlyfireonentity" },
    { 0x2994, "detectid" },
    { 0x2995, "detection_grenade_duration" },
    { 0x2996, "detection_grenade_duration_bonus" },
    { 0x2997, "detection_grenade_hud_effect" },
    { 0x2998, "detection_grenade_range" },
    { 0x2999, "detection_grenade_sweep_time" },
    { 0x299A, "detection_grenade_think" },
    { 0x299B, "detection_highlight_hud_effect" },
    { 0x299C, "detection_highlight_hud_effect_apply" },
    { 0x299D, "detection_highlight_hud_effect_off" },
    { 0x299E, "detection_highlight_hud_effect_old" },
    { 0x299F, "detection_highlight_hud_effect_on" },
    { 0x29A0, "detection_highlight_hud_effect_remove" },
    { 0x29A1, "detection_level" },
    { 0x29A2, "detectiongrenadethink" },
    { 0x29A3, "detectiongrenadewatch" },
    { 0x29A4, "determine_projectile_position" },
    { 0x29A5, "determine_sticky_position" },
    { 0x29A6, "determinecqbanim" },
    { 0x29A7, "determineexposedapproachtype" },
    { 0x29A8, "determineheatcoverexittype" },
    { 0x29A9, "determinenodeapproachtype" },
    { 0x29AA, "determinenodeexittype" },
    { 0x29AB, "determinenonnodeexittype" },
    { 0x29AC, "determinestate" },
    { 0x29AD, "determineweaponnameandattachments" },
    { 0x29AE, "detonate_foam_grenade" },
    { 0x29AF, "detonate_foam_nag_dialogue" },
    { 0x29B0, "detonate_hovertank_aa_projectile_on_death" },
    { 0x29B1, "detonateondeath" },
    { 0x29B2, "detonateonuse" },
    { 0x29B3, "detonateradius" },
    { 0x29B4, "detonatetrap" },
    { 0x29B5, "detour_flag" },
    { 0x29B6, "detoured" },
    { 0x29B7, "detouringpath" },
    { 0x29B8, "detpackstunradius" },
    { 0x29B9, "detroit_cg_precache_models" },
    { 0x29BA, "detroit_drive_in_fov" },
    { 0x29BB, "detroit_kva_bauerdoyoureadme" },
    { 0x29BC, "detroit_laser" },
    { 0x29BD, "detroit_locations" },
    { 0x29BE, "detroit_music_preset_constructor" },
    { 0x29BF, "detroit_spring_cam_lerp_speed" },
    { 0x29C0, "detroit_spring_cam_release_speed" },
    { 0x29C1, "detroitcustomkillstreakfunc" },
    { 0x29C2, "detroitpaladinoverrides" },
    { 0x29C3, "detroitstrikeheightoverrides" },
    { 0x29C4, "detroittramobjids" },
    { 0x29C5, "df_baghdad_combat_pre_load" },
    { 0x29C6, "df_baghdad_dnabomb_pre_load" },
    { 0x29C7, "df_baghdad_dof_presets" },
    { 0x29C8, "df_baghdad_global_spawnfunctions" },
    { 0x29C9, "df_baghdad_intro_pre_load" },
    { 0x29CA, "df_baghdad_lighting" },
    { 0x29CB, "df_baghdad_lighting_captured" },
    { 0x29CC, "df_baghdad_lighting_dna_bomb_01" },
    { 0x29CD, "df_baghdad_lighting_dna_bomb_02" },
    { 0x29CE, "df_baghdad_lighting_dna_bomb_03" },
    { 0x29CF, "df_baghdad_lighting_drones" },
    { 0x29D0, "df_baghdad_lighting_preload" },
    { 0x29D1, "df_baghdad_post_tower_autosaves" },
    { 0x29D2, "df_baghdad_post_tower_pre_load" },
    { 0x29D3, "df_baghdad_pre_load" },
    { 0x29D4, "df_baghdad_precache" },
    { 0x29D5, "df_baghdad_retrun_player_rig" },
    { 0x29D6, "df_baghdad_set_level_lighting_values" },
    { 0x29D7, "df_baghdad_snipers_pre_load" },
    { 0x29D8, "df_baghdad_starts" },
    { 0x29D9, "df_cheap_rpgs" },
    { 0x29DA, "df_enable_boostjump" },
    { 0x29DB, "df_fly_dof_presets" },
    { 0x29DC, "df_fly_lighting" },
    { 0x29DD, "df_fly_lighting_canyon" },
    { 0x29DE, "df_fly_lighting_canyon_finale" },
    { 0x29DF, "df_fly_lighting_end_pod" },
    { 0x29E0, "df_fly_pre_load" },
    { 0x29E1, "df_fly_precache" },
    { 0x29E2, "df_fly_set_level_lighting_values" },
    { 0x29E3, "df_fly_starts" },
    { 0x29E4, "df_global_accuracy" },
    { 0x29E5, "df_objectives" },
    { 0x29E6, "df_player_rig_name" },
    { 0x29E7, "dialog" },
    { 0x29E8, "dialog_collapse" },
    { 0x29E9, "dialog_complain_cold" },
    { 0x29EA, "dialog_hotel_top_floor_nk_alerted" },
    { 0x29EB, "dialog_mech_clear_queued" },
    { 0x29EC, "dialog_meltdown" },
    { 0x29ED, "dialog_monitor_drones_down" },
    { 0x29EE, "dialog_nags_heli" },
    { 0x29EF, "dialog_noise_stinger" },
    { 0x29F0, "dialogcounter" },
    { 0x29F1, "dialogdangerzone" },
    { 0x29F2, "dialogtable" },
    { 0x29F3, "dialogue" },
    { 0x29F4, "dialogue_approaching_drop_point" },
    { 0x29F5, "dialogue_ast_ahead" },
    { 0x29F6, "dialogue_boat_destroyed" },
    { 0x29F7, "dialogue_breach_ahead" },
    { 0x29F8, "dialogue_breach_complete" },
    { 0x29F9, "dialogue_building_jump" },
    { 0x29FA, "dialogue_canal_start" },
    { 0x29FB, "dialogue_carry_scene_01" },
    { 0x29FC, "dialogue_carry_scene_02" },
    { 0x29FD, "dialogue_chase_irons" },
    { 0x29FE, "dialogue_control_room_attack" },
    { 0x29FF, "dialogue_doctor_trolley" },
    { 0x2A00, "dialogue_drone_swarm_intro" },
    { 0x2A01, "dialogue_drone_turret_sequence" },
    { 0x2A02, "dialogue_droppod_intro" },
    { 0x2A03, "dialogue_droppod_intro_prelaunch" },
    { 0x2A04, "dialogue_droppod_prelaunch" },
    { 0x2A05, "dialogue_execute" },
    { 0x2A06, "dialogue_exhaust_hatch" },
    { 0x2A07, "dialogue_exit_trench" },
    { 0x2A08, "dialogue_gd" },
    { 0x2A09, "dialogue_gd_lift" },
    { 0x2A0A, "dialogue_gid_rocket_reminder" },
    { 0x2A0B, "dialogue_gid_swarm_reminder" },
    { 0x2A0C, "dialogue_guardroom_door" },
    { 0x2A0D, "dialogue_hatch_position" },
    { 0x2A0E, "dialogue_head_to_exhaust_vent" },
    { 0x2A0F, "dialogue_hotel_exit" },
    { 0x2A10, "dialogue_hotel_mid_floor_contact" },
    { 0x2A11, "dialogue_hotel_mid_floor_fight_over" },
    { 0x2A12, "dialogue_hotel_mid_floor_glass_gag" },
    { 0x2A13, "dialogue_hotel_missile_dodge" },
    { 0x2A14, "dialogue_hotel_pod_exit_begin" },
    { 0x2A15, "dialogue_hotel_top_floor_landassist" },
    { 0x2A16, "dialogue_hotel_top_floor_landing" },
    { 0x2A17, "dialogue_hotel_top_floor_nk_soldier_spotted" },
    { 0x2A18, "dialogue_huds" },
    { 0x2A19, "dialogue_into_exhaust_hatch" },
    { 0x2A1A, "dialogue_intro" },
    { 0x2A1B, "dialogue_intro_black" },
    { 0x2A1C, "dialogue_introdrive" },
    { 0x2A1D, "dialogue_irons_ending" },
    { 0x2A1E, "dialogue_keep_moving" },
    { 0x2A1F, "dialogue_mb1" },
    { 0x2A20, "dialogue_mb1_bootup" },
    { 0x2A21, "dialogue_mb1_intro" },
    { 0x2A22, "dialogue_mb1_jumpdown" },
    { 0x2A23, "dialogue_mb2" },
    { 0x2A24, "dialogue_mb2_gatesmash" },
    { 0x2A25, "dialogue_mb2_gid_il_convo" },
    { 0x2A26, "dialogue_mech" },
    { 0x2A27, "dialogue_mech_everytime" },
    { 0x2A28, "dialogue_missile_damage" },
    { 0x2A29, "dialogue_missile_launch" },
    { 0x2A2A, "dialogue_more_boats" },
    { 0x2A2B, "dialogue_nag_loop" },
    { 0x2A2C, "dialogue_nag_player" },
    { 0x2A2D, "dialogue_overpass" },
    { 0x2A2E, "dialogue_pa_launch_coundown" },
    { 0x2A2F, "dialogue_pa_security_breach" },
    { 0x2A30, "dialogue_performing_arts_entrance" },
    { 0x2A31, "dialogue_primary_ignitionin" },
    { 0x2A32, "dialogue_queue" },
    { 0x2A33, "dialogue_queue_global" },
    { 0x2A34, "dialogue_queue_single" },
    { 0x2A35, "dialogue_random_last_line" },
    { 0x2A36, "dialogue_random_line" },
    { 0x2A37, "dialogue_ready_to_drop" },
    { 0x2A38, "dialogue_reminder" },
    { 0x2A39, "dialogue_s1elevator_outside" },
    { 0x2A3A, "dialogue_s2_elevator_open" },
    { 0x2A3B, "dialogue_s2_walk" },
    { 0x2A3C, "dialogue_s2elevator_outside" },
    { 0x2A3D, "dialogue_s3_head_doctor" },
    { 0x2A3E, "dialogue_s3_observation" },
    { 0x2A3F, "dialogue_s3escape_guard" },
    { 0x2A40, "dialogue_s3escape_hall" },
    { 0x2A41, "dialogue_silo_contact" },
    { 0x2A42, "dialogue_trench_demo_team" },
    { 0x2A43, "dialogue_truck_push_sequence" },
    { 0x2A44, "dialogue_uv_bake_awcmon" },
    { 0x2A45, "dialogue_wallsmash_nag" },
    { 0x2A46, "dialogue_water_clear" },
    { 0x2A47, "dialogue_will_revael" },
    { 0x2A48, "dialoguelevelintro" },
    { 0x2A49, "dialoguenotetrack" },
    { 0x2A4A, "didpastmeleefail" },
    { 0x2A4B, "didpastpursuitfail" },
    { 0x2A4C, "didshufflemove" },
    { 0x2A4D, "didsomethingotherthanshooting" },
    { 0x2A4E, "didstatusnotify" },
    { 0x2A4F, "didtie" },
    { 0x2A50, "didturretexplosion" },
    { 0x2A51, "die" },
    { 0x2A52, "dieaftertime" },
    { 0x2A53, "died_being_tracked" },
    { 0x2A54, "died_of_headshot" },
    { 0x2A55, "diehardmode" },
    { 0x2A56, "differentiate_motion" },
    { 0x2A57, "differentiated_acceleration" },
    { 0x2A58, "differentiated_jerk" },
    { 0x2A59, "differentiated_last_acceleration" },
    { 0x2A5A, "differentiated_last_origin" },
    { 0x2A5B, "differentiated_last_update" },
    { 0x2A5C, "differentiated_last_velocity" },
    { 0x2A5D, "differentiated_speed" },
    { 0x2A5E, "differentiated_velocity" },
    { 0x2A5F, "difficulty" },
    { 0x2A60, "difficultysettings" },
    { 0x2A61, "difficultysettings_frac_data_points" },
    { 0x2A62, "difficultystring" },
    { 0x2A63, "difficultytype" },
    { 0x2A64, "digitaldistort" },
    { 0x2A65, "digitmodels" },
    { 0x2A66, "dimensionsx" },
    { 0x2A67, "dimensionsy" },
    { 0x2A68, "dir" },
    { 0x2A69, "diraimlimit" },
    { 0x2A6A, "directhackduration" },
    { 0x2A6B, "directhacked" },
    { 0x2A6C, "directhackendtime" },
    { 0x2A6D, "direction" },
    { 0x2A6E, "dirt_on_screen_from_position" },
    { 0x2A6F, "dirt_splatter_simple" },
    { 0x2A70, "dirteffect" },
    { 0x2A71, "dirty" },
    { 0x2A72, "disable_achievement_harder_they_fall" },
    { 0x2A73, "disable_achievement_harder_they_fall_guy" },
    { 0x2A74, "disable_ai_color" },
    { 0x2A75, "disable_ai_swim" },
    { 0x2A76, "disable_aim_assist_on_script_model" },
    { 0x2A77, "disable_alert" },
    { 0x2A78, "disable_all_fixed_scanners" },
    { 0x2A79, "disable_all_turrets" },
    { 0x2A7A, "disable_arrivals" },
    { 0x2A7B, "disable_awareness" },
    { 0x2A7C, "disable_awareness_limited" },
    { 0x2A7D, "disable_badplace_for_red_guys" },
    { 0x2A7E, "disable_blindfire" },
    { 0x2A7F, "disable_blood_pool" },
    { 0x2A80, "disable_bokeh" },
    { 0x2A81, "disable_boost_dash" },
    { 0x2A82, "disable_boost_hud" },
    { 0x2A83, "disable_boost_jump" },
    { 0x2A84, "disable_breathing_sound" },
    { 0x2A85, "disable_bulletwhizbyreaction" },
    { 0x2A86, "disable_careful" },
    { 0x2A87, "disable_cloak_system" },
    { 0x2A88, "disable_cormack_obj" },
    { 0x2A89, "disable_cover_drone" },
    { 0x2A8A, "disable_cover_drone_on_mobile_turret_mount" },
    { 0x2A8B, "disable_cqb_points_of_interest" },
    { 0x2A8C, "disable_cqb_squad" },
    { 0x2A8D, "disable_cqbwalk" },
    { 0x2A8E, "disable_damagefeedback_hud" },
    { 0x2A8F, "disable_damagefeedback_snd" },
    { 0x2A90, "disable_danger_react" },
    { 0x2A91, "disable_default_exo_powers" },
    { 0x2A92, "disable_destructible_bad_places" },
    { 0x2A93, "disable_dive_whizby_react" },
    { 0x2A94, "disable_dof_car_door_throw" },
    { 0x2A95, "disable_dog_control" },
    { 0x2A96, "disable_dog_kinect" },
    { 0x2A97, "disable_dog_sneak" },
    { 0x2A98, "disable_dog_sniff" },
    { 0x2A99, "disable_dog_walk" },
    { 0x2A9A, "disable_dontevershoot" },
    { 0x2A9B, "disable_dynamic_run_speed" },
    { 0x2A9C, "disable_enable_exit_flags" },
    { 0x2A9D, "disable_exits" },
    { 0x2A9E, "disable_exo_during_land_assist" },
    { 0x2A9F, "disable_exo_for_highway" },
    { 0x2AA0, "disable_exo_melee" },
    { 0x2AA1, "disable_explosion" },
    { 0x2AA2, "disable_fall_damage" },
    { 0x2AA3, "disable_features_entering_cinema" },
    { 0x2AA4, "disable_firing" },
    { 0x2AA5, "disable_force_sprint" },
    { 0x2AA6, "disable_free_running" },
    { 0x2AA7, "disable_gideon_jog_when_turning" },
    { 0x2AA8, "disable_grenade_range_triggers" },
    { 0x2AA9, "disable_grenades" },
    { 0x2AAA, "disable_gun_recall" },
    { 0x2AAB, "disable_heat_behavior" },
    { 0x2AAC, "disable_high_jump" },
    { 0x2AAD, "disable_highway_path_player_side" },
    { 0x2AAE, "disable_ignorerandombulletdamage_drone" },
    { 0x2AAF, "disable_interactive_tv_use_triggers" },
    { 0x2AB0, "disable_ir_in_nightvision" },
    { 0x2AB1, "disable_long_death" },
    { 0x2AB2, "disable_me_when_exopush_finished" },
    { 0x2AB3, "disable_mech_chaingun" },
    { 0x2AB4, "disable_mech_rocket" },
    { 0x2AB5, "disable_mech_swarm" },
    { 0x2AB6, "disable_mech_threat_ping" },
    { 0x2AB7, "disable_meele_for_breach" },
    { 0x2AB8, "disable_melee" },
    { 0x2AB9, "disable_middle_civs" },
    { 0x2ABA, "disable_middle_civs_now" },
    { 0x2ABB, "disable_militia_behavior" },
    { 0x2ABC, "disable_mobile_turret_if_not_destroyed" },
    { 0x2ABD, "disable_motion_blur" },
    { 0x2ABE, "disable_mount_point" },
    { 0x2ABF, "disable_my_thermal" },
    { 0x2AC0, "disable_oneshotfx_with_noteworthy" },
    { 0x2AC1, "disable_outerspacelighting_interior" },
    { 0x2AC2, "disable_pain" },
    { 0x2AC3, "disable_physical_dof" },
    { 0x2AC4, "disable_pitbull_use" },
    { 0x2AC5, "disable_player_controls" },
    { 0x2AC6, "disable_player_swim" },
    { 0x2AC7, "disable_player_swimming" },
    { 0x2AC8, "disable_player_underwater_walk" },
    { 0x2AC9, "disable_pod_door_clip" },
    { 0x2ACA, "disable_rappel_trigger_monitor" },
    { 0x2ACB, "disable_readystand" },
    { 0x2ACC, "disable_replace_on_death" },
    { 0x2ACD, "disable_same_side_blocking" },
    { 0x2ACE, "disable_shield_ability" },
    { 0x2ACF, "disable_sniper_glint" },
    { 0x2AD0, "disable_sonar_when_not_allowed" },
    { 0x2AD1, "disable_sonic_aoe" },
    { 0x2AD2, "disable_sprint" },
    { 0x2AD3, "disable_ssao_over_time" },
    { 0x2AD4, "disable_static_mobile_cover" },
    { 0x2AD5, "disable_stealth_debug_hud" },
    { 0x2AD6, "disable_stealth_for_ai" },
    { 0x2AD7, "disable_stealth_smart_stance" },
    { 0x2AD8, "disable_stealth_system" },
    { 0x2AD9, "disable_stencil" },
    { 0x2ADA, "disable_surprise" },
    { 0x2ADB, "disable_swim" },
    { 0x2ADC, "disable_swim_or_underwater_walk" },
    { 0x2ADD, "disable_tactical_goals" },
    { 0x2ADE, "disable_target_tracking" },
    { 0x2ADF, "disable_teamflashbangimmunity" },
    { 0x2AE0, "disable_threat_atlas_van_driver" },
    { 0x2AE1, "disable_threat_grenade_response" },
    { 0x2AE2, "disable_threat_ping" },
    { 0x2AE3, "disable_tracking" },
    { 0x2AE4, "disable_trigger" },
    { 0x2AE5, "disable_trigger_helper" },
    { 0x2AE6, "disable_trigger_while_player_animating" },
    { 0x2AE7, "disable_trigger_with_noteworthy" },
    { 0x2AE8, "disable_trigger_with_targetname" },
    { 0x2AE9, "disable_turbine_elevator_trigger" },
    { 0x2AEA, "disable_turnanims" },
    { 0x2AEB, "disable_turret_missiles" },
    { 0x2AEC, "disable_vol" },
    { 0x2AED, "disable_weapon_pickup_wrapper" },
    { 0x2AEE, "disable_weapons_in_canal_view_room" },
    { 0x2AEF, "disableaicombatreactions" },
    { 0x2AF0, "disablealliescolor" },
    { 0x2AF1, "disableallstreaks" },
    { 0x2AF2, "disableapproach" },
    { 0x2AF3, "disablearrivals" },
    { 0x2AF4, "disableawareness" },
    { 0x2AF5, "disablebadplace" },
    { 0x2AF6, "disablebattlechatter" },
    { 0x2AF7, "disablebulletwhizbyreaction" },
    { 0x2AF8, "disableclientspawntraces" },
    { 0x2AF9, "disablecloudscount" },
    { 0x2AFA, "disablecloudsexploder" },
    { 0x2AFB, "disablecorpsealert" },
    { 0x2AFC, "disablecoverarrivalsonly" },
    { 0x2AFD, "disabled" },
    { 0x2AFE, "disabled_exo" },
    { 0x2AFF, "disabled_use_for" },
    { 0x2B00, "disabledamagecallback" },
    { 0x2B01, "disabledamagecallbackinternal" },
    { 0x2B02, "disabledamagefeedbacksnd" },
    { 0x2B03, "disabledamageshieldpain" },
    { 0x2B04, "disabledefaultfacialanims" },
    { 0x2B05, "disabledoffhandweapons" },
    { 0x2B06, "disabledoorbehavior" },
    { 0x2B07, "disabledronefiringafterkill" },
    { 0x2B08, "disabledronefiringatstart" },
    { 0x2B09, "disabledronefiringduringcrash" },
    { 0x2B0A, "disabledusability" },
    { 0x2B0B, "disabledweapon" },
    { 0x2B0C, "disabledweaponswitch" },
    { 0x2B0D, "disableenemyalert" },
    { 0x2B0E, "disableexits" },
    { 0x2B0F, "disableexo" },
    { 0x2B10, "disablefacialfilleranims" },
    { 0x2B11, "disableforfeit" },
    { 0x2B12, "disablefriendlyfirereaction" },
    { 0x2B13, "disablegeardrop" },
    { 0x2B14, "disablegloballyusablebytype" },
    { 0x2B15, "disablegrenadetracking" },
    { 0x2B16, "disablekillstreakactionslots" },
    { 0x2B17, "disablekillstreaks" },
    { 0x2B18, "disablelongdeath" },
    { 0x2B19, "disablelongdeath_saved" },
    { 0x2B1A, "disablelongpain" },
    { 0x2B1B, "disablemeleeonroof" },
    { 0x2B1C, "disablemonitorflash" },
    { 0x2B1D, "disablemovementtracker" },
    { 0x2B1E, "disableobject" },
    { 0x2B1F, "disableorbitalthermal" },
    { 0x2B20, "disablepain" },
    { 0x2B21, "disableplayercommands" },
    { 0x2B22, "disableplayeruseent" },
    { 0x2B23, "disableranking" },
    { 0x2B24, "disablereactionanims" },
    { 0x2B25, "disableregen" },
    { 0x2B26, "disablereload" },
    { 0x2B27, "disablesonicaoe" },
    { 0x2B28, "disablespawning" },
//
//
    { 0x663C, "ownervehicle" },
    { 0x663D, "p_hits" },
    { 0x663E, "pa_airlock" },
    { 0x663F, "pa_codered" },
    { 0x6640, "pa_emergency" },
    { 0x6641, "pa_emergency_turbine" },
    { 0x6642, "pa_system_filler_after_joker" },
    { 0x6643, "pac_attack_when_alert" },
    { 0x6644, "pac_enemy_group" },
    { 0x6645, "pac_enemy_stats" },
    { 0x6646, "packageholdtimer" },
    { 0x6647, "packagesingletapped" },
    { 0x6648, "padding" },
    { 0x6649, "pain_protection" },
    { 0x664A, "pain_protection_check" },
    { 0x664B, "pain_resistance" },
    { 0x664C, "pain_setflaggedanimknob" },
    { 0x664D, "pain_setflaggedanimknoballrestart" },
    { 0x664E, "pain_setflaggedanimknobrestart" },
    { 0x664F, "pain_test" },
    { 0x6650, "painai" },
    { 0x6651, "painanimlength" },
    { 0x6652, "paindamageincrement" },
    { 0x6653, "paindamageincrementback" },
    { 0x6654, "paindamagemin" },
    { 0x6655, "paindamagestart" },
    { 0x6656, "paindamagetime" },
    { 0x6657, "paindeathnotify" },
    { 0x6658, "painfunction" },
    { 0x6659, "painmanagement" },
    { 0x665A, "painonstairs" },
    { 0x665B, "painpitchdifftolerance" },
    { 0x665C, "paint_grenade_detonate" },
    { 0x665D, "painted" },
    { 0x665E, "painted_tracked" },
    { 0x665F, "paintime" },
    { 0x6660, "paintoutline" },
    { 0x6661, "painyawdiffclosedistsq" },
    { 0x6662, "painyawdiffclosetolerance" },
    { 0x6663, "painyawdifffartolerance" },
    { 0x6664, "pairbattlebuddy" },
    { 0x6665, "palm_anims" },
    { 0x6666, "palm_style_door_open" },
    { 0x6667, "panaramic_screen_fx" },
    { 0x6668, "panel_off" },
    { 0x6669, "panel_on" },
    { 0x666A, "panel_smashed" },
    { 0x666B, "panel_state" },
    { 0x666C, "panic_walla" },
    { 0x666D, "panic_walla_oneshots" },
    { 0x666E, "panned_quad_1_front" },
    { 0x666F, "panned_quad_1_rear" },
    { 0x6670, "panned_quad_2_front" },
    { 0x6671, "panned_quad_2_rear" },
    { 0x6672, "panned_quad_3_front" },
    { 0x6673, "panned_quad_3_rear" },
    { 0x6674, "panoramicfx" },
    { 0x6675, "panzer_delay" },
    { 0x6676, "panzer_ent" },
    { 0x6677, "panzer_ent_offset" },
    { 0x6678, "panzer_node" },
    { 0x6679, "panzer_pos" },
    { 0x667A, "panzer_target" },
    { 0x667B, "parachute_death_monitor" },
    { 0x667C, "parachute_function" },
    { 0x667D, "parachute_movement" },
    { 0x667E, "parachute_notetrack_logic" },
    { 0x667F, "parachute_unload" },
    { 0x6680, "param_map_defaults" },
    { 0x6681, "param_maps" },
    { 0x6682, "param1" },
    { 0x6683, "params" },
    { 0x6684, "params_default" },
    { 0x6685, "parent" },
    { 0x6686, "parent_ent" },
    { 0x6687, "parentcrate" },
    { 0x6688, "parentorigin" },
    { 0x6689, "parking_lot_clear" },
    { 0x668A, "parking_lot_runners" },
    { 0x668B, "parkingalarmcar" },
    { 0x668C, "parkingburkejumpdown" },
    { 0x668D, "parkingguardsreminderdialogue" },
    { 0x668E, "parkinginvestigatorsdialogue" },
    { 0x668F, "parkingreminderdialogue" },
    { 0x6690, "parkingstairskilldialogue" },
    { 0x6691, "parm1" },
    { 0x6692, "parm2" },
    { 0x6693, "parm3" },
    { 0x6694, "parm4" },
    { 0x6695, "parms" },
    { 0x6696, "parse_underwater_triggers" },
    { 0x6697, "parsed" },
    { 0x6698, "parselocationaliases" },
    { 0x6699, "part" },
    { 0x669A, "part_b_mechanism_light_glow_fx" },
    { 0x669B, "part_b_mechanism_light_pulse_fx" },
    { 0x669C, "partciledrylocation" },
    { 0x669D, "participants" },
    { 0x669E, "participation" },
    { 0x669F, "participation_point_cap" },
    { 0x66A0, "participation_point_flattenovertime" },
    { 0x66A1, "particlespawn" },
    { 0x66A2, "particlespawnoriginoffset" },
    { 0x66A3, "particlespray" },
    { 0x66A4, "particlespraymultiplenode" },
    { 0x66A5, "partner" },
    { 0x66A6, "partnerspawning" },
    { 0x66A7, "parts" },
    { 0x66A8, "party_members" },
    { 0x66A9, "partymembers_cb" },
    { 0x66AA, "pass_dot" },
    { 0x66AB, "pass_hovertank_damage_to_player" },
    { 0x66AC, "pass_icon" },
    { 0x66AD, "pass_line_of_sight" },
    { 0x66AE, "pass_mech_melee_damage_to_player" },
    { 0x66AF, "pass_or_throw_active" },
    { 0x66B0, "pass_origin" },
    { 0x66B1, "pass_tappy" },
    { 0x66B2, "pass_target" },
    { 0x66B3, "passenger_2_turret_anim" },
    { 0x66B4, "passenger_2_turret_func" },
    { 0x66B5, "passenger_idle" },
    { 0x66B6, "passenger_shooting" },
    { 0x66B7, "passenger2turret_anime" },
    { 0x66B8, "passkillpickupevent" },
    { 0x66B9, "passoja_death_wait_function" },
    { 0x66BA, "passplayer" },
    { 0x66BB, "passtime" },
    { 0x66BC, "paste_ents" },
    { 0x66BD, "path" },
    { 0x66BE, "path_accel_time" },
    { 0x66BF, "path_chosen" },
    { 0x66C0, "path_deccel_time" },
    { 0x66C1, "path_detour" },
    { 0x66C2, "path_detour_get_detourpath" },
    { 0x66C3, "path_detour_script_origin" },
    { 0x66C4, "path_gate_open" },
    { 0x66C5, "path_gate_wait_till_open" },
    { 0x66C6, "path_gobbler" },
    { 0x66C7, "path_heli" },
    { 0x66C8, "path_idealtime" },
    { 0x66C9, "path_maxspeed" },
    { 0x66CA, "path_mindeccelspeed" },
    { 0x66CB, "path_minspeed" },
    { 0x66CC, "path_nodes" },
    { 0x66CD, "path_solids" },
    { 0x66CE, "path_timeout" },
    { 0x66CF, "path_to_node_at_current_speed" },
    { 0x66D0, "path_to_this_node" },
    { 0x66D1, "path_weight" },
    { 0x66D2, "pathaccel" },
    { 0x66D3, "pathaccelmode" },
    { 0x66D4, "pathchange_candoturnanim" },
    { 0x66D5, "pathchange_cleanupturnanim" },
    { 0x66D6, "pathchange_doturnanim" },
    { 0x66D7, "pathchange_getturnanim" },
    { 0x66D8, "pathchangecheckoverridefunc" },
    { 0x66D9, "pathchangelistener" },
    { 0x66DA, "pathdataavailable" },
    { 0x66DB, "pathdeccel" },
    { 0x66DC, "pathidx" },
    { 0x66DD, "pathinfo_curstartpitch" },
    { 0x66DE, "pathinfo_end_loc" },
    { 0x66DF, "pathinfo_endaim" },
    { 0x66E0, "pathinfo_endpitch" },
    { 0x66E1, "pathinfo_endyaw" },
    { 0x66E2, "pathinfo_len" },
    { 0x66E3, "pathinfo_mode" },
    { 0x66E4, "pathinfo_start_loc" },
    { 0x66E5, "pathinfo_startaim" },
    { 0x66E6, "pathinfo_startpitch" },
    { 0x66E7, "pathinfo_startyaw" },
    { 0x66E8, "pathinfo_t" },
    { 0x66E9, "pathinfo_totalt" },
    { 0x66EA, "pathinfo_velocity" },
    { 0x66EB, "pathing_done" },
    { 0x66EC, "pathmaxrotx" },
    { 0x66ED, "pathmaxrotz" },
    { 0x66EE, "pathrandompercent_reset" },
    { 0x66EF, "pathrandompercent_set" },
    { 0x66F0, "pathrandompercent_zero" },
    { 0x66F1, "pathspeed" },
    { 0x66F2, "pathstartdecceldist" },
    { 0x66F3, "pathtgtspeed" },
    { 0x66F4, "pathturnanimblendtime" },
    { 0x66F5, "pathturnanimoverridefunc" },
    { 0x66F6, "patio_civ_01_cower" },
    { 0x66F7, "patio_civ_03_scream" },
    { 0x66F8, "patio_doors" },
    { 0x66F9, "patio_flashbang" },
    { 0x66FA, "patio_intro_civ_death" },
    { 0x66FB, "patio_male_01_mumble" },
    { 0x66FC, "patrol" },
    { 0x66FD, "patrol_01" },
    { 0x66FE, "patrol_01_unload_spawn_func" },
    { 0x66FF, "patrol_02_unload_spawn_func" },
    { 0x6700, "patrol_03_idle_think" },
    { 0x6701, "patrol_03_unload_spawn_func" },
    { 0x6702, "patrol_04_unload_spawn_func" },
    { 0x6703, "patrol_anim_set" },
    { 0x6704, "patrol_anim_sets" },
    { 0x6705, "patrol_anim_turn180" },
    { 0x6706, "patrol_anims" },
    { 0x6707, "patrol_claimed" },
    { 0x6708, "patrol_creepwalk_unload_spawn_func" },
    { 0x6709, "patrol_do_start_transition_anim" },
    { 0x670A, "patrol_do_stop_transition_anim" },
    { 0x670B, "patrol_end_idle" },
    { 0x670C, "patrol_goal_pos" },
    { 0x670D, "patrol_idle_anim" },
    { 0x670E, "patrol_master" },
    { 0x670F, "patrol_no_stop_transition" },
    { 0x6710, "patrol_pet" },
    { 0x6711, "patrol_post_breach_think" },
    { 0x6712, "patrol_resume_move_start_func" },
    { 0x6713, "patrol_script_animation" },
    { 0x6714, "patrol_scriptedanim" },
    { 0x6715, "patrol_scriptedanims" },
    { 0x6716, "patrol_start" },
    { 0x6717, "patrol_stop" },
    { 0x6718, "patrol_walk_anim" },
    { 0x6719, "patrol_walk_twitch" },
    { 0x671A, "patroller" },
    { 0x671B, "pause_bigmoment_vfx" },
    { 0x671C, "pause_flickerlight" },
    { 0x671D, "pause_oneshot" },
    { 0x671E, "paused" },
    { 0x671F, "pauseeffect" },
    { 0x6720, "pauseexploder" },
    { 0x6721, "pauseexploders" },
    { 0x6722, "pausefxid" },
    { 0x6723, "pausemax" },
    { 0x6724, "pausemin" },
    { 0x6725, "pauseracksystem" },
    { 0x6726, "pausetime" },
    { 0x6727, "pausetimer" },
    { 0x6728, "pausewarbirdenginefxforplayer" },
    { 0x6729, "pausing_bot_connect_monitor" },
    { 0x672A, "pay_machine" },
    { 0x672B, "pbull_callback_crash" },
    { 0x672C, "pbull_callback_from_gas_off_to_rev_hi" },
    { 0x672D, "pbull_callback_from_gas_off_to_rev_low" },
    { 0x672E, "pbull_callback_from_gas_off_to_rev_med" },
    { 0x672F, "pbull_callback_from_reverse_to_reverse_gas_off" },
    { 0x6730, "pbull_callback_from_stopped_to_reverse" },
    { 0x6731, "pbull_callback_gas_off" },
    { 0x6732, "pbull_callback_to_brakes_med" },
    { 0x6733, "pbull_crash_watch" },
    { 0x6734, "pbull_init" },
    { 0x6735, "pbull_is_downshifting" },
    { 0x6736, "pbull_is_reversed" },
    { 0x6737, "pbull_is_revving" },
    { 0x6738, "pbull_is_upshifting" },
    { 0x6739, "pbull_play_reverse_beeps" },
    { 0x673A, "pbull_shift_watch" },
    { 0x673B, "pc_hint_text" },
    { 0x673C, "pc_pitbull_crash" },
    { 0x673D, "pc_pitbull_spawn" },
    { 0x673E, "pc_veh" },
    { 0x673F, "pc_watchstreakuse" },
    { 0x6740, "pcap_drone_opening" },
    { 0x6741, "pcap_pm_rescue" },
    { 0x6742, "pcap_shore_outro" },
    { 0x6743, "pcap_squad_briefing" },
    { 0x6744, "pcap_vo_fus_control_room_burke" },
    { 0x6745, "pcap_vo_fus_control_room_joker" },
    { 0x6746, "pcap_vo_fus_intro_burke" },
    { 0x6747, "pcap_vo_fus_intro_panama_burke" },
    { 0x6748, "pcap_vo_lab_chopper_evac_enter_burke" },
    { 0x6749, "pcap_vo_lab_chopper_evac_enter_cormack" },
    { 0x674A, "pcap_vo_lab_cliff_jump_burke" },
    { 0x674B, "pcap_vo_lab_cliff_rappel_meetup_burke" },
    { 0x674C, "pcap_vo_lab_cliff_rappel_meetup_cormack" },
    { 0x674D, "pcap_vo_lab_cliff_rappel_meetup_knox" },
    { 0x674E, "pcap_vo_lab_intro_guy1" },
    { 0x674F, "pcap_vo_lab_serverroom_burke" },
    { 0x6750, "pcap_vo_lab_serverroom_cormack" },
    { 0x6751, "pcap_vo_lab_serverroom_knox" },
    { 0x6752, "pcap_vo_lab_serverroom_promo_cormack" },
    { 0x6753, "pcap_vo_lab_serverroom_promo_knox" },
    { 0x6754, "pcap_vo_lab_wallclimb_player_hero_01" },
    { 0x6755, "pcap_vo_sanfran_boost_down_burke" },
    { 0x6756, "pcap_vo_sanfran_intro_burke" },
    { 0x6757, "pcap_vo_sanfran_pitbull_crash_burke" },
    { 0x6758, "pcap_vo_sf_b_boosters_cormack" },
    { 0x6759, "pcap_vo_sf_b_bridge_init" },
    { 0x675A, "pcap_vo_sf_b_intro_cormack" },
    { 0x675B, "pcap_vo_sf_b_intro_gideon" },
    { 0x675C, "pd_get_laser_designated_trace" },
    { 0x675D, "pd_laser_designate_target" },
    { 0x675E, "pd_laser_targeting_device" },
    { 0x675F, "pd_monitorlaseroff" },
    { 0x6760, "pd_shouldforcedisablelaser" },
    { 0x6761, "pdrone" },
    { 0x6762, "pdrone_activate" },
    { 0x6763, "pdrone_ai" },
    { 0x6764, "pdrone_ai_deploy" },
    { 0x6765, "pdrone_atlas_init" },
    { 0x6766, "pdrone_can_move_to_point" },
    { 0x6767, "pdrone_can_see_owner_from_point" },
    { 0x6768, "pdrone_can_teleport_to_point" },
    { 0x6769, "pdrone_condition_callback_to_state_deathspin" },
    { 0x676A, "pdrone_condition_callback_to_state_destruct" },
    { 0x676B, "pdrone_condition_callback_to_state_distant" },
    { 0x676C, "pdrone_condition_callback_to_state_flyby" },
    { 0x676D, "pdrone_condition_callback_to_state_flying" },
    { 0x676E, "pdrone_condition_callback_to_state_flyover" },
    { 0x676F, "pdrone_condition_callback_to_state_hover" },
    { 0x6770, "pdrone_condition_callback_to_state_off" },
    { 0x6771, "pdrone_could_be_friendly_fire" },
    { 0x6772, "pdrone_crash_land" },
    { 0x6773, "pdrone_cycle_fire_sound" },
    { 0x6774, "pdrone_damage_function" },
    { 0x6775, "pdrone_deactivate_think" },
    { 0x6776, "pdrone_death_explode" },
    { 0x6777, "pdrone_deploy" },
    { 0x6778, "pdrone_deploy_check" },
    { 0x6779, "pdrone_deploy_hint" },
    { 0x677A, "pdrone_emp_death" },
    { 0x677B, "pdrone_fire_at_enemy" },
    { 0x677C, "pdrone_fire_finished" },
    { 0x677D, "pdrone_fire_request" },
    { 0x677E, "pdrone_fire_weapon" },
    { 0x677F, "pdrone_flying_fx" },
    { 0x6780, "pdrone_get_nodes_in_radius" },
    { 0x6781, "pdrone_gunshot_teammate" },
    { 0x6782, "pdrone_handle_death" },
    { 0x6783, "pdrone_launch" },
    { 0x6784, "pdrone_launched" },
    { 0x6785, "pdrone_marked_state" },
    { 0x6786, "pdrone_monitor_death" },
    { 0x6787, "pdrone_movement_follow" },
    { 0x6788, "pdrone_movement_follow_buddy" },
    { 0x6789, "pdrone_movement_go_to_point" },
    { 0x678A, "pdrone_notify_explosion" },
    { 0x678B, "pdrone_orient_to_closest_ai_target" },
    { 0x678C, "pdrone_orient_to_closest_ent_target" },
    { 0x678D, "pdrone_orient_to_closest_target" },
    { 0x678E, "pdrone_parms" },
    { 0x678F, "pdrone_player_add_ent_target" },
    { 0x6790, "pdrone_player_add_vehicle_target" },
    { 0x6791, "pdrone_player_callback_look" },
    { 0x6792, "pdrone_player_collision_monitor" },
    { 0x6793, "pdrone_player_condition_callback_to_state_flying" },
    { 0x6794, "pdrone_player_condition_callback_to_state_hover" },
    { 0x6795, "pdrone_player_condition_callback_to_state_idle" },
    { 0x6796, "pdrone_player_condition_callback_to_state_looking" },
    { 0x6797, "pdrone_player_death" },
    { 0x6798, "pdrone_player_enter" },
    { 0x6799, "pdrone_player_exit" },
    { 0x679A, "pdrone_player_force_exit" },
    { 0x679B, "pdrone_player_get_current_fov" },
    { 0x679C, "pdrone_player_init" },
    { 0x679D, "pdrone_player_is_driving" },
    { 0x679E, "pdrone_player_loop" },
    { 0x679F, "pdrone_player_spawn" },
    { 0x67A0, "pdrone_player_use" },
    { 0x67A1, "pdrone_return" },
    { 0x67A2, "pdrone_return_pathing" },
    { 0x67A3, "pdrone_security_condition_callback_to_state_deathspin" },
    { 0x67A4, "pdrone_security_condition_callback_to_state_destruct" },
    { 0x67A5, "pdrone_security_condition_callback_to_state_distant" },
    { 0x67A6, "pdrone_security_condition_callback_to_state_flyby" },
    { 0x67A7, "pdrone_security_condition_callback_to_state_flying" },
    { 0x67A8, "pdrone_security_condition_callback_to_state_flyover" },
    { 0x67A9, "pdrone_security_condition_callback_to_state_hover" },
    { 0x67AA, "pdrone_security_condition_callback_to_state_off" },
    { 0x67AB, "pdrone_security_speed_modifier_callback_linear" },
    { 0x67AC, "pdrone_security_speed_modifier_callback_perlin_noise" },
    { 0x67AD, "pdrone_security_speed_modifier_callback_smoother" },
    { 0x67AE, "pdrone_should_hold_fire" },
    { 0x67AF, "pdrone_speed_modifier_callback_linear" },
    { 0x67B0, "pdrone_speed_modifier_callback_perlin_noise" },
    { 0x67B1, "pdrone_speed_modifier_callback_smoother" },
    { 0x67B2, "pdrone_swarm_condition_callback_to_state_distant" },
    { 0x67B3, "pdrone_swarm_condition_callback_to_state_flying" },
    { 0x67B4, "pdrone_swarm_condition_callback_to_state_hover" },
    { 0x67B5, "pdrone_targeting" },
    { 0x67B6, "pdrone_update_threat_sensor" },
    { 0x67B7, "pdroneactive" },
    { 0x67B8, "pdronereturning" },
    { 0x67B9, "peekout" },
    { 0x67BA, "penalty_timer" },
    { 0x67BB, "pendingreinforcementavailable" },
    { 0x67BC, "penthouse_begin" },
    { 0x67BD, "penthouse_main" },
    { 0x67BE, "penthouse_objective" },
    { 0x67BF, "penthouse_reinforcements_01_guy_01_vo" },
    { 0x67C0, "penthouse_reinforcements_01_guy_02_vo" },
    { 0x67C1, "penthouse_reinforcements_02_guy_01_vo" },
    { 0x67C2, "penthouse_reinforcements_02_guy_02_vo" },
    { 0x67C3, "penthouse_start" },
    { 0x67C4, "penthouse_vo" },
    { 0x67C5, "percent" },
    { 0x67C6, "percentchance" },
    { 0x67C7, "perch_runner" },
    { 0x67C8, "perch_spot_wave" },
    { 0x67C9, "perelementswap" },
    { 0x67CA, "perferred_crash_location" },
    { 0x67CB, "perforing_color_driven_anim" },
    { 0x67CC, "perk_deleteondeath" },
    { 0x67CD, "perkfuncs" },
    { 0x67CE, "perkicon" },
    { 0x67CF, "perkname" },
    { 0x67D0, "perkoutlined" },
    { 0x67D1, "perksetfuncs" },
    { 0x67D2, "perksperkname" },
    { 0x67D3, "perksperkpower" },
    { 0x67D4, "perksuseslot" },
    { 0x67D5, "perkunsetfuncs" },
    { 0x67D6, "perkusedeathtracker" },
    { 0x67D7, "perlin_flickering_light" },
    { 0x67D8, "permanentcustommovetransition" },
    { 0x67D9, "persist" },
    { 0x67DA, "persistentdatainfo" },
    { 0x67DB, "persistentdebugline" },
    { 0x67DC, "personalcoldbreath" },
    { 0x67DD, "personalcoldbreathspawner" },
    { 0x67DE, "personalcoldbreathstop" },
    { 0x67DF, "personality" },
    { 0x67E0, "personality_init_function" },
    { 0x67E1, "personality_update_function" },
    { 0x67E2, "personalitymanuallyset" },
    { 0x67E3, "personalradar" },
    { 0x67E4, "personalsighttime" },
    { 0x67E5, "personalusebar" },
    { 0x67E6, "pet_debug_positions" },
    { 0x67E7, "pet_patrol" },
    { 0x67E8, "pet_patrol_create_positions" },
    { 0x67E9, "pet_patrol_get_available_origin" },
    { 0x67EA, "pet_patrol_handle_move_state" },
    { 0x67EB, "pet_patrol_handle_movespeed" },
    { 0x67EC, "pet_patrol_init_positions" },
    { 0x67ED, "phone" },
    { 0x67EE, "phone_conversation" },
    { 0x67EF, "photo_copier" },
    { 0x67F0, "photo_copier_copy_bar_goes" },
    { 0x67F1, "photo_copier_init" },
    { 0x67F2, "photo_copier_light_on" },
    { 0x67F3, "photo_copier_no_light" },
    { 0x67F4, "photo_copier_stop" },
    { 0x67F5, "photo_light_flicker" },
    { 0x67F6, "phrase" },
    { 0x67F7, "physical_output" },
    { 0x67F8, "physics_bodies_off" },
    { 0x67F9, "physics_bodies_on" },
    { 0x67FA, "physics_crash" },
    { 0x67FB, "physics_gravity_vector" },
    { 0x67FC, "physics_impact_watch" },
    { 0x67FD, "physics_launch" },
    { 0x67FE, "physics_launch_with_impulse" },
    { 0x67FF, "physics_object_create" },
    { 0x6800, "physics_object_remove" },
    { 0x6801, "physics_pulse_on" },
    { 0x6802, "physicsjolt_proximity" },
    { 0x6803, "physicssphereforce" },
    { 0x6804, "physicssphereradius" },
    { 0x6805, "physicswaiter" },
    { 0x6806, "pianodamagethink" },
    { 0x6807, "pianothink" },
    { 0x6808, "pick_best_gear" },
    { 0x6809, "pick_player_location_vol" },
    { 0x680A, "pick_target_nag_dialogue" },
    { 0x680B, "pickedupweaponfrom" },
    { 0x680C, "pickinstinctdogspawnpoint" },
    { 0x680D, "picknewtarget" },
    { 0x680E, "pickup_allowed" },
    { 0x680F, "pickup_goal_ang" },
    { 0x6810, "pickup_gun" },
    { 0x6811, "pickup_message_deleted" },
    { 0x6812, "pickup_stinger" },
    { 0x6813, "pickupbounce" },
    { 0x6814, "pickupent" },
    { 0x6815, "pickupobjectdelay" },
    { 0x6816, "pickupstartflashing" },
    { 0x6817, "pickuptimeout" },
    { 0x6818, "pickuptimer" },
    { 0x6819, "pickuptrigger" },
    { 0x681A, "pieces" },
    { 0x681B, "pigeons_camera_view_zone3000" },
    { 0x681C, "pigeons_flock_takeoff" },
    { 0x681D, "pigeons_flyoff_alley1" },
    { 0x681E, "pigeons_ledges_react_roundabout" },
    { 0x681F, "pigeons_rail_react_intro" },
    { 0x6820, "pilot" },
    { 0x6821, "pilot_intro" },
    { 0x6822, "ping_fx" },
    { 0x6823, "pingstate" },
    { 0x6824, "pipe" },
    { 0x6825, "pipe_calc_ballistic" },
    { 0x6826, "pipe_calc_nofx" },
    { 0x6827, "pipe_calc_splash" },
    { 0x6828, "pipe_damage" },
    { 0x6829, "pipe_fx_array" },
    { 0x682A, "pipe_logic" },
    { 0x682B, "pipe_wait_loop" },
    { 0x682C, "pipefx" },
    { 0x682D, "pipes_init" },
    { 0x682E, "pipesdamage" },
    { 0x682F, "pipesetup" },
    { 0x6830, "pistolshoot" },
    { 0x6831, "pitbull_atlas_impact" },
    { 0x6832, "pitbull_atlas_impact_initial" },
    { 0x6833, "pitbull_back_to_speed" },
    { 0x6834, "pitbull_crash_impact_fx" },
    { 0x6835, "pitbull_crash_jump_start" },
    { 0x6836, "pitbull_crash_sound_design" },
    { 0x6837, "pitbull_crash_swap_to_real_model" },
    { 0x6838, "pitbull_crashed_dof" },
    { 0x6839, "pitbull_drive_dof" },
    { 0x683A, "pitbull_flipped_failsafe" },
    { 0x683B, "pitbull_headlights_off" },
    { 0x683C, "pitbull_headlights_on" },
    { 0x683D, "pitbull_hide_part" },
    { 0x683E, "pitbull_impact_blur" },
    { 0x683F, "pitbull_impact_blur_long" },
    { 0x6840, "pitbull_impact_fx" },
    { 0x6841, "pitbull_intro_animation" },
    { 0x6842, "pitbull_intro_control_rumble" },
    { 0x6843, "pitbull_intro_foley_ui" },
    { 0x6844, "pitbull_land_upside_down" },
    { 0x6845, "pitbull_play_lui_cinematic" },
    { 0x6846, "pitbull_roof_impact" },
    { 0x6847, "pitbull_rumble" },
    { 0x6848, "pitbull_rumble_stop" },
    { 0x6849, "pitbull_second_impact" },
    { 0x684A, "pitbull_show_part" },
    { 0x684B, "pitbull_start_flip" },
    { 0x684C, "pitbull_turret_aim" },
    { 0x684D, "pitbull_turret_fire" },
    { 0x684E, "pitbull_turret_set_target" },
    { 0x684F, "pitbull_turret_targeting" },
    { 0x6850, "pitbull_update_hud_brightness" },
    { 0x6851, "pitbull_update_lui_charge" },
    { 0x6852, "pitbull_vehicle_collision_rumble" },
    { 0x6853, "pitbulldestroyedanimation" },
    { 0x6854, "pitch" },
    { 0x6855, "pitch_map_name" },
    { 0x6856, "pitch_rate" },
    { 0x6857, "pitch_time" },
    { 0x6858, "pitching_hard" },
    { 0x6859, "pitching_hard_start_time" },
    { 0x685A, "pivot" },
    { 0x685B, "place" },
    { 0x685C, "place_foam_bomb" },
    { 0x685D, "place_weapon_on" },
    { 0x685E, "placeableconfigs" },
    { 0x685F, "placedsfx" },
    { 0x6860, "placeiedrumblelight" },
    { 0x6861, "placement" },
    { 0x6862, "placementheighttolerance" },
    { 0x6863, "placementlinkentity" },
    { 0x6864, "placementoffsetz" },
    { 0x6865, "placementok" },
    { 0x6866, "placementorigin" },
    { 0x6867, "placementradius" },
    { 0x6868, "placestring" },
    { 0x6869, "placeweaponon" },
    { 0x686A, "placingitemstreakname" },
    { 0x686B, "placingsentry" },
    { 0x686C, "plagueevent" },
    { 0x686D, "plane" },
    { 0x686E, "plane_bomb_cluster" },
    { 0x686F, "plane_bomb_node" },
    { 0x6870, "plane_chase_cam" },
    { 0x6871, "plane_expl_gloves" },
    { 0x6872, "plane_health_monitor" },
    { 0x6873, "plane_health_regen" },
    { 0x6874, "plane_in_formation" },
    { 0x6875, "plane_init" },
    { 0x6876, "plane_intialized" },
    { 0x6877, "plane_sound_node" },
    { 0x6878, "plane_sound_players" },
    { 0x6879, "plane_spots" },
    { 0x687A, "plane_test" },
    { 0x687B, "planeanimatepath" },
    { 0x687C, "planemodel" },
    { 0x687D, "planeplayeffects" },
    { 0x687E, "planes" },
    { 0x687F, "planning_fail" },
    { 0x6880, "plant_emp" },
    { 0x6881, "plant_emp_setup" },
    { 0x6882, "plant_emp_trigger" },
    { 0x6883, "plant_foam_nag_dialogue" },
    { 0x6884, "plant_tracker_begin" },
    { 0x6885, "plant_tracker_debug_checkpoint" },
    { 0x6886, "plant_tracker_light_model_swap" },
    { 0x6887, "plant_tracker_main" },
    { 0x6888, "plant_tracker_objective" },
    { 0x6889, "plant_tracker_rumbles" },
    { 0x688A, "plant_tracker_start" },
    { 0x688B, "plant_tracker_vo" },
    { 0x688C, "plant_tracker_waits" },
    { 0x688D, "planttime" },
    { 0x688E, "platform_door_think" },
    { 0x688F, "platformmatches" },
    { 0x6890, "play_2d_reverb_alarm_sound" },
    { 0x6891, "play_aim_anim" },
    { 0x6892, "play_ally_callout_vo" },
    { 0x6893, "play_ally_warning_vo" },
    { 0x6894, "play_and_store_fx_on_tag" },
    { 0x6895, "play_anim_and_delete" },
    { 0x6896, "play_anim_on_trigger" },
    { 0x6897, "play_announcment_over_pa" },
    { 0x6898, "play_arm_room_dialog" },
    { 0x6899, "play_arm_room_dialog_nag" },
    { 0x689A, "play_back_thruster_light_rz" },
    { 0x689B, "play_backout_sound_breath" },
    { 0x689C, "play_backout_sound_heartbeat" },
    { 0x689D, "play_base_radio_dialog1" },
    { 0x689E, "play_base_soldier_group_dialog" },
    { 0x689F, "play_bike_gesture" },
    { 0x68A0, "play_blood_fx_when_shot" },
    { 0x68A1, "play_blood_pool" },
    { 0x68A2, "play_boost_sound" },
    { 0x68A3, "play_boosters_off_anim" },
    { 0x68A4, "play_bridge_lb_sentinel_flyby" },
    { 0x68A5, "play_building_jump_1_scene" },
    { 0x68A6, "play_camera_shake_tour_ride" },
    { 0x68A7, "play_canopy_bink" },
    { 0x68A8, "play_canopy_closed_bink" },
    { 0x68A9, "play_centroid_switch_floor3" },
    { 0x68AA, "play_centroid_switch_top" },
    { 0x68AB, "play_character_microwave_sparks" },
    { 0x68AC, "play_charged_shot_fx" },
    { 0x68AD, "play_chyron_video" },
    { 0x68AE, "play_cinematic" },
    { 0x68AF, "play_civilian_dialog" },
    { 0x68B0, "play_cliff_rappel_animation" },
    { 0x68B1, "play_combat_state" },
    { 0x68B2, "play_courtyard_hangar_door_rpg" },
    { 0x68B3, "play_credits" },
    { 0x68B4, "play_death_explosion_fx" },
    { 0x68B5, "play_deploy_scene_handcuff_ents" },
    { 0x68B6, "play_detpack_plant_sound" },
    { 0x68B7, "play_dialog" },
    { 0x68B8, "play_dialog_boost" },
    { 0x68B9, "play_dialog_boost_block_chatter" },
    { 0x68BA, "play_dialog_boost_block_mission" },
    { 0x68BB, "play_dialog_boost_block_nag" },
    { 0x68BC, "play_dialog_bridge" },
    { 0x68BD, "play_dialog_bridge_block_crash" },
    { 0x68BE, "play_dialog_bridge_block_crawl" },
    { 0x68BF, "play_dialog_confrontation_block_go" },
    { 0x68C0, "play_dialog_confrontation_block_leave" },
    { 0x68C1, "play_dialog_confrontation_block_mrx" },
    { 0x68C2, "play_dialog_intro" },
    { 0x68C3, "play_dialog_intro_block_cargo" },
    { 0x68C4, "play_dialog_intro_block_fleet" },
    { 0x68C5, "play_dialog_oncoming" },
    { 0x68C6, "play_dialog_oncoming_block_converging" },
    { 0x68C7, "play_dialog_oncoming_block_knocked" },
    { 0x68C8, "play_dialog_street" },
    { 0x68C9, "play_dialog_street_block_assist" },
    { 0x68CA, "play_dialog_street_block_boost_incoming" },
    { 0x68CB, "play_dialog_street_block_boosters" },
    { 0x68CC, "play_dialog_street_block_cover" },
    { 0x68CD, "play_dialog_street_block_foot" },
    { 0x68CE, "play_dialog_street_block_friendlies" },
    { 0x68CF, "play_dialog_street_block_helo" },
    { 0x68D0, "play_dialog_street_block_hurry" },
    { 0x68D1, "play_dialog_street_block_pitbull" },
    { 0x68D2, "play_dialog_street_block_sitrep" },
    { 0x68D3, "play_dialog_street_block_van_stop" },
    { 0x68D4, "play_dialog_tunnel" },
    { 0x68D5, "play_dialog_tunnel_block_bus" },
    { 0x68D6, "play_dialog_tunnel_block_chase" },
    { 0x68D7, "play_dialog_tunnel_block_construction" },
    { 0x68D8, "play_dialog_tunnel_block_tanker" },
    { 0x68D9, "play_dialog_tunnel_block_update" },
    { 0x68DA, "play_dialog_van" },
    { 0x68DB, "play_dialog_van_arrest" },
    { 0x68DC, "play_dialog_van_check" },
    { 0x68DD, "play_dialog_van_collapse" },
    { 0x68DE, "play_dialog_van_deploy" },
    { 0x68DF, "play_dialogue" },
    { 0x68E0, "play_dialogue_boat" },
    { 0x68E1, "play_dialogue_boat_block_close" },
    { 0x68E2, "play_dialogue_boat_block_dive" },
    { 0x68E3, "play_dialogue_boat_block_grapple" },
    { 0x68E4, "play_dialogue_boat_block_intro" },
    { 0x68E5, "play_dialogue_boat_block_missiles" },
    { 0x68E6, "play_dialogue_boat_block_ramp" },
    { 0x68E7, "play_dialogue_climb" },
    { 0x68E8, "play_dialogue_climb_block_boatexit" },
    { 0x68E9, "play_dialogue_climb_block_bridge" },
    { 0x68EA, "play_dialogue_climb_block_careful" },
    { 0x68EB, "play_dialogue_climb_block_climb" },
    { 0x68EC, "play_dialogue_climb_block_contact" },
    { 0x68ED, "play_dialogue_climb_block_containers" },
    { 0x68EE, "play_dialogue_climb_block_crane" },
    { 0x68EF, "play_dialogue_climb_block_cross" },
    { 0x68F0, "play_dialogue_climb_block_drop" },
    { 0x68F1, "play_dialogue_climb_block_grapple1" },
    { 0x68F2, "play_dialogue_climb_block_grapple2" },
    { 0x68F3, "play_dialogue_climb_block_grapple3" },
    { 0x68F4, "play_dialogue_climb_block_ledge" },
    { 0x68F5, "play_dialogue_climb_block_tower" },
    { 0x68F6, "play_dialogue_climb_block_way" },
    { 0x68F7, "play_dialogue_climb_crane_nag" },
    { 0x68F8, "play_dialogue_climb_grapple_nag" },
    { 0x68F9, "play_dialogue_confrontation" },
    { 0x68FA, "play_dialogue_crane_block_go" },
    { 0x68FB, "play_dialogue_crane_block_jump" },
    { 0x68FC, "play_dialogue_crane_block_slide" },
    { 0x68FD, "play_dialogue_crane_block_start" },
    { 0x68FE, "play_dialogue_docks" },
    { 0x68FF, "play_dialogue_docks_backtrack" },
    { 0x6900, "play_dialogue_docks_block_boat" },
    { 0x6901, "play_dialogue_docks_block_boatnag" },
    { 0x6902, "play_dialogue_docks_block_intro" },
    { 0x6903, "play_dialogue_escape" },
    { 0x6904, "play_dialogue_escape_block_announce" },
    { 0x6905, "play_dialogue_escape_block_climb" },
    { 0x6906, "play_dialogue_escape_block_deadend" },
    { 0x6907, "play_dialogue_escape_block_guarddoor" },
    { 0x6908, "play_dialogue_escape_block_intros" },
    { 0x6909, "play_dialogue_escape_block_swarm" },
    { 0x690A, "play_dialogue_office" },
    { 0x690B, "play_dialogue_office_block_baghdad" },
    { 0x690C, "play_dialogue_office_block_congrats" },
    { 0x690D, "play_dialogue_office_block_door" },
    { 0x690E, "play_dialogue_office_block_guard" },
    { 0x690F, "play_dialogue_office_block_kva" },
    { 0x6910, "play_dialogue_oldtown" },
    { 0x6911, "play_dialogue_oldtown_block_contact" },
    { 0x6912, "play_dialogue_oldtown_block_naglines" },
    { 0x6913, "play_dialogue_oldtown_player_spotted" },
    { 0x6914, "play_dialogue_roof" },
    { 0x6915, "play_dialogue_roof_block_alert" },
    { 0x6916, "play_dialogue_roof_block_away" },
    { 0x6917, "play_dialogue_roof_block_fall" },
    { 0x6918, "play_dialogue_roof_block_gates" },
    { 0x6919, "play_dialogue_roof_block_jump" },
    { 0x691A, "play_dialogue_roof_block_run" },
    { 0x691B, "play_dialogue_sewer" },
    { 0x691C, "play_dialogue_sewer_block_announcement" },
    { 0x691D, "play_dialogue_sewer_block_checkpoint" },
    { 0x691E, "play_dialogue_sewer_block_guards" },
    { 0x691F, "play_dialogue_swim" },
    { 0x6920, "play_dialogue_swim_block_cough" },
    { 0x6921, "play_dialogue_swim_block_sewer" },
    { 0x6922, "play_dilaogue_docks_block_ast" },
    { 0x6923, "play_doctor_pip" },
    { 0x6924, "play_drone_range_dialog1" },
    { 0x6925, "play_drone_range_dialog2" },
    { 0x6926, "play_drone_range_dialog3" },
    { 0x6927, "play_dust" },
    { 0x6928, "play_earthquake_rumble" },
    { 0x6929, "play_earthquake_rumble_for_all_players" },
    { 0x692A, "play_emp_audio" },
    { 0x692B, "play_emp_nag_lines" },
    { 0x692C, "play_emp_reboot_bik" },
    { 0x692D, "play_entire_interactive_pod_exit" },
    { 0x692E, "play_environment_microwave_sparks" },
    { 0x692F, "play_event_music" },
    { 0x6930, "play_exo_hover_vfx" },
    { 0x6931, "play_exo_repair_movement_sound" },
    { 0x6932, "play_exo_room_dialog1" },
    { 0x6933, "play_exo_room_dialog1_nag" },
    { 0x6934, "play_exo_room_dialog2" },
    { 0x6935, "play_exo_room_techs_dialog1" },
    { 0x6936, "play_exo_room_techs_dialog2" },
    { 0x6937, "play_explosion_sound_drone_success" },
    { 0x6938, "play_falling_snow" },
    { 0x6939, "play_finale_low_burn" },
    { 0x693A, "play_finale_silo_blue" },
    { 0x693B, "play_finale_silo_center" },
    { 0x693C, "play_finale_silo_end_cine" },
    { 0x693D, "play_finale_silo_neutral" },
    { 0x693E, "play_finale_silo_orange" },
    { 0x693F, "play_finale_silo_orange_approach" },
    { 0x6940, "play_finale_silo_round_tunnel" },
    { 0x6941, "play_finale_silo_yellow" },
    { 0x6942, "play_flickering_bridge_light" },
    { 0x6943, "play_flickering_fire_light" },
    { 0x6944, "play_flickering_hanger_light" },
    { 0x6945, "play_flickering_info_hallway_light" },
    { 0x6946, "play_flickering_info_light" },
    { 0x6947, "play_flickering_interior_light" },
    { 0x6948, "play_flickering_light_school_01" },
    { 0x6949, "play_flickering_light_school_03" },
    { 0x694A, "play_flickerlight_motion_preset" },
    { 0x694B, "play_flickerlight_preset" },
    { 0x694C, "play_front_thruster_light_rz" },
    { 0x694D, "play_fullscreen_blood_splatter" },
    { 0x694E, "play_fullscreen_dirt" },
    { 0x694F, "play_fullscreen_mist" },
    { 0x6950, "play_funeral_dialog" },
    { 0x6951, "play_fx_attached_to_actor" },
    { 0x6952, "play_fx_attached_to_chain" },
    { 0x6953, "play_fx_on_actor" },
    { 0x6954, "play_fx_on_chain" },
    { 0x6955, "play_fx_with_handle" },
    { 0x6956, "play_fxlighting_fx" },
    { 0x6957, "play_garage_bike_dismount" },
    { 0x6958, "play_goliath_death_fx" },
    { 0x6959, "play_grapple_anim" },
    { 0x695A, "play_grenade_range_dialog1" },
    { 0x695B, "play_grenade_range_dialog2" },
    { 0x695C, "play_grenade_range_dialog3" },
    { 0x695D, "play_grenade_range_dialog4" },
    { 0x695E, "play_grenade_range_dialog5" },
    { 0x695F, "play_hit_reaction" },
    { 0x6960, "play_hostage_vehicle_pip" },
    { 0x6961, "play_hotel_exit_adaptive_music" },
    { 0x6962, "play_idle_anim" },
    { 0x6963, "play_idle_back_thruster_rz" },
    { 0x6964, "play_idle_front_thruster_rz" },
    { 0x6965, "play_idle_tread_front_rz" },
    { 0x6966, "play_ilana_vo" },
    { 0x6967, "play_insufficient_lethal_energy_sfx" },
    { 0x6968, "play_insufficient_tactical_energy_sfx" },
    { 0x6969, "play_interior_dialogue" },
    { 0x696A, "play_interval_sound" },
    { 0x696B, "play_irons_bink" },
    { 0x696C, "play_irons_pip" },
    { 0x696D, "play_jammer_1_anim" },
    { 0x696E, "play_jammer_2_anim" },
    { 0x696F, "play_jump_out_anim" },
    { 0x6970, "play_jump_out_of_heli_rumble" },
    { 0x6971, "play_lab_reactor_pip" },
    { 0x6972, "play_lensflare_subway_int_off" },
    { 0x6973, "play_lensflare_subway_int_on" },
    { 0x6974, "play_loop_sound_on_destructible" },
    { 0x6975, "play_loop_sound_on_entity" },
    { 0x6976, "play_loop_sound_on_tag" },
    { 0x6977, "play_loop_until_drop_distance" },
    { 0x6978, "play_loop_until_message" },
    { 0x6979, "play_looping_beep_on_player" },
    { 0x697A, "play_loopsound_in_space" },
    { 0x697B, "play_maglev_train_path" },
    { 0x697C, "play_microwave_physics" },
    { 0x697D, "play_microwave_sparkfx" },
    { 0x697E, "play_missile_whoosh_thread" },
    { 0x697F, "play_mode" },
    { 0x6980, "play_monitor_cinematic" },
    { 0x6981, "play_mwp_sinkhole_forceshadows" },
    { 0x6982, "play_new_and_kill_old_fx_l" },
    { 0x6983, "play_new_and_kill_old_fx_r" },
    { 0x6984, "play_new_idle" },
    { 0x6985, "play_out_of_bounds_vo" },
    { 0x6986, "play_pa_dialog_reset" },
    { 0x6987, "play_pa_exo_dialog1" },
    { 0x6988, "play_pa_exo_dialog2" },
    { 0x6989, "play_pa_street_dialog1" },
    { 0x698A, "play_pain_sound" },
    { 0x698B, "play_persistent_fx_on_screen" },
    { 0x698C, "play_pitbull_add_idle" },
    { 0x698D, "play_pitbull_anim" },
    { 0x698E, "play_pitbull_camera_anim" },
    { 0x698F, "play_pitbull_camera_speed_anim" },
    { 0x6990, "play_pitbull_gear_shift_anim" },
    { 0x6991, "play_pitbull_speed_anim" },
    { 0x6992, "play_pitbull_steer_anim" },
    { 0x6993, "play_pm_rescue_walla" },
    { 0x6994, "play_pulse_light" },
    { 0x6995, "play_pulse_preset" },
    { 0x6996, "play_railgun_fx" },
    { 0x6997, "play_rappel_pip" },
    { 0x6998, "play_reactive_fx" },
    { 0x6999, "play_ready_room_dialog1" },
    { 0x699A, "play_ready_room_dialog2" },
    { 0x699B, "play_ready_room_dialog3" },
    { 0x699C, "play_ready_room_dialog4" },
    { 0x699D, "play_ready_room_elevator_nag" },
    { 0x699E, "play_ready_up_anim" },
    { 0x699F, "play_regular_back_thruster_rz" },
    { 0x69A0, "play_regular_front_thruster_rz" },
    { 0x69A1, "play_regular_tail_thruster_rz" },
    { 0x69A2, "play_regular_tread_back_rz" },
    { 0x69A3, "play_regular_tread_front_rz" },
    { 0x69A4, "play_reload_buzz" },
    { 0x69A5, "play_reload_malfunction" },
    { 0x69A6, "play_reload_malfunction_on_next_reload" },
    { 0x69A7, "play_rest_anim" },
    { 0x69A8, "play_rumble_arm_repair" },
    { 0x69A9, "play_rumble_elevator" },
    { 0x69AA, "play_rumble_funeral_gun_salute" },
    { 0x69AB, "play_rumble_jeep_ride" },
    { 0x69AC, "play_rumble_on_entity" },
    { 0x69AD, "play_rumble_training_s1_mute_breach" },
    { 0x69AE, "play_rumble_training_s1_president_load_fail" },
    { 0x69AF, "play_rumble_training_s1_reload_malfunction" },
    { 0x69B0, "play_rumble_training_s2_president_load" },
    { 0x69B1, "play_rumble_walker_tank" },
    { 0x69B2, "play_s_flicker_fluo_jump2_shadow_on" },
    { 0x69B3, "play_s_flicker_jb1" },
    { 0x69B4, "play_s_flicker_jb2" },
    { 0x69B5, "play_s_flicker_sh" },
    { 0x69B6, "play_seoul_videolog" },
    { 0x69B7, "play_shooting_range_dialog_friendlies" },
    { 0x69B8, "play_shooting_range_dialog_overdrive" },
    { 0x69B9, "play_shooting_range_dialog1" },
    { 0x69BA, "play_shooting_range_dialog1_nag" },
    { 0x69BB, "play_shooting_range_dialog2" },
    { 0x69BC, "play_shooting_range_dialog2_nag" },
    { 0x69BD, "play_shooting_range_dialog3" },
    { 0x69BE, "play_shooting_range_dialog4" },
    { 0x69BF, "play_shooting_range_dialogue_sequence" },
    { 0x69C0, "play_soul_intro_movie" },
    { 0x69C1, "play_sound" },
    { 0x69C2, "play_sound_in_space" },
    { 0x69C3, "play_sound_in_space_with_angles" },
    { 0x69C4, "play_sound_on_entity" },
    { 0x69C5, "play_sound_on_tag" },
    { 0x69C6, "play_sound_on_tag_endon_death" },
    { 0x69C7, "play_sound_stop_on_notify" },
    { 0x69C8, "play_squad_gesture" },
    { 0x69C9, "play_tennis_court_vo" },
    { 0x69CA, "play_throw_anim" },
    { 0x69CB, "play_thruster_amount_given_tag" },
    { 0x69CC, "play_thruster_rotation" },
    { 0x69CD, "play_tour_start_dialog1" },
    { 0x69CE, "play_tower_debris_fx" },
    { 0x69CF, "play_tracking_grenade_impacts" },
    { 0x69D0, "play_training_s1_flag_vo_training_s1_joker_prophet_approaching" },
    { 0x69D1, "play_training_s1_gideon_jeep_nag" },
    { 0x69D2, "play_training_s1_joker_clear_room" },
    { 0x69D3, "play_training_s1_joker_close_kitchen" },
    { 0x69D4, "play_training_s1_joker_dammit" },
    { 0x69D5, "play_training_s1_joker_dont_engage" },
    { 0x69D6, "play_training_s1_joker_drop_em" },
    { 0x69D7, "play_training_s1_joker_everyone_knows" },
    { 0x69D8, "play_training_s1_joker_go_go" },
    { 0x69D9, "play_training_s1_joker_good_kill" },
    { 0x69DA, "play_training_s1_joker_hit_em" },
    { 0x69DB, "play_training_s1_joker_hit_em_mitchell" },
    { 0x69DC, "play_training_s1_joker_mr_president" },
    { 0x69DD, "play_training_s1_joker_mute_charge" },
    { 0x69DE, "play_training_s1_joker_mute_charge_nag" },
    { 0x69DF, "play_training_s1_joker_ok_move" },
    { 0x69E0, "play_training_s1_joker_on_you" },
    { 0x69E1, "play_training_s1_joker_our_ride" },
    { 0x69E2, "play_training_s1_joker_patrol_approaching" },
    { 0x69E3, "play_training_s1_joker_pools_clear" },
    { 0x69E4, "play_training_s1_joker_pools_clear_stealth" },
    { 0x69E5, "play_training_s1_joker_poppin_smoke" },
    { 0x69E6, "play_training_s1_joker_ride_nag" },
    { 0x69E7, "play_training_s1_joker_spotted_us" },
    { 0x69E8, "play_training_s1_joker_stack_up" },
    { 0x69E9, "play_training_s1_joker_take_out" },
    { 0x69EA, "play_training_s1_joker_take_out_nag" },
    { 0x69EB, "play_training_s1_joker_threat_grenade" },
    { 0x69EC, "play_training_s1_joker_two_terrace" },
    { 0x69ED, "play_training_s1_joker_were_clear" },
    { 0x69EE, "play_training_s1_kva_what" },
    { 0x69EF, "play_training_s1_prophet_tracking_potus" },
    { 0x69F0, "play_training_s1_reload_malfunctions" },
    { 0x69F1, "play_training_s1_rivers_clear" },
    { 0x69F2, "play_training_s1_rivers_contact_below" },
    { 0x69F3, "play_training_s1_rivers_got_another" },
    { 0x69F4, "play_training_s1_rivers_got_drones" },
    { 0x69F5, "play_training_s1_rivers_hostiles_road" },
    { 0x69F6, "play_training_s1_rivers_multiple_hostiles" },
    { 0x69F7, "play_training_s1_rivers_pools_clear" },
    { 0x69F8, "play_training_s1_rivers_room_clear" },
    { 0x69F9, "play_training_s1_shit_clear" },
    { 0x69FA, "play_training_s1_wrong_grenade" },
    { 0x69FB, "play_training_s2_gideon_clear_move" },
    { 0x69FC, "play_training_s2_gideon_dont_let_up" },
    { 0x69FD, "play_training_s2_gideon_drone_down" },
    { 0x69FE, "play_training_s2_gideon_go_go" },
    { 0x69FF, "play_training_s2_gideon_hit_door_nag" },
    { 0x6A00, "play_training_s2_gideon_media_room" },
    { 0x6A01, "play_training_s2_gideon_mitchell_assault_drone" },
    { 0x6A02, "play_training_s2_gideon_mitchell_assault_drone_nag" },
    { 0x6A03, "play_training_s2_gideon_mitchell_secure_nag" },
    { 0x6A04, "play_training_s2_gideon_mitchell_sweep" },
    { 0x6A05, "play_training_s2_gideon_mr_president" },
    { 0x6A06, "play_training_s2_gideon_my_lead" },
    { 0x6A07, "play_training_s2_gideon_our_exfil" },
    { 0x6A08, "play_training_s2_gideon_package_secure" },
    { 0x6A09, "play_training_s2_gideon_president_inside" },
    { 0x6A0A, "play_training_s2_gideon_prophet_approaching" },
    { 0x6A0B, "play_training_s2_gideon_smart_grenades" },
    { 0x6A0C, "play_training_s2_gideon_the_warbird" },
    { 0x6A0D, "play_training_s2_gideon_use_overdrive" },
    { 0x6A0E, "play_training_s2_gideon_use_your_shield" },
    { 0x6A0F, "play_training_s2_joker_clear" },
    { 0x6A10, "play_training_s2_joker_contact" },
    { 0x6A11, "play_training_s2_joker_drones" },
    { 0x6A12, "play_training_s2_joker_entering_kitchen" },
    { 0x6A13, "play_training_s2_joker_front_entrance" },
    { 0x6A14, "play_training_s2_joker_here_they" },
    { 0x6A15, "play_training_s2_joker_living_room" },
    { 0x6A16, "play_training_s2_prophet_large_qrf" },
    { 0x6A17, "play_training_vo_prophet_exfil_approach" },
    { 0x6A18, "play_trigger_flashlight_off" },
    { 0x6A19, "play_van_videolog_pip" },
    { 0x6A1A, "play_vb_cardoor_anim" },
    { 0x6A1B, "play_video_log_climb_block_intro" },
    { 0x6A1C, "play_videolog" },
    { 0x6A1D, "play_vision_light_fog_normal" },
    { 0x6A1E, "play_vrap_sounds" },
    { 0x6A1F, "play_warbird_carrying_walker" },
    { 0x6A20, "play_warbird_mobile_turret_dropoff" },
    { 0x6A21, "play_window_sound" },
    { 0x6A22, "playafterburner" },
    { 0x6A23, "playaispawneffect" },
    { 0x6A24, "playalarmloop" },
    { 0x6A25, "playanim" },
    { 0x6A26, "playanimfortime" },
    { 0x6A27, "playanimnatratefortime" },
    { 0x6A28, "playanimnatrateuntilnotetrack" },
    { 0x6A29, "playanimnfortime" },
    { 0x6A2A, "playanimnuntilnotetrack" },
    { 0x6A2B, "playanimuntilnotetrack" },
    { 0x6A2C, "playaudioturretmoveup" },
    { 0x6A2D, "playbark" },
    { 0x6A2E, "playbattlechatter" },
    { 0x6A2F, "playbeameffects" },
    { 0x6A30, "playblendtransition" },
    { 0x6A31, "playblendtransitionstandrun" },
    { 0x6A32, "playbombfx" },
    { 0x6A33, "playbubbleeffect" },
    { 0x6A34, "playbuoylights" },
    { 0x6A35, "playc4effects" },
    { 0x6A36, "playclaymoreeffects" },
    { 0x6A37, "playcloakoverheatdialog" },
    { 0x6A38, "playcontrail" },
    { 0x6A39, "playcranespawnvfx" },
    { 0x6A3A, "playcredits" },
    { 0x6A3B, "playcustomevent" },
    { 0x6A3C, "playdamagesound" },
    { 0x6A3D, "playdeathanim" },
    { 0x6A3E, "playdeathfx" },
    { 0x6A3F, "playdeathsound" },
    { 0x6A40, "playdialog" },
    { 0x6A41, "playedstartingmusic" },
    { 0x6A42, "playeffectongroundent" },
    { 0x6A43, "playengineeffects" },
    { 0x6A44, "playentrysounddelayed" },
    { 0x6A45, "player_abandon_squad_distance_think" },
    { 0x6A46, "player_abandoned_mission_fail" },
    { 0x6A47, "player_abandoned_mission_warning" },
    { 0x6A48, "player_abandoned_mission_warning_vo_setup" },
    { 0x6A49, "player_abandoning_mission_vo" },
    { 0x6A4A, "player_accuracy_think" },
    { 0x6A4B, "player_add_dshk_turret" },
    { 0x6A4C, "player_ads_disable_manager" },
    { 0x6A4D, "player_ads_think" },
    { 0x6A4E, "player_ads_time" },
    { 0x6A4F, "player_aim_debug" },
    { 0x6A50, "player_airbraked" },
    { 0x6A51, "player_alerted_mission_fail" },
    { 0x6A52, "player_alerted_mission_fail_convoy" },
    { 0x6A53, "player_alerted_mission_fail_meter" },
    { 0x6A54, "player_allow_damage" },
    { 0x6A55, "player_and_hatch_doors" },
    { 0x6A56, "player_and_squad" },
    { 0x6A57, "player_angles_at_last_hovertank_fire" },
    { 0x6A58, "player_animated_sequence_cleanup" },
    { 0x6A59, "player_animated_sequence_restrictions" },
    { 0x6A5A, "player_animations" },
    { 0x6A5B, "player_anims" },
    { 0x6A5C, "player_anims_toload" },
    { 0x6A5D, "player_apply_mission_failed_wrapper_on_death_for_duration" },
    { 0x6A5E, "player_assault_snipers" },
    { 0x6A5F, "player_assisted_jump" },
    { 0x6A60, "player_attack_nodes_update" },
    { 0x6A61, "player_attack_think" },
    { 0x6A62, "player_attacked" },
    { 0x6A63, "player_attacker" },
    { 0x6A64, "player_attacker_accuracy" },
    { 0x6A65, "player_basement_objective_mover" },
    { 0x6A66, "player_bike" },
    { 0x6A67, "player_bike_lower" },
    { 0x6A68, "player_bike_obj" },
    { 0x6A69, "player_bike_shutoff" },
    { 0x6A6A, "player_bike_to_ai_model" },
    { 0x6A6B, "player_bike_to_vm_model" },
    { 0x6A6C, "player_bike_wing_flaps" },
    { 0x6A6D, "player_bike_wing_flaps_left" },
    { 0x6A6E, "player_bikenew" },
    { 0x6A6F, "player_blocking_shot" },
    { 0x6A70, "player_blocking_shot_vo_lines" },
    { 0x6A71, "player_blur_ads" },
    { 0x6A72, "player_blur_monitor_ads" },
    { 0x6A73, "player_blur_monitor_non_ads" },
    { 0x6A74, "player_blur_non_ads" },
    { 0x6A75, "player_blur_reset" },
    { 0x6A76, "player_blur_think" },
    { 0x6A77, "player_boat" },
    { 0x6A78, "player_boat_dive" },
    { 0x6A79, "player_boat_gas" },
    { 0x6A7A, "player_bob_scale_set" },
    { 0x6A7B, "player_boost_hint" },
    { 0x6A7C, "player_boost_time" },
    { 0x6A7D, "player_boosting" },
    { 0x6A7E, "player_braking" },
    { 0x6A7F, "player_breach" },
    { 0x6A80, "player_breaks_stealth_during_tutorial" },
    { 0x6A81, "player_breath_amount" },
    { 0x6A82, "player_breath_amount_fill_rate" },
    { 0x6A83, "player_breath_amount_use_rate" },
    { 0x6A84, "player_breath_elem" },
    { 0x6A85, "player_breath_fulltime" },
    { 0x6A86, "player_breath_hud" },
    { 0x6A87, "player_broke_stealth" },
    { 0x6A88, "player_broke_stealth_once" },
    { 0x6A89, "player_bubbles_fx" },
    { 0x6A8A, "player_bus" },
    { 0x6A8B, "player_bus_anim_single_break_when_timeout_or_fail" },
    { 0x6A8C, "player_bus_slomo_end_notetrack" },
    { 0x6A8D, "player_bus_slomo_end_pt2" },
    { 0x6A8E, "player_bus_slomo_start_pt1" },
    { 0x6A8F, "player_bus_slomo_start_pt2" },
    { 0x6A90, "player_bus_slomo_start_pt3" },
    { 0x6A91, "player_bus_slomo_start_pt4" },
    { 0x6A92, "player_bus_slomo_start_pt5" },
    { 0x6A93, "player_bus_start" },
    { 0x6A94, "player_camera_shake" },
    { 0x6A95, "player_camera_shake_land" },
    { 0x6A96, "player_can_be_shot" },
    { 0x6A97, "player_can_see" },
    { 0x6A98, "player_can_see_ai" },
    { 0x6A99, "player_can_see_ai_bones" },
    { 0x6A9A, "player_can_see_ai_through_foliage" },
    { 0x6A9B, "player_can_see_civ" },
    { 0x6A9C, "player_can_see_corpse" },
    { 0x6A9D, "player_can_see_point" },
    { 0x6A9E, "player_can_see_vehicle" },
    { 0x6A9F, "player_can_stop_swimming" },
    { 0x6AA0, "player_canal_drop" },
    { 0x6AA1, "player_cant_be_shot" },
    { 0x6AA2, "player_carried_skybridge" },
    { 0x6AA3, "player_catch_up_on_boost" },
    { 0x6AA4, "player_character_name" },
    { 0x6AA5, "player_charged_shot" },
    { 0x6AA6, "player_chase_progress_mod" },
    { 0x6AA7, "player_chase_speed_control" },
    { 0x6AA8, "player_check_distance_to_ceiling" },
    { 0x6AA9, "player_check_distance_to_ground" },
    { 0x6AAA, "player_chooses_manual_control" },
    { 0x6AAB, "player_cleanup_charge_indicator" },
    { 0x6AAC, "player_cleanup_reticle" },
    { 0x6AAD, "player_cleanup_rumble" },
    { 0x6AAE, "player_cleanup_sound" },
    { 0x6AAF, "player_cleanupongameended" },
    { 0x6AB0, "player_cleanuponteamchange" },
    { 0x6AB1, "player_clear_pass_target" },
    { 0x6AB2, "player_climb_wall" },
    { 0x6AB3, "player_climb_wall_head_sway" },
    { 0x6AB4, "player_clip" },
    { 0x6AB5, "player_clip_pod_door" },
    { 0x6AB6, "player_cloak_on" },
    { 0x6AB7, "player_close_disable_ignore_check" },
    { 0x6AB8, "player_close_to_fail_dist" },
    { 0x6AB9, "player_color_node" },
    { 0x6ABA, "player_color_pulse" },
    { 0x6ABB, "player_command_for_exit" },
    { 0x6ABC, "player_control_on" },
    { 0x6ABD, "player_covertrigger" },
    { 0x6ABE, "player_covertype" },
    { 0x6ABF, "player_cqb_off" },
    { 0x6AC0, "player_cqb_on" },
    { 0x6AC1, "player_crash" },
    { 0x6AC2, "player_damage" },
    { 0x6AC3, "player_damage_atlas_flag_set" },
    { 0x6AC4, "player_damage_check" },
    { 0x6AC5, "player_damaged_car_watcher" },
    { 0x6AC6, "player_death" },
    { 0x6AC7, "player_death_detection" },
    { 0x6AC8, "player_defend_snipers" },
    { 0x6AC9, "player_delete_ball_goal_fx" },
    { 0x6ACA, "player_did_most_damage" },
    { 0x6ACB, "player_died_recently" },
    { 0x6ACC, "player_died_recently_degrades" },
    { 0x6ACD, "player_died_water" },
    { 0x6ACE, "player_dismount" },
    { 0x6ACF, "player_dismount_link_player_end_of_frame" },
    { 0x6AD0, "player_dismount_newbike" },
    { 0x6AD1, "player_dismount_vehicle" },
    { 0x6AD2, "player_dist_limit" },
    { 0x6AD3, "player_dist_to_speaker" },
    { 0x6AD4, "player_distsqrd" },
    { 0x6AD5, "player_do_camera_shake" },
    { 0x6AD6, "player_do_charge_indicator" },
    { 0x6AD7, "player_do_reticle" },
    { 0x6AD8, "player_do_rumble" },
    { 0x6AD9, "player_do_sound" },
    { 0x6ADA, "player_does_not_see_spawner" },
    { 0x6ADB, "player_dof_aperture" },
    { 0x6ADC, "player_dof_distance" },
    { 0x6ADD, "player_dof_max_distance" },
    { 0x6ADE, "player_dolasercoredamage" },
    { 0x6ADF, "player_doorkick" },
    { 0x6AE0, "player_downed_death_buffer_time" },
    { 0x6AE1, "player_driver" },
    { 0x6AE2, "player_drone_control" },
    { 0x6AE3, "player_drone_manager" },
    { 0x6AE4, "player_drop_pod_se_door_kick" },
    { 0x6AE5, "player_drown_end_vm_transition" },
    { 0x6AE6, "player_drowning_damage_thread" },
    { 0x6AE7, "player_drowning_start" },
    { 0x6AE8, "player_dynamic_dof" },
    { 0x6AE9, "player_enable_highlight" },
    { 0x6AEA, "player_enter_round_trigger" },
    { 0x6AEB, "player_enter_turret" },
    { 0x6AEC, "player_enter_walker" },
    { 0x6AED, "player_enter_walker_anim" },
    { 0x6AEE, "player_entering_server_room" },
    { 0x6AEF, "player_enters_mobile_turret_dialogue" },
    { 0x6AF0, "player_escape" },
    { 0x6AF1, "player_exhaust_corridor" },
    { 0x6AF2, "player_exhaust_corridor_rumbles" },
    { 0x6AF3, "player_exit_breach_fail" },
    { 0x6AF4, "player_exit_turret" },
    { 0x6AF5, "player_exit_walker" },
    { 0x6AF6, "player_exit_walker_anim" },
    { 0x6AF7, "player_exiting" },
    { 0x6AF8, "player_exo_activate" },
    { 0x6AF9, "player_exo_activate_single_internal" },
    { 0x6AFA, "player_exo_add_array" },
    { 0x6AFB, "player_exo_add_single" },
    { 0x6AFC, "player_exo_cloak_on" },
    { 0x6AFD, "player_exo_cloak_on_wallclimb" },
    { 0x6AFE, "player_exo_deactivate" },
    { 0x6AFF, "player_exo_deactivate_single_internal" },
    { 0x6B00, "player_exo_disable" },
    { 0x6B01, "player_exo_enable" },
    { 0x6B02, "player_exo_get_owned_array" },
    { 0x6B03, "player_exo_get_unowned_array" },
    { 0x6B04, "player_exo_init" },
    { 0x6B05, "player_exo_is_active" },
    { 0x6B06, "player_exo_is_active_single" },
    { 0x6B07, "player_exo_is_active_single_internal" },
    { 0x6B08, "player_exo_jump_hint" },
    { 0x6B09, "player_exo_jump_hint_off" },
    { 0x6B0A, "player_exo_jump_release_hint_off" },
    { 0x6B0B, "player_exo_monitor" },
    { 0x6B0C, "player_exo_power_on" },
    { 0x6B0D, "player_exo_remove_array" },
    { 0x6B0E, "player_exo_remove_single" },
    { 0x6B0F, "player_exo_set_owned_array" },
    { 0x6B10, "player_exoclimb_mag_moved" },
    { 0x6B11, "player_exoclimb_moved" },
    { 0x6B12, "player_failed_drop" },
    { 0x6B13, "player_fall_lighting" },
    { 0x6B14, "player_fall_zone_swap" },
    { 0x6B15, "player_falling_kill_logic" },
    { 0x6B16, "player_falling_to_death" },
    { 0x6B17, "player_fastzip" },
    { 0x6B18, "player_fastzip_land" },
    { 0x6B19, "player_fired_missiles" },
    { 0x6B1A, "player_follow_volume_think" },
    { 0x6B1B, "player_forest_takedown" },
    { 0x6B1C, "player_forest_takedown_bad_guy_left_vox" },
    { 0x6B1D, "player_forest_takedown_bad_guy_right_vox" },
    { 0x6B1E, "player_fov_54" },
    { 0x6B1F, "player_fov_65" },
    { 0x6B20, "player_fov_controller" },
    { 0x6B21, "player_free_aim" },
    { 0x6B22, "player_friendly_hud_destroy" },
    { 0x6B23, "player_friendlyfire_addreactionevent" },
    { 0x6B24, "player_friendlyfire_waiter" },
    { 0x6B25, "player_friendlyfire_waiter_damage" },
    { 0x6B26, "player_gasping_breath" },
    { 0x6B27, "player_getout" },
    { 0x6B28, "player_getout_sound" },
    { 0x6B29, "player_getout_sound_end" },
    { 0x6B2A, "player_getout_sound_loop" },
    { 0x6B2B, "player_gets_weapons_back" },
    { 0x6B2C, "player_getvelocity_pc" },
    { 0x6B2D, "player_giveachievement_wrapper" },
    { 0x6B2E, "player_grace_period" },
    { 0x6B2F, "player_grapple_check" },
    { 0x6B30, "player_grapple_hint" },
    { 0x6B31, "player_grapple_into_vehicle" },
    { 0x6B32, "player_grappled" },
    { 0x6B33, "player_grenade_check" },
    { 0x6B34, "player_grenade_check_dieout" },
    { 0x6B35, "player_gun_lock_target_origin" },
    { 0x6B36, "player_guns_cooldown_can_shoot" },
    { 0x6B37, "player_guns_cooldown_get_heat" },
    { 0x6B38, "player_guns_cooldown_shoot_notify" },
    { 0x6B39, "player_guns_cooldown_think" },
    { 0x6B3A, "player_hand_plant_lf_wallclimb" },
    { 0x6B3B, "player_hand_plant_rt_wallclimb" },
    { 0x6B3C, "player_handle_charged_shot" },
    { 0x6B3D, "player_handleturrethints" },
    { 0x6B3E, "player_handleturretpickup" },
    { 0x6B3F, "player_handleturretrippable" },
    { 0x6B40, "player_handplant" },
    { 0x6B41, "player_handplant_standalone" },
    { 0x6B42, "player_hands_idle_start" },
    { 0x6B43, "player_hands_idle_stop" },
    { 0x6B44, "player_hangar_waits" },
    { 0x6B45, "player_has_caught_up" },
    { 0x6B46, "player_has_jumped" },
    { 0x6B47, "player_has_printing_himar" },
    { 0x6B48, "player_has_returned_to_road" },
    { 0x6B49, "player_has_returned_to_squad" },
    { 0x6B4A, "player_has_thermal" },
    { 0x6B4B, "player_has_weapon" },
    { 0x6B4C, "player_health_check" },
    { 0x6B4D, "player_health_current" },
    { 0x6B4E, "player_health_packets" },
    { 0x6B4F, "player_heartbeat" },
    { 0x6B50, "player_helo_release" },
    { 0x6B51, "player_hover_height" },
    { 0x6B52, "player_idle" },
    { 0x6B53, "player_ied_footsteps_left" },
    { 0x6B54, "player_ied_footsteps_right" },
    { 0x6B55, "player_in_deep_water" },
    { 0x6B56, "player_in_disable_sniper_volume" },
    { 0x6B57, "player_in_mt" },
    { 0x6B58, "player_in_oncoming" },
    { 0x6B59, "player_init" },
    { 0x6B5A, "player_init_charge_indicator" },
    { 0x6B5B, "player_init_reticle" },
    { 0x6B5C, "player_init_rumble" },
    { 0x6B5D, "player_init_sound" },
    { 0x6B5E, "player_input_control_hint_off" },
    { 0x6B5F, "player_input_ending_aim_button_off" },
    { 0x6B60, "player_input_ending_shoot_button_off" },
    { 0x6B61, "player_input_rappel_hint_off" },
    { 0x6B62, "player_input_shaft_buttons_off" },
    { 0x6B63, "player_input_slide_under_door" },
    { 0x6B64, "player_input_sprint" },
    { 0x6B65, "player_intel_display_object" },
    { 0x6B66, "player_intel_display_object_array" },
    { 0x6B67, "player_intel_display_objects" },
    { 0x6B68, "player_intel_mode_disable" },
    { 0x6B69, "player_intel_mode_think" },
    { 0x6B6A, "player_is_aiming_with_rocket" },
    { 0x6B6B, "player_is_behind_me" },
    { 0x6B6C, "player_is_driving" },
    { 0x6B6D, "player_is_good_missile_target" },
    { 0x6B6E, "player_is_in_scanner_cone" },
    { 0x6B6F, "player_is_near_live_grenade" },
    { 0x6B70, "player_is_pushing_rumble" },
    { 0x6B71, "player_is_rappelling" },
    { 0x6B72, "player_is_shooting" },
    { 0x6B73, "player_is_skipping_setups" },
    { 0x6B74, "player_is_valid_target" },
    { 0x6B75, "player_isusingkillstreak" },
    { 0x6B76, "player_jammer_movie" },
    { 0x6B77, "player_jetpack" },
    { 0x6B78, "player_joined_update_pass_target_hudoutline" },
    { 0x6B79, "player_jump_into_mob_nag_lines" },
    { 0x6B7A, "player_jumped_out_vol" },
    { 0x6B7B, "player_kill_function" },
    { 0x6B7C, "player_kill_trigger" },
    { 0x6B7D, "player_killed" },
    { 0x6B7E, "player_knife" },
    { 0x6B7F, "player_knockdown" },
    { 0x6B80, "player_knockout_wakeup" },
    { 0x6B81, "player_knockout_white" },
    { 0x6B82, "player_land_on_hood" },
    { 0x6B83, "player_land_on_wing" },
    { 0x6B84, "player_lasercoreeffect" },
    { 0x6B85, "player_leave_cafeteria_nag_lines" },
    { 0x6B86, "player_leave_round_trigger" },
    { 0x6B87, "player_leaves_humvee" },
    { 0x6B88, "player_leaving_bodyroom_gag" },
    { 0x6B89, "player_left_road_hint" },
    { 0x6B8A, "player_left_squad_hint" },
    { 0x6B8B, "player_link_to" },
    { 0x6B8C, "player_link_to_cover" },
    { 0x6B8D, "player_linked" },
    { 0x6B8E, "player_linkto_drone_missile" },
    { 0x6B8F, "player_locked_on" },
    { 0x6B90, "player_look_limit_controller" },
    { 0x6B91, "player_looking_at" },
    { 0x6B92, "player_looking_at_object" },
    { 0x6B93, "player_looking_at_relative" },
    { 0x6B94, "player_looking_in_direction_2d" },
    { 0x6B95, "player_los_check" },
    { 0x6B96, "player_loses_speedscale" },
    { 0x6B97, "player_mag_glove_activate_wallclimb" },
    { 0x6B98, "player_mag_glove_lglove_disengage" },
    { 0x6B99, "player_mag_glove_off" },
    { 0x6B9A, "player_mag_glove_rglove_disengage" },
    { 0x6B9B, "player_mech_melee_modifier" },
    { 0x6B9C, "player_mech_melee_modifier_damage_function" },
    { 0x6B9D, "player_missile_firing_logic" },
    { 0x6B9E, "player_mission_failed_handler" },
    { 0x6B9F, "player_mobile_turret_explo" },
    { 0x6BA0, "player_mobile_turret_warning" },
    { 0x6BA1, "player_mode" },
    { 0x6BA2, "player_mount_vehicle" },
    { 0x6BA3, "player_move_mod" },
    { 0x6BA4, "player_moved_forward" },
    { 0x6BA5, "player_movement_tweaks" },
    { 0x6BA6, "player_movement_weapons_setup" },
    { 0x6BA7, "player_moves" },
    { 0x6BA8, "player_movespeed_calc_loop" },
    { 0x6BA9, "player_nades" },
    { 0x6BAA, "player_name_called_recently" },
    { 0x6BAB, "player_near_logging_road_end_log" },
    { 0x6BAC, "player_no_pickup_time" },
    { 0x6BAD, "player_on_disconnect" },
    { 0x6BAE, "player_on_rotors" },
    { 0x6BAF, "player_onbike" },
    { 0x6BB0, "player_one_already_breached" },
    { 0x6BB1, "player_out_of_bounds_count" },
    { 0x6BB2, "player_out_of_bounds_mission_fail" },
    { 0x6BB3, "player_out_of_bounds_warning" },
    { 0x6BB4, "player_out_of_bounds_warning_vo" },
    { 0x6BB5, "player_pbull_honk" },
    { 0x6BB6, "player_pc_velocity" },
    { 0x6BB7, "player_perarts_jump_explosions" },
    { 0x6BB8, "player_picked_team" },
    { 0x6BB9, "player_pitbull" },
    { 0x6BBA, "player_pitbull_init" },
    { 0x6BBB, "player_pitbull_physics_wake_up" },
    { 0x6BBC, "player_pitbull_woosh_sounds" },
    { 0x6BBD, "player_place_ied_foley" },
    { 0x6BBE, "player_plant_frb" },
    { 0x6BBF, "player_pod" },
    { 0x6BC0, "player_popped_flares" },
    { 0x6BC1, "player_pos" },
    { 0x6BC2, "player_post_crash" },
    { 0x6BC3, "player_presinkhole_debris" },
    { 0x6BC4, "player_presinkhole_jump_pipeburst" },
    { 0x6BC5, "player_process_dshk_turrets" },
    { 0x6BC6, "player_projectile_think" },
    { 0x6BC7, "player_proximity_rumble" },
    { 0x6BC8, "player_proxy" },
    { 0x6BC9, "player_proxy_org" },
    { 0x6BCA, "player_proxy_took_damage" },
    { 0x6BCB, "player_push_impulse" },
    { 0x6BCC, "player_pushed_kill" },
    { 0x6BCD, "player_radio_emitter" },
    { 0x6BCE, "player_radio_emitter_overlap" },
    { 0x6BCF, "player_radio_squelch_out_queued" },
    { 0x6BD0, "player_rappel" },
    { 0x6BD1, "player_rappel_camera_sway" },
    { 0x6BD2, "player_rappel_control" },
    { 0x6BD3, "player_rappel_rope_swap" },
    { 0x6BD4, "player_rappel_rumbles" },
    { 0x6BD5, "player_reached_stealth_finish_line" },
    { 0x6BD6, "player_reached_window" },
    { 0x6BD7, "player_reaches_shack" },
    { 0x6BD8, "player_ready_capture" },
    { 0x6BD9, "player_recovered_stealth" },
    { 0x6BDA, "player_recovers_from_red_flashing" },
    { 0x6BDB, "player_regen_restore" },
    { 0x6BDC, "player_regen_scale" },
    { 0x6BDD, "player_remove_dshk_turret" },
    { 0x6BDE, "player_repulsor" },
    { 0x6BDF, "player_resetlasercorevalues" },
    { 0x6BE0, "player_restore_reticle" },
    { 0x6BE1, "player_revived_or_dead" },
    { 0x6BE2, "player_rides_humvee_offset_dismount" },
    { 0x6BE3, "player_rides_in_humvee" },
    { 0x6BE4, "player_rides_in_humvee_offset" },
    { 0x6BE5, "player_rides_shotgun_in_humvee" },
    { 0x6BE6, "player_rig" },
    { 0x6BE7, "player_rig_heli" },
    { 0x6BE8, "player_rig_highway_ledge" },
    { 0x6BE9, "player_rig_lighting_org" },
    { 0x6BEA, "player_rig_lighting_org_willroom" },
    { 0x6BEB, "player_rig_spawn_function" },
    { 0x6BEC, "player_rocket" },
    { 0x6BED, "player_rope" },
    { 0x6BEE, "player_rope_long" },
    { 0x6BEF, "player_run_progress_trigger_think" },
    { 0x6BF0, "player_run_rumble" },
    { 0x6BF1, "player_rushes_ahead" },
    { 0x6BF2, "player_safe" },
    { 0x6BF3, "player_saw_kill" },
    { 0x6BF4, "player_school_disable_values" },
    { 0x6BF5, "player_school_flashlight" },
    { 0x6BF6, "player_screen_flash" },
    { 0x6BF7, "player_scuba" },
    { 0x6BF8, "player_scuba_breathe_sound" },
    { 0x6BF9, "player_scuba_bubbles" },
    { 0x6BFA, "player_scuba_mask" },
    { 0x6BFB, "player_scuba_mask_disable" },
    { 0x6BFC, "player_seek" },
    { 0x6BFD, "player_seek_disable" },
    { 0x6BFE, "player_seek_enable" },
    { 0x6BFF, "player_sees_my_scope" },
    { 0x6C00, "player_sees_spawner" },
    { 0x6C01, "player_sentinel_kva_reveal" },
    { 0x6C02, "player_sentry_timeout" },
    { 0x6C03, "player_server_room_se_end" },
    { 0x6C04, "player_set_all_reticle_colors" },
    { 0x6C05, "player_set_in_water" },
    { 0x6C06, "player_set_pass_target" },
    { 0x6C07, "player_set_swimming" },
    { 0x6C08, "player_setupanimations" },
    { 0x6C09, "player_shadow_monitor" },
    { 0x6C0A, "player_shimmy_1" },
    { 0x6C0B, "player_shimmy_2" },
    { 0x6C0C, "player_shimmy_3" },
    { 0x6C0D, "player_shimmy_4" },
    { 0x6C0E, "player_shimmy_intro" },
    { 0x6C0F, "player_shooting_at" },
    { 0x6C10, "player_shooting_logic" },
    { 0x6C11, "player_shot_guns" },
    { 0x6C12, "player_shouldclearturretpickuphints" },
    { 0x6C13, "player_shoulddisableremoteenter" },
    { 0x6C14, "player_show_missile_reticle" },
    { 0x6C15, "player_show_turret_hud" },
    { 0x6C16, "player_skipping_setup" },
    { 0x6C17, "player_slows_down" },
    { 0x6C18, "player_soft_land_alt" },
    { 0x6C19, "player_speed" },
    { 0x6C1A, "player_speed_control" },
    { 0x6C1B, "player_speed_control_rocket_blast" },
    { 0x6C1C, "player_speed_control_underwater" },
    { 0x6C1D, "player_speed_default" },
    { 0x6C1E, "player_speed_hud" },
    { 0x6C1F, "player_speed_manager" },
    { 0x6C20, "player_speed_percent" },
    { 0x6C21, "player_speed_proc" },
    { 0x6C22, "player_speed_set" },
    { 0x6C23, "player_spotlight" },
    { 0x6C24, "player_stance_monitor" },
    { 0x6C25, "player_started_vtol_grapple_monitor" },
    { 0x6C26, "player_starts_battle" },
    { 0x6C27, "player_state" },
    { 0x6C28, "player_stealth_audio" },
    { 0x6C29, "player_stealth_cloak_think" },
    { 0x6C2A, "player_swim_hint" },
    { 0x6C2B, "player_swimming_moving_water" },
    { 0x6C2C, "player_tank" },
    { 0x6C2D, "player_target" },
    { 0x6C2E, "player_targeting_think" },
    { 0x6C2F, "player_test_points" },
    { 0x6C30, "player_throwgrenade_timer" },
    { 0x6C31, "player_too_far_hint" },
    { 0x6C32, "player_touched_arr" },
    { 0x6C33, "player_touched_car_watcher" },
    { 0x6C34, "player_touching_post_clip" },
    { 0x6C35, "player_training_s1_joker_threat_grenade_nag" },
    { 0x6C36, "player_truck" },
    { 0x6C37, "player_ugv_health" },
    { 0x6C38, "player_ugv_health_hurtagain" },
    { 0x6C39, "player_ugv_health_max_health" },
    { 0x6C3A, "player_under_logging_road_end_log" },
    { 0x6C3B, "player_underwater_breath" },
    { 0x6C3C, "player_underwater_end" },
    { 0x6C3D, "player_underwater_shock" },
    { 0x6C3E, "player_underwater_start" },
    { 0x6C3F, "player_unlink_from_cover" },
    { 0x6C40, "player_unlink_from_drone_missile" },
    { 0x6C41, "player_unlink_on_death" },
    { 0x6C42, "player_unlink_on_sprint" },
    { 0x6C43, "player_unlock" },
    { 0x6C44, "player_unresolved_collision_watch" },
    { 0x6C45, "player_update_pass_target" },
    { 0x6C46, "player_update_pass_target_hudoutline" },
    { 0x6C47, "player_update_slow_aim" },
    { 0x6C48, "player_upkeep" },
    { 0x6C49, "player_use_dshk_with_viewmodel" },
    { 0x6C4A, "player_used_exoclimb_combat" },
    { 0x6C4B, "player_used_exoclimb_cover" },
    { 0x6C4C, "player_used_grapple" },
    { 0x6C4D, "player_used_grenade_recently" },
    { 0x6C4E, "player_using_missile" },
    { 0x6C4F, "player_velocity_display" },
    { 0x6C50, "player_view" },
    { 0x6C51, "player_viewhand_model" },
    { 0x6C52, "player_visible_duration" },
    { 0x6C53, "player_wait_and_unlink" },
    { 0x6C54, "player_walk" },
    { 0x6C55, "player_walk_end" },
    { 0x6C56, "player_warbird_flyout" },
    { 0x6C57, "player_warbird_spawn" },
    { 0x6C58, "player_watchdeath" },
    { 0x6C59, "player_watchexitlasercore" },
    { 0x6C5A, "player_weapons" },
    { 0x6C5B, "player2" },
    { 0x6C5C, "playeractivatedairsupport" },
    { 0x6C5D, "playeraddnotifycommands" },
    { 0x6C5E, "playeraffectedarray" },
    { 0x6C5F, "playerallowalternatemelee" },
    { 0x6C60, "playerallowboostjump" },
    { 0x6C61, "playerallowdodge" },
    { 0x6C62, "playerallowhighjump" },
    { 0x6C63, "playerallowhighjumpdrop" },
    { 0x6C64, "playerallowpowerslide" },
    { 0x6C65, "playerallowweaponpickup" },
    { 0x6C66, "playeranims" },
    { 0x6C67, "playerassist" },
    { 0x6C68, "playerattachpoint" },
    { 0x6C69, "playerboostjumpprecaching" },
    { 0x6C6A, "playerbreathingsound" },
    { 0x6C6B, "playercanuselaser" },
    { 0x6C6C, "playercanuseturret" },
    { 0x6C6D, "playercapturelpm" },
    { 0x6C6E, "playercardplayer" },
    { 0x6C6F, "playercardsplashnotify" },
    { 0x6C70, "playerchangemode" },
    { 0x6C71, "playercleanupbarrel" },
    { 0x6C72, "playercleanupondeath" },
    { 0x6C73, "playercleanuponother" },
    { 0x6C74, "playercleanupthermalvisioncommands" },
    { 0x6C75, "playerclearorbitalsupportonteamchange" },
    { 0x6C76, "playerclearrippableturretinfo" },
    { 0x6C77, "playerclearwarbirdonteamchange" },
    { 0x6C78, "playercloakactivated" },
    { 0x6C79, "playercloakcooldown" },
    { 0x6C7A, "playercloakready" },
    { 0x6C7B, "playercloakwaitforexit" },
    { 0x6C7C, "playerclockdirection" },
    { 0x6C7D, "playercommonreconvehiclesetup" },
    { 0x6C7E, "playercontrolled" },
    { 0x6C7F, "playercontrolorbitalstrike" },
    { 0x6C80, "playercontrolwarbirdsetup" },
    { 0x6C81, "playercostume" },
    { 0x6C82, "playerdamaged" },
    { 0x6C83, "playerdamagerumble" },
    { 0x6C84, "playerdelaycontrol" },
    { 0x6C85, "playerdelayrumble" },
    { 0x6C86, "playerdelaystartsparkseffect" },
    { 0x6C87, "playerdeleteexhaustfxonvehicledeath" },
    { 0x6C88, "playerdestroyglassbelow" },
    { 0x6C89, "playerdied" },
    { 0x6C8A, "playerdisableabilitytypes" },
    { 0x6C8B, "playerdisabledwait" },
    { 0x6C8C, "playerdisablestreakstatic" },
    { 0x6C8D, "playerdisableunderwater" },
    { 0x6C8E, "playerdisplayjoinrequest" },
    { 0x6C8F, "playerdoginit" },
    { 0x6C90, "playerdohunterkillerbehavior" },
    { 0x6C91, "playerdone_anim_laststand" },
    { 0x6C92, "playerdone_anim_neck_snap" },
    { 0x6C93, "playerdone_anim_saved" },
    { 0x6C94, "playerdoridekillstreak" },
    { 0x6C95, "playerdoublegrenadetime" },
    { 0x6C96, "playerdrone" },
    { 0x6C97, "playerdrone_anim_knockdown" },
    { 0x6C98, "playerdrone_create" },
    { 0x6C99, "playerenablestreakstatic" },
    { 0x6C9A, "playerenableunderwater" },
    { 0x6C9B, "playerendinganimations" },
    { 0x6C9C, "playerenterarea" },
    { 0x6C9D, "playerentersoftlanding" },
    { 0x6C9E, "playerfakeshootempgrenadeattarget" },
    { 0x6C9F, "playerfakeshootpaintgrenadeattarget" },
    { 0x6CA0, "playerfakeshootpaintmissile" },
    { 0x6CA1, "playerfindaltnode" },
    { 0x6CA2, "playerfindnodeinfront" },
    { 0x6CA3, "playerfindnodeinfrontinternal" },
    { 0x6CA4, "playerfiresounds" },
    { 0x6CA5, "playerforclientid" },
    { 0x6CA6, "playerfxorg" },
    { 0x6CA7, "playergetclosestnode" },
    { 0x6CA8, "playergetclosestnodeinternal" },
    { 0x6CA9, "playergetkillstreaklastweapon" },
    { 0x6CAA, "playergetnearestnode" },
    { 0x6CAB, "playergetnodelookingat" },
    { 0x6CAC, "playergetorbitalstartpos" },
    { 0x6CAD, "playergetoutsidenode" },
    { 0x6CAE, "playergetrippableammo" },
    { 0x6CAF, "playergetturretendpoint" },
    { 0x6CB0, "playergetusetime" },
    { 0x6CB1, "playergivebackcarepackage" },
    { 0x6CB2, "playergiveturrethead" },
    { 0x6CB3, "playergrenadebasetime" },
    { 0x6CB4, "playergrenaderangetime" },
    { 0x6CB5, "playerhandlebarrel" },
    { 0x6CB6, "playerhandlebootupsequence" },
    { 0x6CB7, "playerhandleboundarystatic" },
    { 0x6CB8, "playerhandleboundarystaticradius" },
    { 0x6CB9, "playerhandledamage" },
    { 0x6CBA, "playerhandleexhaustfx" },
    { 0x6CBB, "playerhandlejoining" },
    { 0x6CBC, "playerhandlekillvehicle" },
    { 0x6CBD, "playerhandleradarping" },
    { 0x6CBE, "playerhasammo" },
    { 0x6CBF, "playerhasrippableturretinfo" },
    { 0x6CC0, "playerhastouchedstick" },
    { 0x6CC1, "playerhasturretheadweapon" },
    { 0x6CC2, "playerhbreachwristequipment" },
    { 0x6CC3, "playerhealth_regularregendelay" },
    { 0x6CC4, "playerhealthregen" },
    { 0x6CC5, "playerhealthregeninit" },
    { 0x6CC6, "playerhideturretoverlay" },
    { 0x6CC7, "playerhudelements" },
    { 0x6CC8, "playerhudoutlineshunterkiller" },
    { 0x6CC9, "playerhurtcheck" },
    { 0x6CCA, "playeridlereminderdialogue" },
    { 0x6CCB, "playerimmunetofire" },
    { 0x6CCC, "playerinit" },
    { 0x6CCD, "playerinorbital" },
    { 0x6CCE, "playerinside" },
    { 0x6CCF, "playerinteractdronecontrol" },
    { 0x6CD0, "playerinvul" },
    { 0x6CD1, "playerinwater" },
    { 0x6CD2, "playerisclose" },
    { 0x6CD3, "playerisinfront" },
    { 0x6CD4, "playerisonleft" },
    { 0x6CD5, "playerisrocketswarmreloading" },
    { 0x6CD6, "playerisrocketswarmtargetlocked" },
    { 0x6CD7, "playerkilled" },
    { 0x6CD8, "playerkilled_internal" },
    { 0x6CD9, "playerkillheavyexo" },
    { 0x6CDA, "playerlaunchcarepackage" },
    { 0x6CDB, "playerlaunchdroppod" },
    { 0x6CDC, "playerleashbehavior" },
    { 0x6CDD, "playerleashdisable" },
    { 0x6CDE, "playerleavearea" },
    { 0x6CDF, "playerleavesoftlanding" },
    { 0x6CE0, "playerlinktodeltablend" },
    { 0x6CE1, "playerlinktodeltadelayed" },
    { 0x6CE2, "playermech_badplace" },
    { 0x6CE3, "playermech_chaingun_watcher" },
    { 0x6CE4, "playermech_damage_manager" },
    { 0x6CE5, "playermech_damage_parts" },
    { 0x6CE6, "playermech_disable_badplace" },
    { 0x6CE7, "playermech_dodamage" },
    { 0x6CE8, "playermech_enable_badplace" },
    { 0x6CE9, "playermech_end" },
    { 0x6CEA, "playermech_fx_init" },
    { 0x6CEB, "playermech_health_restore" },
    { 0x6CEC, "playermech_init" },
    { 0x6CED, "playermech_init_dmg_screens" },
    { 0x6CEE, "playermech_init_vo" },
    { 0x6CEF, "playermech_invalid_gun_callback" },
    { 0x6CF0, "playermech_invalid_rocket_callback" },
    { 0x6CF1, "playermech_invalid_swarm_callback" },
    { 0x6CF2, "playermech_invalid_weapon_instance" },
    { 0x6CF3, "playermech_invalid_weapon_watcher" },
    { 0x6CF4, "playermech_is_damage_allowed" },
    { 0x6CF5, "playermech_link_viewmodel_part" },
    { 0x6CF6, "playermech_mech_regen" },
    { 0x6CF7, "playermech_monitor_rocket_recharge" },
    { 0x6CF8, "playermech_monitor_swarm_recharge" },
    { 0x6CF9, "playermech_monitor_update_recharge" },
    { 0x6CFA, "playermech_physics_push" },
    { 0x6CFB, "playermech_physics_push_finale" },
    { 0x6CFC, "playermech_physics_push_off" },
    { 0x6CFD, "playermech_physics_push_on" },
    { 0x6CFE, "playermech_player_hit_fx" },
    { 0x6CFF, "playermech_restore_player_data" },
    { 0x6D00, "playermech_rocket_targeting_allowed" },
    { 0x6D01, "playermech_rockets_and_swarm_watcher" },
    { 0x6D02, "playermech_rockets_wait_rocket" },
    { 0x6D03, "playermech_rockets_wait_swarm" },
    { 0x6D04, "playermech_save_player_data" },
    { 0x6D05, "playermech_start" },
    { 0x6D06, "playermech_state_manager" },
    { 0x6D07, "playermech_threat_paint" },
    { 0x6D08, "playermech_threat_paint_loop" },
    { 0x6D09, "playermech_threat_paint_ping_loop" },
    { 0x6D0A, "playermech_ui_chaingun_feedback" },
    { 0x6D0B, "playermech_ui_rocket_feedback" },
    { 0x6D0C, "playermech_ui_state_enter" },
    { 0x6D0D, "playermech_ui_state_leave" },
    { 0x6D0E, "playermech_ui_state_reset" },
    { 0x6D0F, "playermech_ui_swarm_feedback" },
    { 0x6D10, "playermech_ui_turn_off_threat_count" },
    { 0x6D11, "playermech_ui_update_lui" },
    { 0x6D12, "playermech_ui_update_threat_compass_values" },
    { 0x6D13, "playermech_ui_weapon_feedback" },
    { 0x6D14, "playermech_watch_emp_grenade" },
    { 0x6D15, "playermodelforweapon" },
    { 0x6D16, "playermoduleshaverippedturret" },
    { 0x6D17, "playermonitordeath" },
    { 0x6D18, "playermonitorfordronedelivery" },
    { 0x6D19, "playermonitormarkedtarget" },
    { 0x6D1A, "playermonitorrocketturretfire" },
    { 0x6D1B, "playermonitorwarbirdpossession" },
    { 0x6D1C, "playermonitorweaponswitch" },
    { 0x6D1D, "playermovetruck" },
    { 0x6D1E, "playermovingdrone" },
    { 0x6D1F, "playernameids" },
    { 0x6D20, "playernode" },
    { 0x6D21, "playeronspawnprompt" },
    { 0x6D22, "playerpainbreathingsound" },
    { 0x6D23, "playerpiggyback" },
    { 0x6D24, "playerplayattachmentdialog" },
    { 0x6D25, "playerplayinvalidpositioneffect" },
    { 0x6D26, "playerplaytargetfx" },
    { 0x6D27, "playerplaythrustersound" },
    { 0x6D28, "playerplayvaporizefx" },
    { 0x6D29, "playerprekilled" },
    { 0x6D2A, "playerprocesstaggedassist" },
    { 0x6D2B, "playerquickkill" },
    { 0x6D2C, "playerrecordrippableammo" },
    { 0x6D2D, "playerremotecoopturret" },
    { 0x6D2E, "playerremotekillstreakhidehud" },
    { 0x6D2F, "playerremotekillstreakshowhud" },
    { 0x6D30, "playerremovenotifycommands" },
    { 0x6D31, "playerreset" },
    { 0x6D32, "playerresetaftercoopstreak" },
    { 0x6D33, "playerresetaftercoopstreakinternal" },
    { 0x6D34, "playerresetafterwarbird" },
    { 0x6D35, "playerresetomnvars" },
    { 0x6D36, "playerresetospomnvars" },
    { 0x6D37, "playerresetwarbirdomnvars" },
    { 0x6D38, "playerrestoreangles" },
    { 0x6D39, "playerrocketsandswarmwatcher" },
    { 0x6D3A, "playerrubberbandmovespeedscale" },
    { 0x6D3B, "players_ready" },
    { 0x6D3C, "players_waiting_to_join" },
    { 0x6D3D, "players_within_distance" },
    { 0x6D3E, "playersafehouseanimations" },
    { 0x6D3F, "playersaveangles" },
    { 0x6D40, "playerscore" },
    { 0x6D41, "playerscores" },
    { 0x6D42, "playerscrambleanimations" },
    { 0x6D43, "playerscramblefinale" },
    { 0x6D44, "playerseeker" },
    { 0x6D45, "playerseesme" },
    { 0x6D46, "playerseesmetime" },
    { 0x6D47, "playersetavailableweaponshud" },
    { 0x6D48, "playersetcamera" },
    { 0x6D49, "playersethudempscrambled" },
    { 0x6D4A, "playersethudempscrambledoff" },
    { 0x6D4B, "playersetjuggexomodel" },
    { 0x6D4C, "playersetupcoopstreak" },
    { 0x6D4D, "playersetupcoopstreakinternal" },
    { 0x6D4E, "playersetupjuggernautexo" },
    { 0x6D4F, "playersetuprecordedturrethead" },
    { 0x6D50, "playersetupstreakprompt" },
    { 0x6D51, "playersetupturretenergybar" },
    { 0x6D52, "playersetupuavpaintoutline" },
    { 0x6D53, "playershouldshowhud" },
    { 0x6D54, "playershowfullstatic" },
    { 0x6D55, "playershowjuggernauthud" },
    { 0x6D56, "playershowstreakstaticfordamage" },
    { 0x6D57, "playershowstreakstaticforrange" },
    { 0x6D58, "playershowturretoverlay" },
    { 0x6D59, "playerslookingforsafespawn" },
    { 0x6D5A, "playersnowfootsteps" },
    { 0x6D5B, "playersnowfootstepscrash" },
    { 0x6D5C, "playerspawned" },
    { 0x6D5D, "playerspawnpos" },
    { 0x6D5E, "playerspeed" },
    { 0x6D5F, "playerspread" },
    { 0x6D60, "playerspeedscale" },
    { 0x6D61, "playerstartoutofboundsstatic" },
    { 0x6D62, "playerstartpromptforstreaksupport" },
    { 0x6D63, "playerstartusingassaultvehicle" },
    { 0x6D64, "playerstartweaponname" },
    { 0x6D65, "playerstatictonormal" },
    { 0x6D66, "playerstatus" },
    { 0x6D67, "playerstealthkill" },
    { 0x6D68, "playerstoppromptforstreaksupport" },
    { 0x6D69, "playerswitchtobigturret" },
    { 0x6D6A, "playerswitchtomediumturret" },
    { 0x6D6B, "playerswitchtorocketturret" },
    { 0x6D6C, "playerswitchtoturret" },
    { 0x6D6D, "playertakestreaksupportinput" },
    { 0x6D6E, "playertargets" },
    { 0x6D6F, "playerteam" },
    { 0x6D70, "playertouchingtrigger" },
    { 0x6D71, "playertouchtriggerthink" },
    { 0x6D72, "playertrackturretammo" },
    { 0x6D73, "playertriggered" },
    { 0x6D74, "playertweaks" },
    { 0x6D75, "playerunderwater" },
    { 0x6D76, "playerunlimitedammothread" },
    { 0x6D77, "playerupdateflagstatus" },
    { 0x6D78, "playerupdateflagstatusonjointeam" },
    { 0x6D79, "playervehicle" },
    { 0x6D7A, "playerview_checkinterrupted" },
    { 0x6D7B, "playerview_endsequence" },
    { 0x6D7C, "playerview_knockdownanim" },
    { 0x6D7D, "playerview_knockdownlate" },
    { 0x6D7E, "playerview_playknockdownanim" },
    { 0x6D7F, "playerview_playknockdownanimlimited" },
    { 0x6D80, "playerview_playmissanim" },
    { 0x6D81, "playerview_show" },
    { 0x6D82, "playerview_spawn" },
    { 0x6D83, "playerview_startsequence" },
    { 0x6D84, "playerview_unlinkplayeranddelete" },
    { 0x6D85, "playerwaitreset" },
    { 0x6D86, "playerwaittillgoliathactivated" },
    { 0x6D87, "playerwaittillridekillstreakblack" },
    { 0x6D88, "playerwaittillridekillstreakcomplete" },
    { 0x6D89, "playerwaittillweaponswitchover" },
    { 0x6D8A, "playerwasnearby" },
    { 0x6D8B, "playerwatch_unresolved_collision" },
    { 0x6D8C, "playerwatch_unresolved_collision_count" },
    { 0x6D8D, "playerwatchemp" },
    { 0x6D8E, "playerwatchflagstatus" },
    { 0x6D8F, "playerwatchforearlyexit" },
    { 0x6D90, "playerwatchnoobtubeuse" },
    { 0x6D91, "playerwatchrocketuse" },
    { 0x6D92, "playerwaterclearwait" },
    { 0x6D93, "playerweapon" },
    { 0x6D94, "playerweather" },
    { 0x6D95, "playerwithinfov2d" },
    { 0x6D96, "playerwristmodelanim" },
    { 0x6D97, "playexplodedeathanim" },
    { 0x6D98, "playface_waitfornotify" },
    { 0x6D99, "playface_waitfortime" },
    { 0x6D9A, "playfacethread" },
    { 0x6D9B, "playfacialanim" },
    { 0x6D9C, "playfakecontrail" },
    { 0x6D9D, "playfireeffects" },
    { 0x6D9E, "playflavorburstline" },
    { 0x6D9F, "playfootstep" },
    { 0x6DA0, "playfootstepeffect" },
    { 0x6DA1, "playfootstepeffectsmall" },
    { 0x6DA2, "playfootstepoverride" },
    { 0x6DA3, "playfx_fordrop" },
    { 0x6DA4, "playfxent" },
    { 0x6DA5, "playfxontag_functionhack" },
    { 0x6DA6, "playfxontag_safe" },
    { 0x6DA7, "playfxturretmoveup" },
    { 0x6DA8, "playgrowl" },
    { 0x6DA9, "playheatfx" },
    { 0x6DAA, "playidle" },
    { 0x6DAB, "playidleanim" },
    { 0x6DAC, "playidleanimation" },
    { 0x6DAD, "playidleface" },
    { 0x6DAE, "playidlesound" },
    { 0x6DAF, "playinformevent" },
    { 0x6DB0, "playing_hit_reaction" },
    { 0x6DB1, "playing_lab_cinematic" },
    { 0x6DB2, "playing_new_enemy_reaction_anim" },
    { 0x6DB3, "playing_pain_sound" },
    { 0x6DB4, "playing_presets" },
    { 0x6DB5, "playing_view_model_cloak_toggle_anim" },
    { 0x6DB6, "playingdeathanim" },
    { 0x6DB7, "playingloopfiresounds" },
    { 0x6DB8, "playingmovementanim" },
    { 0x6DB9, "playinteriorsound" },
    { 0x6DBA, "playjetfx" },
    { 0x6DBB, "playlasercontainmentstart" },
    { 0x6DBC, "playlasercontainmentswap" },
    { 0x6DBD, "playlasercoreevent" },
    { 0x6DBE, "playlaserendingeffect" },
    { 0x6DBF, "playlingereffects" },
    { 0x6DC0, "playlocalsoundwrapper" },
    { 0x6DC1, "playlookanimation" },
    { 0x6DC2, "playloopedfxontag" },
    { 0x6DC3, "playloopedfxontag_originupdate" },
    { 0x6DC4, "playloopingsoundonorigin" },
    { 0x6DC5, "playloopsoundtoplayers" },
    { 0x6DC6, "playmoveanim" },
    { 0x6DC7, "playmoveanimknob" },
    { 0x6DC8, "playmovementsparks" },
    { 0x6DC9, "playmovesound" },
    { 0x6DCA, "playoceanfoam" },
    { 0x6DCB, "playorangegoo" },
    { 0x6DCC, "playorderevent" },
    { 0x6DCD, "playorstopfx_fordrop" },
    { 0x6DCE, "playpainanim" },
    { 0x6DCF, "playpanting" },
    { 0x6DD0, "playphrase" },
    { 0x6DD1, "playpropanim" },
    { 0x6DD2, "playreactionevent" },
    { 0x6DD3, "playresponseevent" },
    { 0x6DD4, "playrocketreloadsound" },
    { 0x6DD5, "playrocketswarmreloadsound" },
    { 0x6DD6, "playsmokefx" },
    { 0x6DD7, "playsound_and_light" },
    { 0x6DD8, "playsound_float" },
    { 0x6DD9, "playsound_loop_on_ent" },
    { 0x6DDA, "playsound_victim" },
    { 0x6DDB, "playsoundatpoint" },
    { 0x6DDC, "playsoundinspace" },
    { 0x6DDD, "playsoundonplayers" },
    { 0x6DDE, "playsoundtoallplayers" },
    { 0x6DDF, "playspace_explosion" },
    { 0x6DE0, "playspace_org" },
    { 0x6DE1, "playspinnerfx" },
    { 0x6DE2, "playtankexhaust" },
    { 0x6DE3, "playthreatevent" },
    { 0x6DE4, "playthrustereffects" },
    { 0x6DE5, "playtickingsound" },
    { 0x6DE6, "playtrailfx" },
    { 0x6DE7, "playtransitionanimation" },
    { 0x6DE8, "playtransitionanimationfunc" },
    { 0x6DE9, "playtransitionanimationthread_withoutwaitsetstates" },
    { 0x6DEA, "playtransitionstandwalk" },
    { 0x6DEB, "playwarbirdenginefx" },
    { 0x6DEC, "playwarmupeffects" },
    { 0x6DED, "playwarmupsounds" },
    { 0x6DEE, "playwaves" },
    { 0x6DEF, "plodding_footsteps" },
    { 0x6DF0, "plodding_footsteps_ends" },
    { 0x6DF1, "plot_points" },
    { 0x6DF2, "plr_dragged_away" },
    { 0x6DF3, "plr_exo_door_kick" },
    { 0x6DF4, "plr_fall_over" },
    { 0x6DF5, "pluggable_move_loop_override_function" },
    { 0x6DF6, "plugins" },
    { 0x6DF7, "plyr_forest_takedown_gun_wrestle" },
    { 0x6DF8, "plyr_forest_takedown_punch" },
    { 0x6DF9, "plyr_forest_takedown_tree_slam" },
    { 0x6DFA, "pm_clipvelocity" },
    { 0x6DFB, "pm_permuterestrictiveclipplanes" },
    { 0x6DFC, "pm_projectvelocity" },
    { 0x6DFD, "pm_rescue_foley" },
    { 0x6DFE, "pm_slidemove" },
    { 0x6DFF, "pm_stepslidemove" },
    { 0x6E00, "pmap_under_construction" },
    { 0x6E01, "pmc_alljuggernauts" },
    { 0x6E02, "pmc_match" },
    { 0x6E03, "pod_cormack_custom_mats_landing_on" },
    { 0x6E04, "pod_cormack_custom_mats_on" },
    { 0x6E05, "pod_door_button_prompt" },
    { 0x6E06, "pod_enemies" },
    { 0x6E07, "pod_engine_fx" },
    { 0x6E08, "pod_flyin" },
    { 0x6E09, "pod_fx_create" },
    { 0x6E0A, "pod_get_up" },
    { 0x6E0B, "pod_get_up_corrected" },
    { 0x6E0C, "pod_goes_flying" },
    { 0x6E0D, "pod_intro_mix" },
    { 0x6E0E, "pod_light_intro" },
    { 0x6E0F, "pod_light_intro_pre" },
    { 0x6E10, "pod_light_strobe" },
    { 0x6E11, "pod_phase1a_start" },
    { 0x6E12, "pod_rumble" },
    { 0x6E13, "pod_screen" },
    { 0x6E14, "pod_scripted_lights" },
    { 0x6E15, "pod_shake_play" },
    { 0x6E16, "podrocket" },
    { 0x6E17, "podsetuptrophyfx" },
    { 0x6E18, "podsquad" },
    { 0x6E19, "point" },
    { 0x6E1A, "point_in_angle_of_crosshairs" },
    { 0x6E1B, "point_in_fov" },
    { 0x6E1C, "point_inside" },
    { 0x6E1D, "point_is_in_screen_circle" },
    { 0x6E1E, "point_source_dambs" },
    { 0x6E1F, "point_tag" },
    { 0x6E20, "point_tag2" },
    { 0x6E21, "point_to_ambush" },
    { 0x6E22, "point1" },
    { 0x6E23, "point2" },
    { 0x6E24, "pointblankevent" },
    { 0x6E25, "pointevents" },
    { 0x6E26, "pointinfov" },
    { 0x6E27, "pointisinairstrikearea" },
    { 0x6E28, "pointnotifylua" },
    { 0x6E29, "poison" },
    { 0x6E2A, "police_drone_play_all_fx" },
    { 0x6E2B, "police_drone_play_anim" },
    { 0x6E2C, "police_drone_play_fx" },
    { 0x6E2D, "poll_for_found" },
    { 0x6E2E, "pollallowedstancesthread" },
    { 0x6E2F, "pool" },
    { 0x6E30, "pool_building_enemy_think" },
    { 0x6E31, "pool_building_walkway_01_enemy_think" },
    { 0x6E32, "pool_civ_01_cower" },
    { 0x6E33, "pool_civ_01_cower_setup" },
    { 0x6E34, "pool_civ_wounded_woman" },
    { 0x6E35, "pool_female_wounded" },
    { 0x6E36, "pool_male_01_cower" },
    { 0x6E37, "pool_walla_scream" },
    { 0x6E38, "poolalliesadvance" },
    { 0x6E39, "poolhouse_drones" },
    { 0x6E3A, "poolhouse_enemies" },
    { 0x6E3B, "poolhouse_prop_cleanup" },
    { 0x6E3C, "poolhouse_spawner_setup" },
    { 0x6E3D, "poolindex" },
    { 0x6E3E, "poolkillanimations" },
    { 0x6E3F, "poolyard_guard_wander_setup" },
    { 0x6E40, "poolyard_guard_wander_watch_for_alert" },
    { 0x6E41, "pop_cormack_into_exfil_anim_to_match_player" },
    { 0x6E42, "pop_flares_when_fired_on" },
    { 0x6E43, "pop_up" },
    { 0x6E44, "pop_up_and_hide_speed" },
    { 0x6E45, "popinpopout" },
    { 0x6E46, "populate_ai_civilians" },
    { 0x6E47, "populate_drone_civilians" },
    { 0x6E48, "populatedronecivilians" },
    { 0x6E49, "popupandshoot" },
    { 0x6E4A, "portable_mg_behavior" },
    { 0x6E4B, "portable_mg_gun_tag" },
    { 0x6E4C, "portable_mg_spot" },
    { 0x6E4D, "portable_radar" },
    { 0x6E4E, "portableradararray" },
    { 0x6E4F, "portableradarbeepsounds" },
    { 0x6E50, "portableradardamagelistener" },
    { 0x6E51, "portableradarproximitytracker" },
    { 0x6E52, "portableradarsetup" },
    { 0x6E53, "portableradaruselistener" },
    { 0x6E54, "portableradarwatchowner" },
    { 0x6E55, "portal_group_off" },
    { 0x6E56, "portal_group_on" },
    { 0x6E57, "pos" },
    { 0x6E58, "pos_angle" },
    { 0x6E59, "pos_array" },
    { 0x6E5A, "pose" },
    { 0x6E5B, "position_ally_for_bomb_plant" },
    { 0x6E5C, "position_elevators" },
    { 0x6E5D, "position_error" },
    { 0x6E5E, "position_for_movement" },
    { 0x6E5F, "position_in_circle" },
    { 0x6E60, "position_in_spear" },
    { 0x6E61, "position_smoothing" },
    { 0x6E62, "positionptm" },
    { 0x6E63, "positivewrap" },
    { 0x6E64, "possesswarbird" },
    { 0x6E65, "possible" },
    { 0x6E66, "possible_targets" },
    { 0x6E67, "possiblethreatcallouts" },
    { 0x6E68, "post" },
    { 0x6E69, "post_car_ride_cormack" },
    { 0x6E6A, "post_car_ride_player" },
    { 0x6E6B, "post_collapse_vfx_on_crash_site" },
    { 0x6E6C, "post_credits_still_image" },
    { 0x6E6D, "post_entity_creation_function" },
    { 0x6E6E, "post_event_geo" },
    { 0x6E6F, "post_event_hp_zones" },
    { 0x6E70, "post_event_nodes" },
    { 0x6E71, "post_event_pathing_blockers" },
    { 0x6E72, "post_explosion_alarms" },
    { 0x6E73, "post_fire_function" },
    { 0x6E74, "post_h_breach_ajani_start" },
    { 0x6E75, "post_h_breach_burke_start" },
    { 0x6E76, "post_h_breach_joker_start" },
    { 0x6E77, "post_intro_loop_anim" },
    { 0x6E78, "post_intro_loop_anim_vm" },
    { 0x6E79, "post_load" },
    { 0x6E7A, "post_load_funcs" },
    { 0x6E7B, "post_load_precache" },
    { 0x6E7C, "post_main_loop_anim" },
    { 0x6E7D, "post_main_loop_anim_vm" },
    { 0x6E7E, "post_middle_takedown_highway_path_player_side" },
    { 0x6E7F, "post_middle_takedown_traffic_done" },
    { 0x6E80, "post_pod_intro_stuff" },
    { 0x6E81, "post_reactor_alarm" },
    { 0x6E82, "post_refuel" },
    { 0x6E83, "post_tower_axis_logic" },
    { 0x6E84, "post_tower_inits_precache" },
    { 0x6E85, "post_win_camshake" },
    { 0x6E86, "post_win_disable_rumbles" },
    { 0x6E87, "postdeathkillevent" },
    { 0x6E88, "postdna_mech_attack" },
    { 0x6E89, "postgamenotifies" },
    { 0x6E8A, "postgamepromotion" },
    { 0x6E8B, "postpainfunc" },
    { 0x6E8C, "postroundtime" },
    { 0x6E8D, "postscriptfunc" },
    { 0x6E8E, "postspawn_rpg_vehicle" },
    { 0x6E8F, "potentialscantargets" },
    { 0x6E90, "potentialtarget" },
    { 0x6E91, "potentialtargetanimations" },
    { 0x6E92, "pov_mode" },
    { 0x6E93, "power_outage_audio" },
    { 0x6E94, "practiceloadout" },
    { 0x6E95, "practiceround" },
    { 0x6E96, "practiceroundassistevent" },
    { 0x6E97, "practiceroundclasstablename" },
    { 0x6E98, "practiceroundcostumetablename" },
    { 0x6E99, "practicerounddialogplayed" },
    { 0x6E9A, "practicerounddialogvalid" },
    { 0x6E9B, "practiceroundgame" },
    { 0x6E9C, "practiceroundkillevent" },
    { 0x6E9D, "pre_bomb_plant_lighting" },
    { 0x6E9E, "pre_bridge_collapse_helo_idle" },
    { 0x6E9F, "pre_bridge_collapse_scene" },
    { 0x6EA0, "pre_event_hp_zones" },
    { 0x6EA1, "pre_event_nodes" },
    { 0x6EA2, "pre_event_pathing_blockers" },
    { 0x6EA3, "pre_fire_function" },
    { 0x6EA4, "pre_guesthouse_vo" },
    { 0x6EA5, "pre_h_breach_ajani_start" },
    { 0x6EA6, "pre_h_breach_burke_start" },
    { 0x6EA7, "pre_h_breach_joker_start" },
    { 0x6EA8, "pre_hack_security_check" },
    { 0x6EA9, "pre_hangar_hall_explosion" },
    { 0x6EAA, "pre_load" },
    { 0x6EAB, "pre_lobby_framedelay" },
    { 0x6EAC, "pre_lobby_update" },
    { 0x6EAD, "pre_reactor_alarms" },
    { 0x6EAE, "pre_spotted_func" },
    { 0x6EAF, "pre_unload" },
    { 0x6EB0, "pre_unload_idle" },
    { 0x6EB1, "prebreachcurrentweapon" },
    { 0x6EB2, "precache_big_cave" },
    { 0x6EB3, "precache_boost_fx_npc" },
    { 0x6EB4, "precache_boost_fx_player" },
    { 0x6EB5, "precache_cave_entry" },
    { 0x6EB6, "precache_cave_hallway" },
    { 0x6EB7, "precache_code" },
    { 0x6EB8, "precache_combat_cave" },
    { 0x6EB9, "precache_crash_site" },
    { 0x6EBA, "precache_destructible" },
    { 0x6EBB, "precache_destructibles" },
    { 0x6EBC, "precache_exo_temperature" },
    { 0x6EBD, "precache_for_hovertank" },
    { 0x6EBE, "precache_fx" },
    { 0x6EBF, "precache_ice_bridge" },
    { 0x6EC0, "precache_icons" },
    { 0x6EC1, "precache_lake" },
    { 0x6EC2, "precache_lake_cinema" },
    { 0x6EC3, "precache_lui_event_strings" },
    { 0x6EC4, "precache_lui_hovertank_screens" },
    { 0x6EC5, "precache_main" },
    { 0x6EC6, "precache_microwave_anims" },
    { 0x6EC7, "precache_microwave_grenade_fx" },
    { 0x6EC8, "precache_narrow_cave" },
    { 0x6EC9, "precache_overlook" },
    { 0x6ECA, "precache_player_land_assist" },
    { 0x6ECB, "precache_presets" },
    { 0x6ECC, "precache_scanner_turret" },
    { 0x6ECD, "precache_script" },
    { 0x6ECE, "precache_script_models" },
    { 0x6ECF, "precache_scripts" },
    { 0x6ED0, "precache_skyjack" },
    { 0x6ED1, "precache_stuff" },
    { 0x6ED2, "precache_var_grenade_fx" },
    { 0x6ED3, "precache_vtol_takedown" },
    { 0x6ED4, "precacheanims" },
    { 0x6ED5, "precacheassets" },
    { 0x6ED6, "precacheassets_and_initflags" },
    { 0x6ED7, "precachecivilian" },
    { 0x6ED8, "precacheciviliananims" },
    { 0x6ED9, "precachedooranimations" },
    { 0x6EDA, "precacheflags" },
    { 0x6EDB, "precachefx" },
    { 0x6EDC, "precacheharmonicbreach" },
    { 0x6EDD, "precacheharmonicbreachanimations" },
    { 0x6EDE, "precacheharmonicbreachfx" },
    { 0x6EDF, "precacheharmonicbreachitems" },
    { 0x6EE0, "precacheharmonicbreachplayerrig" },
    { 0x6EE1, "precachemodelarray" },
    { 0x6EE2, "precacheorbital" },
    { 0x6EE3, "precachepropmodels" },
    { 0x6EE4, "precachescriptmodelanimations" },
    { 0x6EE5, "precachescriptmodelanims" },
    { 0x6EE6, "precachesecuritycamera" },
    { 0x6EE7, "precachesetup" },
    { 0x6EE8, "precachevehicleanimations" },
    { 0x6EE9, "precisepositioning" },
    { 0x6EEA, "predamageshieldignoreme" },
    { 0x6EEB, "preending_confculldist" },
    { 0x6EEC, "preferalliesbydistance" },
    { 0x6EED, "preferbyteambase" },
    { 0x6EEE, "preferdompoints" },
    { 0x6EEF, "preferhardpointpoints" },
    { 0x6EF0, "preferplayeranchors" },
    { 0x6EF1, "preferred_crash_location" },
    { 0x6EF2, "preferred_crash_style" },
    { 0x6EF3, "preferred_death_anim" },
    { 0x6EF4, "preferredoffsetfromowner" },
    { 0x6EF5, "preferredtarget" },
    { 0x6EF6, "prefers_drones" },
    { 0x6EF7, "prefertwarzone" },
    { 0x6EF8, "preflight_vo" },
    { 0x6EF9, "prekillcamnotify" },
    { 0x6EFA, "prekilledfunc" },
    { 0x6EFB, "preload" },
    { 0x6EFC, "preloadweapons" },
    { 0x6EFD, "prelobby_camera_ratio" },
    { 0x6EFE, "prelobby_camerazoff" },
    { 0x6EFF, "prelobby_camerazoff_zoom" },
    { 0x6F00, "prelobby_fardist" },
    { 0x6F01, "prelobby_movespeed" },
    { 0x6F02, "prelobby_neardist" },
    { 0x6F03, "prelobby_ratio_zoom" },
    { 0x6F04, "prelobby_targetzoff" },
    { 0x6F05, "prelobby_targetzoff_zoom" },
    { 0x6F06, "prelobbyzoom" },
    { 0x6F07, "prematch_done_time" },
    { 0x6F08, "prematch_over" },
    { 0x6F09, "prematchperiod" },
    { 0x6F0A, "prematchperiodend" },
    { 0x6F0B, "prematurecornergrenadedeath" },
    { 0x6F0C, "prep_bobbing" },
    { 0x6F0D, "prep_cinematic" },
    { 0x6F0E, "prep_ending" },
    { 0x6F0F, "prep_for_controls" },
    { 0x6F10, "prep_user_for_drone" },
    { 0x6F11, "prep_user_for_dronecrate" },
    { 0x6F12, "prepare_blast_doors" },
    { 0x6F13, "prepare_dialog" },
    { 0x6F14, "prepare_dialogue" },
    { 0x6F15, "prepare_option_for_change" },
    { 0x6F16, "prepare_show_threat" },
    { 0x6F17, "prepare_to_be_shot" },
    { 0x6F18, "prepare_to_teleport" },
    { 0x6F19, "prepareattackplayer" },
    { 0x6F1A, "prepared" },
    { 0x6F1B, "prepareforclasschange" },
    { 0x6F1C, "preplaced_guys_function" },
    { 0x6F1D, "preplacedpostscriptfunc" },
    { 0x6F1E, "prereqs" },
    { 0x6F1F, "preset_cache" },
    { 0x6F20, "preset_constructors" },
    { 0x6F21, "preset_name" },
    { 0x6F22, "presets" },
    { 0x6F23, "president" },
    { 0x6F24, "presseddown" },
    { 0x6F25, "pressedup" },
    { 0x6F26, "presses" },
    { 0x6F27, "pressure_explosion" },
    { 0x6F28, "pressure_explosion_damage" },
    { 0x6F29, "pressure_explosion_lead_up" },
    { 0x6F2A, "pressure_explosion_leadup_1" },
    { 0x6F2B, "pressure_explosion_leadup_2" },
    { 0x6F2C, "pressure_explosion_leadup_3" },
    { 0x6F2D, "pressure_explosion_leadup_4" },
    { 0x6F2E, "pressure_explosion_leadup_5" },
    { 0x6F2F, "pressure_explosion_leadup_6" },
    { 0x6F30, "pressure_explosion_leadup_7" },
    { 0x6F31, "pretend_to_be_dead" },
    { 0x6F32, "pretending_to_be_dead" },
    { 0x6F33, "prev" },
    { 0x6F34, "prev_accel_oneshot_time" },
    { 0x6F35, "prev_attached_path" },
    { 0x6F36, "prev_attachedpath" },
    { 0x6F37, "prev_cue_name" },
    { 0x6F38, "prev_defend_node" },
    { 0x6F39, "prev_dist" },
    { 0x6F3A, "prev_dp" },
    { 0x6F3B, "prev_dv" },
    { 0x6F3C, "prev_dx" },
    { 0x6F3D, "prev_eyel_diff" },
    { 0x6F3E, "prev_eyer_diff" },
    { 0x6F3F, "prev_height" },
    { 0x6F40, "prev_impacttime" },
    { 0x6F41, "prev_node" },
    { 0x6F42, "prev_pitch" },
    { 0x6F43, "prev_rate" },
    { 0x6F44, "prev_role" },
    { 0x6F45, "prev_speed" },
    { 0x6F46, "prev_state" },
    { 0x6F47, "prev_throttle" },
    { 0x6F48, "prev_time" },
    { 0x6F49, "prev_turret_state" },
    { 0x6F4A, "prev_velo" },
    { 0x6F4B, "prev_yards" },
    { 0x6F4C, "prev_zv" },
    { 0x6F4D, "prevattack" },
    { 0x6F4E, "prevenemy" },
    { 0x6F4F, "prevent_friendly_from_shooting_during_stealth" },
    { 0x6F50, "prevent_look_until_notify" },
    { 0x6F51, "prevent_tracking_drone_in_water" },
    { 0x6F52, "preventpainforashorttime" },
    { 0x6F53, "prevframevelocity" },
    { 0x6F54, "previewcostume" },
    { 0x6F55, "previewgearcategory" },
    { 0x6F56, "previewgearid" },
    { 0x6F57, "previous_bump_zvel" },
    { 0x6F58, "previous_button" },
    { 0x6F59, "previous_intensityhdr" },
    { 0x6F5A, "previous_position" },
    { 0x6F5B, "previous_turret_target" },
    { 0x6F5C, "previous_weapon" },
    { 0x6F5D, "previous_yaw" },
    { 0x6F5E, "previousadrenaline" },
    { 0x6F5F, "previousadrenalinesupport" },
    { 0x6F60, "previousclasstime" },
    { 0x6F61, "previousgoalnode" },
    { 0x6F62, "previousintensityhdr" },
    { 0x6F63, "previously_played_fx_joint_l" },
    { 0x6F64, "previously_played_fx_joint_r" },
    { 0x6F65, "previously_played_fx_name_l" },
    { 0x6F66, "previously_played_fx_name_r" },
    { 0x6F67, "previouspitchdelta" },
    { 0x6F68, "previousprimary" },
    { 0x6F69, "previoustrackedplayer" },
    { 0x6F6A, "prevleanfracpitch" },
    { 0x6F6B, "prevleanfracyaw" },
    { 0x6F6C, "prevlethalvarclass" },
    { 0x6F6D, "prevlethalvartype" },
    { 0x6F6E, "prevmovearchetype" },
    { 0x6F6F, "prevmovemode" },
    { 0x6F70, "prevmovestate" },
    { 0x6F71, "prevnameplatematerial" },
    { 0x6F72, "prevownerteam" },
    { 0x6F73, "prevputguninhandtime" },
    { 0x6F74, "prevsnowmobiledeath" },
    { 0x6F75, "prevsnowmobiledeathtime" },
    { 0x6F76, "prevstairsstate" },
    { 0x6F77, "prevstance" },
    { 0x6F78, "prevtacticalvarclass" },
    { 0x6F79, "prevtacticalvartype" },
    { 0x6F7A, "prevturnrate" },
    { 0x6F7B, "prevzoneindex" },
    { 0x6F7C, "price" },
    { 0x6F7D, "price_breach_ent" },
    { 0x6F7E, "price_breach_ent_movesto_player" },
    { 0x6F7F, "price_breach_ent_rotatesto_player" },
    { 0x6F80, "primary_light" },
    { 0x6F81, "primary_weapon_array" },
    { 0x6F82, "primaryattachment" },
    { 0x6F83, "primarygrenade" },
    { 0x6F84, "primaryname" },
    { 0x6F85, "primaryprogressbarfontsize" },
    { 0x6F86, "primaryprogressbarheight" },
    { 0x6F87, "primaryprogressbartextx" },
    { 0x6F88, "primaryprogressbartexty" },
    { 0x6F89, "primaryprogressbarwidth" },
    { 0x6F8A, "primaryprogressbarx" },
    { 0x6F8B, "primaryprogressbary" },
    { 0x6F8C, "primarytarget" },
    { 0x6F8D, "primarytorestore" },
    { 0x6F8E, "primaryturretanim" },
    { 0x6F8F, "primaryweaponent" },
    { 0x6F90, "primaryweapons" },
    { 0x6F91, "primaryweaponsammo" },
    { 0x6F92, "primer" },
    { 0x6F93, "print_altitude" },
    { 0x6F94, "print_csv_asset" },
    { 0x6F95, "print_debug_text_hud" },
    { 0x6F96, "print_debug_text_string_hud" },
    { 0x6F97, "print_distance_on_ent" },
    { 0x6F98, "print_fx_options" },
    { 0x6F99, "print_org" },
    { 0x6F9A, "print_roll" },
    { 0x6F9B, "print_speed" },
    { 0x6F9C, "print_state" },
    { 0x6F9D, "print_throttle" },
    { 0x6F9E, "print_tilt" },
    { 0x6F9F, "print_vehicle_info" },
    { 0x6FA0, "print_yaw" },
    { 0x6FA1, "print3d_over_target" },
    { 0x6FA2, "print3d_time" },
    { 0x6FA3, "print3ddraw" },
    { 0x6FA4, "print3dfortime" },
    { 0x6FA5, "print3drise" },
    { 0x6FA6, "print3dthread" },
    { 0x6FA7, "print3dtime" },
    { 0x6FA8, "print3duntilnotify" },
    { 0x6FA9, "printabovehead" },
    { 0x6FAA, "printandsoundoneveryone" },
    { 0x6FAB, "printandsoundonplayer" },
    { 0x6FAC, "printandsoundonteam" },
    { 0x6FAD, "printboldonteam" },
    { 0x6FAE, "printboldonteamarg" },
    { 0x6FAF, "printdisplaceinfo" },
    { 0x6FB0, "printer" },
    { 0x6FB1, "printerdebugger" },
    { 0x6FB2, "printhealthtoscreen" },
    { 0x6FB3, "printlnscreenandconsole" },
    { 0x6FB4, "printonplayers" },
    { 0x6FB5, "printonteam" },
    { 0x6FB6, "printonteamarg" },
    { 0x6FB7, "printorigin3duntilnotify" },
    { 0x6FB8, "printshoot" },
    { 0x6FB9, "printshootproc" },
    { 0x6FBA, "printyaws" },
    { 0x6FBB, "printyawtoenemy" },
    { 0x6FBC, "prioritize_colorcoded_nodes" },
    { 0x6FBD, "prioritize_watch_nodes_toward_enemies" },
    { 0x6FBE, "priority" },
    { 0x6FBF, "priority_sort" },
    { 0x6FC0, "priority_vols" },
    { 0x6FC1, "prison_turret_active" },
    { 0x6FC2, "prison_turret_alarm_sfx" },
    { 0x6FC3, "prison_turret_burn_sfx" },
    { 0x6FC4, "prison_turret_laser_glow" },
    { 0x6FC5, "prison_turret_warning_light_enemy" },
    { 0x6FC6, "prison_turret_warning_light_friendly" },
    { 0x6FC7, "prison_turrets" },
    { 0x6FC8, "prison_turrets_alive" },
    { 0x6FC9, "prisoncustomkillstreakfunc" },
    { 0x6FCA, "prisoner_6_shadow_and_loop" },
    { 0x6FCB, "prisoner_randomizer" },
    { 0x6FCC, "prisonpaladinoverrides" },
    { 0x6FCD, "prisonturretportableradar" },
    { 0x6FCE, "prisonturrettimer" },
    { 0x6FCF, "prisonturrettrackingoverlay" },
    { 0x6FD0, "privatematch" },
    { 0x6FD1, "pro_cave_get_up" },
    { 0x6FD2, "pro_cave_grabbing_gun" },
    { 0x6FD3, "pro_cave_help_ilona" },
    { 0x6FD4, "pro_cave_helped_up" },
    { 0x6FD5, "pro_cave_ilona_pick_up_gun" },
    { 0x6FD6, "pro_cave_pick_up_gun" },
    { 0x6FD7, "pro_cave_roll_over" },
    { 0x6FD8, "pro_cave_stowing_gun" },
    { 0x6FD9, "pro_hall_follow_dot" },
    { 0x6FDA, "prob_scale" },
    { 0x6FDB, "probability" },
    { 0x6FDC, "probedistancemethod" },
    { 0x6FDD, "process" },
    { 0x6FDE, "process_animation" },
    { 0x6FDF, "process_blend" },
    { 0x6FE0, "process_button_held_and_clicked" },
    { 0x6FE1, "process_buttonmash" },
    { 0x6FE2, "process_buttonmash_finale_scene" },
    { 0x6FE3, "process_buttonmash_handle_fail" },
    { 0x6FE4, "process_buttonmash_handle_hint" },
    { 0x6FE5, "process_color_order_to_ai" },
    { 0x6FE6, "process_cover_node" },
    { 0x6FE7, "process_cover_node_with_last_in_mind_allies" },
    { 0x6FE8, "process_cover_node_with_last_in_mind_axis" },
    { 0x6FE9, "process_deathflags" },
    { 0x6FEA, "process_flight_path" },
    { 0x6FEB, "process_fov" },
    { 0x6FEC, "process_fx_rotater" },
    { 0x6FED, "process_melee_notetracks" },
    { 0x6FEE, "process_moving_platform_death" },
    { 0x6FEF, "process_path_node" },
    { 0x6FF0, "process_reticle_multikill" },
    { 0x6FF1, "process_screen_shake" },
    { 0x6FF2, "process_stab_finale_scene" },
    { 0x6FF3, "process_traffic_leader_pending_due_to_lane_split" },
    { 0x6FF4, "processassistevent" },
    { 0x6FF5, "processattachments" },
    { 0x6FF6, "processchallenge" },
    { 0x6FF7, "processdamagetaken" },
    { 0x6FF8, "processed" },
    { 0x6FF9, "processed_trigger" },
    { 0x6FFA, "processing_emp_death_function" },
    { 0x6FFB, "processingkilledchallenges" },
    { 0x6FFC, "processlobbydata" },
    { 0x6FFD, "processlobbyscoreboards" },
    { 0x6FFE, "processviaitemstatsprogress" },
    { 0x6FFF, "processviaitemstatsstate" },
    { 0x7000, "progress" },
    { 0x7001, "progress_bar" },
    { 0x7002, "progress_dif" },
    { 0x7003, "progress_maps" },
    { 0x7004, "progress_node" },
    { 0x7005, "progress_path_create" },
    { 0x7006, "progress_path_get_my_node_from_org" },
    { 0x7007, "progress_path_move_to_correct_node" },
    { 0x7008, "progress_trigger_callbacks" },
    { 0x7009, "progressioncombat" },
    { 0x700A, "progressionkillhades" },
    { 0x700B, "progressionoutro" },
    { 0x700C, "progressionsupportphase1" },
    { 0x700D, "progressionsupportphase2" },
    { 0x700E, "progressionsupportphase3" },
    { 0x700F, "project_into_plane" },
    { 0x7010, "project_perpendicular" },
    { 0x7011, "projectile" },
    { 0x7012, "projectile_alive" },
    { 0x7013, "projectileexplode" },
    { 0x7014, "projectilesstopped" },
    { 0x7015, "projector" },
    { 0x7016, "promote_nearest_friendly" },
    { 0x7017, "promote_nearest_friendly_with_classname" },
    { 0x7018, "promotionsplashnotify" },
    { 0x7019, "prompt_show_hide" },
    { 0x701A, "promptforstreaksupport" },
    { 0x701B, "promptid" },
    { 0x701C, "prone_anim_override" },
    { 0x701D, "prone_hint_trigger" },
    { 0x701E, "prone_rate_override" },
    { 0x701F, "prone_transitionto" },
    { 0x7020, "prone_visible_from" },
    { 0x7021, "proneaiming" },
    { 0x7022, "pronecombatmainloop" },
    { 0x7023, "pronecrawl" },
    { 0x7024, "pronecrawltoprone" },
    { 0x7025, "pronelegsstraighttree" },
    { 0x7026, "pronereload" },
    { 0x7027, "pronerun_begin" },
    { 0x7028, "pronestill" },
    { 0x7029, "pronestop_begin" },
    { 0x702A, "pronetime" },
    { 0x702B, "proneto" },
    { 0x702C, "pronetocrouch" },
    { 0x702D, "pronetocrouchrun" },
    { 0x702E, "pronetocrouchwalk" },
    { 0x702F, "pronetopronemove" },
    { 0x7030, "pronetopronerun" },
    { 0x7031, "pronetostand" },
    { 0x7032, "pronetostandrun" },
    { 0x7033, "pronetostandwalk" },
    { 0x7034, "pronewalk_begin" },
    { 0x7035, "prop_anims" },
    { 0x7036, "prop_cig_throw" },
    { 0x7037, "prop_delete" },
    { 0x7038, "prop_delete_cig" },
    { 0x7039, "prop_notetrack_exist" },
    { 0x703A, "prop_notetracks" },
    { 0x703B, "prop10_drones" },
    { 0x703C, "prop30" },
    { 0x703D, "propanims" },
    { 0x703E, "propsendinganimations" },
    { 0x703F, "protect_radius" },
    { 0x7040, "protect_watch_allies" },
    { 0x7041, "proxbar" },
    { 0x7042, "proxbartext" },
    { 0x7043, "proxtriggerlos" },
    { 0x7044, "proxtriggerthink" },
    { 0x7045, "proxy" },
    { 0x7046, "proxy_alarm_on" },
    { 0x7047, "prv_cac" },
    { 0x7048, "prv_cac_weapon" },
    { 0x7049, "prv_vl_cao_focus" },
    { 0x704A, "ps_item" },
    { 0x704B, "pull_fence_dust" },
    { 0x704C, "pulse" },
    { 0x704D, "pulse_button_timeout" },
    { 0x704E, "pulse_compass_text" },
    { 0x704F, "pulse_fx" },
    { 0x7050, "pulse_presets" },
    { 0x7051, "pulse_think" },
    { 0x7052, "pulseorbitalsupportreloadtext" },
    { 0x7053, "punch_door" },
    { 0x7054, "punish_view_level" },
    { 0x7055, "punishment" },
    { 0x7056, "punishment_anim" },
    { 0x7057, "punishment_check" },
    { 0x7058, "punishment_level" },
    { 0x7059, "punishment_push" },
    { 0x705A, "punishment_recovery" },
    { 0x705B, "pursue_player" },
    { 0x705C, "push_dude_into_shelves" },
    { 0x705D, "push_item_on_que" },
    { 0x705E, "push_right_after_flag" },
    { 0x705F, "pushmode" },
    { 0x7060, "pushpoint" },
    { 0x7061, "put_bridge_in_proper_place" },
    { 0x7062, "put_cardoor_on_will" },
    { 0x7063, "put_roadsurface_in_proper_place" },
    { 0x7064, "put_toy_in_volume" },
    { 0x7065, "putgunaway" },
    { 0x7066, "putgunbackinhandonkillanimscript" },
    { 0x7067, "putguninhand" },
    { 0x7068, "putweaponbackinrighthand" },
    { 0x7069, "pv_maxlrgvelocity" },
    { 0x706A, "pv_maxmedvelocity" },
    { 0x706B, "pv_maxsmlvelocity" },
    { 0x706C, "pv_maxvelocity" },
    { 0x706D, "pv_minvelocitythreshold" },
    { 0x706E, "pv_numvelocityranges" },
    { 0x706F, "pyramid_death_report" },
    { 0x7070, "pyramid_spawn" },
    { 0x7071, "pyramid_spawner_reports_death" },
    { 0x7072, "q" },
    { 0x7073, "qafinished" },
    { 0x7074, "qsetgoalpos" },
    { 0x7075, "qte_fail_off" },
    { 0x7076, "qte_grab_hold_off" },
    { 0x7077, "qte_middle_dodge_off" },
    { 0x7078, "qte_middle_jump_off" },
    { 0x7079, "qte_middle_pull_kva_off" },
    { 0x707A, "qte_middle_pull_windshield_off" },
    { 0x707B, "qte_middle_shoot_off" },
    { 0x707C, "qte_pry_open_off" },
    { 0x707D, "qte_shoot_kva_off" },
    { 0x707E, "qte_success_off" },
    { 0x707F, "qte_swim_off" },
    { 0x7080, "quad_enable" },
    { 0x7081, "quadrant_display" },
    { 0x7082, "quadrantanimweights" },
    { 0x7083, "qualityspotshadow" },
    { 0x7084, "quarter_up_position" },
    { 0x7085, "queen" },
    { 0x7086, "queen_change_path" },
    { 0x7087, "queen_count" },
    { 0x7088, "queen_curl" },
    { 0x7089, "queen_data_accel" },
    { 0x708A, "queen_data_decel" },
    { 0x708B, "queen_data_desired_speed" },
    { 0x708C, "queen_data_follow_radii" },
    { 0x708D, "queen_deadzone" },
    { 0x708E, "queen_drone_fly" },
    { 0x708F, "queen_drone_form_hemisphere" },
    { 0x7090, "queen_drone_gopath" },
    { 0x7091, "queen_factor" },
    { 0x7092, "queen_follow_anim" },
    { 0x7093, "queen_relative_speed" },
    { 0x7094, "querymemberanimstate" },
    { 0x7095, "querymemberstate" },
    { 0x7096, "queueadd" },
    { 0x7097, "queueanim" },
    { 0x7098, "queuecreate" },
    { 0x7099, "queued_anim_threads" },
    { 0x709A, "queueremovefirst" },
    { 0x709B, "queues" },
    { 0x709C, "quick_cursor" },
    { 0x709D, "quick_death" },
    { 0x709E, "quick_pulse" },
    { 0x709F, "quick_transition_flash" },
    { 0x70A0, "quickcommands" },
    { 0x70A1, "quickgunlevelevent" },
    { 0x70A2, "quickmessagetoall" },
    { 0x70A3, "quickresponses" },
    { 0x70A4, "quicksort" },
    { 0x70A5, "quicksort_compare" },
    { 0x70A6, "quicksort_flag_compare" },
    { 0x70A7, "quicksortmid" },
    { 0x70A8, "quickstatements" },
    { 0x70A9, "r" },
    { 0x70AA, "r_hudoutlineenable" },
    { 0x70AB, "r_hudoutlinehaloblurradius" },
    { 0x70AC, "r_hudoutlinehalolumscale" },
    { 0x70AD, "r_hudoutlinepostmode" },
    { 0x70AE, "radar_dish_rotate" },
    { 0x70AF, "radarmover" },
    { 0x70B0, "radial_angle_to_vector" },
    { 0x70B1, "radial_button_current_group" },
    { 0x70B2, "radial_button_definitions" },
    { 0x70B3, "radial_button_group" },
    { 0x70B4, "radial_button_group_info" },
    { 0x70B5, "radial_button_previous_group" },
    { 0x70B6, "radial_init" },
    { 0x70B7, "radiant_pos" },
    { 0x70B8, "radiation_totalpercent" },
    { 0x70B9, "radii" },
    { 0x70BA, "radio_add" },
    { 0x70BB, "radio_chatter" },
    { 0x70BC, "radio_dialog_add_and_go" },
    { 0x70BD, "radio_dialogue" },
    { 0x70BE, "radio_dialogue_clear_stack" },
    { 0x70BF, "radio_dialogue_interupt" },
    { 0x70C0, "radio_dialogue_nag_loop" },
    { 0x70C1, "radio_dialogue_overlap" },
    { 0x70C2, "radio_dialogue_overlap_stop" },
    { 0x70C3, "radio_dialogue_play" },
    { 0x70C4, "radio_dialogue_queue" },
    { 0x70C5, "radio_dialogue_queue_global" },
    { 0x70C6, "radio_dialogue_queue_single" },
    { 0x70C7, "radio_dialogue_remove_from_stack" },
    { 0x70C8, "radio_dialogue_safe" },
    { 0x70C9, "radio_dialogue_stop" },
    { 0x70CA, "radio_queue_thread" },
    { 0x70CB, "radio_run_guy" },
    { 0x70CC, "radio_try_squelch_out" },
    { 0x70CD, "radio_walkby_guy_vo" },
    { 0x70CE, "radiometricunithdr" },
    { 0x70CF, "radiometricunitshdr" },
    { 0x70D0, "radiosity" },
    { 0x70D1, "radiosityhdr" },
    { 0x70D2, "radiosityscale" },
    { 0x70D3, "radiosityscale_ng" },
    { 0x70D4, "radiosityscalehdr" },
    { 0x70D5, "radius_pos" },
    { 0x70D6, "radiusartilleryshellshock" },
    { 0x70D7, "radiussq" },
    { 0x70D8, "ragdoll_corpses" },
    { 0x70D9, "ragdoll_directionscale" },
    { 0x70DA, "ragdoll_fall_anim" },
    { 0x70DB, "ragdoll_getout_death" },
    { 0x70DC, "ragdoll_immediate" },
    { 0x70DD, "ragdoll_start_vel" },
    { 0x70DE, "ragdolldeath" },
    { 0x70DF, "ragdollonfirefx" },
    { 0x70E0, "ragdolltime" },
    { 0x70E1, "rail_gun_done" },
    { 0x70E2, "rail_gun_start" },
    { 0x70E3, "rail_gun_warbird_damage_function" },
    { 0x70E4, "railgun_ambient_air" },
    { 0x70E5, "railgun_cargo_ship_missiles" },
    { 0x70E6, "railgun_charge" },
    { 0x70E7, "railgun_damage_timer" },
    { 0x70E8, "railgun_enemies" },
    { 0x70E9, "railgun_hud_update" },
    { 0x70EA, "railgun_minigun_1" },
    { 0x70EB, "railgun_minigun_fire" },
    { 0x70EC, "railgun_missile_impact" },
    { 0x70ED, "railgun_ready" },
    { 0x70EE, "railgun_track_damage" },
    { 0x70EF, "railgun_track_damage_static" },
    { 0x70F0, "railgun_warbird_think" },
    { 0x70F1, "railing_dangerzone_think" },
    { 0x70F2, "rain" },
    { 0x70F3, "rain_attach_player_drizzle" },
    { 0x70F4, "rain_attach_player_heavy" },
    { 0x70F5, "rain_attach_player_heavy_speedy" },
    { 0x70F6, "rain_attach_player_medium" },
    { 0x70F7, "rain_elevator_fx" },
    { 0x70F8, "raineffectchange" },
    { 0x70F9, "rainhard" },
    { 0x70FA, "raininit" },
    { 0x70FB, "rainlevel" },
    { 0x70FC, "rainlevelrandomwait" },
    { 0x70FD, "rainlevelwait" },
    { 0x70FE, "rainlight" },
    { 0x70FF, "rainmedium" },
    { 0x7100, "rainnone" },
    { 0x7101, "raise_blast_doors" },
    { 0x7102, "raise_shield" },
    { 0x7103, "rake_with_bullets" },
    { 0x7104, "rambo" },
    { 0x7105, "ramboaccuracymult" },
    { 0x7106, "ramboaim" },
    { 0x7107, "ramboaiminternal" },
    { 0x7108, "ramboanims" },
    { 0x7109, "rambochance" },
    { 0x710A, "ramp_down_motion_blur" },
    { 0x710B, "ramp_up_motion_blur" },
    { 0x710C, "rand_pos_or_neg" },
    { 0x710D, "rand_second_accel_thresh" },
    { 0x710E, "random" },
    { 0x710F, "random_bloody_death" },
    { 0x7110, "random_damage" },
    { 0x7111, "random_dog_barks" },
    { 0x7112, "random_drag_amount" },
    { 0x7113, "random_dynamic_attachment" },
    { 0x7114, "random_factor" },
    { 0x7115, "random_killer_update" },
    { 0x7116, "random_killspawner" },
    { 0x7117, "random_move_rate_blend" },
    { 0x7118, "random_spawn" },
    { 0x7119, "random_spread" },
    { 0x711A, "random_vector" },
    { 0x711B, "random_weight" },
    { 0x711C, "random_weight_sorted" },
    { 0x711D, "randomaditionaltime" },
    { 0x711E, "randomanimoftwo" },
    { 0x711F, "randomfasteranimspeed" },
    { 0x7120, "randomgrenaderange" },
    { 0x7121, "randomidleanimation" },
    { 0x7122, "randomidleanims" },
    { 0x7123, "randomintrange_limit" },
    { 0x7124, "randominttable" },
    { 0x7125, "randominttablesize" },
    { 0x7126, "randomize_flock_positions" },
    { 0x7127, "randomize_name_list" },
    { 0x7128, "randomize_turret_spread" },
    { 0x7129, "randomizeidleset" },
    { 0x712A, "randomoccurrance" },
    { 0x712B, "randompathstoptime" },
    { 0x712C, "randomspawnscore" },
    { 0x712D, "randomvector" },
    { 0x712E, "randomvectorincone" },
    { 0x712F, "randomvectorrange" },
    { 0x7130, "randomzonespawn" },
    { 0x7131, "range" },
    { 0x7132, "range_name" },
    { 0x7133, "range_slop" },
    { 0x7134, "rangeinmeters" },
    { 0x7135, "ranges" },
    { 0x7136, "rank_for_items" },
    { 0x7137, "rankedmatch" },
    { 0x7138, "rankedmatchupdates" },
    { 0x7139, "rankingenabled" },
    { 0x713A, "ranktable" },
    { 0x713B, "rankupsplashnotify" },
    { 0x713C, "rankxp" },
    { 0x713D, "rappel_animation_rumbles" },
    { 0x713E, "rappel_control_hint" },
    { 0x713F, "rappel_kill_achievement" },
    { 0x7140, "rappel_rumbles" },
    { 0x7141, "rappel_vo_callouts" },
    { 0x7142, "rappeller" },
    { 0x7143, "rateofchange" },
    { 0x7144, "raven_player_can_see_ai" },
    { 0x7145, "raw_weight" },
    { 0x7146, "razor_cormack_hand_on_crate" },
    { 0x7147, "razor_cormack_reaches_crate" },
    { 0x7148, "razor_cormack_stowing_gun" },
    { 0x7149, "razor_crate_move" },
    { 0x714A, "razor_player_hand_off_crate" },
    { 0x714B, "razor_player_hand_on_crate" },
    { 0x714C, "razor_rb_hatch_close" },
    { 0x714D, "razor_rb_lifting_off" },
    { 0x714E, "razor_rb_missile_hit" },
    { 0x714F, "razor_rb_missile_launch" },
    { 0x7150, "razor_surface_override_function" },
    { 0x7151, "razorback" },
    { 0x7152, "razorback_cargo" },
    { 0x7153, "razorback_cargo_player" },
    { 0x7154, "razorback_cormack" },
    { 0x7155, "razorback_dialogue" },
    { 0x7156, "razorback_explosion" },
    { 0x7157, "razorback_fire_start" },
    { 0x7158, "razorback_fire_stop" },
    { 0x7159, "razorback_fly_in" },
    { 0x715A, "razorback_gun_enable" },
    { 0x715B, "razorback_ilana" },
    { 0x715C, "razorback_land" },
    { 0x715D, "razorback_lighting" },
    { 0x715E, "razorback_mech" },
    { 0x715F, "razorback_mech_behavior" },
    { 0x7160, "razorback_mech_missiles" },
    { 0x7161, "razorback_mech_shoot" },
    { 0x7162, "razorback_org" },
    { 0x7163, "razorback_razorback" },
    { 0x7164, "razorback_rumble" },
    { 0x7165, "razorback_spotlight" },
    { 0x7166, "razorback_spotlight_init" },
    { 0x7167, "razorback_trigger_handler" },
    { 0x7168, "rb_blast_marks" },
    { 0x7169, "rb_flee_goal_pick" },
    { 0x716A, "re_enable_combat" },
    { 0x716B, "re_target" },
    { 0x716C, "reach_aborted" },
    { 0x716D, "reach_death_notify" },
    { 0x716E, "reach_goal_pos" },
    { 0x716F, "reach_with_arrivals_begin" },
    { 0x7170, "reach_with_planting" },
    { 0x7171, "reach_with_planting_and_arrivals" },
    { 0x7172, "reach_with_standard_adjustments_begin" },
    { 0x7173, "reach_with_standard_adjustments_end" },
    { 0x7174, "reached_node" },
    { 0x7175, "reachers" },
    { 0x7176, "reachidle" },
    { 0x7177, "reacquire_state" },
    { 0x7178, "reacquire_without_facing" },
    { 0x7179, "reacquirewhennecessary" },
    { 0x717A, "react_anim" },
    { 0x717B, "reactingtobullet" },
    { 0x717C, "reaction" },
    { 0x717D, "reaction_ai" },
    { 0x717E, "reaction_explosions" },
    { 0x717F, "reaction_pickup_event" },
    { 0x7180, "reaction_pickup_player_proximity" },
    { 0x7181, "reaction_pickup_queue_explosion" },
    { 0x7182, "reaction_proc" },
    { 0x7183, "reaction_sleep" },
    { 0x7184, "reaction_sleep_wait_wakeup" },
    { 0x7185, "reaction_sleep_wait_wakeup_dist" },
    { 0x7186, "reaction_wait" },
    { 0x7187, "reactionanim" },
    { 0x7188, "reactioncasualty" },
    { 0x7189, "reactionfriendlyfire" },
    { 0x718A, "reactionscheckloop" },
    { 0x718B, "reactiontakingfire" },
    { 0x718C, "reactiontaunt" },
    { 0x718D, "reactive_fx_ents" },
    { 0x718E, "reactive_fx_thread" },
    { 0x718F, "reactive_sound_ents" },
    { 0x7190, "reactive_thread" },
    { 0x7191, "reactor_alarm" },
    { 0x7192, "reactor_bot_drive_self_start" },
    { 0x7193, "reactor_bot_drive_self_stop" },
    { 0x7194, "reactor_bot_drive_shelf_start" },
    { 0x7195, "reactor_bot_drive_shelf_stop" },
    { 0x7196, "reactor_bot_elevator_open" },
    { 0x7197, "reactor_bot_elevator_start_lp" },
    { 0x7198, "reactor_bot_elevator_stop_lp" },
    { 0x7199, "reactor_bot_final_elevator_start" },
    { 0x719A, "reactor_bot_final_elevator_stop" },
    { 0x719B, "reactor_bot_initial_elevator_start" },
    { 0x719C, "reactor_bot_initial_elevator_stop" },
    { 0x719D, "reactor_bot_shelf_drop" },
    { 0x719E, "reactor_bot_shelf_pickup" },
    { 0x719F, "reactor_bot_turn_self" },
    { 0x71A0, "reactor_bot_turn_shelf" },
    { 0x71A1, "reactor_catwalk_spawner_trigger_think" },
    { 0x71A2, "reactor_entrance_rally" },
    { 0x71A3, "reactor_entrance_rally_anim" },
    { 0x71A4, "reactor_light_rays" },
    { 0x71A5, "reactor_reveal_lighting" },
    { 0x71A6, "reactor_robots_badplace_think" },
    { 0x71A7, "reactor_robots_shelf_think" },
    { 0x71A8, "reactor_room" },
    { 0x71A9, "reactor_room_allies_run_from_crate" },
    { 0x71AA, "reactor_room_catwalk_combat" },
    { 0x71AB, "reactor_room_catwalk_death" },
    { 0x71AC, "reactor_room_combat" },
    { 0x71AD, "reactor_room_combat_mid_checkpoint" },
    { 0x71AE, "reactor_room_combat_seek_player" },
    { 0x71AF, "reactor_room_crane" },
    { 0x71B0, "reactor_room_crane_adjust_housing" },
    { 0x71B1, "reactor_room_crane_grab_crate" },
    { 0x71B2, "reactor_room_crane_light" },
    { 0x71B3, "reactor_room_crane_murderplayer_think" },
    { 0x71B4, "reactor_room_crane_rotate_to_angle" },
    { 0x71B5, "reactor_room_crane_think" },
    { 0x71B6, "reactor_room_crate_think" },
    { 0x71B7, "reactor_room_crate_tracking" },
    { 0x71B8, "reactor_room_drone_cleanup" },
    { 0x71B9, "reactor_room_drones" },
    { 0x71BA, "reactor_room_get_best_crate" },
    { 0x71BB, "reactor_room_link_cables" },
    { 0x71BC, "reactor_room_microwave_grenade_equip" },
    { 0x71BD, "reactor_room_redshirt_cleanup" },
    { 0x71BE, "reactor_room_redshirts" },
    { 0x71BF, "reactor_room_reveal_ally_vo_close_check" },
    { 0x71C0, "reactor_room_reveal_door" },
    { 0x71C1, "reactor_room_reveal_enemies_think" },
    { 0x71C2, "reactor_room_reveal_scene" },
    { 0x71C3, "reactor_room_reveal_scene_ally_think" },
    { 0x71C4, "reactor_room_reveal_scene_approach" },
    { 0x71C5, "reactor_room_reveal_scene_guys_ready" },
    { 0x71C6, "reactor_room_reveal_squibs" },
    { 0x71C7, "reactor_room_robot_emp_death" },
    { 0x71C8, "reactor_room_robot_grid_ally_safeguard" },
    { 0x71C9, "reactor_room_robot_monitor_death" },
    { 0x71CA, "reactor_room_robot_scripted_think" },
    { 0x71CB, "reactor_room_robot_think" },
    { 0x71CC, "reactor_room_robots" },
    { 0x71CD, "reactor_room_robots_lift_adjust_bars" },
    { 0x71CE, "reactor_room_sonic_hint_use_check" },
    { 0x71CF, "reactto" },
    { 0x71D0, "reacttobulletchance" },
    { 0x71D1, "reacttobulletsinterruptcheck" },
    { 0x71D2, "readncolumns" },
    { 0x71D3, "readtriple" },
    { 0x71D4, "ready" },
    { 0x71D5, "ready_for_reveal" },
    { 0x71D6, "ready_knuckles_delete" },
    { 0x71D7, "ready_room_assault_rifle" },
    { 0x71D8, "ready_room_elevator_right" },
    { 0x71D9, "ready_room_gideon" },
    { 0x71DA, "ready_room_player" },
    { 0x71DB, "ready_room_sniper_rifle" },
    { 0x71DC, "ready_room_things" },
    { 0x71DD, "readyanimarray" },
    { 0x71DE, "readyanimweights" },
    { 0x71DF, "readyforatriumbreach" },
    { 0x71E0, "readyplayer" },
    { 0x71E1, "readystand_anims_inited" },
    { 0x71E2, "readytobemanhandled" },
    { 0x71E3, "readytobreach" },
    { 0x71E4, "readytodie" },
    { 0x71E5, "readytomanhandle" },
    { 0x71E6, "readytomeleetarget" },
    { 0x71E7, "readytoreturntocover" },
    { 0x71E8, "real_target" },
    { 0x71E9, "realorigin" },
    { 0x71EA, "realtext" },
    { 0x71EB, "rear_dist" },
    { 0x71EC, "reassign_ctf_team_spawns" },
    { 0x71ED, "rebuild_friendly_icon" },
    { 0x71EE, "rec_bathroom_guy" },
    { 0x71EF, "rec_chair_kva_gets_shot" },
    { 0x71F0, "rec_drive_lookat_trigger_think" },
    { 0x71F1, "rec_drone_scanner" },
    { 0x71F2, "rec_exo_arm_repair_attempt_01_npc" },
    { 0x71F3, "rec_exo_arm_repair_attempt_02_npc" },
    { 0x71F4, "rec_exo_arm_repair_attempt_03_npc" },
    { 0x71F5, "rec_exo_arm_repair_attempt_exit_npc" },
    { 0x71F6, "rec_funeral_21_gun_salute" },
    { 0x71F7, "rec_funeral_part_1_cormack" },
    { 0x71F8, "rec_funeral_part_2_cormack" },
    { 0x71F9, "rec_funeral_part_2_irons" },
    { 0x71FA, "rec_guy_doubledoor_breach_start" },
    { 0x71FB, "rec_jeep_adr_gdn" },
    { 0x71FC, "rec_jeep_ride_pt1" },
    { 0x71FD, "rec_jeep_ride_pt2" },
    { 0x71FE, "rec_jeep_ride_pt3" },
    { 0x71FF, "rec_kva_with_president_gets_shot" },
    { 0x7200, "rec_littlebird_formation_spawn" },
    { 0x7201, "rec_mute_breach_slo_mo1" },
    { 0x7202, "rec_mute01_chair_kva_killed" },
    { 0x7203, "rec_mute01_joker_breach" },
    { 0x7204, "rec_mute01_joker_kick" },
    { 0x7205, "rec_mute01_joker_run" },
    { 0x7206, "rec_mute01_joker_start" },
    { 0x7207, "rec_mute01_joker_turn" },
    { 0x7208, "rec_mute01_kva_hits_wall" },
    { 0x7209, "rec_mute01_kva_kicked" },
    { 0x720A, "rec_mute01_kva_with_gun_killed" },
    { 0x720B, "rec_mute01_potus_free" },
    { 0x720C, "rec_player_drone_end" },
    { 0x720D, "rec_player_drone_start" },
    { 0x720E, "rec_player_exo_breach_start" },
    { 0x720F, "rec_plr_kills_president" },
    { 0x7210, "rec_readyroom_elevator_left_close" },
    { 0x7211, "rec_readyroom_elevator_left_hatch_back" },
    { 0x7212, "rec_readyroom_elevator_left_hatch_front" },
    { 0x7213, "rec_readyroom_elevator_left_open" },
    { 0x7214, "rec_readyroom_elevator_left_open2" },
    { 0x7215, "rec_readyroom_elevator_left_up" },
    { 0x7216, "rec_readyroom_elevator_right_close" },
    { 0x7217, "rec_readyroom_elevator_right_open" },
    { 0x7218, "rec_readyroom_elevator_right_open2" },
    { 0x7219, "rec_readyroom_elevator_right_up" },
    { 0x721A, "rec_readyroom_gideon_pushes_button" },
    { 0x721B, "rec_s1_drones_attack" },
    { 0x721C, "rec_s1_drones_fly_by" },
    { 0x721D, "rec_s1_drones_wait_for_attack" },
    { 0x721E, "rec_s1_president_killed" },
    { 0x721F, "rec_s2_breach_gun_holster" },
    { 0x7220, "rec_s2_breach_slo_mo" },
    { 0x7221, "rec_s2_door_guy_ambush" },
    { 0x7222, "rec_s2_drones_attack" },
    { 0x7223, "rec_s2_exfil_car_plr_hand" },
    { 0x7224, "rec_s2_exfil_car_plr_help_potus" },
    { 0x7225, "rec_s2_exfil_car_plr_start" },
    { 0x7226, "rec_s2_exfil_potus_enter_car" },
    { 0x7227, "rec_s2_exfil_potus_start" },
    { 0x7228, "rec_sim_reveal_gideon" },
    { 0x7229, "rec_sim_reveal_irons" },
    { 0x722A, "rec_sim_start_joker" },
    { 0x722B, "rec_slomo_audio_handler" },
    { 0x722C, "rec_slomo_kill_bad_guy" },
    { 0x722D, "rec_star_trek_door_close" },
    { 0x722E, "rec_star_trek_door_open" },
    { 0x722F, "rec_t2_warbird_decloak" },
    { 0x7230, "rec_t2_warbird_door_open" },
    { 0x7231, "rec_t2_warbird_land" },
    { 0x7232, "rec_t2_warbird_start" },
    { 0x7233, "rec_threat01_joker_kick" },
    { 0x7234, "rec_threat01_joker_start" },
    { 0x7235, "rec_tour_end_jeep_gate_plr_close" },
    { 0x7236, "rec_tour_end_jeep_gate_plr_open" },
    { 0x7237, "rec_tour_escort_jeep_start" },
    { 0x7238, "rec_tour_hangar_background" },
    { 0x7239, "rec_tour_npc_jeep_exit_gate_close" },
    { 0x723A, "rec_tour_npc_jeep_exit_gate_open" },
    { 0x723B, "rec_tour_ride_driver_gear_shift" },
    { 0x723C, "rec_tour_ride_gid_exits_jeep" },
    { 0x723D, "rec_tour_ride_gid_hand_on_door" },
    { 0x723E, "rec_tour_ride_irons_gestures" },
    { 0x723F, "rec_tour_ride_irons_turns_to_plr" },
    { 0x7240, "rec_tour_ride_irons_waves" },
    { 0x7241, "rec_tour_ride_plr_door" },
    { 0x7242, "rec_tour_ride_plr_exits_jeep" },
    { 0x7243, "rec_tour_ride_veh_leftdoor_close" },
    { 0x7244, "rec_tour_ride_veh_leftdoor_open" },
    { 0x7245, "rec_tour_ride_veh_rightdoor_close" },
    { 0x7246, "rec_tour_ride_veh_rightdoor_open" },
    { 0x7247, "rec_tour_titan_1_start" },
    { 0x7248, "rec_tour_titan_2_walk_anim_start" },
    { 0x7249, "rec_tour_titan_gate_plr_open" },
    { 0x724A, "rec_tour_vehicle_1_start" },
    { 0x724B, "rec_tour_vtol_takeoff_spawn" },
    { 0x724C, "rec_train1_end" },
    { 0x724D, "rec_train1_exfil_car_start" },
    { 0x724E, "rec_train1_stealth_car_spawn" },
    { 0x724F, "rec_train1_stealth_car_stop" },
    { 0x7250, "rec_train2_ambush_car_1" },
    { 0x7251, "rec_train2_ambush_car_2" },
    { 0x7252, "rec_train2_exfil_car_end" },
    { 0x7253, "rec_train2_exfil_car_start" },
    { 0x7254, "rec_training01_lodge_stealth_exit_end" },
    { 0x7255, "rec_training01_lodge_stealth_exit_start" },
    { 0x7256, "rec_training01_lodge_stealth_open" },
    { 0x7257, "rec_training1_jeep_arrive" },
    { 0x7258, "rec_training1_jeep_enter" },
    { 0x7259, "rec_training1_jeep_irons_door_close" },
    { 0x725A, "rec_training1_jeep_irons_door_open" },
    { 0x725B, "rec_training1_jeep_player_door_close" },
    { 0x725C, "rec_welcometoatlas_gideon" },
    { 0x725D, "rec_welcometoatlas_irons" },
    { 0x725E, "recall" },
    { 0x725F, "recentdamageamount" },
    { 0x7260, "recentkillcount" },
    { 0x7261, "recently_loaded_listener" },
    { 0x7262, "recentlysawenemy" },
    { 0x7263, "rechamber" },
    { 0x7264, "recharge" },
    { 0x7265, "recipeclassapplyjuggernaut" },
    { 0x7266, "reclaimedreservedobjectives" },
    { 0x7267, "recoildirection" },
    { 0x7268, "recoilscale" },
    { 0x7269, "recon_allies" },
    { 0x726A, "recon_anim_struct" },
    { 0x726B, "recon_begin" },
    { 0x726C, "recon_checkpoint_lasttime" },
    { 0x726D, "recon_log_loadout" },
    { 0x726E, "recon_log_spawnpoint_info" },
    { 0x726F, "recon_main" },
    { 0x7270, "recon_objective_lasttime" },
    { 0x7271, "recon_player" },
    { 0x7272, "recon_player_downed" },
    { 0x7273, "recon_set_spawnpoint" },
    { 0x7274, "recon_start" },
    { 0x7275, "recon_vo" },
    { 0x7276, "reconhandledeath" },
    { 0x7277, "reconhandletimeout" },
    { 0x7278, "reconhandletimeoutwarning" },
    { 0x7279, "reconhudremove" },
    { 0x727A, "reconhudsetup" },
    { 0x727B, "reconlogplayerinfo" },
    { 0x727C, "reconnect_fake_pitbull" },
    { 0x727D, "reconplayerexit" },
    { 0x727E, "reconsetinactivity" },
    { 0x727F, "reconspawnturret" },
    { 0x7280, "reconuav_stinger_target_pos" },
    { 0x7281, "record_bread_crumbs_for_ambush" },
    { 0x7282, "record_enemy_notification" },
    { 0x7283, "record_enemy_sightings" },
    { 0x7284, "record_grenade_rising_edges" },
    { 0x7285, "record_grenade_throw_times" },
    { 0x7286, "record_last_player_damage" },
    { 0x7287, "record_sighting" },
    { 0x7288, "record_stealth_event" },
    { 0x7289, "recordfinalkillcam" },
    { 0x728A, "recordsegemtdata" },
    { 0x728B, "recordtogglescopestates" },
    { 0x728C, "recordvalidationinfraction" },
    { 0x728D, "recover" },
    { 0x728E, "recover_cargo" },
    { 0x728F, "recover_from_careful_disable" },
    { 0x7290, "recover_interval" },
    { 0x7291, "recovery_breach_cleanup_player" },
    { 0x7292, "recovery_breach_setup_player" },
    { 0x7293, "recovery_dynamic_event" },
    { 0x7294, "recovery_locations" },
    { 0x7295, "recovery_thermal_manager" },
    { 0x7296, "recoverycustomospfunc" },
    { 0x7297, "recoveryeventcustomospfunc" },
    { 0x7298, "recursed" },
    { 0x7299, "red" },
    { 0x729A, "red_burn_lighting_fog" },
    { 0x729B, "red_hoodoo_fx" },
    { 0x729C, "red_hoodoo1" },
    { 0x729D, "red_hoodoos" },
    { 0x729E, "red_light_strobe_courtyard" },
    { 0x729F, "red_point" },
    { 0x72A0, "redfill" },
    { 0x72A1, "redfill2" },
    { 0x72A2, "redo" },
    { 0x72A3, "redshirt_death_vo" },
    { 0x72A4, "reduce_damage_while_holding_cardoor" },
    { 0x72A5, "reduce_player_movement_videolog" },
    { 0x72A6, "reduced_nonplayer_damage" },
    { 0x72A7, "reducegiptponkillanimscript" },
    { 0x72A8, "reducetakecoverwarnings" },
    { 0x72A9, "reenable_grapple" },
    { 0x72AA, "ref" },
    { 0x72AB, "ref_col" },
    { 0x72AC, "reference" },
    { 0x72AD, "refill_starting_weapons" },
    { 0x72AE, "refillammo" },
    { 0x72AF, "refillammohorde" },
    { 0x72B0, "refillbattery" },
    { 0x72B1, "refillclip" },
    { 0x72B2, "refillsinglecountammo" },
    { 0x72B3, "reflection_pod_guys" },
    { 0x72B4, "reflection_pod_guys_landing" },
    { 0x72B5, "reflection_pod_guys2" },
    { 0x72B6, "reflectionprobebuttons" },
    { 0x72B7, "reflectionprobenmlluminance" },
    { 0x72B8, "refraction_turrets" },
    { 0x72B9, "refraction_turrets_alive" },
    { 0x72BA, "refraction_turrets_moved_down" },
    { 0x72BB, "refractioncustomkillstreakfunc" },
    { 0x72BC, "refractioncustomospfunc" },
    { 0x72BD, "refractionturrettimer" },
    { 0x72BE, "refractionvulcancustomfunc" },
    { 0x72BF, "refresh_core_snipers_enemies" },
    { 0x72C0, "refresh_existing_bots" },
    { 0x72C1, "refresh_reactive_fx_ents" },
    { 0x72C2, "refuel_timings" },
    { 0x72C3, "refuel_vo" },
    { 0x72C4, "refugee_butress_down" },
    { 0x72C5, "refugee_butress_down_time" },
    { 0x72C6, "refugee_camp_ai" },
    { 0x72C7, "refugee_camp_autopilot_engaged" },
    { 0x72C8, "refugee_camp_civ_convo_01" },
    { 0x72C9, "refugee_camp_cleanup" },
    { 0x72CA, "refugee_camp_dialogue" },
    { 0x72CB, "refugee_camp_intro_dialogue" },
    { 0x72CC, "refugee_camp_main" },
    { 0x72CD, "refugee_camp_security_checkpoint_dialogue" },
    { 0x72CE, "refugee_debug" },
    { 0x72CF, "refugee_walk" },
    { 0x72D0, "regen_cooldown" },
    { 0x72D1, "regen_front_armor" },
    { 0x72D2, "regenhealthmod" },
    { 0x72D3, "regenrate" },
    { 0x72D4, "regenspeed" },
    { 0x72D5, "register_ai_anims" },
    { 0x72D6, "register_archetype" },
    { 0x72D7, "register_boost_dodge" },
    { 0x72D8, "register_boost_jump" },
    { 0x72D9, "register_boost_slam" },
    { 0x72DA, "register_common_mp_snd_messages" },
    { 0x72DB, "register_common_snd_messages" },
    { 0x72DC, "register_death" },
    { 0x72DD, "register_difficulty" },
    { 0x72DE, "register_fx" },
    { 0x72DF, "register_kill" },
    { 0x72E0, "register_level_name" },
    { 0x72E1, "register_moving_collision_on_nodes" },
    { 0x72E2, "register_new_weapon" },
    { 0x72E3, "register_notetracks" },
    { 0x72E4, "register_player_anims" },
    { 0x72E5, "register_pluggable_move_loop_override" },
    { 0x72E6, "register_radio_squelches" },
    { 0x72E7, "register_shot_hit" },
    { 0x72E8, "register_snd_messages" },
    { 0x72E9, "register_sp_perks" },
    { 0x72EA, "register_target_lock_change_func" },
    { 0x72EB, "register_trigger_callbacks" },
    { 0x72EC, "register_vehicle_anims" },
    { 0x72ED, "registerarchetype" },
    { 0x72EE, "registerdvars" },
    { 0x72EF, "registerhalftimedvar" },
    { 0x72F0, "registeringshothit" },
    { 0x72F1, "registerlaststandparameter" },
    { 0x72F2, "registermissioncallback" },
    { 0x72F3, "registernotetracks" },
    { 0x72F4, "registernumlivesdvar" },
    { 0x72F5, "registernumteamsdvar" },
    { 0x72F6, "registerroundlimitdvar" },
    { 0x72F7, "registerroundswitchdvar" },
    { 0x72F8, "registerscorelimitdvar" },
    { 0x72F9, "registertimelimitdvar" },
    { 0x72FA, "registertweakable" },
    { 0x72FB, "registerwatchdvar" },
    { 0x72FC, "registerwatchdvarfloat" },
    { 0x72FD, "registerwatchdvarint" },
    { 0x72FE, "registerwinlimitdvar" },
    { 0x72FF, "registerxpeventinfo" },
    { 0x7300, "regular_exo_hover_vfx" },
    { 0x7301, "regular_plane_controls" },
    { 0x7302, "reincrement_count_if_deleted" },
    { 0x7303, "reinforce_on_death" },
    { 0x7304, "reinforcement_endtime" },
    { 0x7305, "reinforcementcratekillstreakthink" },
    { 0x7306, "reinforcementcratespecialtythink" },
    { 0x7307, "reinitializematchrulesonmigration" },
    { 0x7308, "reinitializescorelimitonmigration" },
    { 0x7309, "reinitializethermal" },
    { 0x730A, "relativepoint" },
    { 0x730B, "release_hint_off" },
    { 0x730C, "release_player_view_to_rig_anim" },
    { 0x730D, "release_x_breakout" },
    { 0x730E, "releasegas" },
    { 0x730F, "releasemeetingcivilians" },
    { 0x7310, "releasestring" },
    { 0x7311, "reload_ammo" },
    { 0x7312, "reload_checker_hack" },
    { 0x7313, "reload_disable_safe" },
    { 0x7314, "reload_enable" },
    { 0x7315, "reload_launchers" },
    { 0x7316, "reload_malfunction_disable_on_grenade_throw" },
    { 0x7317, "reloading" },
    { 0x7318, "reloading_big_orbitalsupport_gun" },
    { 0x7319, "reloading_buddy_medium_orbitalsupport_gun" },
    { 0x731A, "reloading_medium_orbitalsupport_gun" },
    { 0x731B, "reloading_rocket_orbitalsupport_gun" },
    { 0x731C, "reloadrocket" },
    { 0x731D, "reloadrocketswarm" },
    { 0x731E, "reloadtracking" },
    { 0x731F, "remainingrocketshots" },
    { 0x7320, "reminder_boost_jump_drone_street" },
    { 0x7321, "remote_missile_height_override" },
    { 0x7322, "remote_vehicle_setup" },
    { 0x7323, "remotecontrolled" },
    { 0x7324, "remoteent" },
    { 0x7325, "remotemissile_actionslot" },
    { 0x7326, "remotemissile_fx" },
    { 0x7327, "remotemissileenttracetooriginpassedwrapper" },
    { 0x7328, "remotemissileinprogress" },
    { 0x7329, "remoteridetransition" },
    { 0x732A, "remoteturretlist" },
    { 0x732B, "remove_ai_from_colors" },
    { 0x732C, "remove_all_actors_that_are_squelched" },
    { 0x732D, "remove_all_actors_with_same_characterid" },
    { 0x732E, "remove_all_intel" },
    { 0x732F, "remove_and_insert_at_traffic_tail" },
    { 0x7330, "remove_and_insert_before_leader" },
    { 0x7331, "remove_and_insert_behind_leader" },
    { 0x7332, "remove_avatar" },
    { 0x7333, "remove_bad_locked_targets" },
    { 0x7334, "remove_boost_jump" },
    { 0x7335, "remove_camera_view_angles" },
    { 0x7336, "remove_cardoor_from_npc" },
    { 0x7337, "remove_cheap_flashlight" },
    { 0x7338, "remove_cockpit_from_view" },
    { 0x7339, "remove_color_from_array" },
    { 0x733A, "remove_corpse_loop_while_stealth_broken" },
    { 0x733B, "remove_crawled" },
    { 0x733C, "remove_damage_function" },
    { 0x733D, "remove_damagefeedback" },
    { 0x733E, "remove_dead_bodies_from_cone" },
    { 0x733F, "remove_dead_from_array" },
    { 0x7340, "remove_deathfx_entity_delay" },
    { 0x7341, "remove_display_name" },
    { 0x7342, "remove_diveboat_weapons" },
    { 0x7343, "remove_drone_mode" },
    { 0x7344, "remove_drone_turret_drones" },
    { 0x7345, "remove_dropped_guns_near_explosives" },
    { 0x7346, "remove_dupes" },
    { 0x7347, "remove_ends_from_path" },
    { 0x7348, "remove_exo_temperature_hud" },
    { 0x7349, "remove_extra_autosave_check" },
    { 0x734A, "remove_fighter_jet_hud" },
    { 0x734B, "remove_flashlight_on_goal" },
    { 0x734C, "remove_flashlight_upon_combat" },
    { 0x734D, "remove_friendly_fire_damage_modifier" },
    { 0x734E, "remove_from_animloop" },
    { 0x734F, "remove_from_array_when_dead" },
    { 0x7350, "remove_from_arrays" },
    { 0x7351, "remove_from_bot_damage_targets" },
    { 0x7352, "remove_from_bot_use_targets" },
    { 0x7353, "remove_from_flock" },
    { 0x7354, "remove_from_idle_array_on_death" },
    { 0x7355, "remove_from_tactics_array_on_delete" },
    { 0x7356, "remove_from_tactics_array_on_pickup" },
    { 0x7357, "remove_from_target_array_on_death" },
    { 0x7358, "remove_from_targets_on_death" },
    { 0x7359, "remove_from_traffic_lane" },
    { 0x735A, "remove_fxlighting_object" },
    { 0x735B, "remove_global_spawn_function" },
    { 0x735C, "remove_grapple" },
    { 0x735D, "remove_h_breach_hostages" },
    { 0x735E, "remove_heroes_from_array" },
    { 0x735F, "remove_hint" },
    { 0x7360, "remove_hovertank_weapons" },
    { 0x7361, "remove_hud" },
    { 0x7362, "remove_hud_drone_target" },
    { 0x7363, "remove_hud_outline_binocs" },
    { 0x7364, "remove_intact_bridge" },
    { 0x7365, "remove_intel_item" },
    { 0x7366, "remove_invalid_locks" },
    { 0x7367, "remove_level_first_frame" },
    { 0x7368, "remove_light_from_face" },
    { 0x7369, "remove_lock_target" },
    { 0x736A, "remove_magic_bullet_shield_from_guy_on_unload_or_death" },
    { 0x736B, "remove_monitored_tags" },
    { 0x736C, "remove_moving_obstacle" },
    { 0x736D, "remove_moving_obstacle_on_death" },
    { 0x736E, "remove_name" },
    { 0x736F, "remove_nocolor_from_array" },
    { 0x7370, "remove_nodes_with_users_from_array" },
    { 0x7371, "remove_non_riders_from_array" },
    { 0x7372, "remove_noteworthy_from_array" },
    { 0x7373, "remove_object_from_tactics_system" },
    { 0x7374, "remove_on_spawner_delete" },
    { 0x7375, "remove_option" },
    { 0x7376, "remove_outline_on_death" },
    { 0x7377, "remove_passenger_from_player_pitbull" },
    { 0x7378, "remove_patrol_anim_set" },
    { 0x7379, "remove_pre_penthouse_trees" },
    { 0x737A, "remove_reflection_objects" },
    { 0x737B, "remove_replace_on_death" },
    { 0x737C, "remove_script_car" },
    { 0x737D, "remove_script_friendnames_from_list" },
    { 0x737E, "remove_selected_option" },
    { 0x737F, "remove_slowmo_breacher" },
    { 0x7380, "remove_spawn_function" },
    { 0x7381, "remove_sticky" },
    { 0x7382, "remove_sticky_on_explosion" },
    { 0x7383, "remove_sticky_on_respawn" },
    { 0x7384, "remove_target" },
    { 0x7385, "remove_target_on_timeout" },
    { 0x7386, "remove_tracking_on_disconnect" },
    { 0x7387, "remove_turret_on_mount" },
    { 0x7388, "remove_unarmed_when_pickup_new_wep" },
    { 0x7389, "remove_user_from_drone" },
    { 0x738A, "remove_user_from_dronecrate" },
    { 0x738B, "remove_vehicle_from_tactics_array_on_death" },
    { 0x738C, "remove_vehicle_spawned_thisframe" },
    { 0x738D, "remove_vol_index" },
    { 0x738E, "remove_when_out_of_range" },
    { 0x738F, "remove_without_classname" },
    { 0x7390, "remove_without_model" },
    { 0x7391, "remove_zipline_on_death" },
    { 0x7392, "removeactivecounteruav" },
    { 0x7393, "removeactivespawner" },
    { 0x7394, "removeactiveuav" },
    { 0x7395, "removeallfromlivescount" },
    { 0x7396, "removebombcarrierclass" },
    { 0x7397, "removebombzone" },
    { 0x7398, "removeburiedlightgrid" },
    { 0x7399, "removechild" },
    { 0x739A, "removecoopturretbuddy" },
    { 0x739B, "removecoopturretbuddyondisconnect" },
    { 0x739C, "removed" },
    { 0x739D, "removedestroyedchildren" },
    { 0x739E, "removedisconnectedplayerfromplacement" },
    { 0x739F, "removedronevisionandlightsetpermap" },
    { 0x73A0, "removeemp" },
    { 0x73A1, "removeentityheadicon" },
    { 0x73A2, "removeexplosivedrone" },
    { 0x73A3, "removeflagcarrierclass" },
    { 0x73A4, "removefromalivecount" },
    { 0x73A5, "removefrombattlebuddywaitlist" },
    { 0x73A6, "removefromcarepackagedronelistondeath" },
    { 0x73A7, "removefromcharactersarray" },
    { 0x73A8, "removefromexplosivedronelistondeath" },
    { 0x73A9, "removefromhelilist" },
    { 0x73AA, "removefromlittlebirdlistondeath" },
    { 0x73AB, "removefromlivescount" },
    { 0x73AC, "removefromparticipantsarray" },
    { 0x73AD, "removefromsquad" },
    { 0x73AE, "removefromsystem" },
    { 0x73AF, "removefromteamcount" },
    { 0x73B0, "removefromtotalspawned" },
    { 0x73B1, "removefromtrackingdronelistondeath" },
    { 0x73B2, "removefromturretlist" },
    { 0x73B3, "removefxentwithentity" },
    { 0x73B4, "removegroupedtridrone" },
    { 0x73B5, "removeharmonicbreachhostages" },
    { 0x73B6, "removekillcamentity" },
    { 0x73B7, "removekillstreakicons" },
    { 0x73B8, "removelastelement" },
    { 0x73B9, "removelightarmorondeath" },
    { 0x73BA, "removelightarmoronmatchend" },
    { 0x73BB, "removelowermessage" },
    { 0x73BC, "removenotetrack" },
    { 0x73BD, "removeofficerfromsquad" },
    { 0x73BE, "removeonnextairdrop" },
    { 0x73BF, "removeorbitalsupportbuddy" },
    { 0x73C0, "removeorbitalsupportbuddyonchangeteams" },
    { 0x73C1, "removeorbitalsupportbuddyoncommand" },
    { 0x73C2, "removeorbitalsupportbuddyondisconnect" },
    { 0x73C3, "removeorbitalsupportbuddyonspectate" },
    { 0x73C4, "removeorbitalsupportplayer" },
    { 0x73C5, "removeorbitalsupportplayeraftertime" },
    { 0x73C6, "removeorbitalsupportplayeronchangeteams" },
    { 0x73C7, "removeorbitalsupportplayeroncommand" },
    { 0x73C8, "removeorbitalsupportplayeroncrash" },
    { 0x73C9, "removeorbitalsupportplayerondisconnect" },
    { 0x73CA, "removeorbitalsupportplayerongamecleanup" },
    { 0x73CB, "removeorbitalsupportplayeronspectate" },
    { 0x73CC, "removeospvisionandlightsetpermap" },
    { 0x73CD, "removeoverlaydeath" },
    { 0x73CE, "removeperkhud" },
    { 0x73CF, "removeperks" },
    { 0x73D0, "removepickup" },
    { 0x73D1, "removeplanefromlist" },
    { 0x73D2, "removeplayerondisconnect" },
    { 0x73D3, "removeplayertarget" },
    { 0x73D4, "removepod" },
    { 0x73D5, "removerack" },
    { 0x73D6, "removerevnmeshes" },
    { 0x73D7, "removesafetyhealth" },
    { 0x73D8, "removeselffrom_squadlastseenenemypos" },
    { 0x73D9, "removesolarreflectorlevelwatch" },
    { 0x73DA, "removesolarreflectorplayer" },
    { 0x73DB, "removesolarreflectorplayeraftertime" },
    { 0x73DC, "removesolarreflectorplayeroncommand" },
    { 0x73DD, "removesolarreflectorplayerwatch" },
    { 0x73DE, "removespawnmessageshortly" },
    { 0x73DF, "removespeaker" },
    { 0x73E0, "removestreaksupportprompt" },
    { 0x73E1, "removethreatevents" },
    { 0x73E2, "removethreaticon" },
    { 0x73E3, "removetrackingdrone" },
    { 0x73E4, "removetransitionmeshes" },
    { 0x73E5, "removetruckguardoutline" },
    { 0x73E6, "removeuavmodel" },
    { 0x73E7, "removeundefined" },
    { 0x73E8, "removevulcanvisionandlightsetpermap" },
    { 0x73E9, "removewarbirdbuddy" },
    { 0x73EA, "removewarbirdbuddyoncommand" },
    { 0x73EB, "removewarbirdvisionsetpermap" },
    { 0x73EC, "removeweapons" },
    { 0x73ED, "rempveoverlaydeath" },
    { 0x73EE, "render_alerted_info" },
    { 0x73EF, "render_detect_ranges" },
    { 0x73F0, "render_detect_ranges_for_entity" },
    { 0x73F1, "render_ranges_for_a_corpse" },
    { 0x73F2, "render_ranges_for_the_corpses" },
    { 0x73F3, "render_vision_cone" },
    { 0x73F4, "render_vision_cone_for_entity" },
    { 0x73F5, "repair_desk_align_needle" },
    { 0x73F6, "repair_desk_grab_needle" },
    { 0x73F7, "repair_desk_harness_close" },
    { 0x73F8, "repair_desk_harness_release" },
    { 0x73F9, "repair_desk_push_needle" },
    { 0x73FA, "repair_desk_remove_needle" },
    { 0x73FB, "repair_guy_01" },
    { 0x73FC, "repair_guy_02" },
    { 0x73FD, "repair_weights" },
    { 0x73FE, "repeat_hint_until_comply" },
    { 0x73FF, "repeat_hint_until_comply_oldstyle" },
    { 0x7400, "repeatoneshotprisonalarm" },
    { 0x7401, "repel_player_missile" },
    { 0x7402, "replace_on_death" },
    { 0x7403, "replenishloadout" },
    { 0x7404, "report_trigger" },
    { 0x7405, "reportalias" },
    { 0x7406, "repulsor_fx" },
    { 0x7407, "repulsoractive" },
    { 0x7408, "repulsornumber" },
    { 0x7409, "requestreacttobullet" },
    { 0x740A, "required_aiming_time_s" },
    { 0x740B, "requiredexitstance" },
    { 0x740C, "requiredmapaspectratio" },
    { 0x740D, "requireonground" },
    { 0x740E, "requires_player_los" },
    { 0x740F, "requireslos" },
    { 0x7410, "rescue_guard_fire" },
    { 0x7411, "rescuedplayers" },
    { 0x7412, "resdhirt1" },
    { 0x7413, "research_building_combat_complete" },
    { 0x7414, "research_building_enemy_think" },
    { 0x7415, "research_facility_bridge_logic" },
    { 0x7416, "research_facility_combat_dialogue" },
    { 0x7417, "research_facility_interior_dialogue" },
    { 0x7418, "research_left_01_enemy_think" },
    { 0x7419, "research_left_lower_01_enemy_think" },
    { 0x741A, "research_platform_enemy_think" },
    { 0x741B, "research_right_01_enemy_think" },
    { 0x741C, "research_right_lower_01_enemy_think" },
    { 0x741D, "reselect_entitites" },
    { 0x741E, "reserve_turret" },
    { 0x741F, "reset_accuracy" },
    { 0x7420, "reset_ai_from_drone" },
    { 0x7421, "reset_angles" },
    { 0x7422, "reset_animname" },
    { 0x7423, "reset_axis_of_selected_ents" },
    { 0x7424, "reset_bot_settings_for_a_few_frames" },
    { 0x7425, "reset_button_buffers" },
    { 0x7426, "reset_cmds" },
    { 0x7427, "reset_copier" },
    { 0x7428, "reset_damage_info_when_healed" },
    { 0x7429, "reset_dds_categories" },
    { 0x742A, "reset_event_type" },
    { 0x742B, "reset_forced_target_if_no_line_of_sight" },
    { 0x742C, "reset_friendly_fire_when_player_lands" },
    { 0x742D, "reset_fx_hud_colors" },
    { 0x742E, "reset_goalvolume" },
    { 0x742F, "reset_group_advance_to_enemy_timer" },
    { 0x7430, "reset_health" },
    { 0x7431, "reset_highway_path_player_side" },
    { 0x7432, "reset_maxsightdistsqrd" },
    { 0x7433, "reset_origin" },
    { 0x7434, "reset_player_health" },
    { 0x7435, "reset_player_stats_on_exit" },
    { 0x7436, "reset_shot_on_reload" },
    { 0x7437, "reset_thread_sent" },
    { 0x7438, "reset_threatbias" },
    { 0x7439, "reset_threatbiasgroup" },
    { 0x743A, "reset_time" },
    { 0x743B, "reset_turret" },
    { 0x743C, "reset_unresolved_collision_handler" },
    { 0x743D, "reset_visionset_on_disconnect" },
    { 0x743E, "reset_visionset_on_spawn" },
    { 0x743F, "reset_visionset_on_team_change" },
    { 0x7440, "reset_walkdist" },
    { 0x7441, "reset_zone_owners" },
    { 0x7442, "resetaccuracyandpause" },
    { 0x7443, "resetadrenaline" },
    { 0x7444, "resetanimmode" },
    { 0x7445, "resetattackerlist" },
    { 0x7446, "resetbrinkofdeathkillstreakshortly" },
    { 0x7447, "resetc4explodethisframe" },
    { 0x7448, "resetcliponabort" },
    { 0x7449, "resetfastheal" },
    { 0x744A, "resetgates" },
    { 0x744B, "resetgiveuponenemytime" },
    { 0x744C, "resetgoalradius" },
    { 0x744D, "resetinterval" },
    { 0x744E, "resetlookforbettercovertime" },
    { 0x744F, "resetmissdebouncetime" },
    { 0x7450, "resetmisstime" },
    { 0x7451, "resetnextsaytimes" },
    { 0x7452, "resetnotify" },
    { 0x7453, "resetoncancel" },
    { 0x7454, "resetondeath" },
    { 0x7455, "resetplayeronteamchange" },
    { 0x7456, "resetplayervariables" },
    { 0x7457, "resetreinforcements" },
    { 0x7458, "resetrespondtodeathtime" },
    { 0x7459, "resetrotategateconstant" },
    { 0x745A, "resetrotategates" },
    { 0x745B, "resetseekoutenemytime" },
    { 0x745C, "resetskill" },
    { 0x745D, "resetsniperaim" },
    { 0x745E, "resetstate" },
    { 0x745F, "resetstingerlocking" },
    { 0x7460, "resetstingerlockingondeath" },
    { 0x7461, "resettags" },
    { 0x7462, "resetuidvarsonconnect" },
    { 0x7463, "resetuidvarsondeath" },
    { 0x7464, "resetuidvarsonspawn" },
    { 0x7465, "resetuidvarsonspectate" },
    { 0x7466, "resetusability" },
    { 0x7467, "resetvirtuallobbypresentable" },
    { 0x7468, "resetvulnerabletimers" },
    { 0x7469, "resetweapon" },
    { 0x746A, "reso_bridge_distantce_dot" },
    { 0x746B, "resolvebraggingrights" },
    { 0x746C, "resonance_light" },
    { 0x746D, "respawn_asspectator" },
    { 0x746E, "respawn_death_spawn" },
    { 0x746F, "respawn_enemies_force_vision_check" },
    { 0x7470, "respawn_friendlies_force_vision_check" },
    { 0x7471, "respawn_mode" },
    { 0x7472, "respawn_on_death" },
    { 0x7473, "respawn_reinforcements_without_vision_check" },
    { 0x7474, "respawn_spawner" },
    { 0x7475, "respawn_spawner_org" },
    { 0x7476, "respawn_watcher" },
    { 0x7477, "respawn_with_launcher" },
    { 0x7478, "respawneliminatedplayers" },
    { 0x7479, "respawnplayer" },
    { 0x747A, "respawntimerstarttime" },
    { 0x747B, "respond_to_threat_grenade" },
    { 0x747C, "responder" },
    { 0x747D, "responderclockdirection" },
    { 0x747E, "respondto" },
    { 0x747F, "respondtodeadteammate" },
    { 0x7480, "respondtodeathtime" },
    { 0x7481, "response_distance_min" },
    { 0x7482, "response_wait" },
    { 0x7483, "response_wait_axis" },
    { 0x7484, "responseevent_failsafe" },
    { 0x7485, "responsegeneric" },
    { 0x7486, "responsetakingfire" },
    { 0x7487, "responsethreatcallout" },
    { 0x7488, "responsethreatexposed" },
    { 0x7489, "restart_exterior_vfx" },
    { 0x748A, "restart_fx_looper" },
    { 0x748B, "restart_oneshots" },
    { 0x748C, "restart_selected_exploders" },
    { 0x748D, "restarteffect" },
    { 0x748E, "restartexploder" },
    { 0x748F, "restartfxid" },
    { 0x7490, "restartmoveloop" },
    { 0x7491, "restartwarbirdenginefxforplayer" },
    { 0x7492, "restaurant_civ_03_cower" },
    { 0x7493, "restaurant_door_civ_killed" },
    { 0x7494, "restaurant_doors_open" },
    { 0x7495, "restaurant_fish_tank_destruct" },
    { 0x7496, "restaurant_water" },
    { 0x7497, "restaurant_wet_floor_think" },
    { 0x7498, "restore_after_deathsdoor" },
    { 0x7499, "restore_default_exo_powers" },
    { 0x749A, "restore_footstep_notetrack_scripts" },
    { 0x749B, "restore_footsteps" },
    { 0x749C, "restore_idle" },
    { 0x749D, "restore_ignore_setting" },
    { 0x749E, "restore_moveplaybackrate" },
    { 0x749F, "restore_movetransitionrate" },
    { 0x74A0, "restore_players_weapons" },
    { 0x74A1, "restore_prebreach_weapons" },
    { 0x74A2, "restore_reload" },
    { 0x74A3, "restore_thrusters_all" },
    { 0x74A4, "restore_vehicle_speed" },
    { 0x74A5, "restore_water_footsteps" },
    { 0x74A6, "restoreangles" },
    { 0x74A7, "restoredata" },
    { 0x74A8, "restoredefaultpitch" },
    { 0x74A9, "restoredefaults" },
    { 0x74AA, "restoredefaultturnrate" },
    { 0x74AB, "restoreheadicon" },
    { 0x74AC, "restoreperk" },
    { 0x74AD, "restoreperks" },
    { 0x74AE, "restorepitch" },
    { 0x74AF, "restoreplayeractions" },
    { 0x74B0, "restoreplayercontrols" },
    { 0x74B1, "restoreplayerweaponstatepersistent" },
    { 0x74B2, "restorevision" },
    { 0x74B3, "restoreweapon" },
    { 0x74B4, "restoreweaponclipammo" },
    { 0x74B5, "restoreweapons" },
    { 0x74B6, "restoreweaponstockammo" },
    { 0x74B7, "restrict_movement_while_releasing_the_pm" },
    { 0x74B8, "restrict_player_view_to_rig_anim" },
    { 0x74B9, "restricted_airspace" },
    { 0x74BA, "resume_driving_from_dodge" },
    { 0x74BB, "resume_vehicle_traffic_roundabout_straightways" },
    { 0x74BC, "resumetimer" },
    { 0x74BD, "retarget_lighting" },
    { 0x74BE, "retarget_model_init" },
    { 0x74BF, "reticle_hide" },
    { 0x74C0, "reticle_origin" },
    { 0x74C1, "reticle_show" },
    { 0x74C2, "retract_rope" },
    { 0x74C3, "retreat_from_vol_to_vol" },
    { 0x74C4, "retreat_function" },
    { 0x74C5, "retreat_group" },
    { 0x74C6, "retreat_path" },
    { 0x74C7, "retreat_proc" },
    { 0x74C8, "retreat_vols" },
    { 0x74C9, "retreat_volume" },
    { 0x74CA, "retreat_volume_and_set_flag" },
    { 0x74CB, "retreat_watcher" },
    { 0x74CC, "retreating_kva" },
    { 0x74CD, "return_after_offhand" },
    { 0x74CE, "return_allies_after_videolog_plays" },
    { 0x74CF, "return_boost_dash" },
    { 0x74D0, "return_fall_tollerance" },
    { 0x74D1, "return_false" },
    { 0x74D2, "return_fire_rocket" },
    { 0x74D3, "return_full_mobility" },
    { 0x74D4, "return_hud" },
    { 0x74D5, "return_notify_on_event" },
    { 0x74D6, "return_player_movement_videolog" },
    { 0x74D7, "return_stealth_distances" },
    { 0x74D8, "return_tag" },
    { 0x74D9, "return_threat_bias_from_agro" },
    { 0x74DA, "return_to_normal" },
    { 0x74DB, "return_to_position" },
    { 0x74DC, "returnaftertime" },
    { 0x74DD, "returnfilterednoteworthyarray" },
    { 0x74DE, "returnflag" },
    { 0x74DF, "returnhome" },
    { 0x74E0, "returns" },
    { 0x74E1, "returntocover" },
    { 0x74E2, "returntrue" },
    { 0x74E3, "reuse_avatar" },
    { 0x74E4, "rev" },
    { 0x74E5, "rev_main_anims" },
    { 0x74E6, "rev_main_anims_vm" },
    { 0x74E7, "reveal_explosion" },
    { 0x74E8, "reveal_scene" },
    { 0x74E9, "reveal_scene_start" },
    { 0x74EA, "revengeevent" },
    { 0x74EB, "revengeunlockevent" },
    { 0x74EC, "reverb" },
    { 0x74ED, "reverb_alarm_volume" },
    { 0x74EE, "reverb_alarm_volume_update_rate" },
    { 0x74EF, "reverb_bypass" },
    { 0x74F0, "reverb_enable" },
    { 0x74F1, "reverb_settings" },
    { 0x74F2, "reverb_track" },
    { 0x74F3, "reverb1" },
    { 0x74F4, "reverb2" },
    { 0x74F5, "reverse_cloak" },
    { 0x74F6, "reverse_mag_glove_crane_move" },
    { 0x74F7, "reverse_node" },
    { 0x74F8, "reverse_street_train_function" },
    { 0x74F9, "reversegravity" },
    { 0x74FA, "revertvisionsetforplayer" },
    { 0x74FB, "revive_player" },
    { 0x74FC, "revive_watch_for_finished" },
    { 0x74FD, "revived" },
    { 0x74FE, "revivesetup" },
    { 0x74FF, "revivetagevent" },
    { 0x7500, "revivetriggerthink" },
    { 0x7501, "revivetriggerthinkhorde" },
    { 0x7502, "rh_exit_door" },
    { 0x7503, "rh_loader_movement" },
    { 0x7504, "ride_hovertank_ai" },
    { 0x7505, "ride_in_mech" },
    { 0x7506, "rider_anims" },
    { 0x7507, "rider_death_detection" },
    { 0x7508, "rider_func" },
    { 0x7509, "rider_think_loop" },
    { 0x750A, "riders" },
    { 0x750B, "riders_no_damage" },
    { 0x750C, "riders_unloadable" },
    { 0x750D, "ridevisionset" },
    { 0x750E, "ridingvehicle" },
    { 0x750F, "rifle_butt" },
    { 0x7510, "rifleshoot" },
    { 0x7511, "rifleshootobjectiveambush" },
    { 0x7512, "rifleshootobjectivenormal" },
    { 0x7513, "rifleshootobjectivesuppress" },
    { 0x7514, "rig" },
    { 0x7515, "riggetgravity" },
    { 0x7516, "riggetvelocity" },
    { 0x7517, "right_alias" },
    { 0x7518, "right_arrow" },
    { 0x7519, "right_big_loop_start" },
    { 0x751A, "right_big_pivot" },
    { 0x751B, "right_brakelight_tag" },
    { 0x751C, "right_dir" },
    { 0x751D, "right_door_anim" },
    { 0x751E, "right_ent" },
    { 0x751F, "right_headlight_tag" },
    { 0x7520, "right_left_punish_dist" },
    { 0x7521, "right_loop_start" },
    { 0x7522, "right_pivot" },
    { 0x7523, "right_post" },
    { 0x7524, "right_swing_pressed" },
    { 0x7525, "right_swing_released" },
    { 0x7526, "right_swipe_monitor" },
    { 0x7527, "right_tap_monitor" },
    { 0x7528, "rightstickrotateavatar" },
    { 0x7529, "rigprocessvelocity" },
    { 0x752A, "rigsetgravity" },
    { 0x752B, "rigsetvelocity" },
    { 0x752C, "ring" },
    { 0x752D, "riot_shield_collision" },
    { 0x752E, "riot_shield_names" },
    { 0x752F, "riotshield_approach_conditions" },
    { 0x7530, "riotshield_approach_type" },
    { 0x7531, "riotshield_bullet_hit_shield" },
    { 0x7532, "riotshield_bullet_hit_shield_clear" },
    { 0x7533, "riotshield_charge" },
    { 0x7534, "riotshield_choose_pose" },
    { 0x7535, "riotshield_clear" },
    { 0x7536, "riotshield_death" },
    { 0x7537, "riotshield_endmovetransition" },
    { 0x7538, "riotshield_fastwalk_off" },
    { 0x7539, "riotshield_fastwalk_on" },
    { 0x753A, "riotshield_flashbang" },
    { 0x753B, "riotshield_flee" },
    { 0x753C, "riotshield_flee_and_drop_shield" },
    { 0x753D, "riotshield_grenadecower" },
    { 0x753E, "riotshield_init_flee" },
    { 0x753F, "riotshield_initialized" },
    { 0x7540, "riotshield_lock_orientation" },
    { 0x7541, "riotshield_melee_aivsai" },
    { 0x7542, "riotshield_melee_standard" },
    { 0x7543, "riotshield_pain" },
    { 0x7544, "riotshield_sprint_off" },
    { 0x7545, "riotshield_sprint_on" },
    { 0x7546, "riotshield_startcombat" },
    { 0x7547, "riotshield_startmovetransition" },
    { 0x7548, "riotshield_turn_into_regular_ai" },
    { 0x7549, "riotshield_unlock_orientation" },
    { 0x754A, "riotshield_watch_for_change_weapon" },
    { 0x754B, "riotshield_watch_for_exo_shield_pullback" },
    { 0x754C, "riotshield_watch_for_exo_shield_release" },
    { 0x754D, "riotshield_watch_for_ladder_early_exit" },
    { 0x754E, "riotshield_watch_for_start_change_weapon" },
    { 0x754F, "riotshieldcleanup" },
    { 0x7550, "riotshieldcollisionentity" },
    { 0x7551, "riotshielddistancetest" },
    { 0x7552, "riotshieldentity" },
    { 0x7553, "riotshieldkillevent" },
    { 0x7554, "riotshieldmod" },
    { 0x7555, "riotshieldretrievetrigger" },
    { 0x7556, "riotshieldtakeweapon" },
    { 0x7557, "riotshieldxpbullets" },
    { 0x7558, "rippable" },
    { 0x7559, "ripples_on_body" },
    { 0x755A, "ris_is_muted" },
    { 0x755B, "ris_max_off_time" },
    { 0x755C, "ris_max_on_time" },
    { 0x755D, "ris_mute_time" },
    { 0x755E, "ris_off_time" },
    { 0x755F, "river_drilling_animation" },
    { 0x7560, "river_drills" },
    { 0x7561, "river_entry_splash_fx" },
    { 0x7562, "river_room_combat_dialouge" },
    { 0x7563, "river_slow_movement_ai_think" },
    { 0x7564, "riverbounce_hideents" },
    { 0x7565, "road_battle_setup" },
    { 0x7566, "road_width" },
    { 0x7567, "roaming_light" },
    { 0x7568, "robot" },
    { 0x7569, "rock_mob" },
    { 0x756A, "rock_the_boat" },
    { 0x756B, "rocket_ai" },
    { 0x756C, "rocket_cine_dof" },
    { 0x756D, "rocket_cleanupondeath" },
    { 0x756E, "rocket_destroyed_for_achievement" },
    { 0x756F, "rocket_fail_lighting" },
    { 0x7570, "rocket_fail_smoke" },
    { 0x7571, "rocket_fire_rumbles" },
    { 0x7572, "rocket_jump_human" },
    { 0x7573, "rocket_jump_human_railing" },
    { 0x7574, "rocket_kill_watcher" },
    { 0x7575, "rocket_success_dof_debugging" },
    { 0x7576, "rocket_success_lighting_pre_cine" },
    { 0x7577, "rocket_success_pt2_gideon_in_frame" },
    { 0x7578, "rocket_success_pt2_lighting_debugging" },
    { 0x7579, "rocket_swarm" },
    { 0x757A, "rocket_swarm_create_and_manage_attractor" },
    { 0x757B, "rocket_swarm_death_thread" },
    { 0x757C, "rocket_swarm_end_position" },
    { 0x757D, "rocket_swarm_fired_rumbles" },
    { 0x757E, "rocket_swarm_get_height_offset" },
    { 0x757F, "rocket_swarm_iterate_next_node" },
    { 0x7580, "rocket_swarm_linear_think" },
    { 0x7581, "rocket_swarm_path_node_think" },
    { 0x7582, "rocket_swarm_path_think" },
    { 0x7583, "rocket_swarm_random_course_change" },
    { 0x7584, "rocket_swarm_should_path" },
    { 0x7585, "rocket_swarm_start_position" },
    { 0x7586, "rocket_swarm_straight_rocket" },
    { 0x7587, "rocket_swarm_target_course_change" },
    { 0x7588, "rocket_target_think" },
    { 0x7589, "rocket_targets" },
    { 0x758A, "rocket_think" },
    { 0x758B, "rocket_two_stage_swarm_think" },
    { 0x758C, "rocketammo" },
    { 0x758D, "rocketattachment" },
    { 0x758E, "rocketclip" },
    { 0x758F, "rocketdestroyaftertime" },
    { 0x7590, "rocketlauncherammo" },
    { 0x7591, "rocketpodup" },
    { 0x7592, "rocketpositionupdate" },
    { 0x7593, "rocketreloadsound" },
    { 0x7594, "rockets" },
    { 0x7595, "rockettargetent" },
    { 0x7596, "rocketturret" },
    { 0x7597, "rocketvisible" },
    { 0x7598, "rocking" },
    { 0x7599, "rocks" },
    { 0x759A, "role" },
    { 0x759B, "roll" },
    { 0x759C, "roll_ent" },
    { 0x759D, "rolling_lp" },
    { 0x759E, "rollingdeath" },
    { 0x759F, "roof_breach_anticipation_fx" },
    { 0x75A0, "roof_breach_burke_plant" },
    { 0x75A1, "roof_breach_chunks_bursts" },
    { 0x75A2, "roof_breach_device_area_mark" },
    { 0x75A3, "roof_breach_device_explosion" },
    { 0x75A4, "roof_breach_device_plant_dust" },
    { 0x75A5, "roof_breach_device_plant_mini_charges" },
    { 0x75A6, "roof_breach_device_radial_sml_explosions" },
    { 0x75A7, "roof_breach_fx" },
    { 0x75A8, "roof_breach_laser_detonate" },
    { 0x75A9, "roof_logic" },
    { 0x75AA, "roof_scene_enter_water_cleanup" },
    { 0x75AB, "roof_scene_grass_close_window_blast_doors" },
    { 0x75AC, "roof_scene_grass_death_squad_handler" },
    { 0x75AD, "roof_scene_grass_deploy_guards" },
    { 0x75AE, "roof_scene_grass_guard_cleanup" },
    { 0x75AF, "roof_scene_grass_handle_guard_doors" },
    { 0x75B0, "roof_scene_grass_monitor_guard_clear" },
    { 0x75B1, "roof_scene_grass_section" },
    { 0x75B2, "roof_scene_grass_section_failstates" },
    { 0x75B3, "roof_scene_grass_setup_blast_door_clip" },
    { 0x75B4, "roof_scene_guards" },
    { 0x75B5, "roof_scene_hide_rig" },
    { 0x75B6, "roof_scene_industrial_death_squad_handler" },
    { 0x75B7, "roof_scene_industrial_drone_swarm_launch_manager" },
    { 0x75B8, "roof_scene_industrial_launch_drone_swarm" },
    { 0x75B9, "roof_scene_industrial_open_hatch" },
    { 0x75BA, "roof_scene_industrial_section" },
    { 0x75BB, "roof_scene_industrial_section_failstates" },
    { 0x75BC, "roof_scene_industrial_set_up_swarm" },
    { 0x75BD, "roof_scene_master_handler" },
    { 0x75BE, "roof_scene_scripted_elevator_shaft_close" },
    { 0x75BF, "roof_scene_scripted_ilona_fire_at_swarm" },
    { 0x75C0, "roof_scene_scripted_ilona_fire_at_swarm_behavior_clear" },
    { 0x75C1, "roof_scene_set_up" },
    { 0x75C2, "roof_scene_setup_failstates" },
    { 0x75C3, "roof_scene_slide" },
    { 0x75C4, "roof_scene_slide_ilana_anim_to_swim" },
    { 0x75C5, "roof_scene_slide_raise_gates" },
    { 0x75C6, "roof_scene_slide_remove_glass_blocker" },
    { 0x75C7, "roof_scene_slide_slomo_start" },
    { 0x75C8, "roof_scene_slide_slomo_stop" },
    { 0x75C9, "roof_scene_slide_wait_for_player_jumped" },
    { 0x75CA, "roof_scene_vignette_civilians" },
    { 0x75CB, "roof_scene_vignettes" },
    { 0x75CC, "roof_trigger" },
    { 0x75CD, "roof_use_trigger" },
    { 0x75CE, "rooftop_ambient_dust" },
    { 0x75CF, "rooftop_anim_length" },
    { 0x75D0, "rooftop_bombshakes" },
    { 0x75D1, "rooftop_enemy_counter" },
    { 0x75D2, "rooftop_enemy_think" },
    { 0x75D3, "rooftop_enemy_think_left" },
    { 0x75D4, "rooftop_enemy_think_right" },
    { 0x75D5, "rooftop_glass_explode" },
    { 0x75D6, "rooftop_slide" },
    { 0x75D7, "rooftop_slo_mo_override" },
    { 0x75D8, "rooftop_strafe" },
    { 0x75D9, "rooftop_strafe_start" },
    { 0x75DA, "rooftopreminderdialogue" },
    { 0x75DB, "rooftopwatchparkingguards" },
    { 0x75DC, "room_has_multiple_doors" },
    { 0x75DD, "room_volume" },
    { 0x75DE, "roomtype" },
    { 0x75DF, "root_anim" },
    { 0x75E0, "rope" },
    { 0x75E1, "rope_end_rappel" },
    { 0x75E2, "rope_knox" },
    { 0x75E3, "rope_link" },
    { 0x75E4, "rope_model" },
    { 0x75E5, "rope_setupanimation" },
    { 0x75E6, "rope_started" },
    { 0x75E7, "ropesound" },
    { 0x75E8, "rot_bot" },
    { 0x75E9, "rot_top" },
    { 0x75EA, "rotate" },
    { 0x75EB, "rotate_axis_angle" },
    { 0x75EC, "rotate_camera_to_internal" },
    { 0x75ED, "rotate_camera_to_match_ent" },
    { 0x75EE, "rotate_camera_to_offset_angles" },
    { 0x75EF, "rotate_camera_to_see_ent" },
    { 0x75F0, "rotate_ent_towards_center" },
    { 0x75F1, "rotate_missile_targets" },
    { 0x75F2, "rotate_over_time" },
    { 0x75F3, "rotate_player_to_facing_angles" },
    { 0x75F4, "rotate_roll_link" },
    { 0x75F5, "rotate_space_debris" },
    { 0x75F6, "rotate_the_universe" },
    { 0x75F7, "rotate_to_goal" },
    { 0x75F8, "rotate_until_no_diff" },
    { 0x75F9, "rotateavatartagcamera" },
    { 0x75FA, "rotatedirection" },
    { 0x75FB, "rotatedryerfan" },
    { 0x75FC, "rotategatebounce" },
    { 0x75FD, "rotategates" },
    { 0x75FE, "rotategatesconstant" },
    { 0x75FF, "rotatehelispawn" },
    { 0x7600, "rotatemeshes" },
    { 0x7601, "rotateorbitalshippivots" },
    { 0x7602, "rotateorbitalships" },
    { 0x7603, "rotateplane" },
    { 0x7604, "rotateradar" },
    { 0x7605, "rotatetargets" },
    { 0x7606, "rotatethink" },
    { 0x7607, "rotatetime" },
    { 0x7608, "rotatetoangle" },
    { 0x7609, "rotateuavrig" },
    { 0x760A, "rotating_gate_constant" },
    { 0x760B, "rotating_gates" },
    { 0x760C, "rotatinglinkarray" },
    { 0x760D, "rotation_is_occuring" },
    { 0x760E, "rotation_offset" },
    { 0x760F, "rotation_parent" },
    { 0x7610, "rotation_total" },
    { 0x7611, "rotor_anim" },
    { 0x7612, "round_float" },
    { 0x7613, "round_millisec_on_sec" },
    { 0x7614, "round_target_unit_per_second" },
    { 0x7615, "roundabout_bicycle_riders" },
    { 0x7616, "roundabout_center_vehicle_nodes" },
    { 0x7617, "roundabout_center_vehicle_nodes_cg" },
    { 0x7618, "roundabout_center_vehicles" },
    { 0x7619, "roundabout_center_vehicles_cg" },
    { 0x761A, "roundabout_center_vehicles_moving" },
    { 0x761B, "roundabout_center_vehicles_tank_explo" },
    { 0x761C, "roundabout_civilian_flee_path_and_run_select" },
    { 0x761D, "roundabout_combat" },
    { 0x761E, "roundabout_combat_dialogue" },
    { 0x761F, "roundabout_combat_initial" },
    { 0x7620, "roundabout_combat_start_slow_motion" },
    { 0x7621, "roundabout_combat_started" },
    { 0x7622, "roundabout_combat_tanker_explode" },
    { 0x7623, "roundabout_combat_tanker_explode_veh_cg" },
    { 0x7624, "roundabout_combat_tanker_fire_damage" },
    { 0x7625, "roundabout_exited" },
    { 0x7626, "roundabout_flee_goals" },
    { 0x7627, "roundabout_general_mayhem" },
    { 0x7628, "roundabout_lobby_couch" },
    { 0x7629, "roundabout_lobby_couch_front" },
    { 0x762A, "roundabout_lobby_elevator" },
    { 0x762B, "roundabout_lobby_elevator_exiting_react_1" },
    { 0x762C, "roundabout_lobby_elevator_exiting_react_2" },
    { 0x762D, "roundabout_lobby_elevator_waiting_react_1" },
    { 0x762E, "roundabout_lobby_elevator_waiting_react_2" },
    { 0x762F, "roundabout_lobby_phone" },
    { 0x7630, "roundabout_lobby_phone_front" },
    { 0x7631, "roundabout_lobby_phone2" },
    { 0x7632, "roundabout_lobby_reacts_into_walk" },
    { 0x7633, "roundabout_lobby_security_desk" },
    { 0x7634, "roundabout_lobby_security_desk_front" },
    { 0x7635, "roundabout_lobby_vehicles" },
    { 0x7636, "roundabout_lobby_vehicles_cg" },
    { 0x7637, "roundabout_lobby_walkingtalk" },
    { 0x7638, "roundabout_magic_microwave_grenade" },
    { 0x7639, "roundabout_panic_walla" },
    { 0x763A, "roundabout_ropes" },
    { 0x763B, "roundabout_rpg_car_damage_function" },
    { 0x763C, "roundabout_rpg_fire" },
    { 0x763D, "roundabout_rush_goal" },
    { 0x763E, "roundabout_setup" },
    { 0x763F, "roundabout_setup_center_vehicle_nodes" },
    { 0x7640, "roundabout_setup_center_vehicle_nodes_cg" },
    { 0x7641, "roundabout_setup_center_vehicles" },
    { 0x7642, "roundabout_setup_center_vehicles_cg" },
    { 0x7643, "roundabout_street_car_hood_hit" },
    { 0x7644, "roundabout_street_car_hood_hit_driver" },
    { 0x7645, "roundabout_street_drop_bikes" },
    { 0x7646, "roundabout_swap_vehicle_for_model" },
    { 0x7647, "roundabout_tanker_damage" },
    { 0x7648, "roundabout_tanker_enemy_settings" },
    { 0x7649, "roundabout_tanker_enemy_settings_other" },
    { 0x764A, "roundabout_tanker_explosion" },
    { 0x764B, "roundabout_tanker_lookat" },
    { 0x764C, "roundabout_tanker_magic_rpg" },
    { 0x764D, "roundabout_traffic" },
    { 0x764E, "roundabout_walla_flag_explosion" },
    { 0x764F, "roundactive" },
    { 0x7650, "roundbegin" },
    { 0x7651, "rounddecimalplaces" },
    { 0x7652, "roundend" },
    { 0x7653, "roundenddelay" },
    { 0x7654, "roundenddof" },
    { 0x7655, "roundendwait" },
    { 0x7656, "roundheadshots" },
    { 0x7657, "roundkills" },
    { 0x7658, "roundnumber" },
    { 0x7659, "roundsplayed" },
    { 0x765A, "roundswitch" },
    { 0x765B, "roundswitchdvar" },
    { 0x765C, "roundswitchmax" },
    { 0x765D, "roundswitchmin" },
    { 0x765E, "roundup" },
    { 0x765F, "roundupgradepoints" },
    { 0x7660, "roundwinnerdialog" },
    { 0x7661, "rows" },
    { 0x7662, "rpg_at_heli" },
    { 0x7663, "rpg_at_squad_01" },
    { 0x7664, "rpg_explosion" },
    { 0x7665, "rpg_guys" },
    { 0x7666, "rpg_juke" },
    { 0x7667, "rpg_shoot" },
    { 0x7668, "rpg_shoot_dist" },
    { 0x7669, "rpgdeath" },
    { 0x766A, "rpgdestroywall" },
    { 0x766B, "rpgplayerrepulsor" },
    { 0x766C, "rpgplayerrepulsor_create" },
    { 0x766D, "rpgplayerrepulsor_getnummisses" },
    { 0x766E, "rpgshoot" },
    { 0x766F, "rs_angle" },
    { 0x7670, "rspns_cat_name" },
    { 0x7671, "rspns_cat_name_alt" },
    { 0x7672, "rt_harness_breakout" },
    { 0x7673, "rubberband_settings" },
    { 0x7674, "rules" },
    { 0x7675, "rumble" },
    { 0x7676, "rumble_base_entity" },
    { 0x7677, "rumble_basetime" },
    { 0x7678, "rumble_cam_shake" },
    { 0x7679, "rumble_duration" },
    { 0x767A, "rumble_ent" },
    { 0x767B, "rumble_entity" },
    { 0x767C, "rumble_flydrone_animation" },
    { 0x767D, "rumble_flydrone_control" },
    { 0x767E, "rumble_frogger_vehicles" },
    { 0x767F, "rumble_heavy" },
    { 0x7680, "rumble_heavy_1" },
    { 0x7681, "rumble_heavy_2" },
    { 0x7682, "rumble_heavy_3" },
    { 0x7683, "rumble_killer" },
    { 0x7684, "rumble_large" },
    { 0x7685, "rumble_light" },
    { 0x7686, "rumble_light_1" },
    { 0x7687, "rumble_light_2" },
    { 0x7688, "rumble_light_3" },
    { 0x7689, "rumble_loop" },
    { 0x768A, "rumble_medium" },
    { 0x768B, "rumble_middle_takedown_throw_guy" },
    { 0x768C, "rumble_notetracks" },
    { 0x768D, "rumble_radius" },
    { 0x768E, "rumble_ramp_off" },
    { 0x768F, "rumble_ramp_on" },
    { 0x7690, "rumble_ramp_to" },
    { 0x7691, "rumble_randomaditionaltime" },
    { 0x7692, "rumble_roundabout_rpg_car_hit" },
    { 0x7693, "rumble_roundabout_tanker" },
    { 0x7694, "rumble_scale" },
    { 0x7695, "rumble_set_ent_rumble_intensity_for_time" },
    { 0x7696, "rumble_small" },
    { 0x7697, "rumble_thread" },
    { 0x7698, "rumble_till_out_of_range" },
    { 0x7699, "rumbleatriumbreach" },
    { 0x769A, "rumblemonitor" },
    { 0x769B, "rumbleon" },
    { 0x769C, "rumbleplayerdistantexplosion" },
    { 0x769D, "rumbleplayerheavy" },
    { 0x769E, "rumbleplayerlight" },
    { 0x769F, "rumblesniperdronefire" },
    { 0x76A0, "rumblesniperdronenearexplosion" },
    { 0x76A1, "rumblesniperdronetakenout" },
    { 0x76A2, "rumbletrigger" },
    { 0x76A3, "rumbling" },
    { 0x76A4, "run_accuracy" },
    { 0x76A5, "run_assembly_line" },
    { 0x76A6, "run_ball" },
    { 0x76A7, "run_call_after_wait_array" },
    { 0x76A8, "run_clearfacialanim" },
    { 0x76A9, "run_dog_command" },
    { 0x76AA, "run_fan" },
    { 0x76AB, "run_func_after_wait_array" },
    { 0x76AC, "run_nodes1" },
    { 0x76AD, "run_noself_call_after_wait_array" },
    { 0x76AE, "run_override_weights" },
    { 0x76AF, "run_overrideanim" },
    { 0x76B0, "run_overrideanim_hasstairanimarray" },
    { 0x76B1, "run_overridebulletreact" },
    { 0x76B2, "run_overridesound" },
    { 0x76B3, "run_playfacialanim" },
    { 0x76B4, "run_post_function" },
    { 0x76B5, "run_selfiebooth" },
    { 0x76B6, "run_spawn_functions" },
    { 0x76B7, "run_speed" },
    { 0x76B8, "run_speed_state" },
    { 0x76B9, "run_thread_on_noteworthy" },
    { 0x76BA, "run_thread_on_notify" },
    { 0x76BB, "run_thread_on_targetname" },
    { 0x76BC, "run_to_heli_heli_landing" },
    { 0x76BD, "run_to_heli_manticore_scene" },
    { 0x76BE, "run_to_new_spot_and_setup_gun" },
    { 0x76BF, "run_traffic" },
    { 0x76C0, "run_train" },
    { 0x76C1, "run_train_shaker" },
    { 0x76C2, "run_train_with_shaking" },
    { 0x76C3, "run_tram_killstreak" },
    { 0x76C4, "runanim" },
    { 0x76C5, "runaway_drone_think" },
    { 0x76C6, "runaway_guy_delete" },
    { 0x76C7, "runbeam" },
    { 0x76C8, "runbeamupdate" },
    { 0x76C9, "runcombat" },
    { 0x76CA, "rundecidewhatandhowtoshoot" },
    { 0x76CB, "rundroplocations" },
    { 0x76CC, "runhordecollect" },
    { 0x76CD, "runhordedefend" },
    { 0x76CE, "runhordedefuse" },
    { 0x76CF, "runhordeintel" },
    { 0x76D0, "runhordemode" },
    { 0x76D1, "runhordeobjective" },
    { 0x76D2, "runhordezombies" },
    { 0x76D3, "runingturnrate" },
    { 0x76D4, "runloopcount" },
    { 0x76D5, "runloopisnearbeginning" },
    { 0x76D6, "runngun" },
    { 0x76D7, "runngun_backward" },
    { 0x76D8, "runngunincrement" },
    { 0x76D9, "runnguntransitionpoint" },
    { 0x76DA, "runngunweight" },
    { 0x76DB, "running_car" },
    { 0x76DC, "running_handle_hud_outline_binocs" },
    { 0x76DD, "running_intance_accumulator" },
    { 0x76DE, "running_to_goal" },
    { 0x76DF, "running_up_the_stairs_fail" },
    { 0x76E0, "runningaimblendtime" },
    { 0x76E1, "runningaimlimits" },
    { 0x76E2, "runningmechblendtime" },
    { 0x76E3, "runningreacttobullets" },
    { 0x76E4, "runningtovehicle" },
    { 0x76E5, "runnormalround" },
    { 0x76E6, "runonshootbehaviorend" },
    { 0x76E7, "runpos" },
    { 0x76E8, "runroundspawning" },
    { 0x76E9, "runshootwhilemoving" },
    { 0x76EA, "runtovehicleoverride" },
    { 0x76EB, "runzombieround" },
    { 0x76EC, "rushed" },
    { 0x76ED, "rvb_apply_reverb" },
    { 0x76EE, "rvb_deactive_reverb" },
    { 0x76EF, "rvb_get_applied_reverb" },
    { 0x76F0, "rvb_init" },
    { 0x76F1, "rvb_set_dry_level" },
    { 0x76F2, "rvb_set_wet_level" },
    { 0x76F3, "rvb_start_preset" },
    { 0x76F4, "rvb_use_string_table" },
    { 0x76F5, "rvbx_apply_inital_reverb" },
    { 0x76F6, "rvbx_create" },
    { 0x76F7, "rvbx_get_preset_from_string_table" },
    { 0x76F8, "rvbx_get_reverb_preset" },
    { 0x76F9, "rvbx_get_reverb_preset_from_stringtable_internal" },
    { 0x76FA, "rvbx_store_current_reverb_track" },
    { 0x76FB, "s_flicker_catwalk_alarm" },
    { 0x76FC, "s1_deleted_prisoners_anims" },
    { 0x76FD, "s1_drive_and_elevator_scene" },
    { 0x76FE, "s1_elevator_boundary_function" },
    { 0x76FF, "s1_motionset_avaliable" },
    { 0x7700, "s1_popping_smoke" },
    { 0x7701, "s1_truck_unload_main_allies_anims" },
    { 0x7702, "s1_truck_unload_main_guards_anims" },
    { 0x7703, "s2_elevator_door_close" },
    { 0x7704, "s2_elevator_door_open" },
    { 0x7705, "s2_elevator_door_open_top" },
    { 0x7706, "s2_elevator_ride_down" },
    { 0x7707, "s2_prison_amb" },
    { 0x7708, "s2_walk_execution_pa" },
    { 0x7709, "s2_walk_footsteps" },
    { 0x770A, "s2_walk_vo_execution" },
    { 0x770B, "s2elevator_fade_transition" },
    { 0x770C, "s2elevator_trolley_intro_scene" },
    { 0x770D, "s2walk_ambient_character_cleanup" },
    { 0x770E, "s2walk_cage_door_open" },
    { 0x770F, "s2walk_dynamic_speed_adjuster" },
    { 0x7710, "s2walk_guard_cages_vo_notetrack" },
    { 0x7711, "s2walk_guard_end_cleanup" },
    { 0x7712, "s2walk_guard_gate_vo_notetrack" },
    { 0x7713, "s2walk_player_push" },
    { 0x7714, "s3_body_movement" },
    { 0x7715, "s3_break_glass" },
    { 0x7716, "s3_controlroom_attack_vo_notetrack" },
    { 0x7717, "s3_controlroom_exit_vo_notetrack1" },
    { 0x7718, "s3_controlroom_exit_vo_notetrack2" },
    { 0x7719, "s3_controlroom_exit_vo_notetrack3" },
    { 0x771A, "s3_controlroom_exit_vo_notetrack4" },
    { 0x771B, "s3_controlroom_exit_vo_notetrack5" },
    { 0x771C, "s3_controlroom_exit_vo_notetrack6" },
    { 0x771D, "s3_controlroom_exit_vo_notetrack7" },
    { 0x771E, "s3_controlroom_vo_notetrack1" },
    { 0x771F, "s3_controlroom_vo_notetrack2" },
    { 0x7720, "s3_controlroom_vo_notetrack3" },
    { 0x7721, "s3_controlroom_vo_notetrack4" },
    { 0x7722, "s3_controlroom_vo_notetrack5" },
    { 0x7723, "s3_controlroom_vo_notetrack6" },
    { 0x7724, "s3_enter_security_room" },
    { 0x7725, "s3_escape_ally_gun_help_anim" },
    { 0x7726, "s3_escape_console_gun_action" },
    { 0x7727, "s3_escape_console_monitor" },
    { 0x7728, "s3_escape_controlroom_door_notetrack" },
    { 0x7729, "s3_escape_controlroom_exit_door_notetrack" },
    { 0x772A, "s3_escape_controlroom_exit_door_swipe_sfx_notetrack" },
    { 0x772B, "s3_escape_deathwatcher" },
    { 0x772C, "s3_escape_door_notetrack" },
    { 0x772D, "s3_escape_elevator_movement" },
    { 0x772E, "s3_escape_elevator_start" },
    { 0x772F, "s3_escape_guard_function" },
    { 0x7730, "s3_escape_guards_enter" },
    { 0x7731, "s3_escape_gun_action" },
    { 0x7732, "s3_escape_hack_action" },
    { 0x7733, "s3_escape_hack_action_switcher" },
    { 0x7734, "s3_escape_outer_door" },
    { 0x7735, "s3_escape_player_exo_and_gun_anim" },
    { 0x7736, "s3_escape_player_gun" },
    { 0x7737, "s3_escape_sliding_door_player" },
    { 0x7738, "s3_fade_over_time" },
    { 0x7739, "s3_get_gun_vo_notetrack1" },
    { 0x773A, "s3_get_gun_vo_notetrack2" },
    { 0x773B, "s3_get_gun_vo_notetrack3" },
    { 0x773C, "s3_guard_takedown_vo_notetrack" },
    { 0x773D, "s3_interrogate_doctor_scene" },
    { 0x773E, "s3_splitup_event" },
    { 0x773F, "s3_toggle_rig" },
    { 0x7740, "s3escape_console_cinematic_watcher" },
    { 0x7741, "s3escape_console_pause_checkpoint" },
    { 0x7742, "s3escape_console_setup" },
    { 0x7743, "s3escape_doctor_kill" },
    { 0x7744, "s3escape_doctor_killbox_prompt" },
    { 0x7745, "s3escape_doctor_scene" },
    { 0x7746, "s3escape_fade_to_black" },
    { 0x7747, "s3escape_gideon_gun_anim" },
    { 0x7748, "s3escape_intro_scene" },
    { 0x7749, "sabbomb" },
    { 0x774A, "safe_activate_trigger_with_targetname" },
    { 0x774B, "safe_str" },
    { 0x774C, "safe_to_spawn_vehciles" },
    { 0x774D, "safe_vehicle_delete" },
    { 0x774E, "safe_volume" },
    { 0x774F, "safefromgas" },
    { 0x7750, "safehouse_backyard_damb" },
    { 0x7751, "safehouse_balcony_siren" },
    { 0x7752, "safehouse_escape_music" },
    { 0x7753, "safehouse_exo_trans_fade_in" },
    { 0x7754, "safehouse_exo_trans_fade_out" },
    { 0x7755, "safehouse_int_trigger_think" },
    { 0x7756, "safehouse_sonic_destruct" },
    { 0x7757, "safehousebackyardalertmonitoroff" },
    { 0x7758, "safehousebackyardalertmonitoron" },
    { 0x7759, "safehousebackyarddamagetriggers" },
    { 0x775A, "safehousebackyarddamagetriggerstoggle" },
    { 0x775B, "safehousebackyarddamagetriggerwaits" },
    { 0x775C, "safehousebagdropreminder" },
    { 0x775D, "safehousebagdroprumblelight" },
    { 0x775E, "safehousebeginentrance" },
    { 0x775F, "safehousebeginexit" },
    { 0x7760, "safehousechangeclothes" },
    { 0x7761, "safehouseclearfirstfloordialogue" },
    { 0x7762, "safehouseclearsecondfloordialogue" },
    { 0x7763, "safehousecourtyarddistraction" },
    { 0x7764, "safehousecourtyarddistractioninterrupt" },
    { 0x7765, "safehousecourtyardsightwatch" },
    { 0x7766, "safehousecourtyardtakedownilonafail" },
    { 0x7767, "safehousecourtyardtakedownknifenpc" },
    { 0x7768, "safehousecourtyardtakedownprops" },
    { 0x7769, "safehousedoorinit" },
    { 0x776A, "safehousedoorplayerblocker" },
    { 0x776B, "safehousedoorsetlocked" },
    { 0x776C, "safehousedoorunlockednotetrack" },
    { 0x776D, "safehouseenddronecontrolsetup" },
    { 0x776E, "safehouseenemiesignoreplayer" },
    { 0x776F, "safehouseenemyinit" },
    { 0x7770, "safehouseexit2floor" },
    { 0x7771, "safehouseexit2floorviewmodel" },
    { 0x7772, "safehouseexitautosaves" },
    { 0x7773, "safehouseexitdeadbodysetupcouchguard" },
    { 0x7774, "safehouseexitdeadbodysetuppacingguard" },
    { 0x7775, "safehouseexitplayerjumpwatcher" },
    { 0x7776, "safehouseexitplayerleaps" },
    { 0x7777, "safehouseexittogglegates" },
    { 0x7778, "safehousefailcoverblown" },
    { 0x7779, "safehousefailkvaalerted" },
    { 0x777A, "safehousefailtargetescaped" },
    { 0x777B, "safehouseflaginit" },
    { 0x777C, "safehousefollowplayernotifies" },
    { 0x777D, "safehousefollowreminder1" },
    { 0x777E, "safehousefollowreminder2" },
    { 0x777F, "safehousefollowreminder3" },
    { 0x7780, "safehouseforceopensafehousedoor" },
    { 0x7781, "safehousefrontdoorreminder" },
    { 0x7782, "safehousegatebashfx" },
    { 0x7783, "safehouseglobalsetup" },
    { 0x7784, "safehouseglobalvars" },
    { 0x7785, "safehouseguardalertwatch" },
    { 0x7786, "safehouseguardsightwatch" },
    { 0x7787, "safehouseguardtriggerwatch" },
    { 0x7788, "safehouseilanabagdropwait" },
    { 0x7789, "safehouseilanacheckdeckweapon" },
    { 0x778A, "safehouseilanaclearsafehouse" },
    { 0x778B, "safehouseilanaexitstairs" },
    { 0x778C, "safehouseilanaopendooridle" },
    { 0x778D, "safehouseilanaopensafehousedoor" },
    { 0x778E, "safehouseilanaplanningguardsearlykill" },
    { 0x778F, "safehouseilanasafehouseexit" },
    { 0x7790, "safehouseilanasetupteamkill" },
    { 0x7791, "safehouseilanasonicexocheck" },
    { 0x7792, "safehouseilanastairway" },
    { 0x7793, "safehouseilanatransition" },
    { 0x7794, "safehouseilanaweaponshot" },
    { 0x7795, "safehousekilldialogue" },
    { 0x7796, "safehousekillreminder" },
    { 0x7797, "safehousekvafollowtargetdeath" },
    { 0x7798, "safehousemonitorbagdrophint" },
    { 0x7799, "safehousemonitorbagdropinteract" },
    { 0x779A, "safehouseobjectivesetup" },
    { 0x779B, "safehouseoutrodialogue" },
    { 0x779C, "safehousepacingguard" },
    { 0x779D, "safehousepacingguardalertmonitor" },
    { 0x779E, "safehousepacingguardconversationmonitor" },
    { 0x779F, "safehousepacingguarddeath" },
    { 0x77A0, "safehousepacingguardtriggerwatch" },
    { 0x77A1, "safehousepatrolleralertwatch" },
    { 0x77A2, "safehouseplanningguard" },
    { 0x77A3, "safehouseplanningguarddeathcheck" },
    { 0x77A4, "safehouseplanningguardfailendnotetrack" },
    { 0x77A5, "safehouseplanningguardfailwatch" },
    { 0x77A6, "safehouseplanningguards" },
    { 0x77A7, "safehouseplanningguardsdialog" },
    { 0x77A8, "safehouseplanningguardsweapons" },
    { 0x77A9, "safehouseplayermovespeedscale1stfloor" },
    { 0x77AA, "safehouseplayermovespeedscale2ndfloor" },
    { 0x77AB, "safehouseprecache" },
    { 0x77AC, "safehouseremoveplayerblocker" },
    { 0x77AD, "safehouseremovethreatgrenade" },
    { 0x77AE, "safehousesecondfloorilonacouchkill" },
    { 0x77AF, "safehousesecondfloorreminder" },
    { 0x77B0, "safehousesetcompletedobjflags" },
    { 0x77B1, "safehousesetupsniperdroneilana" },
    { 0x77B2, "safehousesleepingguard" },
    { 0x77B3, "safehousesleepingguardanimcheck" },
    { 0x77B4, "safehousesleepingguarddeath" },
    { 0x77B5, "safehousesniperdronecloaking" },
    { 0x77B6, "safehousesniperdronelaunch" },
    { 0x77B7, "safehousesonicdustfx" },
    { 0x77B8, "safehousespawnbackalleykva" },
    { 0x77B9, "safehousespawnbackalleyrooftopkva" },
    { 0x77BA, "safehousespawnwindowshooters" },
    { 0x77BB, "safehousestartpoints" },
    { 0x77BC, "safehousestartpointsfinal" },
    { 0x77BD, "safehousetakedownreturnplayercontrol" },
    { 0x77BE, "safehousetoggleexitflagtriggers" },
    { 0x77BF, "safehousetransitiondialogue" },
    { 0x77C0, "safehousetranstoalleygatesetup" },
    { 0x77C1, "safehousetvdestructible" },
    { 0x77C2, "safehousevideochatmovie" },
    { 0x77C3, "safehousewindowshootermonitor" },
    { 0x77C4, "safehousewindowshootermovetarget" },
    { 0x77C5, "safehousewindowshooterthink" },
    { 0x77C6, "safehousewindowshutterdestroy" },
    { 0x77C7, "safelyplayanimatrateuntilnotetrack" },
    { 0x77C8, "safelyplayanimnatrateuntilnotetrack" },
    { 0x77C9, "safelyplayanimnuntilnotetrack" },
    { 0x77CA, "safelyplayanimuntilnotetrack" },
    { 0x77CB, "safemod" },
    { 0x77CC, "safeorigin" },
    { 0x77CD, "safetyteleport_actor" },
    { 0x77CE, "safetyteleport_allies" },
    { 0x77CF, "saint" },
    { 0x77D0, "salvo_ammo" },
    { 0x77D1, "salvo_cooldown_max" },
    { 0x77D2, "salvo_cooldown_min" },
    { 0x77D3, "salvo_idx" },
    { 0x77D4, "salvo0" },
    { 0x77D5, "salvo1" },
    { 0x77D6, "sam_acquiretarget" },
    { 0x77D7, "sam_attacktargets" },
    { 0x77D8, "sam_fireontarget" },
    { 0x77D9, "sam_watchcrashing" },
    { 0x77DA, "sam_watchlaser" },
    { 0x77DB, "sam_watchleaving" },
    { 0x77DC, "sam_watchlineofsight" },
    { 0x77DD, "samb" },
    { 0x77DE, "samb1_name" },
    { 0x77DF, "samb2_name" },
    { 0x77E0, "same_color_code_as_last_time" },
    { 0x77E1, "same_mech_chaingun_last_state" },
    { 0x77E2, "same_mech_rocket_last_state" },
    { 0x77E3, "same_mech_swarm_last_state" },
    { 0x77E4, "sameshotdamage" },
    { 0x77E5, "sammissilegroup" },
    { 0x77E6, "sammissilegroups" },
    { 0x77E7, "samtargetent" },
    { 0x77E8, "samturret" },
    { 0x77E9, "sanfran_b_bridge_clut" },
    { 0x77EA, "sanfran_b_dark_lightset" },
    { 0x77EB, "sanfran_b_darker_lightset" },
    { 0x77EC, "sanfran_b_dim" },
    { 0x77ED, "sanfran_b_exterior_clut" },
    { 0x77EE, "sanfran_b_exterior_clut_fast" },
    { 0x77EF, "sanfran_b_fire" },
    { 0x77F0, "sanfran_b_hangar_lightset" },
    { 0x77F1, "sanfran_b_info_top_lightset" },
    { 0x77F2, "sanfran_b_interior_blue_clut" },
    { 0x77F3, "sanfran_b_interior_clut" },
    { 0x77F4, "sanfran_b_lightset" },
    { 0x77F5, "sanfran_b_locations" },
    { 0x77F6, "sanfran_intro_screen" },
    { 0x77F7, "sanfran_locations" },
    { 0x77F8, "sarray_clear" },
    { 0x77F9, "sarray_copy" },
    { 0x77FA, "sarray_create_func_obj" },
    { 0x77FB, "sarray_get" },
    { 0x77FC, "sarray_length" },
    { 0x77FD, "sarray_pop" },
    { 0x77FE, "sarray_push" },
    { 0x77FF, "sarray_set" },
    { 0x7800, "sarray_sort_by_handler" },
    { 0x7801, "sarray_spawn" },
    { 0x7802, "save" },
    { 0x7803, "save_exhaust_hatch" },
    { 0x7804, "save_flank_info" },
    { 0x7805, "save_friendlies" },
    { 0x7806, "save_game_big_jump" },
    { 0x7807, "save_game_drone_swarm_street_begin" },
    { 0x7808, "save_game_start_building_fob" },
    { 0x7809, "save_game_when_dead" },
    { 0x780A, "save_ignore_setting" },
    { 0x780B, "save_intel_for_all_players" },
    { 0x780C, "save_redo_buffer" },
    { 0x780D, "save_turret_sharing_info" },
    { 0x780E, "save_undo_buffer" },
    { 0x780F, "savecommit_aftergrenade" },
    { 0x7810, "saved" },
    { 0x7811, "saved_actionslotdata" },
    { 0x7812, "saved_bg_viewbobmax" },
    { 0x7813, "saved_hud_damagefeedback" },
    { 0x7814, "saved_lastweapon" },
    { 0x7815, "saved_targetname" },
    { 0x7816, "savedata" },
    { 0x7817, "savedcompassfadetime" },
    { 0x7818, "savedefaultturnrate" },
    { 0x7819, "savednotify" },
    { 0x781A, "savedorigin" },
    { 0x781B, "savedposition" },
    { 0x781C, "saveheadicon" },
    { 0x781D, "savehere" },
    { 0x781E, "saveplayerweaponstatepersistent" },
    { 0x781F, "savetostructfn" },
    { 0x7820, "saw_mgturretlink" },
    { 0x7821, "sawcorpse" },
    { 0x7822, "sawenemymove" },
    { 0x7823, "saydamaged" },
    { 0x7824, "saygenericdialogue" },
    { 0x7825, "saying_vo" },
    { 0x7826, "saylocalsound" },
    { 0x7827, "saylocalsounddelayed" },
    { 0x7828, "sayspecificdialogue" },
    { 0x7829, "sbadplacename" },
    { 0x782A, "scaffolding_update_my_volume_think" },
    { 0x782B, "scalar_actual" },
    { 0x782C, "scalar_target" },
    { 0x782D, "scale" },
    { 0x782E, "scale_3d_hint_button" },
    { 0x782F, "scale_3d_hud_elem" },
    { 0x7830, "scale_flame_sound_logic2" },
    { 0x7831, "scale_missile_reticle_with_dist" },
    { 0x7832, "scale_vehicle_speed" },
    { 0x7833, "scaler" },
    { 0x7834, "scalesoundsonexit" },
    { 0x7835, "scalestickinput" },
    { 0x7836, "scalevelocity" },
    { 0x7837, "scan_space_with_noise" },
    { 0x7838, "scancamerafoundpotentialtarget" },
    { 0x7839, "scancamerainitvariables" },
    { 0x783A, "scancameraswitching" },
    { 0x783B, "scancameratargetdialogue" },
    { 0x783C, "scancounter" },
    { 0x783D, "scanfadeintro" },
    { 0x783E, "scanfadeoutro" },
    { 0x783F, "scanforrocketenemies" },
    { 0x7840, "scaninitremindermonitor" },
    { 0x7841, "scanlinemeshes" },
    { 0x7842, "scanner_beam" },
    { 0x7843, "scanner_cone_inside_ents" },
    { 0x7844, "scanner_forward" },
    { 0x7845, "scanner_front_door_close" },
    { 0x7846, "scanner_front_door_open" },
    { 0x7847, "scanner_local_velocity" },
    { 0x7848, "scanner_local_yaw" },
    { 0x7849, "scanner_mode" },
    { 0x784A, "scanner_monitor_emp_damage" },
    { 0x784B, "scanner_offset_from_vehicle_facing" },
    { 0x784C, "scanner_origin" },
    { 0x784D, "scanner_pa_vo" },
    { 0x784E, "scanner_pause_timer" },
    { 0x784F, "scanner_rear_door_close" },
    { 0x7850, "scanner_return" },
    { 0x7851, "scanner_rumble" },
    { 0x7852, "scanner_sweep_direction" },
    { 0x7853, "scanner_tilt" },
    { 0x7854, "scanner_yaw" },
    { 0x7855, "scanning" },
    { 0x7856, "scanprogress" },
    { 0x7857, "scantag" },
    { 0x7858, "scantagaudio" },
    { 0x7859, "scantakestoolongmonitor" },
    { 0x785A, "scantime" },
    { 0x785B, "scavenger_altmode" },
    { 0x785C, "scavenger_secondary" },
    { 0x785D, "scene_control_room_ai" },
    { 0x785E, "scene_control_room_fade_up" },
    { 0x785F, "scene_enemy_walk_setup_loops" },
    { 0x7860, "scene_intro_walk" },
    { 0x7861, "scene_models" },
    { 0x7862, "scene_origin" },
    { 0x7863, "scene_s1_in_elevator" },
    { 0x7864, "scene_walk" },
    { 0x7865, "schedule_remove_avatar" },
    { 0x7866, "school_animated_fences" },
    { 0x7867, "school_begin_onbike" },
    { 0x7868, "school_bodies_room_no_crouching" },
    { 0x7869, "school_burke_external" },
    { 0x786A, "school_deadroom_dialogue" },
    { 0x786B, "school_dialogue" },
    { 0x786C, "school_drone_spawn" },
    { 0x786D, "school_enter_dialogue" },
    { 0x786E, "school_exterior_cleaning_crew_dialogue" },
    { 0x786F, "school_exterior_dialogue" },
    { 0x7870, "school_fall" },
    { 0x7871, "school_fall_frame_hide" },
    { 0x7872, "school_fall_into_basement" },
    { 0x7873, "school_fall_rumble" },
    { 0x7874, "school_fall_slowmo_lerp" },
    { 0x7875, "school_funtions_to_load" },
    { 0x7876, "school_jeep_light_tgl" },
    { 0x7877, "school_kva_basement_dialogue" },
    { 0x7878, "school_kva_basement_rats_dialogue" },
    { 0x7879, "school_kva_fall_notice_guy" },
    { 0x787A, "school_kva_spot_guy" },
    { 0x787B, "school_light_burst_dialogue" },
    { 0x787C, "school_lightning_strike" },
    { 0x787D, "school_main" },
    { 0x787E, "school_objective" },
    { 0x787F, "school_shimmy_dialogue" },
    { 0x7880, "school_stairs_dialogue" },
    { 0x7881, "school_thisway_dialogue" },
    { 0x7882, "school_upthestairs" },
    { 0x7883, "school_wall_grab_rumble" },
    { 0x7884, "schoolfall_start" },
    { 0x7885, "science_room" },
    { 0x7886, "scn_cap_mech_door_closes" },
    { 0x7887, "scn_cap_mech_door_grab" },
    { 0x7888, "scn_truck_sounds" },
    { 0x7889, "score_and_sort_current_spawns" },
    { 0x788A, "score_col" },
    { 0x788B, "score_factor" },
    { 0x788C, "score_fx" },
    { 0x788D, "score_handler" },
    { 0x788E, "score_keeper" },
    { 0x788F, "score_manager_detect_damage" },
    { 0x7890, "score_manager_detect_enemy_death" },
    { 0x7891, "score_manager_detect_timeout" },
    { 0x7892, "score_manager_force_stop" },
    { 0x7893, "score_manager_increase_score" },
    { 0x7894, "score_manager_init" },
    { 0x7895, "score_manager_print_current_score" },
    { 0x7896, "score_manager_print_final_score" },
    { 0x7897, "score_manager_waittill_timeout_or_maxscore" },
    { 0x7898, "scoreatlifestart" },
    { 0x7899, "scorefactors_awayfromenemies" },
    { 0x789A, "scorefactors_domination" },
    { 0x789B, "scorefactors_freeforall" },
    { 0x789C, "scorefactors_hardpoint" },
    { 0x789D, "scorefactors_nearteam" },
    { 0x789E, "scorefactors_safeguard" },
    { 0x789F, "scorefactors_searchandrescue" },
    { 0x78A0, "scorefactors_twar" },
    { 0x78A1, "scorelimitoverride" },
    { 0x78A2, "scorepercentagecutoff" },
    { 0x78A3, "scoreperplayer" },
    { 0x78A4, "scorespawns_awayfromenemies" },
    { 0x78A5, "scorespawns_domination" },
    { 0x78A6, "scorespawns_freeforall" },
    { 0x78A7, "scorespawns_hardpoint" },
    { 0x78A8, "scorespawns_nearteam" },
    { 0x78A9, "scorespawns_safeguard" },
    { 0x78AA, "scorespawns_searchandrescue" },
    { 0x78AB, "scorespawns_twar" },
    { 0x78AC, "scr_anim" },
    { 0x78AD, "scr_anim_viewmodel" },
    { 0x78AE, "scr_anim_vm" },
    { 0x78AF, "scr_anim_vm_index" },
    { 0x78B0, "scr_animsound" },
    { 0x78B1, "scr_animtree" },
    { 0x78B2, "scr_face" },
    { 0x78B3, "scr_goaltime" },
    { 0x78B4, "scr_look" },
    { 0x78B5, "scr_model" },
    { 0x78B6, "scr_notetrack" },
    { 0x78B7, "scr_prim_lght" },
    { 0x78B8, "scr_prim_light" },
    { 0x78B9, "scr_radio" },
    { 0x78BA, "scr_sound" },
    { 0x78BB, "scr_stub" },
    { 0x78BC, "scr_text" },
    { 0x78BD, "scr_viewanim" },
    { 0x78BE, "scramble_amb_siren_loop" },
    { 0x78BF, "scramble_siren_01" },
    { 0x78C0, "scramble_siren_setup" },
    { 0x78C1, "scrambleatlasrpg" },
    { 0x78C2, "scramblecivdrones" },
    { 0x78C3, "scramblecivfinale" },
    { 0x78C4, "scramblecivhotel" },
    { 0x78C5, "scramblecivhothall" },
    { 0x78C6, "scrambleciviliancower" },
    { 0x78C7, "scramblecivilianflee" },
    { 0x78C8, "scramblecivpatio" },
    { 0x78C9, "scramblecivpool" },
    { 0x78CA, "scramblecivrestaurant" },
    { 0x78CB, "scramblecivrestaurantdooropener" },
    { 0x78CC, "scramblecivsetup" },
    { 0x78CD, "scrambled" },
    { 0x78CE, "scrambledestroycafewall" },
    { 0x78CF, "scrambledronesfightreminderdialogue" },
    { 0x78D0, "scrambledronesplayerrestaurantreminderdialogue" },
    { 0x78D1, "scrambleeventcurrent" },
    { 0x78D2, "scrambleevents" },
    { 0x78D3, "scramblefailplayerleftilanadialogue" },
    { 0x78D4, "scramblefinalealldronesdeaddialogue" },
    { 0x78D5, "scramblefinaleallies" },
    { 0x78D6, "scramblefinalecar" },
    { 0x78D7, "scramblefinaleextrawoundedally" },
    { 0x78D8, "scramblefinalefirstwoundedally" },
    { 0x78D9, "scramblefinaleplayermovetruckreminderdialogue" },
    { 0x78DA, "scramblefinaleplayeruserpgreminderdialogue" },
    { 0x78DB, "scramblefinalesuppresssniperdialogue" },
    { 0x78DC, "scramblefiredamagemonitor" },
    { 0x78DD, "scramblegapjumpslomo" },
    { 0x78DE, "scramblehideplayergapjump" },
    { 0x78DF, "scramblehotelilanafirstdialogue" },
    { 0x78E0, "scramblehotelilanahitdialogue" },
    { 0x78E1, "scramblehoteljumpdownreminderdialogue" },
    { 0x78E2, "scramblehotelleapfrogcompletedialogue" },
    { 0x78E3, "scramblehotelplayerfirstdialogue" },
    { 0x78E4, "scramblehotelplayerrunreminderdialogue" },
    { 0x78E5, "scramblehotelsuppressorrunreminderdialogue" },
    { 0x78E6, "scramblehotelsuppresssniperreminderdialogue" },
    { 0x78E7, "scramblehothallciv" },
    { 0x78E8, "scrambleid" },
    { 0x78E9, "scrambleilanagapjump" },
    { 0x78EA, "scrambleintrogapjumpreminderdialogue" },
    { 0x78EB, "scrambleintrothroughdoorreminderdialogue" },
    { 0x78EC, "scramblejumprumbleheavy" },
    { 0x78ED, "scramblejumprumblelight" },
    { 0x78EE, "scramblemodifyplayerviewkick" },
    { 0x78EF, "scramblemonitormovetruckhint" },
    { 0x78F0, "scrambleplayercafejump" },
    { 0x78F1, "scrambleplayerfishtankstumble" },
    { 0x78F2, "scrambleplayergapjump" },
    { 0x78F3, "scrambleplayerhoteljump" },
    { 0x78F4, "scrambleplayerjumpwatcher" },
    { 0x78F5, "scrambleplayerleaps" },
    { 0x78F6, "scrambler_light" },
    { 0x78F7, "scrambler_light_off" },
    { 0x78F8, "scramblerbeepsounds" },
    { 0x78F9, "scramblerdamagelistener" },
    { 0x78FA, "scramblerestaurantcivexit" },
    { 0x78FB, "scramblerestaurantdoorsopen" },
    { 0x78FC, "scramblerestaurantexitclip" },
    { 0x78FD, "scramblerproximitytracker" },
    { 0x78FE, "scramblers" },
    { 0x78FF, "scramblersetup" },
    { 0x7900, "scrambleruselistener" },
    { 0x7901, "scramblerwatchowner" },
    { 0x7902, "scramblesetupexittruck" },
    { 0x7903, "scramblesniperkillplayerfailmsg" },
    { 0x7904, "scramblesniperragdoll" },
    { 0x7905, "scramblesnipertowerdestruction" },
    { 0x7906, "scramblesnipertowerdestructionshake" },
    { 0x7907, "scramblespawndronesa" },
    { 0x7908, "scramblespawndronesb" },
    { 0x7909, "scramblestartdoorinit" },
    { 0x790A, "scramblestartdoorshots" },
    { 0x790B, "scrambletruckfiredamagevol" },
    { 0x790C, "scrambletruckpushrumbleheavy" },
    { 0x790D, "scramblevehicleexplodeondeath" },
    { 0x790E, "scramblevisitorcentergateopen" },
    { 0x790F, "scramproxyactive" },
    { 0x7910, "scramproxyperk" },
    { 0x7911, "scrape_pos" },
    { 0x7912, "scrape_sounds" },
    { 0x7913, "scrapeenabled" },
    { 0x7914, "scrapefadeouttime" },
    { 0x7915, "scrapeseperationtime" },
    { 0x7916, "scrapeupdaterate" },
    { 0x7917, "screen" },
    { 0x7918, "screen_detailed_alpha" },
    { 0x7919, "screen_effect_base" },
    { 0x791A, "screen_effect_fade" },
    { 0x791B, "screen_effect_on_open_bottom" },
    { 0x791C, "screen_effect_on_open_side" },
    { 0x791D, "screen_effect_sides" },
    { 0x791E, "screen_fade" },
    { 0x791F, "screen_fade_in" },
    { 0x7920, "screen_fade_out" },
    { 0x7921, "screen_flicker" },
    { 0x7922, "screen_flicker_full" },
    { 0x7923, "screen_flicker_full_solo" },
    { 0x7924, "screenangle" },
    { 0x7925, "screeneffect" },
    { 0x7926, "screennamemap" },
    { 0x7927, "screenpos" },
    { 0x7928, "screenshakefade" },
    { 0x7929, "script_accel" },
    { 0x792A, "script_accel_fraction" },
    { 0x792B, "script_accumulate" },
    { 0x792C, "script_accuracy" },
    { 0x792D, "script_ai_invulnerable" },
    { 0x792E, "script_aigroup" },
    { 0x792F, "script_airresistance" },
    { 0x7930, "script_airspeed" },
    { 0x7931, "script_allow_driver_death" },
    { 0x7932, "script_allow_rider_death" },
    { 0x7933, "script_allow_rider_deaths" },
    { 0x7934, "script_allowdeath" },
    { 0x7935, "script_ammo_alt_clip" },
    { 0x7936, "script_ammo_alt_extra" },
    { 0x7937, "script_ammo_clip" },
    { 0x7938, "script_ammo_extra" },
    { 0x7939, "script_ammo_max" },
    { 0x793A, "script_angles" },
    { 0x793B, "script_anglevehicle" },
    { 0x793C, "script_animation" },
    { 0x793D, "script_animname" },
    { 0x793E, "script_area" },
    { 0x793F, "script_assaultnode" },
    { 0x7940, "script_attackai" },
    { 0x7941, "script_attackeraccuracy" },
    { 0x7942, "script_attackmetype" },
    { 0x7943, "script_attackpattern" },
    { 0x7944, "script_attackspeed" },
    { 0x7945, "script_audio_blend_mode" },
    { 0x7946, "script_audio_enter_func" },
    { 0x7947, "script_audio_enter_msg" },
    { 0x7948, "script_audio_exit_func" },
    { 0x7949, "script_audio_exit_msg" },
    { 0x794A, "script_audio_point_func" },
    { 0x794B, "script_audio_progress_func" },
    { 0x794C, "script_audio_progress_map" },
    { 0x794D, "script_audio_progress_msg" },
    { 0x794E, "script_audio_update_rate" },
    { 0x794F, "script_audio_use_distance_only" },
    { 0x7950, "script_audio_zones" },
    { 0x7951, "script_autosave" },
    { 0x7952, "script_autosavename" },
    { 0x7953, "script_autotarget" },
    { 0x7954, "script_avoidplayer" },
    { 0x7955, "script_avoidvehicles" },
    { 0x7956, "script_axial" },
    { 0x7957, "script_badplace" },
    { 0x7958, "script_balcony" },
    { 0x7959, "script_baseoffire" },
    { 0x795A, "script_battlechatter" },
    { 0x795B, "script_battleplan" },
    { 0x795C, "script_bcdialog" },
    { 0x795D, "script_bctrigger" },
    { 0x795E, "script_bg_offset" },
    { 0x795F, "script_bombmode_dual" },
    { 0x7960, "script_bombmode_original" },
    { 0x7961, "script_bombmode_single" },
    { 0x7962, "script_brake" },
    { 0x7963, "script_breach_id" },
    { 0x7964, "script_breachgroup" },
    { 0x7965, "script_bulletshield" },
    { 0x7966, "script_burst" },
    { 0x7967, "script_burst_max" },
    { 0x7968, "script_burst_min" },
    { 0x7969, "script_button" },
    { 0x796A, "script_car_on_left" },
    { 0x796B, "script_car_on_right" },
    { 0x796C, "script_careful" },
    { 0x796D, "script_cars" },
    { 0x796E, "script_chance" },
    { 0x796F, "script_char_group" },
    { 0x7970, "script_char_index" },
    { 0x7971, "script_chatgroup" },
    { 0x7972, "script_cheap" },
    { 0x7973, "script_cleartargetyaw" },
    { 0x7974, "script_cobratarget" },
    { 0x7975, "script_color_allies" },
    { 0x7976, "script_color_axis" },
    { 0x7977, "script_color_delay_override" },
    { 0x7978, "script_colorlast" },
    { 0x7979, "script_color_assign_intelligently" },
    { 0x797A, "script_combatbehavior" },
    { 0x797B, "script_combatmode" },
    { 0x797C, "script_count" },
    { 0x797D, "script_count_max" },
    { 0x797E, "script_count_min" },
    { 0x797F, "script_crashtype" },
    { 0x7980, "script_crashtypeoverride" },
    { 0x7981, "script_damage" },
    { 0x7982, "script_danger_react" },
    { 0x7983, "script_death" },
    { 0x7984, "script_death_max" },
    { 0x7985, "script_death_min" },
    { 0x7986, "script_deathchain" },
    { 0x7987, "script_deathflag" },
    { 0x7988, "script_deathflag_longdeath" },
    { 0x7989, "script_deathroll" },
    { 0x798A, "script_deathtime" },
    { 0x798B, "script_decel" },
    { 0x798C, "script_decel_fraction" },
    { 0x798D, "script_delay_max" },
    { 0x798E, "script_delay_min" },
    { 0x798F, "script_delay_post" },
    { 0x7990, "script_delay_spawn" },
    { 0x7991, "script_delayed_playerseek" },
    { 0x7992, "script_delete" },
    { 0x7993, "script_deleteai" },
    { 0x7994, "script_dest_cover_chunkfx" },
    { 0x7995, "script_dest_cover_chunkhealth" },
    { 0x7996, "script_dest_cover_chunksnd" },
    { 0x7997, "script_dest_cover_dmg_dist" },
    { 0x7998, "script_dest_cover_dmg_model" },
    { 0x7999, "script_dest_cover_numchunks" },
    { 0x799A, "script_destruct_collision" },
    { 0x799B, "script_destructable_area" },
    { 0x799C, "script_destructible_tree_think" },
    { 0x799D, "script_diequietly" },
    { 0x799E, "script_difficulty" },
    { 0x799F, "script_disablevehicleaudio" },
    { 0x79A0, "script_disconnectpaths" },
    { 0x79A1, "script_displaceable" },
    { 0x79A2, "script_dof_far_blur" },
    { 0x79A3, "script_dof_far_end" },
    { 0x79A4, "script_dof_far_start" },
    { 0x79A5, "script_dof_near_blur" },
    { 0x79A6, "script_dof_near_end" },
    { 0x79A7, "script_dof_near_start" },
    { 0x79A8, "script_dont_link_turret" },
    { 0x79A9, "script_dontpeek" },
    { 0x79AA, "script_dontshootwhilemoving" },
    { 0x79AB, "script_dontunloadonend" },
    { 0x79AC, "script_dot" },
    { 0x79AD, "script_drone" },
    { 0x79AE, "script_drone_override" },
    { 0x79AF, "script_drone_repeat_count" },
    { 0x79B0, "script_dronelag" },
    { 0x79B1, "script_drones_max" },
    { 0x79B2, "script_drones_min" },
    { 0x79B3, "script_dronestartmove" },
    { 0x79B4, "script_duration" },
    { 0x79B5, "script_earthquake" },
    { 0x79B6, "script_emptyspawner" },
    { 0x79B7, "script_end_flag_clear" },
    { 0x79B8, "script_ender" },
    { 0x79B9, "script_engage" },
    { 0x79BA, "script_engagedelay" },
    { 0x79BB, "script_ent_flag_clear" },
    { 0x79BC, "script_ent_flag_set" },
    { 0x79BD, "script_ent_flag_wait" },
    { 0x79BE, "script_explode" },
    { 0x79BF, "script_exploder" },
    { 0x79C0, "script_exploder_delay" },
    { 0x79C1, "script_exploder_group" },
    { 0x79C2, "script_explosive_bullet_shield" },
    { 0x79C3, "script_faceangles" },
    { 0x79C4, "script_faceenemydist" },
    { 0x79C5, "script_facing" },
    { 0x79C6, "script_fallback" },
    { 0x79C7, "script_fallback_group" },
    { 0x79C8, "script_falldirection" },
    { 0x79C9, "script_favoriteenemy" },
    { 0x79CA, "script_fightdist" },
    { 0x79CB, "script_firefx" },
    { 0x79CC, "script_firefxdelay" },
    { 0x79CD, "script_firefxsound" },
    { 0x79CE, "script_firefxtimeout" },
    { 0x79CF, "script_firelink" },
    { 0x79D0, "script_fireondrones" },
    { 0x79D1, "script_fixednode" },
    { 0x79D2, "script_fixedposition" },
    { 0x79D3, "script_flag" },
    { 0x79D4, "script_flag_clear" },
    { 0x79D5, "script_flag_delay" },
    { 0x79D6, "script_flag_false" },
    { 0x79D7, "script_flag_flase" },
    { 0x79D8, "script_flag_set" },
    { 0x79D9, "script_flag_true" },
    { 0x79DA, "script_flag_wait" },
    { 0x79DB, "script_flagwait" },
    { 0x79DC, "script_flakaicount" },
    { 0x79DD, "script_flanker" },
    { 0x79DE, "script_flashbangs" },
    { 0x79DF, "script_flowrate" },
    { 0x79E0, "script_fogset_end" },
    { 0x79E1, "script_fogset_start" },
    { 0x79E2, "script_followmax" },
    { 0x79E3, "script_followmin" },
    { 0x79E4, "script_followmode" },
    { 0x79E5, "script_force_count" },
    { 0x79E6, "script_forcecolor" },
    { 0x79E7, "script_forcefire_delay" },
    { 0x79E8, "script_forcefire_duration" },
    { 0x79E9, "script_forcegoal" },
    { 0x79EA, "script_forcegrenade" },
    { 0x79EB, "script_forcespawn" },
    { 0x79EC, "script_forceyaw" },
    { 0x79ED, "script_friendly_fire_disable" },
    { 0x79EE, "script_friendname" },
    { 0x79EF, "script_friendnames" },
    { 0x79F0, "script_fxcommand" },
    { 0x79F1, "script_fxid" },
    { 0x79F2, "script_fxstart" },
    { 0x79F3, "script_fxstop" },
    { 0x79F4, "script_gameobjectname" },
    { 0x79F5, "script_gametype_atdm" },
    { 0x79F6, "script_gametype_ctf" },
    { 0x79F7, "script_gametype_dm" },
    { 0x79F8, "script_gametype_hq" },
    { 0x79F9, "script_gametype_koth" },
    { 0x79FA, "script_gametype_sd" },
    { 0x79FB, "script_gametype_tdm" },
    { 0x79FC, "script_gatetrigger" },
    { 0x79FD, "script_ghettotag" },
    { 0x79FE, "script_goal_radius" },
    { 0x79FF, "script_goal_type" },
    { 0x7A00, "script_goal_yaw" },
    { 0x7A01, "script_goalheight" },
    { 0x7A02, "script_goalpitch" },
    { 0x7A03, "script_goalvolume" },
    { 0x7A04, "script_goalyaw" },
    { 0x7A05, "script_god_mode" },
    { 0x7A06, "script_godmode" },
    { 0x7A07, "script_grenades" },
    { 0x7A08, "script_grenadeshield" },
    { 0x7A09, "script_grenadespeed" },
    { 0x7A0A, "script_group" },
    { 0x7A0B, "script_growl" },
    { 0x7A0C, "script_health" },
    { 0x7A0D, "script_helimove" },
    { 0x7A0E, "script_hidden" },
    { 0x7A0F, "script_hint" },
    { 0x7A10, "script_hoverwait" },
    { 0x7A11, "script_idleanim" },
    { 0x7A12, "script_idlereach" },
    { 0x7A13, "script_ignore_suppression" },
    { 0x7A14, "script_ignoreall" },
    { 0x7A15, "script_ignoreme" },
    { 0x7A16, "script_immunetoflash" },
    { 0x7A17, "script_increment" },
    { 0x7A18, "script_index" },
    { 0x7A19, "script_intensity_max" },
    { 0x7A1A, "script_intensity_min" },
    { 0x7A1B, "script_keepdriver" },
    { 0x7A1C, "script_kill_vehicle_spawner" },
    { 0x7A1D, "script_killspawner" },
    { 0x7A1E, "script_killspawner_group" },
    { 0x7A1F, "script_land" },
    { 0x7A20, "script_landmark" },
    { 0x7A21, "script_laser" },
    { 0x7A22, "script_light" },
    { 0x7A23, "script_light_startnotify" },
    { 0x7A24, "script_light_stopnotify" },
    { 0x7A25, "script_linikto" },
    { 0x7A26, "script_linkto" },
    { 0x7A27, "script_location" },
    { 0x7A28, "script_longdeath" },
    { 0x7A29, "script_looping" },
    { 0x7A2A, "script_manualtarget" },
    { 0x7A2B, "script_mapsize_08" },
    { 0x7A2C, "script_mapsize_16" },
    { 0x7A2D, "script_mapsize_32" },
    { 0x7A2E, "script_mapsize_64" },
    { 0x7A2F, "script_max_left_angle" },
    { 0x7A30, "script_max_right_angle" },
    { 0x7A31, "script_maxdist" },
    { 0x7A32, "script_maxspawn" },
    { 0x7A33, "script_mg_angle" },
    { 0x7A34, "script_mg42" },
    { 0x7A35, "script_mg42auto" },
//  { 0x7A36, "" },
    { 0x7A37, "script_mgturret" },
    { 0x7A38, "script_mgturretauto" },
    { 0x7A39, "script_minspec_hooks_level" },
    { 0x7A3A, "script_minspec_level" },
    { 0x7A3B, "script_missiles" },
    { 0x7A3C, "script_model_anims" },
    { 0x7A3D, "script_modelname" },
    { 0x7A3E, "script_models" },
    { 0x7A3F, "script_mortargroup" },
    { 0x7A40, "script_moveoverride" },
    { 0x7A41, "script_moveplaybackrate" },
    { 0x7A42, "script_mover" },
    { 0x7A43, "script_mover_add_animation" },
    { 0x7A44, "script_mover_add_hintstring" },
    { 0x7A45, "script_mover_add_parameters" },
    { 0x7A46, "script_mover_agent_spawn_watch" },
    { 0x7A47, "script_mover_allow_usable" },
    { 0x7A48, "script_mover_animate" },
    { 0x7A49, "script_mover_animations" },
    { 0x7A4A, "script_mover_apply_move_parameters" },
    { 0x7A4B, "script_mover_classnames" },
    { 0x7A4C, "script_mover_connect_watch" },
    { 0x7A4D, "script_mover_connectpaths" },
    { 0x7A4E, "script_mover_defaults" },
    { 0x7A4F, "script_mover_delay" },
    { 0x7A50, "script_mover_delete" },
    { 0x7A51, "script_mover_disconnectpaths" },
    { 0x7A52, "script_mover_func_on_notify" },
    { 0x7A53, "script_mover_handle_notetracks" },
    { 0x7A54, "script_mover_hide" },
    { 0x7A55, "script_mover_hintstrings" },
    { 0x7A56, "script_mover_init" },
    { 0x7A57, "script_mover_init_move_parameters" },
    { 0x7A58, "script_mover_is_animated" },
    { 0x7A59, "script_mover_is_dynamic_path" },
    { 0x7A5A, "script_mover_is_script_mover" },
    { 0x7A5B, "script_mover_levelnotify" },
    { 0x7A5C, "script_mover_move_to_named_goal" },
    { 0x7A5D, "script_mover_move_to_target" },
    { 0x7A5E, "script_mover_named_goals" },
    { 0x7A5F, "script_mover_notify" },
    { 0x7A60, "script_mover_notsolid" },
    { 0x7A61, "script_mover_parameters" },
    { 0x7A62, "script_mover_parse_ent" },
    { 0x7A63, "script_mover_parse_move_parameters" },
    { 0x7A64, "script_mover_parse_range" },
    { 0x7A65, "script_mover_parse_targets" },
    { 0x7A66, "script_mover_play_animation" },
    { 0x7A67, "script_mover_reset" },
    { 0x7A68, "script_mover_reset_init" },
    { 0x7A69, "script_mover_save_default_move_parameters" },
    { 0x7A6A, "script_mover_set_defaults" },
    { 0x7A6B, "script_mover_set_param" },
    { 0x7A6C, "script_mover_set_usable" },
    { 0x7A6D, "script_mover_show" },
    { 0x7A6E, "script_mover_solid" },
    { 0x7A6F, "script_mover_start" },
    { 0x7A70, "script_mover_trigger" },
    { 0x7A71, "script_mover_trigger_off" },
    { 0x7A72, "script_mover_trigger_on" },
    { 0x7A73, "script_mover_update_paths" },
    { 0x7A74, "script_mover_use_trigger" },
    { 0x7A75, "script_mover_watch_for_reset" },
    { 0x7A76, "script_mp_style_helicopter" },
    { 0x7A77, "script_multiplier" },
    { 0x7A78, "script_namenumber" },
    { 0x7A79, "script_nobark" },
    { 0x7A7A, "script_nobloodpool" },
    { 0x7A7B, "script_node_pausetime" },
    { 0x7A7C, "script_nodestate" },
    { 0x7A7D, "script_nodrop" },
    { 0x7A7E, "script_noflip" },
    { 0x7A7F, "script_nofriendlywave" },
    { 0x7A80, "script_nohealth" },
    { 0x7A81, "script_nomg" },
    { 0x7A82, "script_nostairs" },
    { 0x7A83, "script_nosurprise" },
    { 0x7A84, "script_noteworthy2" },
    { 0x7A85, "script_notify" },
    { 0x7A86, "script_noturnanim" },
    { 0x7A87, "script_notworthy" },
    { 0x7A88, "script_nowall" },
    { 0x7A89, "script_objective" },
    { 0x7A8A, "script_objective_active" },
    { 0x7A8B, "script_objective_inactive" },
    { 0x7A8C, "script_objectname" },
    { 0x7A8D, "script_offradius" },
    { 0x7A8E, "script_offtime" },
    { 0x7A8F, "script_old_forcecolor" },
    { 0x7A90, "script_oneway" },
    { 0x7A91, "script_onlyidle" },
    { 0x7A92, "script_origin_other" },
    { 0x7A93, "script_origin_roof" },
    { 0x7A94, "script_origin_target_array" },
    { 0x7A95, "script_pacifist" },
    { 0x7A96, "script_painter_maxdist" },
    { 0x7A97, "script_painter_treeorient" },
    { 0x7A98, "script_paintergroup" },
    { 0x7A99, "script_parameters" },
    { 0x7A9A, "script_params" },
    { 0x7A9B, "script_pathtype" },
    { 0x7A9C, "script_patroller" },
    { 0x7A9D, "script_percent" },
    { 0x7A9E, "script_personality" },
    { 0x7A9F, "script_pet" },
    { 0x7AA0, "script_physics" },
    { 0x7AA1, "script_physicsjolt" },
    { 0x7AA2, "script_pilottalk" },
    { 0x7AA3, "script_plane" },
    { 0x7AA4, "script_playerconeradius" },
    { 0x7AA5, "script_playerseek" },
    { 0x7AA6, "script_prefab_exploder" },
    { 0x7AA7, "script_presound" },
    { 0x7AA8, "script_print_fx" },
    { 0x7AA9, "script_probe_heli_closed" },
    { 0x7AAA, "script_probe_heli_default" },
    { 0x7AAB, "script_probe_heli_open" },
    { 0x7AAC, "script_probe_heli_reset" },
    { 0x7AAD, "script_probe_pitbull_default" },
    { 0x7AAE, "script_probe_pitbull_tunnel_exterior" },
    { 0x7AAF, "script_probe_pitbull_tunnel_exterior_no_trigger" },
    { 0x7AB0, "script_probe_pitbull_tunnel_interior" },
    { 0x7AB1, "script_qualityspotshadow" },
    { 0x7AB2, "script_radius" },
    { 0x7AB3, "script_random_killspawner" },
    { 0x7AB4, "script_randomspawn" },
    { 0x7AB5, "script_readystand" },
    { 0x7AB6, "script_repeat" },
    { 0x7AB7, "script_requires_player" },
    { 0x7AB8, "script_reuse" },
    { 0x7AB9, "script_reuse_max" },
    { 0x7ABA, "script_reuse_min" },
    { 0x7ABB, "script_rumble" },
    { 0x7ABC, "script_savedata" },
    { 0x7ABD, "script_savetrigger_timer" },
    { 0x7ABE, "script_screen_fxid" },
    { 0x7ABF, "script_seekgoal" },
    { 0x7AC0, "script_self_remove" },
    { 0x7AC1, "script_selfremove" },
    { 0x7AC2, "script_shotcount" },
    { 0x7AC3, "script_side" },
    { 0x7AC4, "script_sightrange" },
    { 0x7AC5, "script_skilloverride" },
    { 0x7AC6, "script_slowmo_breach" },
    { 0x7AC7, "script_slowmo_breach_doortype" },
    { 0x7AC8, "script_slowmo_breach_spawners" },
    { 0x7AC9, "script_smokegroup" },
    { 0x7ACA, "script_sound" },
    { 0x7ACB, "script_soundalias" },
    { 0x7ACC, "script_spawn_here" },
    { 0x7ACD, "script_spawn_once" },
    { 0x7ACE, "script_spawn_pool" },
    { 0x7ACF, "script_spawngroup" },
    { 0x7AD0, "script_spawnsubgroup" },
    { 0x7AD1, "script_specialops" },
    { 0x7AD2, "script_specialopsname" },
    { 0x7AD3, "script_speed" },
    { 0x7AD4, "script_spotlight" },
    { 0x7AD5, "script_spotlimit" },
    { 0x7AD6, "script_squad" },
    { 0x7AD7, "script_squadname" },
    { 0x7AD8, "script_stack" },
    { 0x7AD9, "script_stance" },
    { 0x7ADA, "script_start" },
    { 0x7ADB, "script_startinghealth" },
    { 0x7ADC, "script_startingposition" },
    { 0x7ADD, "script_startname" },
    { 0x7ADE, "script_startrunning" },
    { 0x7ADF, "script_state_compare" },
    { 0x7AE0, "script_stay_drone" },
    { 0x7AE1, "script_stealth" },
    { 0x7AE2, "script_stealth_dontseek" },
    { 0x7AE3, "script_stealth_function" },
    { 0x7AE4, "script_stealthgroup" },
    { 0x7AE5, "script_stopnode" },
    { 0x7AE6, "script_stoptoshoot" },
    { 0x7AE7, "script_sunenable" },
    { 0x7AE8, "script_sunsamplesizenear" },
    { 0x7AE9, "script_sunshadowscale" },
    { 0x7AEA, "script_suppression" },
    { 0x7AEB, "script_surfacetype" },
    { 0x7AEC, "script_tankgroup" },
    { 0x7AED, "script_targetoffset_z" },
    { 0x7AEE, "script_targettype" },
    { 0x7AEF, "script_team" },
    { 0x7AF0, "script_tess_distance" },
    { 0x7AF1, "script_tess_falloff" },
    { 0x7AF2, "script_threatbias" },
    { 0x7AF3, "script_threatbiasgroup" },
    { 0x7AF4, "script_threshold" },
    { 0x7AF5, "script_timeout" },
    { 0x7AF6, "script_timer" },
    { 0x7AF7, "script_to_state" },
    { 0x7AF8, "script_trace" },
    { 0x7AF9, "script_transient" },
    { 0x7AFA, "script_transmission" },
    { 0x7AFB, "script_trigger_group" },
    { 0x7AFC, "script_triggered_playerseek" },
    { 0x7AFD, "script_triggername" },
    { 0x7AFE, "script_turningdir" },
    { 0x7AFF, "script_turret" },
    { 0x7B00, "script_turret_ambush" },
    { 0x7B01, "script_turret_reuse_max" },
    { 0x7B02, "script_turret_reuse_min" },
    { 0x7B03, "script_turret_share" },
    { 0x7B04, "script_turretmg" },
    { 0x7B05, "script_type" },
    { 0x7B06, "script_unload" },
    { 0x7B07, "script_unloaddelay" },
    { 0x7B08, "script_unloadmgguy" },
    { 0x7B09, "script_unloadtype" },
    { 0x7B0A, "script_usemg42" },
    { 0x7B0B, "script_usenormals" },
    { 0x7B0C, "script_vehicle_lights_off" },
    { 0x7B0D, "script_vehicle_lights_on" },
    { 0x7B0E, "script_vehicle_move_to_node" },
    { 0x7B0F, "script_vehicle_seflremove" },
    { 0x7B10, "script_vehicle_selfremove" },
    { 0x7B11, "script_vehicleaianim" },
    { 0x7B12, "script_vehiclecargo" },
    { 0x7B13, "script_vehicledetour" },
    { 0x7B14, "script_vehicledetourgroup" },
    { 0x7B15, "script_vehicledetourtype" },
    { 0x7B16, "script_vehiclegroup" },
    { 0x7B17, "script_vehiclegroupdelete" },
    { 0x7B18, "script_vehiclenodegroup" },
    { 0x7B19, "script_vehicleride" },
    { 0x7B1A, "script_vehiclespawngroup" },
    { 0x7B1B, "script_vehiclestartmove" },
    { 0x7B1C, "script_vehicletriggergroup" },
    { 0x7B1D, "script_vehiclewalk" },
    { 0x7B1E, "script_visionset_end" },
    { 0x7B1F, "script_visionset_start" },
    { 0x7B20, "script_wait" },
    { 0x7B21, "script_wait_add" },
    { 0x7B22, "script_wait_max" },
    { 0x7B23, "script_wait_min" },
    { 0x7B24, "script_wheeldirection" },
    { 0x7B25, "script_wingman" },
    { 0x7B26, "script_wtf" },
    { 0x7B27, "script_yawspeed" },
    { 0x7B28, "scriptabilities" },
    { 0x7B29, "scriptable_pillars_light_retarget" },
    { 0x7B2A, "scriptable_primary_light_centerofinterest" },
    { 0x7B2B, "scriptable_primary_light_override" },
    { 0x7B2C, "scriptable_primary_light_setstate" },
    { 0x7B2D, "scriptable_primary_light_setstate_color" },
    { 0x7B2E, "scriptable_primary_light_setstate_cone" },
    { 0x7B2F, "scriptable_primary_light_setstate_dir" },
    { 0x7B30, "scriptable_primary_light_setstate_intensity" },
    { 0x7B31, "scriptable_primary_light_setstate_pos" },
    { 0x7B32, "scriptable_primary_light_setstate_radius" },
    { 0x7B33, "scriptable_primary_light_think" },
    { 0x7B34, "scriptdetour_persist" },
    { 0x7B35, "scripted_dialogue" },
    { 0x7B36, "scripted_elems" },
    { 0x7B37, "scripted_fx_on_struct" },
    { 0x7B38, "scripted_line_delay" },
    { 0x7B39, "scripted_node" },
    { 0x7B3A, "scripted_path_style" },
    { 0x7B3B, "scripted_screen_flicker_loop" },
    { 0x7B3C, "scripted_spawn" },
    { 0x7B3D, "scripted_spin_fan_blades" },
    { 0x7B3E, "scriptedarrivalententity" },
    { 0x7B3F, "scripteddialoguebuffertime" },
    { 0x7B40, "scripteddialoguestarttime" },
    { 0x7B41, "scriptflag" },
    { 0x7B42, "scriptmodel" },
    { 0x7B43, "scriptmodelplayanimwithnotify" },
    { 0x7B44, "scriptmodelplayanimwithnotify_notetracks" },
    { 0x7B45, "scriptperks" },
    { 0x7B46, "scriptstarttime" },
    { 0x7B47, "scripttargets" },
    { 0x7B48, "scrub_guy" },
    { 0x7B49, "scuba_assisted" },
    { 0x7B4A, "scuba_fx_cleanup" },
    { 0x7B4B, "scuba_org" },
    { 0x7B4C, "scubamask_distortion" },
    { 0x7B4D, "sd_1st_int_window_goal" },
    { 0x7B4E, "sd_anim_generic_reach_and_play" },
    { 0x7B4F, "sd_anim_reach_and_play_loop" },
    { 0x7B50, "sd_autosave_check" },
    { 0x7B51, "sd_bomb_just_planted" },
    { 0x7B52, "sd_bombs" },
    { 0x7B53, "sd_bombzones" },
    { 0x7B54, "sd_drone_kamikaze" },
    { 0x7B55, "sd_drone_patrol_think" },
    { 0x7B56, "sd_endgame" },
    { 0x7B57, "sd_flee_drone_swarm" },
    { 0x7B58, "sd_force_patrol1_anim_set" },
    { 0x7B59, "sd_glass_projection_setup" },
    { 0x7B5A, "sd_glass_projection_think" },
    { 0x7B5B, "sd_handle_glass_smash" },
    { 0x7B5C, "sd_intersection_chopper" },
    { 0x7B5D, "sd_intersection2_smoke_and_spawn" },
    { 0x7B5E, "sd_intersection3_smoke_laser_spawn" },
    { 0x7B5F, "sd_loadout" },
    { 0x7B60, "sd_onbombtimerend" },
    { 0x7B61, "sd_panel_impact" },
    { 0x7B62, "sd_path_check1" },
    { 0x7B63, "sd_patrol1_command" },
    { 0x7B64, "sd_patrol1_player_close_check" },
    { 0x7B65, "sd_press_use" },
    { 0x7B66, "sd_shop_logo_control" },
    { 0x7B67, "sd_smoke_laser_ambush" },
    { 0x7B68, "sd_snake_crash_into_player" },
    { 0x7B69, "sd_spawn_and_retreat_goals" },
    { 0x7B6A, "sd_spawn_crossfire_2nd_floor_enemies" },
    { 0x7B6B, "sd_spawn_turret_truck" },
    { 0x7B6C, "sd_spawn_zipline_group1" },
    { 0x7B6D, "sd_spawn_zipline_group2" },
    { 0x7B6E, "sd_street_combat" },
    { 0x7B6F, "sd_switch_axis_colors" },
    { 0x7B70, "sd_triggers" },
    { 0x7B71, "sd_upstairs_enemies_spawn" },
    { 0x7B72, "sd_vo_inside_restaurant" },
    { 0x7B73, "sd_zipline_enemy_think" },
    { 0x7B74, "sdbomb" },
    { 0x7B75, "sdbombmodel" },
    { 0x7B76, "sdrone_weapon_fire_sound_next" },
    { 0x7B77, "sdrone_weapon_fire_sounds" },
    { 0x7B78, "se_balcony_finale" },
    { 0x7B79, "se_balcony_finale_balcony" },
    { 0x7B7A, "se_balcony_finale_irons" },
    { 0x7B7B, "se_balcony_finale_player" },
    { 0x7B7C, "se_balcony_finale_player_speed" },
    { 0x7B7D, "se_balcony_part1_up_to_tackle" },
    { 0x7B7E, "se_balcony_reveal_head_sway" },
    { 0x7B7F, "se_breach_guards" },
    { 0x7B80, "se_breach_patrol_guy_01" },
    { 0x7B81, "se_breach_patrol_guy_02" },
    { 0x7B82, "se_bridge_takedown" },
    { 0x7B83, "se_burke_cover_tree_wave" },
    { 0x7B84, "se_burke_dive_over_log" },
    { 0x7B85, "se_burke_forest_wall_climb" },
    { 0x7B86, "se_burke_hill_slide" },
    { 0x7B87, "se_burke_river_cross" },
    { 0x7B88, "se_burke_river_over_log" },
    { 0x7B89, "se_burke_river_to_wall" },
    { 0x7B8A, "se_burke_stumble_knee" },
    { 0x7B8B, "se_burke_stumble_run" },
    { 0x7B8C, "se_burke_takedown_01" },
    { 0x7B8D, "se_burke_tree_cover_01" },
    { 0x7B8E, "se_burke_tree_stump" },
    { 0x7B8F, "se_burke_tree_to_wall" },
    { 0x7B90, "se_canal_breach" },
    { 0x7B91, "se_check_player_too_far_from_burke" },
    { 0x7B92, "se_cormack_meet" },
    { 0x7B93, "se_cormack_meet_init" },
    { 0x7B94, "se_door_kick" },
    { 0x7B95, "se_exfil" },
    { 0x7B96, "se_exfil_fx" },
    { 0x7B97, "se_exfil_razorback" },
    { 0x7B98, "se_exhaust_hatch" },
    { 0x7B99, "se_exhaust_hatch_player" },
    { 0x7B9A, "se_exhaust_land" },
    { 0x7B9B, "se_facility_breach" },
    { 0x7B9C, "se_foam_corridor" },
    { 0x7B9D, "se_foam_corridor_approach" },
    { 0x7B9E, "se_foam_corridor_bomb" },
    { 0x7B9F, "se_foam_corridor_grenade" },
    { 0x7BA0, "se_foam_corridor_guy_4" },
    { 0x7BA1, "se_foam_room" },
    { 0x7BA2, "se_foam_room_bomb" },
    { 0x7BA3, "se_foam_room_player" },
    { 0x7BA4, "se_forest_takedown_01" },
    { 0x7BA5, "se_forest_takedown_01_distance_think" },
    { 0x7BA6, "se_forest_takedown_01_fail_conditions" },
    { 0x7BA7, "se_hovertank_exit" },
    { 0x7BA8, "se_hovertank_exit_cormack_shadow" },
    { 0x7BA9, "se_hovertank_exit_cover_fire" },
    { 0x7BAA, "se_hovertank_exit_cover_fire_cleanup" },
    { 0x7BAB, "se_hovertank_mount" },
    { 0x7BAC, "se_hovertank_reveal" },
    { 0x7BAD, "se_hovertank_reveal_actor" },
    { 0x7BAE, "se_hovertank_reveal_lift_think" },
    { 0x7BAF, "se_intro" },
    { 0x7BB0, "se_intro_ambient_jets" },
    { 0x7BB1, "se_intro_ambient_warbirds" },
    { 0x7BB2, "se_intro_burke_react" },
    { 0x7BB3, "se_intro_flyin_gideon" },
    { 0x7BB4, "se_intro_missiles" },
    { 0x7BB5, "se_intro_shack" },
    { 0x7BB6, "se_irons_chase" },
    { 0x7BB7, "se_irons_elevator_doors" },
    { 0x7BB8, "se_irons_end_helo" },
    { 0x7BB9, "se_irons_react_to_gunfire" },
    { 0x7BBA, "se_irons_reveal" },
    { 0x7BBB, "se_irons_reveal_exo" },
    { 0x7BBC, "se_irons_reveal_handle_button_prompts_on_arm" },
    { 0x7BBD, "se_irons_reveal_handle_material_swap" },
    { 0x7BBE, "se_irons_reveal_head_jolt" },
    { 0x7BBF, "se_irons_reveal_head_sway" },
    { 0x7BC0, "se_irons_reveal_monitor_button_on_arm" },
    { 0x7BC1, "se_irons_reveal_pt2_gideon" },
    { 0x7BC2, "se_knox_courtyard_hangar_door_hack_open" },
    { 0x7BC3, "se_kva_basement_2" },
    { 0x7BC4, "se_kva_basement_2_idle" },
    { 0x7BC5, "se_link_player_to_rig" },
    { 0x7BC6, "se_mech_exit" },
    { 0x7BC7, "se_mech_march" },
    { 0x7BC8, "se_missile_load" },
    { 0x7BC9, "se_player_exfil_out_of_bounds_check" },
    { 0x7BCA, "se_player_hill_slide" },
    { 0x7BCB, "se_player_rig_move_to_irons" },
    { 0x7BCC, "se_search_drone_backup" },
    { 0x7BCD, "se_search_drone_deer" },
    { 0x7BCE, "se_search_drone_spotted_player" },
    { 0x7BCF, "se_search_drone_vehicle" },
    { 0x7BD0, "se_search_drones_01" },
    { 0x7BD1, "se_server_room_entrance" },
    { 0x7BD2, "se_server_room_player_close" },
    { 0x7BD3, "se_server_room_player_kills_guy" },
    { 0x7BD4, "se_server_room_player_misses" },
    { 0x7BD5, "se_slow_player_if_too_far_ahead" },
    { 0x7BD6, "se_vehicle_mute_charge" },
    { 0x7BD7, "se_vehicle_takedown_01" },
    { 0x7BD8, "se_vehicle_takedown_dummyfunc" },
    { 0x7BD9, "se_vehicle_takedown_fail_condition_guy" },
    { 0x7BDA, "se_vehicle_takedown_fail_conditions" },
    { 0x7BDB, "se_vehicle_takedown_stealth_alert_check" },
    { 0x7BDC, "se_wall_climb_roots" },
    { 0x7BDD, "se_will_reveal" },
    { 0x7BDE, "se_will_reveal_irons" },
    { 0x7BDF, "search_drone_alert_monitor" },
    { 0x7BE0, "search_drone_alerted_dialogue" },
    { 0x7BE1, "search_drone_behavior" },
    { 0x7BE2, "search_drone_damage_detection" },
    { 0x7BE3, "search_drone_random_turns" },
    { 0x7BE4, "search_drone_spotted_player" },
    { 0x7BE5, "search_drone_warning_dialogue" },
    { 0x7BE6, "search_drones_count" },
    { 0x7BE7, "search_string" },
    { 0x7BE8, "seattag" },
    { 0x7BE9, "sec_door_breach_anim" },
    { 0x7BEA, "sec_godray" },
    { 0x7BEB, "sec_room_attach_to_elevator" },
    { 0x7BEC, "sec_room_elevator_open" },
    { 0x7BED, "sec_room_move_to_elevator" },
    { 0x7BEE, "sec_trig1" },
    { 0x7BEF, "sec_trig2" },
    { 0x7BF0, "sec_trig3" },
    { 0x7BF1, "sec_trig4" },
    { 0x7BF2, "second_floor_snipers" },
    { 0x7BF3, "second_floor_trigger_think" },
    { 0x7BF4, "second_line_of_fire" },
    { 0x7BF5, "second_nightclub_room_setup" },
    { 0x7BF6, "second_room_nightclub_setup" },
    { 0x7BF7, "secondaryattachment" },
    { 0x7BF8, "secondaryattachment3" },
    { 0x7BF9, "secondarygrenade" },
    { 0x7BFA, "secondaryname" },
    { 0x7BFB, "secondaryreinforcementhinttext" },
    { 0x7BFC, "secondarytarget" },
    { 0x7BFD, "secondaryweaponent" },
    { 0x7BFE, "secondguys_total" },
    { 0x7BFF, "secondguysalive" },
    { 0x7C00, "secondline_alive_check" },
    { 0x7C01, "secondline_flee_check" },
    { 0x7C02, "secondowner" },
    { 0x7C03, "secsoffiringbeforereload" },
    { 0x7C04, "secsoffiringbeforereloaddefault" },
    { 0x7C05, "section_1_civilians" },
    { 0x7C06, "securehardpointevent" },
    { 0x7C07, "securestarted" },
    { 0x7C08, "security_building_entrance" },
    { 0x7C09, "security_camera_dialogue" },
    { 0x7C0A, "security_center_anim_struct" },
    { 0x7C0B, "security_center_begin" },
    { 0x7C0C, "security_center_bink" },
    { 0x7C0D, "security_center_bink_off" },
    { 0x7C0E, "security_center_drones_turn_on" },
    { 0x7C0F, "security_center_drones_turn_on_internal" },
    { 0x7C10, "security_center_drones_turn_on_setup" },
    { 0x7C11, "security_center_exit" },
    { 0x7C12, "security_center_fan_blades" },
    { 0x7C13, "security_center_fan_blades_internal" },
    { 0x7C14, "security_center_guard_exposed_vo_said" },
    { 0x7C15, "security_center_guard_left_tagged" },
    { 0x7C16, "security_center_guard_right_tagged" },
    { 0x7C17, "security_center_guard_spawner_setup" },
    { 0x7C18, "security_center_hatch_trigger" },
    { 0x7C19, "security_center_lights" },
    { 0x7C1A, "security_center_main" },
    { 0x7C1B, "security_center_main_screen_bink" },
    { 0x7C1C, "security_center_player_rig_and_hatch_door_setup" },
    { 0x7C1D, "security_center_rooftop_drone" },
    { 0x7C1E, "security_center_rooftop_obj" },
    { 0x7C1F, "security_center_script_brushmodels" },
    { 0x7C20, "security_center_server_lights" },
    { 0x7C21, "security_center_start" },
    { 0x7C22, "security_center_vo" },
    { 0x7C23, "security_check_1_dialogue" },
    { 0x7C24, "security_checkpoint_trigger_play_beep" },
    { 0x7C25, "security_checkpoint_trigger_think" },
    { 0x7C26, "security_doors_approach" },
    { 0x7C27, "security_drone_attack" },
    { 0x7C28, "security_drone_hit_react" },
    { 0x7C29, "security_drone_sparks" },
    { 0x7C2A, "security_drones" },
    { 0x7C2B, "security_elevator_approach" },
    { 0x7C2C, "security_elevator_descent" },
    { 0x7C2D, "security_elevator_descent_ai" },
    { 0x7C2E, "security_elevator_descent_player" },
    { 0x7C2F, "security_elevator_open" },
    { 0x7C30, "security_elevator_open_anim" },
    { 0x7C31, "security_elevator_prompt" },
    { 0x7C32, "security_room" },
    { 0x7C33, "security_triggers" },
    { 0x7C34, "securitycameraadsmonitor" },
    { 0x7C35, "securitycameraclearalltargets" },
    { 0x7C36, "securitycameraclearscannedtarget" },
    { 0x7C37, "securitycameradisable" },
    { 0x7C38, "securitycameraenable" },
    { 0x7C39, "securitycamerafovcheck" },
    { 0x7C3A, "securitycamerahud" },
    { 0x7C3B, "securitycameramarktargets" },
    { 0x7C3C, "securitycameraminimapangles" },
    { 0x7C3D, "securitycamerapotentialsignalmatch" },
    { 0x7C3E, "securitycamerareturndistancetotarget" },
    { 0x7C3F, "securitycamerascanhud" },
    { 0x7C40, "securitycamerascantrace" },
    { 0x7C41, "securitycameraswitching" },
    { 0x7C42, "securitycameratargetfrequency" },
    { 0x7C43, "securitycameratransitionblur" },
    { 0x7C44, "securitycameraviewlink" },
    { 0x7C45, "securitycamerazoomincontrols" },
    { 0x7C46, "securitycamerazoominstructions" },
    { 0x7C47, "securitycamerazoommodifier" },
    { 0x7C48, "securitycamerazoomoutcontrols" },
    { 0x7C49, "see_enemy_dot" },
    { 0x7C4A, "see_enemy_dot_close" },
    { 0x7C4B, "see_frames" },
    { 0x7C4C, "seeing" },
    { 0x7C4D, "seek_player_on_detection" },
    { 0x7C4E, "seek_player_on_fail" },
    { 0x7C4F, "seek_player_on_trigger" },
    { 0x7C50, "seeker_clear" },
    { 0x7C51, "seeker_dialogue" },
    { 0x7C52, "seeker_think" },
    { 0x7C53, "seeking_path" },
    { 0x7C54, "seekoutenemytime" },
    { 0x7C55, "seekplayercheck" },
    { 0x7C56, "seen_attacker" },
    { 0x7C57, "seen_audio_ent" },
    { 0x7C58, "segments" },
    { 0x7C59, "select_all_exploders_of_currently_selected" },
    { 0x7C5A, "select_by_name" },
    { 0x7C5B, "select_by_name_list" },
    { 0x7C5C, "select_by_substring" },
    { 0x7C5D, "select_entity" },
    { 0x7C5E, "select_index_array" },
    { 0x7C5F, "select_last_entity" },
    { 0x7C60, "select_target_think" },
    { 0x7C61, "selectairstrikelocation" },
    { 0x7C62, "selectbestspawnpoint" },
    { 0x7C63, "selected" },
    { 0x7C64, "selected_ent_buttons" },
    { 0x7C65, "selected_fx" },
    { 0x7C66, "selected_fx_ents" },
    { 0x7C67, "selected_fx_option_index" },
    { 0x7C68, "selectedclass" },
    { 0x7C69, "selectedmove_forward" },
    { 0x7C6A, "selectedmove_right" },
    { 0x7C6B, "selectedmove_up" },
    { 0x7C6C, "selectedrotate_pitch" },
    { 0x7C6D, "selectedrotate_roll" },
    { 0x7C6E, "selectedrotate_yaw" },
    { 0x7C6F, "selectinglocation" },
    { 0x7C70, "selectonemanarmyclass" },
    { 0x7C71, "self_delete" },
    { 0x7C72, "self_destruct_goliath" },
    { 0x7C73, "self_func" },
    { 0x7C74, "self_to_target_local_angles" },
    { 0x7C75, "self_tracking_functions" },
    { 0x7C76, "selfdeathicons" },
    { 0x7C77, "selfdeletedelay" },
    { 0x7C78, "selfiebooth" },
    { 0x7C79, "selfrevivethinkloop" },
    { 0x7C7A, "semifirenumshots" },
    { 0x7C7B, "semtex_sticky_handle" },
    { 0x7C7C, "semtexstickevent" },
    { 0x7C7D, "send_activate_zone_msg" },
    { 0x7C7E, "send_ai_to_colorvolume" },
    { 0x7C7F, "send_cormack" },
    { 0x7C80, "send_deactivate_zone_msg" },
    { 0x7C81, "send_heli_through_path" },
    { 0x7C82, "send_notify" },
    { 0x7C83, "send_swarm_to_chopper" },
    { 0x7C84, "send_will_wait" },
    { 0x7C85, "sendagentweaponnotify" },
    { 0x7C86, "sendallenemiesintriggertogoalvol" },
    { 0x7C87, "sendupdateddmscores" },
    { 0x7C88, "sendupdatedteamscores" },
    { 0x7C89, "sensoroutlined" },
    { 0x7C8A, "sent_chopper" },
    { 0x7C8B, "sent_guy_1_decloak" },
    { 0x7C8C, "sent_guy_1_footsteps" },
    { 0x7C8D, "sent_guy_1_footsteps_part2" },
    { 0x7C8E, "sent_guy_1_footsteps_part3" },
    { 0x7C8F, "sent_guy_2_decloak" },
    { 0x7C90, "sent_guy_2_footsteps" },
    { 0x7C91, "sent_guy_3_decloak" },
    { 0x7C92, "sent_guy_3_footsteps" },
    { 0x7C93, "sent_guy1_cloak" },
    { 0x7C94, "sent_guy1_mask_down" },
    { 0x7C95, "sent_guy1_mask_up" },
    { 0x7C96, "sentinel_guy1" },
    { 0x7C97, "sentinel_kva_fov_function" },
    { 0x7C98, "sentinel_op1" },
    { 0x7C99, "sentinel_op2" },
    { 0x7C9A, "sentinel_op4" },
    { 0x7C9B, "sentinel_reveal_dialogue_continue" },
    { 0x7C9C, "sentinel_reveal_final_vo" },
    { 0x7C9D, "sentinel_reveal_guy1_decloak" },
    { 0x7C9E, "sentinel_reveal_guy2_decloak" },
    { 0x7C9F, "sentinel_reveal_guy3_decloak" },
    { 0x7CA0, "sentinel_reveal_lighting" },
    { 0x7CA1, "sentinel_reveal_lighting_origins" },
    { 0x7CA2, "sentinel_reveal_moment_dialogue" },
    { 0x7CA3, "sentinel_reveal_slowmo_start" },
    { 0x7CA4, "sentinel_reveal_slowmo_stop" },
    { 0x7CA5, "sentinel_team_vo" },
    { 0x7CA6, "sentintel_reveal_dialogue" },
    { 0x7CA7, "sentintel_reveal_door_dialogue" },
    { 0x7CA8, "sentry_attacktargets" },
    { 0x7CA9, "sentry_beepsounds" },
    { 0x7CAA, "sentry_burstfirestart" },
    { 0x7CAB, "sentry_burstfirestop" },
    { 0x7CAC, "sentry_directhacked" },
    { 0x7CAD, "sentry_fire" },
    { 0x7CAE, "sentry_handledamage" },
    { 0x7CAF, "sentry_handledeath" },
    { 0x7CB0, "sentry_handleownerdisconnect" },
    { 0x7CB1, "sentry_handleuse" },
    { 0x7CB2, "sentry_heatmonitor" },
    { 0x7CB3, "sentry_initsentry" },
    { 0x7CB4, "sentry_lasermark" },
    { 0x7CB5, "sentry_makenotsolid" },
    { 0x7CB6, "sentry_makesolid" },
    { 0x7CB7, "sentry_oncarrierchangedteam" },
    { 0x7CB8, "sentry_oncarrierdeath" },
    { 0x7CB9, "sentry_oncarrierdisconnect" },
    { 0x7CBA, "sentry_ongameended" },
    { 0x7CBB, "sentry_place_delay" },
    { 0x7CBC, "sentry_setactive" },
    { 0x7CBD, "sentry_setcancelled" },
    { 0x7CBE, "sentry_setcarried" },
    { 0x7CBF, "sentry_setinactive" },
    { 0x7CC0, "sentry_setowner" },
    { 0x7CC1, "sentry_setplaced" },
    { 0x7CC2, "sentry_spindown" },
    { 0x7CC3, "sentry_spinup" },
    { 0x7CC4, "sentry_stopattackingtargets" },
    { 0x7CC5, "sentry_targetlocksound" },
    { 0x7CC6, "sentry_timeout" },
    { 0x7CC7, "sentry_watchdisabled" },
    { 0x7CC8, "sentrygun" },
    { 0x7CC9, "sentrymodeoff" },
    { 0x7CCA, "sentrymodeon" },
    { 0x7CCB, "sentrysettings" },
    { 0x7CCC, "sentrytype" },
    { 0x7CCD, "seo_ambient_ground_explosions" },
    { 0x7CCE, "seo_atlas_meet_cormack" },
    { 0x7CCF, "seo_atlas_meet_gideon" },
    { 0x7CD0, "seo_atlas_meet_will" },
    { 0x7CD1, "seo_big_car_explo" },
    { 0x7CD2, "seo_binocs_equip" },
    { 0x7CD3, "seo_canal_dynamic_bombs" },
    { 0x7CD4, "seo_canal_heli_attacked" },
    { 0x7CD5, "seo_canal_razorback" },
    { 0x7CD6, "seo_dirt_explosions" },
    { 0x7CD7, "seo_drone_missile" },
    { 0x7CD8, "seo_drone_missile_impact" },
    { 0x7CD9, "seo_droppod1_cormack" },
    { 0x7CDA, "seo_droppod1_will" },
    { 0x7CDB, "seo_droppod2_alt_will" },
    { 0x7CDC, "seo_droppod2_cormack" },
    { 0x7CDD, "seo_droppod3_exit" },
    { 0x7CDE, "seo_droppod3_intro_cormack" },
    { 0x7CDF, "seo_finale_cormack_assist_player" },
    { 0x7CE0, "seo_finale_cormack_crouch" },
    { 0x7CE1, "seo_finale_cormack_enter_scene" },
    { 0x7CE2, "seo_finale_cormack_grab_metal" },
    { 0x7CE3, "seo_finale_cormack_pull_player" },
    { 0x7CE4, "seo_finale_cormack_rescue" },
    { 0x7CE5, "seo_finale_cormack_walk_to_player" },
    { 0x7CE6, "seo_finale_player_arm_slice" },
    { 0x7CE7, "seo_finale_player_bounces" },
    { 0x7CE8, "seo_finale_player_dragged_away" },
    { 0x7CE9, "seo_finale_player_falls" },
    { 0x7CEA, "seo_finale_player_grab_hatch" },
    { 0x7CEB, "seo_finale_player_hatch_react" },
    { 0x7CEC, "seo_finale_player_jump_onto_platform" },
    { 0x7CED, "seo_finale_player_lands" },
    { 0x7CEE, "seo_finale_player_leg_down" },
    { 0x7CEF, "seo_finale_player_leg_up" },
    { 0x7CF0, "seo_finale_player_retrieve_bomb" },
    { 0x7CF1, "seo_finale_player_two_handed_hatch_pull" },
    { 0x7CF2, "seo_finale_rumble_heavy" },
    { 0x7CF3, "seo_finale_rumble_light" },
    { 0x7CF4, "seo_finale_start" },
    { 0x7CF5, "seo_finale_will_bomb_accept" },
    { 0x7CF6, "seo_finale_will_bomb_arm" },
    { 0x7CF7, "seo_finale_will_bomb_hatch_trap" },
    { 0x7CF8, "seo_finale_will_bomb_turn" },
    { 0x7CF9, "seo_finale_will_first_attempt_to_free" },
    { 0x7CFA, "seo_finale_will_grab_hatch" },
    { 0x7CFB, "seo_finale_will_grabs_player" },
    { 0x7CFC, "seo_finale_will_jump_onto_platform" },
    { 0x7CFD, "seo_finale_will_open_hatch" },
    { 0x7CFE, "seo_finale_will_place_bomb" },
    { 0x7CFF, "seo_finale_will_pushes_player" },
    { 0x7D00, "seo_finale_will_second_attempt" },
    { 0x7D01, "seo_finale_will_start" },
    { 0x7D02, "seo_finale_will_struggle" },
    { 0x7D03, "seo_finale_wp_belly_explo" },
    { 0x7D04, "seo_finale_wp_big_explo" },
    { 0x7D05, "seo_finale_wp_hatch_close" },
    { 0x7D06, "seo_finale_wp_init_explo" },
    { 0x7D07, "seo_finale_wp_landing_gears_up" },
    { 0x7D08, "seo_finale_wp_lift_off" },
    { 0x7D09, "seo_finale_wp_prepare_to_lift_off" },
    { 0x7D0A, "seo_finale_wp_take_off" },
    { 0x7D0B, "seo_finale_wp_wing_explo" },
    { 0x7D0C, "seo_fireball_explosions" },
    { 0x7D0D, "seo_fob_fake_jet_flyby" },
    { 0x7D0E, "seo_fob_initial_razorback" },
    { 0x7D0F, "seo_fob_pod_descend" },
    { 0x7D10, "seo_fob_pod_door_land" },
    { 0x7D11, "seo_fob_pod_door_open" },
    { 0x7D12, "seo_fob_pod_flaps" },
    { 0x7D13, "seo_fob_pod_land" },
    { 0x7D14, "seo_fob_razorback_01" },
    { 0x7D15, "seo_fob_razorback_02" },
    { 0x7D16, "seo_fob_tank_01" },
    { 0x7D17, "seo_fob_tank_02" },
    { 0x7D18, "seo_fob_tank_03" },
    { 0x7D19, "seo_fob_tank_procedural" },
    { 0x7D1A, "seo_get_vip_away_cg" },
    { 0x7D1B, "seo_gideon_meet_atlast_start" },
    { 0x7D1C, "seo_hotel_ent_wp_takeoff" },
    { 0x7D1D, "seo_intro_patrol_drones" },
    { 0x7D1E, "seo_mall_sizeup_crmk_powerup" },
    { 0x7D1F, "seo_mall_sizeup_crmk_runjump" },
    { 0x7D20, "seo_mall_sizeup_crmk_turn" },
    { 0x7D21, "seo_mall_sizeup_crmk_walk" },
    { 0x7D22, "seo_mall_sizeup_will_powerup" },
    { 0x7D23, "seo_mall_sizeup_will_runjump" },
    { 0x7D24, "seo_mall_sizeup_will_walk" },
    { 0x7D25, "seo_mall_sizeup_will_wpn_sling" },
    { 0x7D26, "seo_meet_atlas_civ_scriptmodel_cg" },
    { 0x7D27, "seo_meet_atlas_slowmo_end" },
    { 0x7D28, "seo_meet_atlas_slowmo_start" },
    { 0x7D29, "seo_outro_falling_debris" },
    { 0x7D2A, "seo_outro_pause_env_fx" },
    { 0x7D2B, "seo_outro_rolling_smk" },
    { 0x7D2C, "seo_outro_thick_smk_vm" },
    { 0x7D2D, "seo_outro_tire_fire" },
    { 0x7D2E, "seo_outro_wp_belly_explo_1" },
    { 0x7D2F, "seo_outro_wp_belly_explo_2" },
    { 0x7D30, "seo_outro_wp_belly_explo_2_end" },
    { 0x7D31, "seo_outro_wp_env_fx_start" },
    { 0x7D32, "seo_outro_wp_explo_sequence_start" },
    { 0x7D33, "seo_outro_wp_init_explo" },
    { 0x7D34, "seo_outro_wp_tail_explo" },
    { 0x7D35, "seo_outro_wp_tail_explo_shockwave" },
    { 0x7D36, "seo_outro_wp_tail_explo_shockwave_ground" },
    { 0x7D37, "seo_outro_wp_take_off_start" },
    { 0x7D38, "seo_outro_wp_wing_fall_off" },
    { 0x7D39, "seo_outro_wp_wp_powerup" },
    { 0x7D3A, "seo_per_arts_jump_explo_3" },
    { 0x7D3B, "seo_pod_break_loose_and_fall" },
    { 0x7D3C, "seo_pod_cormack_exit" },
    { 0x7D3D, "seo_pod_cormack_land" },
    { 0x7D3E, "seo_pod_cormack_pivot" },
    { 0x7D3F, "seo_pod_cormack_reach_hatch" },
    { 0x7D40, "seo_pod_cormack_walk_2" },
    { 0x7D41, "seo_pod_enter_cormack_fs" },
    { 0x7D42, "seo_pod_enter_cormack_lt_pull" },
    { 0x7D43, "seo_pod_enter_cormack_lt_reach" },
    { 0x7D44, "seo_pod_enter_cormack_rt_pull" },
    { 0x7D45, "seo_pod_enter_cormack_rt_reach" },
    { 0x7D46, "seo_pod_enter_jack_fs" },
    { 0x7D47, "seo_pod_enter_jack_lt_pull" },
    { 0x7D48, "seo_pod_enter_jack_lt_reach" },
    { 0x7D49, "seo_pod_enter_jack_rt_pull" },
    { 0x7D4A, "seo_pod_enter_jack_rt_reach" },
    { 0x7D4B, "seo_pod_enter_player_fs" },
    { 0x7D4C, "seo_pod_enter_player_lt_hand" },
    { 0x7D4D, "seo_pod_enter_player_lt_pull" },
    { 0x7D4E, "seo_pod_enter_player_lt_reach" },
    { 0x7D4F, "seo_pod_enter_player_rt_hand" },
    { 0x7D50, "seo_pod_enter_player_rt_pull" },
    { 0x7D51, "seo_pod_enter_player_rt_reach" },
    { 0x7D52, "seo_pod_enter_start" },
    { 0x7D53, "seo_pod_enter_will_fs" },
    { 0x7D54, "seo_pod_enter_will_lt_pull" },
    { 0x7D55, "seo_pod_enter_will_lt_reach" },
    { 0x7D56, "seo_pod_enter_will_rt_pull" },
    { 0x7D57, "seo_pod_enter_will_rt_reach" },
    { 0x7D58, "seo_pod_ext_player_land" },
    { 0x7D59, "seo_pod_ext_player_turn" },
    { 0x7D5A, "seo_pod_int_player_exit" },
    { 0x7D5B, "seo_pod_int_player_kick_attempt" },
    { 0x7D5C, "seo_pod_int_player_kick_open_hatch" },
    { 0x7D5D, "seo_pod_int_player_lean_in_door" },
    { 0x7D5E, "seo_pod_int_player_move_to_hatch" },
    { 0x7D5F, "seo_pod_int_player_move_to_hatch_left" },
    { 0x7D60, "seo_pod_int_player_move_to_hatch_right" },
    { 0x7D61, "seo_pod_int_player_reach_hatch" },
    { 0x7D62, "seo_pod_int_player_unbuckle" },
    { 0x7D63, "seo_pod_int_player_unbuckle_left" },
    { 0x7D64, "seo_pod_int_player_unbuckle_right" },
    { 0x7D65, "seo_pod_launch_cam_shake" },
    { 0x7D66, "seo_pod_new_guy_exit" },
    { 0x7D67, "seo_pod_new_guy_gets_up" },
    { 0x7D68, "seo_pod_new_guy_land" },
    { 0x7D69, "seo_pod_overhead_screen_start" },
    { 0x7D6A, "seo_pod_phase3_door_pop" },
    { 0x7D6B, "seo_pod_phase3_screen_boot" },
    { 0x7D6C, "seo_pod_phase3_screen_down" },
    { 0x7D6D, "seo_pod_phase3_screen_up" },
    { 0x7D6E, "seo_pod_phase3_seat_arm_down" },
    { 0x7D6F, "seo_pod_phase3_seat_arm_up" },
    { 0x7D70, "seo_pod_phase3_turn_lever" },
    { 0x7D71, "seo_pod_phase3_vm_seat_arm_up" },
    { 0x7D72, "seo_pod_will_land" },
    { 0x7D73, "seo_pod_will_walk_1" },
    { 0x7D74, "seo_pod_will_walk_2" },
    { 0x7D75, "seo_single_drones_flyby" },
    { 0x7D76, "seo_sinkhole_wp_flyby" },
    { 0x7D77, "seo_smoke_grenade_ambush" },
    { 0x7D78, "seo_start_drone_submix" },
    { 0x7D79, "seo_stop_intro_patrol_drones" },
    { 0x7D7A, "seo_stop_single_drones_flyby" },
    { 0x7D7B, "seo_swarm_die" },
    { 0x7D7C, "seo_swarm_emp_wave" },
    { 0x7D7D, "seo_truck_explo" },
    { 0x7D7E, "seo_video_log_start" },
    { 0x7D7F, "seo_vista_amb_explos" },
    { 0x7D80, "seo_vista_bombing_run" },
    { 0x7D81, "seo_will_car_door_explo" },
    { 0x7D82, "seo_will_death_hatch_open_wait_cycle" },
    { 0x7D83, "seo_will_death_plant_charge_part1" },
    { 0x7D84, "seo_will_death_plant_charge_part2" },
    { 0x7D85, "seo_zipline_harpoon_fire" },
    { 0x7D86, "seo_zipline_harpoon_impact" },
    { 0x7D87, "seo_zipline_rappel_begin" },
    { 0x7D88, "seo_zipline_rappel_land" },
    { 0x7D89, "seo_zipline_retract_rope" },
    { 0x7D8A, "seoul_building_jump_sequence" },
    { 0x7D8B, "seoul_cg_precache_models" },
    { 0x7D8C, "seoul_color_think" },
    { 0x7D8D, "seoul_cover_art" },
    { 0x7D8E, "seoul_drone_swarm_intro" },
    { 0x7D8F, "seoul_encounter_01" },
    { 0x7D90, "seoul_finale_cinematic_lighting" },
    { 0x7D91, "seoul_fob" },
    { 0x7D92, "seoul_foley_override_handler" },
    { 0x7D93, "seoul_hotel_entrance" },
    { 0x7D94, "seoul_land_assist" },
    { 0x7D95, "seoul_locations" },
    { 0x7D96, "seoul_missile_evade" },
    { 0x7D97, "seoul_start" },
    { 0x7D98, "seoul_start_from_pod" },
    { 0x7D99, "seoul_truck_push" },
    { 0x7D9A, "seoul_zipline_scripted" },
    { 0x7D9B, "seoul_zipline_scripted_custom" },
    { 0x7D9C, "separation_factor" },
    { 0x7D9D, "serial_playback_lock" },
    { 0x7D9E, "server_culled_sounds" },
    { 0x7D9F, "server_lights" },
    { 0x7DA0, "server_lights_setup" },
    { 0x7DA1, "server_room_approach_dialogue" },
    { 0x7DA2, "server_room_dialogue" },
    { 0x7DA3, "server_room_fire_knox_gun" },
    { 0x7DA4, "server_room_guy_killed_by_knox" },
    { 0x7DA5, "server_room_lasers" },
    { 0x7DA6, "server_room_logic" },
    { 0x7DA7, "server_room_nag_dialogue" },
    { 0x7DA8, "server_room_promo_logic" },
    { 0x7DA9, "server_room_se_end" },
    { 0x7DAA, "server_unit_01" },
    { 0x7DAB, "server_unit_02" },
    { 0x7DAC, "sessioncostume" },
    { 0x7DAD, "set" },
    { 0x7DAE, "set_accuracy" },
    { 0x7DAF, "set_accuracy_based_on_situation" },
    { 0x7DB0, "set_agent_health" },
    { 0x7DB1, "set_agent_team" },
    { 0x7DB2, "set_agent_values" },
    { 0x7DB3, "set_ai_anims" },
    { 0x7DB4, "set_ai_bcvoice" },
    { 0x7DB5, "set_ai_number" },
    { 0x7DB6, "set_aim_and_turn_limits" },
    { 0x7DB7, "set_all_exceptions" },
    { 0x7DB8, "set_allowdeath" },
    { 0x7DB9, "set_ambient" },
    { 0x7DBA, "set_ambush_sidestep_anims" },
    { 0x7DBB, "set_anglemod_move_vector" },
    { 0x7DBC, "set_anim_array" },
    { 0x7DBD, "set_anim_array_aiming" },
    { 0x7DBE, "set_anim_playback_rate" },
    { 0x7DBF, "set_animarray_add_smg_turn_aims_stand" },
    { 0x7DC0, "set_animarray_add_turn_aims_crouch" },
    { 0x7DC1, "set_animarray_add_turn_aims_stand" },
    { 0x7DC2, "set_animarray_burst_and_semi_fire_crouch" },
    { 0x7DC3, "set_animarray_burst_and_semi_fire_stand" },
    { 0x7DC4, "set_animarray_crouch_aim" },
    { 0x7DC5, "set_animarray_crouching" },
    { 0x7DC6, "set_animarray_crouching_left" },
    { 0x7DC7, "set_animarray_crouching_right" },
    { 0x7DC8, "set_animarray_crouching_turns" },
    { 0x7DC9, "set_animarray_custom_burst_and_semi_fire_crouch" },
    { 0x7DCA, "set_animarray_custom_burst_and_semi_fire_stand" },
    { 0x7DCB, "set_animarray_mech_burst_and_semi_fire_stand" },
    { 0x7DCC, "set_animarray_mech_burst_and_semi_fire_walk" },
    { 0x7DCD, "set_animarray_mech_standing_turns" },
    { 0x7DCE, "set_animarray_prone" },
    { 0x7DCF, "set_animarray_smg_standing_turns" },
    { 0x7DD0, "set_animarray_stance_change" },
    { 0x7DD1, "set_animarray_stance_change_smg" },
    { 0x7DD2, "set_animarray_standing" },
    { 0x7DD3, "set_animarray_standing_left" },
    { 0x7DD4, "set_animarray_standing_right" },
    { 0x7DD5, "set_animarray_standing_turns" },
    { 0x7DD6, "set_animarray_standing_turns_pistol" },
    { 0x7DD7, "set_animname" },
    { 0x7DD8, "set_archetype" },
    { 0x7DD9, "set_array" },
    { 0x7DDA, "set_attached_models" },
    { 0x7DDB, "set_avatar_dof" },
    { 0x7DDC, "set_baghdad_standard_dof" },
    { 0x7DDD, "set_baseaccuracy" },
    { 0x7DDE, "set_basic_animated_model" },
    { 0x7DDF, "set_battlechatter" },
    { 0x7DE0, "set_battlechatter_variable" },
    { 0x7DE1, "set_blast_walk_anims" },
    { 0x7DE2, "set_blur" },
    { 0x7DE3, "set_boost_lighting" },
    { 0x7DE4, "set_brakes" },
    { 0x7DE5, "set_breaching_variable" },
    { 0x7DE6, "set_bridge_lighting" },
    { 0x7DE7, "set_cam_shake" },
    { 0x7DE8, "set_cam_shake_drop" },
    { 0x7DE9, "set_canyon_dof" },
    { 0x7DEA, "set_cargo_ship_drone_view_lighting" },
    { 0x7DEB, "set_cloak_material_for_npc_weapon" },
    { 0x7DEC, "set_cloak_material_for_vm_weapon" },
    { 0x7DED, "set_cloak_on_model" },
    { 0x7DEE, "set_cloak_parameter" },
    { 0x7DEF, "set_color_goal_node" },
    { 0x7DF0, "set_combat_stand_animset" },
    { 0x7DF1, "set_completed_flags" },
    { 0x7DF2, "set_completed_objective_flags" },
    { 0x7DF3, "set_console_status" },
    { 0x7DF4, "set_contested_zone" },
    { 0x7DF5, "set_contested_zone_wait" },
    { 0x7DF6, "set_corner_anim_array" },
    { 0x7DF7, "set_corpse_detection_ranges_for_cloak_system" },
    { 0x7DF8, "set_count" },
    { 0x7DF9, "set_counts" },
    { 0x7DFA, "set_crouching_animarray_aiming" },
    { 0x7DFB, "set_crouching_turns" },
    { 0x7DFC, "set_custom_gameskill_func" },
    { 0x7DFD, "set_custom_move_start_transition" },
    { 0x7DFE, "set_custom_patrol_anim_set" },
    { 0x7DFF, "set_custom_run_anim" },
    { 0x7E00, "set_damb_component_stringtable" },
    { 0x7E01, "set_damb_loops_stringtable" },
    { 0x7E02, "set_damb_stringtable" },
    { 0x7E03, "set_deadquote" },
    { 0x7E04, "set_death_icon" },
    { 0x7E05, "set_death_model" },
    { 0x7E06, "set_deathanim" },
    { 0x7E07, "set_deathsdoor" },
    { 0x7E08, "set_default_aim_limits" },
    { 0x7E09, "set_default_breath_values" },
    { 0x7E0A, "set_default_hud_parameters" },
    { 0x7E0B, "set_default_pathenemy_settings" },
    { 0x7E0C, "set_default_start" },
    { 0x7E0D, "set_default_swimmer_aim_limits" },
    { 0x7E0E, "set_delays" },
    { 0x7E0F, "set_demigod_while" },
    { 0x7E10, "set_df_objective_active" },
    { 0x7E11, "set_df_objective_active_spiderturrets" },
    { 0x7E12, "set_difficulty_from_locked_settings" },
    { 0x7E13, "set_disable_friendlyfire_value_delayed" },
    { 0x7E14, "set_display_name" },
    { 0x7E15, "set_dog_walk_anim" },
    { 0x7E16, "set_door_charge_anim_normal" },
    { 0x7E17, "set_door_charge_anim_special" },
    { 0x7E18, "set_early_level" },
    { 0x7E19, "set_empty_promotion_order" },
    { 0x7E1A, "set_entflag_on_notify" },
    { 0x7E1B, "set_event_distance" },
    { 0x7E1C, "set_exception" },
    { 0x7E1D, "set_exo_ability_hud_omnvar" },
    { 0x7E1E, "set_exo_temperature_over_time" },
    { 0x7E1F, "set_external_temperature_over_time" },
    { 0x7E20, "set_favoriteenemy" },
    { 0x7E21, "set_firing" },
    { 0x7E22, "set_firing_disabled" },
    { 0x7E23, "set_fixednode_false" },
    { 0x7E24, "set_fixednode_true" },
    { 0x7E25, "set_flag_in_trigger" },
    { 0x7E26, "set_flag_on_burke_wave_to_ambulance" },
    { 0x7E27, "set_flag_on_dead" },
    { 0x7E28, "set_flag_on_dead_or_dying" },
    { 0x7E29, "set_flag_on_death" },
    { 0x7E2A, "set_flag_on_func_wait_proc" },
    { 0x7E2B, "set_flag_on_spawned" },
    { 0x7E2C, "set_flag_on_spawned_ai_proc" },
    { 0x7E2D, "set_flag_on_targetname_trigger" },
    { 0x7E2E, "set_flag_on_trigger" },
    { 0x7E2F, "set_flag_rappel_player_input_start" },
    { 0x7E30, "set_flag_rappel_player_input_stop" },
    { 0x7E31, "set_flag_when_in_volume" },
    { 0x7E32, "set_flavorbursts" },
    { 0x7E33, "set_flavorbursts_team_state" },
    { 0x7E34, "set_fog" },
    { 0x7E35, "set_fog_progress" },
    { 0x7E36, "set_fog_to_ent_values" },
    { 0x7E37, "set_fog_to_ent_values_dfog" },
    { 0x7E38, "set_force_color" },
    { 0x7E39, "set_force_color_spawner" },
    { 0x7E3A, "set_force_cover" },
    { 0x7E3B, "set_force_script_models_highway_path_player_side" },
    { 0x7E3C, "set_force_sprint" },
    { 0x7E3D, "set_forced_target" },
    { 0x7E3E, "set_forcedgoal" },
    { 0x7E3F, "set_forcegoal" },
    { 0x7E40, "set_forward_and_up_vectors" },
    { 0x7E41, "set_friendlyfire_warnings" },
    { 0x7E42, "set_fx_hudelement" },
    { 0x7E43, "set_generic_deathanim" },
    { 0x7E44, "set_generic_idle_anim" },
    { 0x7E45, "set_generic_run_anim" },
    { 0x7E46, "set_generic_run_anim_array" },
    { 0x7E47, "set_goal_ent" },
    { 0x7E48, "set_goal_entity" },
    { 0x7E49, "set_goal_from_settings" },
    { 0x7E4A, "set_goal_height_from_settings" },
    { 0x7E4B, "set_goal_node" },
    { 0x7E4C, "set_goal_node_targetname" },
    { 0x7E4D, "set_goal_pos" },
    { 0x7E4E, "set_goal_radius" },
    { 0x7E4F, "set_goal_volume" },
    { 0x7E50, "set_goalradius" },
    { 0x7E51, "set_goalvolume" },
    { 0x7E52, "set_grenadeammo" },
    { 0x7E53, "set_grid_color_dark" },
    { 0x7E54, "set_group_advance_to_enemy_parameters" },
    { 0x7E55, "set_guy_on_fire" },
    { 0x7E56, "set_health" },
    { 0x7E57, "set_helmet_closed" },
    { 0x7E58, "set_helmet_open" },
    { 0x7E59, "set_hemi_ao" },
    { 0x7E5A, "set_high_priority_target_for_bot" },
    { 0x7E5B, "set_hudoutline" },
    { 0x7E5C, "set_idle_anim" },
    { 0x7E5D, "set_ignoreall" },
    { 0x7E5E, "set_ignoreme" },
    { 0x7E5F, "set_ignoresonicaoe" },
    { 0x7E60, "set_ignoresuppression" },
    { 0x7E61, "set_initial_rush_goal" },
    { 0x7E62, "set_intensities" },
    { 0x7E63, "set_intro_lighting" },
    { 0x7E64, "set_irons_tour_ride_reflection" },
    { 0x7E65, "set_itiot_flags" },
    { 0x7E66, "set_landing_target_fx" },
    { 0x7E67, "set_laser_ambush_stats" },
    { 0x7E68, "set_level_lighting_values" },
    { 0x7E69, "set_level_player_rumble_ent_intensity" },
    { 0x7E6A, "set_level_player_rumble_ent_intensity_for_time" },
    { 0x7E6B, "set_light_set_for_player" },
    { 0x7E6C, "set_lighting_values" },
    { 0x7E6D, "set_lookat_from_dest" },
    { 0x7E6E, "set_lookat_point" },
    { 0x7E6F, "set_main_vol_and_retreat_vol" },
    { 0x7E70, "set_manual_target" },
    { 0x7E71, "set_maxed_momentum" },
    { 0x7E72, "set_maxsightdistsqrd" },
    { 0x7E73, "set_mech_chaingun_last_state" },
    { 0x7E74, "set_mech_chaingun_state" },
    { 0x7E75, "set_mech_rocket_last_state" },
    { 0x7E76, "set_mech_rocket_state" },
    { 0x7E77, "set_mech_state" },
    { 0x7E78, "set_mech_swarm_last_state" },
    { 0x7E79, "set_mech_swarm_state" },
    { 0x7E7A, "set_mech_weapon_state" },
    { 0x7E7B, "set_melee_early" },
    { 0x7E7C, "set_melee_timer" },
    { 0x7E7D, "set_mission_failed_override" },
    { 0x7E7E, "set_momentum" },
    { 0x7E7F, "set_momentum_multiplier" },
    { 0x7E80, "set_move_animset" },
    { 0x7E81, "set_moveplaybackrate" },
    { 0x7E82, "set_movetransitionrate" },
    { 0x7E83, "set_new_bomber" },
    { 0x7E84, "set_normal_time_if_gun_fired" },
    { 0x7E85, "set_npc_anims" },
    { 0x7E86, "set_obj_markers_current" },
    { 0x7E87, "set_objective_active" },
    { 0x7E88, "set_objective_inactive" },
    { 0x7E89, "set_off_exploders" },
    { 0x7E8A, "set_oncoming_lighting" },
    { 0x7E8B, "set_operator_temperature_over_time" },
    { 0x7E8C, "set_optimal_flight_dist" },
    { 0x7E8D, "set_option_index" },
    { 0x7E8E, "set_org" },
    { 0x7E8F, "set_origin_and_angles" },
    { 0x7E90, "set_origin_per_time" },
    { 0x7E91, "set_pacifist" },
    { 0x7E92, "set_painted_trackrounds" },
    { 0x7E93, "set_patrol_anim_set" },
    { 0x7E94, "set_patrol_run_anim_array" },
    { 0x7E95, "set_pitbull_anim" },
    { 0x7E96, "set_pitbull_anim_node" },
    { 0x7E97, "set_pivot_pos" },
    { 0x7E98, "set_player_attacker_accuracy" },
    { 0x7E99, "set_player_detection_distance_for_speed" },
    { 0x7E9A, "set_player_link_angles_tag_relative" },
    { 0x7E9B, "set_player_rig_spawn_function" },
    { 0x7E9C, "set_player_speed_hud" },
    { 0x7E9D, "set_player_start" },
    { 0x7E9E, "set_player_viewhand_model" },
    { 0x7E9F, "set_pos" },
    { 0x7EA0, "set_post_slide_blend_time" },
    { 0x7EA1, "set_president_anims" },
    { 0x7EA2, "set_promotion_order" },
    { 0x7EA3, "set_pull_weight" },
    { 0x7EA4, "set_random_flock_goal_position" },
    { 0x7EA5, "set_rank_xp_and_prestige_for_bot" },
    { 0x7EA6, "set_reactive_motion_values" },
    { 0x7EA7, "set_refugee_camp_walk_anims" },
    { 0x7EA8, "set_reverb_stringtable" },
    { 0x7EA9, "set_room_to_breached" },
    { 0x7EAA, "set_rumble_intensity" },
    { 0x7EAB, "set_run_anim" },
    { 0x7EAC, "set_run_anim_array" },
    { 0x7EAD, "set_s1_animarray_add_turn_aims_crouch" },
    { 0x7EAE, "set_s1_animarray_add_turn_aims_stand" },
    { 0x7EAF, "set_s1_animarray_burst_and_semi_fire_crouch" },
    { 0x7EB0, "set_s1_animarray_burst_and_semi_fire_stand" },
    { 0x7EB1, "set_s1_animarray_crouch_aim" },
    { 0x7EB2, "set_s1_animarray_crouching_turns" },
    { 0x7EB3, "set_s1_animarray_stance_change" },
    { 0x7EB4, "set_s1_animarray_stance_change_smg" },
    { 0x7EB5, "set_s1_animarray_standing_turns" },
    { 0x7EB6, "set_scripted_pathing_style" },
    { 0x7EB7, "set_security_center_tv" },
    { 0x7EB8, "set_security_lights" },
    { 0x7EB9, "set_seoul_fall_height" },
    { 0x7EBA, "set_smdvars" },
    { 0x7EBB, "set_snipers_section_clear" },
    { 0x7EBC, "set_spawncount" },
    { 0x7EBD, "set_spot_color" },
    { 0x7EBE, "set_spot_intensity" },
    { 0x7EBF, "set_stage" },
    { 0x7EC0, "set_standing_animarray_aiming" },
    { 0x7EC1, "set_standing_cover_turns" },
    { 0x7EC2, "set_standing_turns" },
    { 0x7EC3, "set_start_pos" },
    { 0x7EC4, "set_start_transients" },
    { 0x7EC5, "set_stat_dvars" },
    { 0x7EC6, "set_stream_origin_for_intro" },
    { 0x7EC7, "set_street_lighting" },
    { 0x7EC8, "set_stringtable_mapname" },
    { 0x7EC9, "set_sun_flare" },
    { 0x7ECA, "set_sun_flare_position" },
    { 0x7ECB, "set_sun_shadow_params" },
    { 0x7ECC, "set_swimming_animarray_aiming" },
    { 0x7ECD, "set_swimming_turns" },
    { 0x7ECE, "set_talker_until_msg" },
    { 0x7ECF, "set_talking_currently" },
    { 0x7ED0, "set_target_player_or_will" },
    { 0x7ED1, "set_target_tracking_disabled" },
    { 0x7ED2, "set_team_bcvoice" },
    { 0x7ED3, "set_team_pacifist" },
    { 0x7ED4, "set_temp_hud_text" },
    { 0x7ED5, "set_this_flag_when_im_dead" },
    { 0x7ED6, "set_threat_grenade_response" },
    { 0x7ED7, "set_threatbias" },
    { 0x7ED8, "set_threatbiasgroup" },
    { 0x7ED9, "set_threshold" },
    { 0x7EDA, "set_time_between_attacks" },
    { 0x7EDB, "set_tool_hudelem" },
    { 0x7EDC, "set_traffic_change_speedup" },
    { 0x7EDD, "set_trigger_flag_permissions" },
    { 0x7EDE, "set_trophy_ammo" },
    { 0x7EDF, "set_tunnel_lighting" },
    { 0x7EE0, "set_tunnel_lighting_1" },
    { 0x7EE1, "set_tunnel_lighting_2" },
    { 0x7EE2, "set_turret_death_anim" },
    { 0x7EE3, "set_turret_team" },
    { 0x7EE4, "set_tv_screen_broken" },
    { 0x7EE5, "set_tv_screen_unbroken" },
    { 0x7EE6, "set_umbra_values" },
    { 0x7EE7, "set_unstorable_weapon" },
    { 0x7EE8, "set_up_ambient_battle" },
    { 0x7EE9, "set_up_auto_non_ai_turret" },
    { 0x7EEA, "set_up_bus_crash_anims" },
    { 0x7EEB, "set_up_exo_temperature" },
    { 0x7EEC, "set_up_median_crash_anims" },
    { 0x7EED, "set_up_pitbull_crash_anims" },
    { 0x7EEE, "set_up_pitbull_escape_anims" },
    { 0x7EEF, "set_up_player_gundown" },
    { 0x7EF0, "set_up_player_s1" },
    { 0x7EF1, "set_up_player_s2" },
    { 0x7EF2, "set_up_police_battle" },
    { 0x7EF3, "set_up_president" },
    { 0x7EF4, "set_up_president_s2" },
    { 0x7EF5, "set_up_tank_exit_anims" },
    { 0x7EF6, "set_up_target" },
    { 0x7EF7, "set_urgent_walk_anims" },
    { 0x7EF8, "set_van_lighting" },
    { 0x7EF9, "set_variable_grenades_with_no_switch" },
    { 0x7EFA, "set_vehicle_anims" },
    { 0x7EFB, "set_vehicle_anims_slow" },
    { 0x7EFC, "set_vehicle_anims_turret" },
    { 0x7EFD, "set_vehicle_effect" },
    { 0x7EFE, "set_vehicle_goal_position" },
    { 0x7EFF, "set_vehicle_speed" },
    { 0x7F00, "set_vision_set" },
    { 0x7F01, "set_vision_set_player" },
    { 0x7F02, "set_visionset_for_watching_players" },
    { 0x7F03, "set_wait_then_clear_skipbloodpool" },
    { 0x7F04, "set_waits" },
    { 0x7F05, "set_walkdist" },
    { 0x7F06, "set_weapon_data" },
    { 0x7F07, "set_when_time_flag_balcony_tackle_fake_okay" },
    { 0x7F08, "set_when_time_flag_balcony_tackle_okay" },
    { 0x7F09, "set_when_time_flag_balcony_tackle_too_late" },
    { 0x7F0A, "set_whizby_radius" },
    { 0x7F0B, "set_whizby_spread" },
    { 0x7F0C, "set_wind" },
    { 0x7F0D, "set_x" },
    { 0x7F0E, "set_y" },
    { 0x7F0F, "set_z" },
    { 0x7F10, "set_zero_speed" },
    { 0x7F11, "set_zone_stringtable" },
    { 0x7F12, "set2dicon" },
    { 0x7F13, "set3dicon" },
    { 0x7F14, "set3duseicon" },
    { 0x7F15, "setactivegrenadetimer" },
    { 0x7F16, "setadrenaline" },
    { 0x7F17, "setadrenalinesupport" },
    { 0x7F18, "setaimingparams" },
    { 0x7F19, "setairdropcratecollision" },
    { 0x7F1A, "setalertoutline" },
    { 0x7F1B, "setalertstencilstate" },
    { 0x7F1C, "setalertstencilstate_axis" },
    { 0x7F1D, "setalleystransitionculldist" },
    { 0x7F1E, "setallvehiclefx" },
    { 0x7F1F, "setaltsceneobj" },
    { 0x7F20, "setalwaysusepistol" },
    { 0x7F21, "setanimaimweight" },
    { 0x7F22, "setanimrestart_once" },
    { 0x7F23, "setanims" },
    { 0x7F24, "setanims_coverleft_stand" },
    { 0x7F25, "setanims_coverright_stand" },
    { 0x7F26, "setanims_coverup_stand" },
    { 0x7F27, "setanims_slow" },
    { 0x7F28, "setanims_turret" },
    { 0x7F29, "setanimtree" },
    { 0x7F2A, "setattackingteam" },
    { 0x7F2B, "setautospot" },
    { 0x7F2C, "setbackenemygunlevelevent" },
    { 0x7F2D, "setbackfirstplayergunlevelevent" },
    { 0x7F2E, "setbacklevel" },
    { 0x7F2F, "setblackbox" },
    { 0x7F30, "setblastshield" },
    { 0x7F31, "setboostdash" },
    { 0x7F32, "setcanuse" },
    { 0x7F33, "setcarepackage" },
    { 0x7F34, "setcarrier" },
    { 0x7F35, "setcarriervisible" },
    { 0x7F36, "setcarryicon" },
    { 0x7F37, "setcarryingsentry" },
    { 0x7F38, "setcarryingturret" },
    { 0x7F39, "setcinematiccamerastyle" },
    { 0x7F3A, "setclaimteam" },
    { 0x7F3B, "setclass" },
    { 0x7F3C, "setcombatrecordstat" },
    { 0x7F3D, "setcombatrecordstatifgreater" },
    { 0x7F3E, "setcombatstandmoveanimweights" },
    { 0x7F3F, "setcommonrulesfrommatchrulesdata" },
    { 0x7F40, "setcontestedicons" },
    { 0x7F41, "setcopycatloadout" },
    { 0x7F42, "setcrawlingpaintransanim" },
    { 0x7F43, "setcrouchmovement" },
    { 0x7F44, "setcurrentgroup" },
    { 0x7F45, "setdeepwaterweapon" },
    { 0x7F46, "setdefaultactionslot" },
    { 0x7F47, "setdefaultcallbacks" },
    { 0x7F48, "setdefaultcorneranimmode" },
    { 0x7F49, "setdefaultcostumeifneeded" },
    { 0x7F4A, "setdefaultdof" },
    { 0x7F4B, "setdefaulthudoutlinedvars" },
    { 0x7F4C, "setdefaulthudoutlinestyle" },
    { 0x7F4D, "setdefaultpostfx" },
    { 0x7F4E, "setdefaultwallanimmode" },
    { 0x7F4F, "setdelaymine" },
    { 0x7F50, "setdeployedjuggernaut" },
    { 0x7F51, "setdifficulty" },
    { 0x7F52, "setdistanceonparts" },
    { 0x7F53, "setdodgeanims" },
    { 0x7F54, "setdof" },
    { 0x7F55, "setdot_height" },
    { 0x7F56, "setdot_ontick" },
    { 0x7F57, "setdot_origin" },
    { 0x7F58, "setdot_radius" },
    { 0x7F59, "setdoubleload" },
    { 0x7F5A, "setdrivenanim" },
    { 0x7F5B, "setdronehealth" },
    { 0x7F5C, "setdronevisionandlightsetpermap" },
    { 0x7F5D, "setdropped" },
    { 0x7F5E, "setdvar_cg_ng" },
    { 0x7F5F, "setdynamiceventstartpercent" },
    { 0x7F60, "setempimmune" },
    { 0x7F61, "setemptydvar" },
    { 0x7F62, "setendgame" },
    { 0x7F63, "setenemydetection" },
    { 0x7F64, "setenemydifficultysettings" },
    { 0x7F65, "setentitydamagecallback" },
    { 0x7F66, "setentityheadicon" },
    { 0x7F67, "setexomelee" },
    { 0x7F68, "setexoslam" },
    { 0x7F69, "setexoslide" },
    { 0x7F6A, "setexplosivegelteamheadicon" },
    { 0x7F6B, "setextrascore0" },
    { 0x7F6C, "setextrascore1" },
    { 0x7F6D, "setfinalstand" },
    { 0x7F6E, "setfireloopmod" },
    { 0x7F6F, "setfirstinfected" },
    { 0x7F70, "setflagaftertime" },
    { 0x7F71, "setflashbangimmunity" },
    { 0x7F72, "setflashfrac" },
    { 0x7F73, "setfogsliders" },
    { 0x7F74, "setfootstepeffect" },
    { 0x7F75, "setfootstepeffectsmall" },
    { 0x7F76, "setfovscale" },
    { 0x7F77, "setfreefall" },
    { 0x7F78, "setfriendlydetection" },
    { 0x7F79, "setfriendlyspawn" },
    { 0x7F7A, "setgameobjecthudindex" },
    { 0x7F7B, "setghilliemodels" },
    { 0x7F7C, "setglobalaimsettings" },
    { 0x7F7D, "setglobaldifficulty" },
/* 1 gap
    "setgoalradius",
*/
    { 0x7F80, "setgrenadetimer" },
    { 0x7F81, "setgroup_down" },
    { 0x7F82, "setgroup_up" },
    { 0x7F83, "setguns" },
    { 0x7F84, "setharmonicbreachhudoutlinestyle" },
    { 0x7F85, "sethasdonecombat" },
    { 0x7F86, "setheadicon" },
    { 0x7F87, "setheadicon_multiple" },
    { 0x7F88, "setheadmodel" },
    { 0x7F89, "setheight" },
    { 0x7F8A, "sethighjump" },
    { 0x7F8B, "sethudnumbursts" },
    { 0x7F8C, "sethudtimer" },
    { 0x7F8D, "seticonshader" },
    { 0x7F8E, "seticonsize" },
    { 0x7F8F, "setidleface" },
    { 0x7F90, "setidlefacedelayed" },
    { 0x7F91, "setinfectedmodels" },
    { 0x7F92, "setinfectedmsg" },
    { 0x7F93, "setinflictorstat" },
    { 0x7F94, "setinitialtonormalinfected" },
    { 0x7F95, "setintelmode" },
    { 0x7F96, "setinterval" },
    { 0x7F97, "setjuiced" },
    { 0x7F98, "setjumpincrease" },
    { 0x7F99, "setkeyobject" },
    { 0x7F9A, "setkillcamentity" },
    { 0x7F9B, "setkillcamerastyle" },
    { 0x7F9C, "setkillstreaks" },
    { 0x7F9D, "setlastcallouttype" },
    { 0x7F9E, "setlaststoppedtime" },
    { 0x7F9F, "setlevelcompleted" },
    { 0x7FA0, "setlightarmor" },
    { 0x7FA1, "setlightarmorhp" },
    { 0x7FA2, "setlightingstate" },
    { 0x7FA3, "setlightweight" },
    { 0x7FA4, "setlocaljammer" },
    { 0x7FA5, "setlowermessage" },
    { 0x7FA6, "setmapcenterfordev" },
    { 0x7FA7, "setmapkillstreaktimer" },
    { 0x7FA8, "setmarksman" },
    { 0x7FA9, "setmeleeattackdist" },
    { 0x7FAA, "setmenu" },
    { 0x7FAB, "setmineteamheadicon" },
    { 0x7FAC, "setmissilespecialclipmaskdelayed" },
    { 0x7FAD, "setmisstime" },
    { 0x7FAE, "setmlgicons" },
    { 0x7FAF, "setmodel_warbird" },
    { 0x7FB0, "setmodelfromarray" },
    { 0x7FB1, "setmodelremoteturret" },
    { 0x7FB2, "setmodelturretbaseonly" },
    { 0x7FB3, "setmodelturretplacementfailed" },
    { 0x7FB4, "setmodelturretplacementgood" },
    { 0x7FB5, "setmodelvisibility" },
    { 0x7FB6, "setmoveanim" },
    { 0x7FB7, "setmovenonforwardanims" },
    { 0x7FB8, "setmovespeedincrease" },
    { 0x7FB9, "setmpinstinctplayer" },
    { 0x7FBA, "setnameandrank_andaddtosquad" },
    { 0x7FBB, "setneutralicons" },
    { 0x7FBC, "setnewplayerchain" },
    { 0x7FBD, "setnextdogattackallowtime" },
    { 0x7FBE, "setnextplayergrenadetime" },
    { 0x7FBF, "setnotetrackeffect" },
    { 0x7FC0, "setnotetracksound" },
    { 0x7FC1, "setnpcid" },
    { 0x7FC2, "setobjatrium" },
    { 0x7FC3, "setobjectivehinttext" },
    { 0x7FC4, "setobjectivescoretext" },
    { 0x7FC5, "setobjectivetext" },
    { 0x7FC6, "setobjectivetextcolors" },
    { 0x7FC7, "setobjfollowtarget" },
    { 0x7FC8, "setobjinfilsafehouse" },
    { 0x7FC9, "setobjintercepthades" },
    { 0x7FCA, "setobjmarketscan" },
    { 0x7FCB, "setobjsniperdronesupport" },
    { 0x7FCC, "setoceansinvalueshightide" },
    { 0x7FCD, "setoceansinvalueslowtide" },
    { 0x7FCE, "setoldslam" },
    { 0x7FCF, "setonemanarmy" },
    { 0x7FD0, "setorbitallaserforteam" },
    { 0x7FD1, "setorbitalsupportbuddy" },
    { 0x7FD2, "setorbitalsupportplayer" },
    { 0x7FD3, "setorbitalview" },
    { 0x7FD4, "setoriginbyname" },
    { 0x7FD5, "setospvisionandlightsetpermap" },
    { 0x7FD6, "setoverdrive" },
    { 0x7FD7, "setoverkillpro" },
    { 0x7FD8, "setoverridewatchdvar" },
    { 0x7FD9, "setovertimelimitdvar" },
    { 0x7FDA, "setownerteam" },
    { 0x7FDB, "setpainted" },
    { 0x7FDC, "setparent" },
    { 0x7FDD, "setpastpursuitfailed" },
    { 0x7FDE, "setpersonalbestifgreater" },
    { 0x7FDF, "setpersonalbestiflower" },
    { 0x7FE0, "setpersonaluav" },
    { 0x7FE1, "setpersstat" },
    { 0x7FE2, "setpickedup" },
    { 0x7FE3, "setplayer_anims" },
    { 0x7FE4, "setplayerbcnameid" },
    { 0x7FE5, "setplayerheadicon" },
    { 0x7FE6, "setplayerheadicon_large" },
    { 0x7FE7, "setplayermodels" },
    { 0x7FE8, "setplayerscoreboardinfo" },
    { 0x7FE9, "setplayerstance" },
    { 0x7FEA, "setplayerstat" },
    { 0x7FEB, "setplayerstatifgreater" },
    { 0x7FEC, "setplayerstatiflower" },
    { 0x7FED, "setplayertocamera" },
    { 0x7FEE, "setpoint" },
    { 0x7FEF, "setpointbar" },
    { 0x7FF0, "setpose" },
    { 0x7FF1, "setposemovement" },
    { 0x7FF2, "setposemovementfnarray" },
    { 0x7FF3, "setposition" },
    { 0x7FF4, "setposture" },
    { 0x7FF5, "setprimaryspawnweapon" },
    { 0x7FF6, "setprisonturretplayer" },
    { 0x7FF7, "setragdolldeath" },
    { 0x7FF8, "setrambogrenadeoffsets" },
    { 0x7FF9, "setrandomorbitalsupportstartposition" },
    { 0x7FFA, "setrearview" },
    { 0x7FFB, "setrecoilscale" },
    { 0x7FFC, "setrefillgrenades" },
    { 0x7FFD, "setrefractionturretplayer" },
    { 0x7FFE, "setregenspeed" },
    { 0x7FFF, "setripoffturrethead" },
    { 0x8000, "setsaboteur" },
    { 0x8001, "setsafehouseextdrawdist" },
    { 0x8002, "setsafehouseintdrawdist" },
    { 0x8003, "setsaveddvar_cg_ng" },
    { 0x8004, "setselfunusuable" },
    { 0x8005, "setselfusable" },
    { 0x8006, "setshallowwaterweapon" },
    { 0x8007, "setsharpfocus" },
    { 0x8008, "setshield" },
    { 0x8009, "setshootenttoenemy" },
    { 0x800A, "setshootstyle" },
    { 0x800B, "setshootstyleforsuppression" },
    { 0x800C, "setshootstyleforvisibleenemy" },
    { 0x800D, "setshootwhilemoving" },
    { 0x800E, "setshowgrenades" },
    { 0x800F, "setsize" },
    { 0x8010, "setskill" },
    { 0x8011, "setsniperaccuracy" },
    { 0x8012, "setsolarreflectorplayer" },
    { 0x8013, "setsonicblast" },
    { 0x8014, "setsoundstate" },
    { 0x8015, "setspawnpoint" },
    { 0x8016, "setspawnvariables" },
    { 0x8017, "setspecialloadout" },
    { 0x8018, "setspecialloadouts" },
    { 0x8019, "setspectatepermissions" },
    { 0x801A, "setspectator" },
    { 0x801B, "setsteadyaimpro" },
    { 0x801C, "setsteelnerves" },
    { 0x801D, "setstencilstate" },
    { 0x801E, "setstim" },
    { 0x801F, "setstoppingpower" },
    { 0x8020, "setstunresistance" },
    { 0x8021, "setsurvivaltime" },
    { 0x8022, "settacticalinsertion" },
    { 0x8023, "settargetandshader" },
    { 0x8024, "settargetangularacceleration" },
    { 0x8025, "settargetentity_smoothtracking" },
    { 0x8026, "settargetoutline" },
    { 0x8027, "setteam" },
    { 0x8028, "setteamheadicon" },
    { 0x8029, "setteamheadicon_large" },
    { 0x802A, "setteamicons" },
    { 0x802B, "setteammodels" },
    { 0x802C, "setteamradarwrapper" },
    { 0x802D, "setteamusetext" },
    { 0x802E, "setteamusetime" },
    { 0x802F, "setthermal" },
    { 0x8030, "setthermaldof" },
    { 0x8031, "setthirdpersondof" },
    { 0x8032, "settimeofnextsound" },
    { 0x8033, "settimeromnvar" },
    { 0x8034, "settings" },
    { 0x8035, "settoneverdelete" },
    { 0x8036, "settridroneteamheadicon" },
    { 0x8037, "setturretfireondrones" },
    { 0x8038, "setturretusable" },
    { 0x8039, "settweakablelastvalue" },
    { 0x803A, "settweakablevalue" },
    { 0x803B, "setuav" },
    { 0x803C, "setuioptionsmenu" },
    { 0x803D, "setunderwateraudiozone" },
    { 0x803E, "setunstableground" },
    { 0x803F, "setup" },
    { 0x8040, "setup_a10_waits" },
    { 0x8041, "setup_additive_aim" },
    { 0x8042, "setup_ai" },
    { 0x8043, "setup_ai_eq_triggers" },
    { 0x8044, "setup_ai_for_bus_sequence" },
    { 0x8045, "setup_aianimthreads" },
    { 0x8046, "setup_alley_anims" },
    { 0x8047, "setup_alley_escape_breach" },
    { 0x8048, "setup_alley_wall_climb_foley" },
    { 0x8049, "setup_allies" },
    { 0x804A, "setup_ally_squad" },
    { 0x804B, "setup_ally_squad_member" },
    { 0x804C, "setup_alpha_squad" },
    { 0x804D, "setup_ambient_walker_tank" },
    { 0x804E, "setup_and_fire_missles_at_guys_repeated" },
    { 0x804F, "setup_anim_array" },
    { 0x8050, "setup_anim_receivers" },
    { 0x8051, "setup_animated_guy" },
    { 0x8052, "setup_atlas_drone" },
    { 0x8053, "setup_audio" },
    { 0x8054, "setup_audio_dnabomb" },
    { 0x8055, "setup_audio_zone_bridge_intact" },
    { 0x8056, "setup_audio_zone_tunnel" },
    { 0x8057, "setup_bigmoment_notetracks" },
    { 0x8058, "setup_bones" },
    { 0x8059, "setup_bot_ball" },
    { 0x805A, "setup_bot_conf" },
    { 0x805B, "setup_bot_ctf" },
    { 0x805C, "setup_bot_dom" },
    { 0x805D, "setup_bot_gun" },
    { 0x805E, "setup_bot_hp" },
    { 0x805F, "setup_bot_infect" },
    { 0x8060, "setup_bot_sd" },
    { 0x8061, "setup_bot_twar" },
    { 0x8062, "setup_bot_war" },
    { 0x8063, "setup_boulder_audio" },
    { 0x8064, "setup_boulder_data" },
    { 0x8065, "setup_breach_marker" },
    { 0x8066, "setup_bridge_explosion_anim_sequence" },
    { 0x8067, "setup_bridge_explosion_anim_sequence_bridge" },
    { 0x8068, "setup_bridge_explosion_anim_sequence_humans" },
    { 0x8069, "setup_bridge_explosion_anim_sequence_vehicles" },
    { 0x806A, "setup_bridge_explosion_trigger" },
    { 0x806B, "setup_briefing_anims" },
    { 0x806C, "setup_buddy_drone_deploy_anims" },
    { 0x806D, "setup_building_traverse_and_vista" },
    { 0x806E, "setup_burke" },
    { 0x806F, "setup_burke_aim_anims" },
    { 0x8070, "setup_burke_river_cross_notetracks" },
    { 0x8071, "setup_button_notifies" },
    { 0x8072, "setup_callbacks" },
    { 0x8073, "setup_camparams" },
    { 0x8074, "setup_canyon" },
    { 0x8075, "setup_canyon_dam" },
    { 0x8076, "setup_canyon_dam_old_controls" },
    { 0x8077, "setup_canyon_exit" },
    { 0x8078, "setup_canyon_old_controls" },
    { 0x8079, "setup_canyon2" },
    { 0x807A, "setup_canyon2_old_controls" },
    { 0x807B, "setup_canyon3" },
    { 0x807C, "setup_canyon3_old_controls" },
    { 0x807D, "setup_capture" },
    { 0x807E, "setup_car_passing_lights" },
    { 0x807F, "setup_car_ride_moment" },
    { 0x8080, "setup_cave_entry_loading_razorback" },
    { 0x8081, "setup_cg_start_points" },
    { 0x8082, "setup_charged_shot" },
    { 0x8083, "setup_cherry_picker_turret" },
    { 0x8084, "setup_chopper_crash_anims" },
    { 0x8085, "setup_choppers" },
    { 0x8086, "setup_civ_animations" },
    { 0x8087, "setup_civ_fence_special" },
    { 0x8088, "setup_civs" },
    { 0x8089, "setup_civs_baseball" },
    { 0x808A, "setup_civs_fence" },
    { 0x808B, "setup_civs_foodtruck" },
    { 0x808C, "setup_civs_infosign" },
    { 0x808D, "setup_civs_talking" },
    { 0x808E, "setup_civs_walkers" },
    { 0x808F, "setup_cleanup_vehicle" },
    { 0x8090, "setup_climb_anims" },
    { 0x8091, "setup_climb_anims_parse_anim_offsets" },
    { 0x8092, "setup_climb_model" },
    { 0x8093, "setup_climb_special_arrays" },
    { 0x8094, "setup_clip" },
    { 0x8095, "setup_clip_pickups" },
    { 0x8096, "setup_cloak_cover" },
    { 0x8097, "setup_combat" },
    { 0x8098, "setup_common" },
    { 0x8099, "setup_complete_missile_not_prefab" },
    { 0x809A, "setup_complete_missile_prefab" },
    { 0x809B, "setup_control_room_door_explosion_light" },
    { 0x809C, "setup_control_room_player_start" },
    { 0x809D, "setup_control_room_scene_dof" },
    { 0x809E, "setup_control_room_screen_light" },
    { 0x809F, "setup_cormack_meetup_scene_notetracks" },
    { 0x80A0, "setup_corpses" },
    { 0x80A1, "setup_cover_crouch" },
    { 0x80A2, "setup_cover_nodes_street" },
    { 0x80A3, "setup_cover_prone" },
    { 0x80A4, "setup_cover_stand" },
    { 0x80A5, "setup_crash_events" },
    { 0x80A6, "setup_crash_flicker_presets" },
    { 0x80A7, "setup_crash_light_motions" },
    { 0x80A8, "setup_crash_site_intro_anims" },
    { 0x80A9, "setup_crevasse_fall_and_recover" },
    { 0x80AA, "setup_crouching_anim_array" },
    { 0x80AB, "setup_day_lighting_volume" },
    { 0x80AC, "setup_deck_deploy_warbird" },
    { 0x80AD, "setup_decon_gate_anims" },
    { 0x80AE, "setup_deer_notetracks" },
    { 0x80AF, "setup_default_level_vars" },
    { 0x80B0, "setup_destructible_dots" },
    { 0x80B1, "setup_destructibles" },
    { 0x80B2, "setup_destructibles_thread" },
    { 0x80B3, "setup_det_intro_catch_anims" },
    { 0x80B4, "setup_dialogue" },
    { 0x80B5, "setup_dnabomb" },
    { 0x80B6, "setup_dnabomb_anims" },
    { 0x80B7, "setup_dof_default_interior" },
    { 0x80B8, "setup_dof_default_interior_volume" },
    { 0x80B9, "setup_dof_door_breach" },
    { 0x80BA, "setup_dof_drone" },
    { 0x80BB, "setup_dof_enter_turret" },
    { 0x80BC, "setup_dof_exit_turret" },
    { 0x80BD, "setup_dof_funeral" },
    { 0x80BE, "setup_dof_funeral_cg" },
    { 0x80BF, "setup_dof_government_breach" },
    { 0x80C0, "setup_dof_government_climb" },
    { 0x80C1, "setup_dof_government_overlook" },
    { 0x80C2, "setup_dof_hostage_release" },
    { 0x80C3, "setup_dof_intro" },
    { 0x80C4, "setup_dof_mini_atrium" },
    { 0x80C5, "setup_dof_mini_atrium_volume" },
    { 0x80C6, "setup_dof_presets" },
    { 0x80C7, "setup_dof_roundabout_tanker_explosion" },
    { 0x80C8, "setup_dof_safehousefollow" },
    { 0x80C9, "setup_dof_safehouseintro" },
    { 0x80CA, "setup_dof_security" },
    { 0x80CB, "setup_dof_security_volume" },
    { 0x80CC, "setup_dof_server_room" },
    { 0x80CD, "setup_dof_shoreline" },
    { 0x80CE, "setup_dof_takedownkill" },
    { 0x80CF, "setup_dof_tour_ride" },
    { 0x80D0, "setup_dof_training_2_drone" },
    { 0x80D1, "setup_dof_van_takedown" },
    { 0x80D2, "setup_dof_viewmodel_presets" },
    { 0x80D3, "setup_dont_leave_failure" },
    { 0x80D4, "setup_dont_leave_hint" },
    { 0x80D5, "setup_dont_leave_squad" },
    { 0x80D6, "setup_dont_leave_squad_hint" },
    { 0x80D7, "setup_door_anim" },
    { 0x80D8, "setup_door_anim_leader" },
    { 0x80D9, "setup_doorshield_anims" },
    { 0x80DA, "setup_drive_shadows" },
    { 0x80DB, "setup_drone_intro_anims" },
    { 0x80DC, "setup_drone_mode" },
    { 0x80DD, "setup_drone_street_fight" },
    { 0x80DE, "setup_drone_swarm_crates" },
    { 0x80DF, "setup_droppod_intro_anims" },
    { 0x80E0, "setup_dynamic_detour" },
    { 0x80E1, "setup_elevator_security_light" },
    { 0x80E2, "setup_end_gate" },
    { 0x80E3, "setup_end_scene" },
    { 0x80E4, "setup_ending_anims" },
    { 0x80E5, "setup_entrance_gate_anims" },
    { 0x80E6, "setup_evacuation_scene" },
    { 0x80E7, "setup_exfil_anims" },
    { 0x80E8, "setup_exit_ride_anims" },
    { 0x80E9, "setup_exitdrive_control_hints" },
    { 0x80EA, "setup_exitdrive_encounters" },
    { 0x80EB, "setup_exitdrive_ending_anims" },
    { 0x80EC, "setup_exitdrive_starting_anims" },
    { 0x80ED, "setup_exo_arm_moment_lighting" },
    { 0x80EE, "setup_exo_climb_audio" },
    { 0x80EF, "setup_exo_door_kick_anims" },
    { 0x80F0, "setup_exo_room_lighting_volume" },
    { 0x80F1, "setup_eye_highlights" },
    { 0x80F2, "setup_eye_highlights_02" },
    { 0x80F3, "setup_eye_highlights_gideon" },
    { 0x80F4, "setup_fall_cloth_floey" },
    { 0x80F5, "setup_fastzip_anims" },
    { 0x80F6, "setup_fastzip_unload" },
    { 0x80F7, "setup_fence_climb_anims" },
    { 0x80F8, "setup_final_chopper" },
    { 0x80F9, "setup_final_lighting" },
    { 0x80FA, "setup_final_straightaway_bus_jump" },
    { 0x80FB, "setup_final_straightaway_buttresses" },
    { 0x80FC, "setup_final_straightaway_missiles" },
    { 0x80FD, "setup_finale_anims" },
    { 0x80FE, "setup_firelight_explosion_hangar" },
    { 0x80FF, "setup_firing_range_stall_lighting_volume" },
    { 0x8100, "setup_first_fight_left_guy" },
    { 0x8101, "setup_first_fight_right_guy1" },
    { 0x8102, "setup_first_fight_right_guy2" },
    { 0x8103, "setup_flag_exploders" },
    { 0x8104, "setup_flank_wall_climb_lighting" },
    { 0x8105, "setup_flank_wall_climb_lighting_complete" },
    { 0x8106, "setup_flickerlight_motion_presets" },
    { 0x8107, "setup_flickerlight_presets" },
    { 0x8108, "setup_flickerlight_presets2" },
    { 0x8109, "setup_flipbook_models" },
    { 0x810A, "setup_fob_blocker_guy_loop" },
    { 0x810B, "setup_fog_tweak" },
    { 0x810C, "setup_food_line_and_guards" },
    { 0x810D, "setup_footstep_fx" },
    { 0x810E, "setup_free_drive_path" },
    { 0x810F, "setup_free_run_cover_crouch_anims" },
    { 0x8110, "setup_free_run_move_anims" },
    { 0x8111, "setup_free_run_transition_anims" },
    { 0x8112, "setup_funeral" },
    { 0x8113, "setup_funeral_ambi_fade" },
    { 0x8114, "setup_fusion_finale_arm_fx" },
    { 0x8115, "setup_fusion_finale_arm_rimlight" },
    { 0x8116, "setup_fusion_finale_helicopter_light" },
    { 0x8117, "setup_fusion_finale_light_flicker" },
    { 0x8118, "setup_fusion_finale_light_rim" },
    { 0x8119, "setup_fusion_finale_light_rim_fov" },
    { 0x811A, "setup_fusion_finale_lightgrid" },
    { 0x811B, "setup_fusion_light_model_flicker" },
    { 0x811C, "setup_fusion_light_model_flicker2" },
    { 0x811D, "setup_fusion_light_model_flicker3" },
    { 0x811E, "setup_fx" },
    { 0x811F, "setup_fx_chain" },
    { 0x8120, "setup_gag_stage_littlebird_load" },
    { 0x8121, "setup_gag_stage_littlebird_unload" },
    { 0x8122, "setup_galaxy_hatch" },
    { 0x8123, "setup_gameplay" },
    { 0x8124, "setup_gangnam_station_intersection" },
    { 0x8125, "setup_gate_crash" },
    { 0x8126, "setup_generic_allies" },
    { 0x8127, "setup_generic_no_shot_vo" },
    { 0x8128, "setup_generic_taking_the_shot_vo" },
    { 0x8129, "setup_generic_target_acquired_vo" },
    { 0x812A, "setup_generic_target_down_vo" },
    { 0x812B, "setup_gideon" },
    { 0x812C, "setup_gideon_climb_notetracks" },
    { 0x812D, "setup_gideon_intro_foley" },
    { 0x812E, "setup_goliath_bridge_anims" },
    { 0x812F, "setup_government_climb_sunlerp" },
    { 0x8130, "setup_government_rpg_explosion_dof" },
    { 0x8131, "setup_government_rpg_explosion_lighting" },
    { 0x8132, "setup_groundnode_detour" },
    { 0x8133, "setup_guy_for_animation" },
    { 0x8134, "setup_guy_for_droppod" },
    { 0x8135, "setup_hangar_door_open_sequence" },
    { 0x8136, "setup_hangar_interior_walls" },
    { 0x8137, "setup_hangar_notetracks" },
    { 0x8138, "setup_hangar_shadow_shell" },
    { 0x8139, "setup_harmonic_breach_anims" },
    { 0x813A, "setup_hazmant_suit_room" },
    { 0x813B, "setup_hazmat_intro_allies" },
    { 0x813C, "setup_helicopter_blades_damage" },
    { 0x813D, "setup_help_keys" },
    { 0x813E, "setup_hemiao_enable" },
    { 0x813F, "setup_hero" },
    { 0x8140, "setup_hints" },
    { 0x8141, "setup_hospital" },
    { 0x8142, "setup_hospital_bodies" },
    { 0x8143, "setup_hospital_notetracks" },
    { 0x8144, "setup_hospital_post_breach_anims" },
    { 0x8145, "setup_hospital_transition" },
    { 0x8146, "setup_hostage_key_fov_tune" },
    { 0x8147, "setup_hotel_exo_punch_breach_anims" },
    { 0x8148, "setup_hoverbike_meet_up_notetracks" },
    { 0x8149, "setup_hovertank" },
    { 0x814A, "setup_hovertank_combat" },
    { 0x814B, "setup_hud_elem" },
    { 0x814C, "setup_hud_lighting" },
    { 0x814D, "setup_ignore_suppression_triggers" },
    { 0x814E, "setup_ilona_lighting" },
    { 0x814F, "setup_individual_exploder" },
    { 0x8150, "setup_injured_soldiers" },
    { 0x8151, "setup_intel_cormack" },
    { 0x8152, "setup_intel_main" },
    { 0x8153, "setup_intel_player" },
    { 0x8154, "setup_intro" },
    { 0x8155, "setup_intro_canyon" },
    { 0x8156, "setup_intro_canyon_old_controls" },
    { 0x8157, "setup_intro_old_controls" },
    { 0x8158, "setup_investigate_location" },
    { 0x8159, "setup_jet_waits" },
    { 0x815A, "setup_jetbike_checkpoint_anims" },
    { 0x815B, "setup_jetbike_motorpool_anims" },
    { 0x815C, "setup_joker" },
    { 0x815D, "setup_kill_drone_trig" },
    { 0x815E, "setup_kill_drone_trig_proc" },
    { 0x815F, "setup_knockdown_sequence" },
    { 0x8160, "setup_lab_entrance_light" },
    { 0x8161, "setup_lab_script_exit_volume" },
    { 0x8162, "setup_lab_script_volume" },
    { 0x8163, "setup_lagos_intro_alley_transition_volume" },
    { 0x8164, "setup_lagos_intro_alley_volume" },
    { 0x8165, "setup_lagos_intro_interiors_post_exo_volume" },
    { 0x8166, "setup_lagos_intro_interiors_volume" },
    { 0x8167, "setup_lake_anims" },
    { 0x8168, "setup_land_assist_jump_anims" },
    { 0x8169, "setup_lane_information" },
    { 0x816A, "setup_last_movement_timer" },
    { 0x816B, "setup_level_lighting_values" },
    { 0x816C, "setup_level_rumble_ent" },
    { 0x816D, "setup_level_transient_zone_variable" },
    { 0x816E, "setup_levelvars" },
    { 0x816F, "setup_lightgrid_lighting_drone" },
    { 0x8170, "setup_lighting" },
    { 0x8171, "setup_lighting_alley" },
    { 0x8172, "setup_lighting_alley_interiors" },
    { 0x8173, "setup_lighting_alley_interiors_volume" },
    { 0x8174, "setup_lighting_alley_volume" },
    { 0x8175, "setup_lighting_alley1_start" },
    { 0x8176, "setup_lighting_alley2_start" },
    { 0x8177, "setup_lighting_ambush" },
    { 0x8178, "setup_lighting_basement_start" },
    { 0x8179, "setup_lighting_boat_crash" },
    { 0x817A, "setup_lighting_boat_start" },
    { 0x817B, "setup_lighting_canal_area" },
    { 0x817C, "setup_lighting_canal_area_volume" },
    { 0x817D, "setup_lighting_chase_buildings" },
    { 0x817E, "setup_lighting_chase_buildings_volume" },
    { 0x817F, "setup_lighting_chase_start" },
    { 0x8180, "setup_lighting_chase_start_volume" },
    { 0x8181, "setup_lighting_chase_tunnel" },
    { 0x8182, "setup_lighting_chase_tunnel_transition" },
    { 0x8183, "setup_lighting_chase_tunnel_transition_volume" },
    { 0x8184, "setup_lighting_chase_tunnel_volume" },
    { 0x8185, "setup_lighting_climb_start" },
    { 0x8186, "setup_lighting_confrontation_start" },
    { 0x8187, "setup_lighting_control_room_start" },
    { 0x8188, "setup_lighting_courtyard_start" },
    { 0x8189, "setup_lighting_day" },
    { 0x818A, "setup_lighting_door_breach" },
    { 0x818B, "setup_lighting_drone" },
    { 0x818C, "setup_lighting_drone_attack" },
    { 0x818D, "setup_lighting_elevator_ride" },
    { 0x818E, "setup_lighting_escape_start" },
    { 0x818F, "setup_lighting_exo_hangar" },
    { 0x8190, "setup_lighting_exo_hangar_doorway" },
    { 0x8191, "setup_lighting_exo_hangar_doorway_volume" },
    { 0x8192, "setup_lighting_exo_hangar_volume" },
    { 0x8193, "setup_lighting_exo_room" },
    { 0x8194, "setup_lighting_finale_start" },
    { 0x8195, "setup_lighting_firing_doorway_volume" },
    { 0x8196, "setup_lighting_firing_range" },
    { 0x8197, "setup_lighting_firing_range_doorway" },
    { 0x8198, "setup_lighting_firing_range_entrance" },
    { 0x8199, "setup_lighting_firing_range_entrance_volume" },
    { 0x819A, "setup_lighting_firing_range_exit" },
    { 0x819B, "setup_lighting_firing_range_exit_volume" },
    { 0x819C, "setup_lighting_firing_range_gallery" },
    { 0x819D, "setup_lighting_firing_range_lights_moment" },
    { 0x819E, "setup_lighting_firing_range_stall" },
    { 0x819F, "setup_lighting_firing_range_stall_01_volume" },
    { 0x81A0, "setup_lighting_firing_range_stall_02_volume" },
    { 0x81A1, "setup_lighting_firing_range_stall_03_volume" },
    { 0x81A2, "setup_lighting_firing_range_stall_04_volume" },
    { 0x81A3, "setup_lighting_firing_range_stall_05_volume" },
    { 0x81A4, "setup_lighting_firing_range_stall_06_volume" },
    { 0x81A5, "setup_lighting_firing_range_stall_07_volume" },
    { 0x81A6, "setup_lighting_firing_range_stall_08_volume" },
    { 0x81A7, "setup_lighting_firing_range_stall_exposure" },
    { 0x81A8, "setup_lighting_firing_range_volume" },
    { 0x81A9, "setup_lighting_flank_start" },
    { 0x81AA, "setup_lighting_fly_drone" },
    { 0x81AB, "setup_lighting_fly_drone_off" },
    { 0x81AC, "setup_lighting_fly_drone_off_night" },
    { 0x81AD, "setup_lighting_fly_drone_off_turbine" },
    { 0x81AE, "setup_lighting_fly_drone_turbine" },
    { 0x81AF, "setup_lighting_frogger_start" },
    { 0x81B0, "setup_lighting_funeral_sequence" },
    { 0x81B1, "setup_lighting_funeral_start" },
    { 0x81B2, "setup_lighting_fx_during_mini_games" },
    { 0x81B3, "setup_lighting_generic_volume" },
    { 0x81B4, "setup_lighting_government" },
    { 0x81B5, "setup_lighting_government_breach" },
    { 0x81B6, "setup_lighting_government_ext" },
    { 0x81B7, "setup_lighting_government_ext_volume" },
    { 0x81B8, "setup_lighting_government_hostage" },
    { 0x81B9, "setup_lighting_government_hostage_volume" },
    { 0x81BA, "setup_lighting_government_overlook" },
    { 0x81BB, "setup_lighting_government_overlook_door" },
    { 0x81BC, "setup_lighting_government_overlook_volume" },
    { 0x81BD, "setup_lighting_government_start" },
    { 0x81BE, "setup_lighting_government_volume" },
    { 0x81BF, "setup_lighting_hangar_demos" },
    { 0x81C0, "setup_lighting_hangar_doors" },
    { 0x81C1, "setup_lighting_harmonic_breach" },
    { 0x81C2, "setup_lighting_harmonic_breach_dof" },
    { 0x81C3, "setup_lighting_harmonic_breach_hud" },
    { 0x81C4, "setup_lighting_hostage_release" },
    { 0x81C5, "setup_lighting_house_interior" },
    { 0x81C6, "setup_lighting_house_interior_transition" },
    { 0x81C7, "setup_lighting_house_interior_transition_volume" },
    { 0x81C8, "setup_lighting_house_interior_volume" },
    { 0x81C9, "setup_lighting_initial_rpgs" },
    { 0x81CA, "setup_lighting_intro_drone" },
    { 0x81CB, "setup_lighting_intro_start" },
    { 0x81CC, "setup_lighting_lab_interior" },
    { 0x81CD, "setup_lighting_lab_interior_volume" },
    { 0x81CE, "setup_lighting_lab_start" },
    { 0x81CF, "setup_lighting_lab_warehouse" },
    { 0x81D0, "setup_lighting_lab_warehouse_volume" },
    { 0x81D1, "setup_lighting_lagos_generic" },
    { 0x81D2, "setup_lighting_lagos_intro_alley" },
    { 0x81D3, "setup_lighting_lagos_intro_alley_transition" },
    { 0x81D4, "setup_lighting_lagos_intro_interiors" },
    { 0x81D5, "setup_lighting_lagos_intro_post_exo_interiors" },
    { 0x81D6, "setup_lighting_lagos_sunflare_volume" },
    { 0x81D7, "setup_lighting_lobby" },
    { 0x81D8, "setup_lighting_lobby_volume" },
    { 0x81D9, "setup_lighting_marketplace" },
    { 0x81DA, "setup_lighting_marketplace_interiors" },
    { 0x81DB, "setup_lighting_marketplace_interiors_volume" },
    { 0x81DC, "setup_lighting_marketplace_volume" },
    { 0x81DD, "setup_lighting_middle_takedown_start" },
    { 0x81DE, "setup_lighting_night" },
    { 0x81DF, "setup_lighting_night_pool" },
    { 0x81E0, "setup_lighting_office_start" },
    { 0x81E1, "setup_lighting_old_town_start" },
    { 0x81E2, "setup_lighting_oncoming_start" },
    { 0x81E3, "setup_lighting_outro" },
    { 0x81E4, "setup_lighting_outro_start" },
    { 0x81E5, "setup_lighting_outro_volume" },
    { 0x81E6, "setup_lighting_override_exo_wallclimb" },
    { 0x81E7, "setup_lighting_pantry_interior" },
    { 0x81E8, "setup_lighting_pantry_interior_volume" },
    { 0x81E9, "setup_lighting_post_h_breach_start" },
    { 0x81EA, "setup_lighting_post_middle_takedown_start" },
    { 0x81EB, "setup_lighting_pre_h_breach_start" },
    { 0x81EC, "setup_lighting_rail_start" },
    { 0x81ED, "setup_lighting_railwalk" },
    { 0x81EE, "setup_lighting_railwalk_volume" },
    { 0x81EF, "setup_lighting_reactor_exit_start" },
    { 0x81F0, "setup_lighting_reactor_start" },
    { 0x81F1, "setup_lighting_ready_room_elevators" },
    { 0x81F2, "setup_lighting_rec_yard" },
    { 0x81F3, "setup_lighting_rec_yard_transition" },
    { 0x81F4, "setup_lighting_rec_yard_transition_volume" },
    { 0x81F5, "setup_lighting_rec_yard_volume" },
    { 0x81F6, "setup_lighting_roof_start" },
    { 0x81F7, "setup_lighting_roundabout" },
    { 0x81F8, "setup_lighting_roundabout_start" },
    { 0x81F9, "setup_lighting_roundabout_transition" },
    { 0x81FA, "setup_lighting_roundabout_transition_volume" },
    { 0x81FB, "setup_lighting_roundabout_volume" },
    { 0x81FC, "setup_lighting_security_start" },
    { 0x81FD, "setup_lighting_sewer_start" },
    { 0x81FE, "setup_lighting_shoreline" },
    { 0x81FF, "setup_lighting_shoreline_start" },
    { 0x8200, "setup_lighting_sunflare" },
    { 0x8201, "setup_lighting_suv_takedown" },
    { 0x8202, "setup_lighting_swim_start" },
    { 0x8203, "setup_lighting_tanker_aftermath" },
    { 0x8204, "setup_lighting_tanker_aftermath_cleanup" },
    { 0x8205, "setup_lighting_tanker_aftermath_volume" },
    { 0x8206, "setup_lighting_tour_augmented_reality_start" },
    { 0x8207, "setup_lighting_tour_end_start" },
    { 0x8208, "setup_lighting_tour_exo_begin_start" },
    { 0x8209, "setup_lighting_tour_exo_exit_start" },
    { 0x820A, "setup_lighting_tour_firing_range_start" },
    { 0x820B, "setup_lighting_tour_ride_begin_start" },
    { 0x820C, "setup_lighting_traffic_crossing" },
    { 0x820D, "setup_lighting_traffic_crossing_volume" },
    { 0x820E, "setup_lighting_training_2_begin_start" },
    { 0x820F, "setup_lighting_training_2_end_start" },
    { 0x8210, "setup_lighting_training_2_golf_course_start" },
    { 0x8211, "setup_lighting_training_2_lodge_begin_start" },
    { 0x8212, "setup_lighting_training_2_lodge_breach_start" },
    { 0x8213, "setup_lighting_training_2_lodge_exit_start" },
    { 0x8214, "setup_lighting_training_2_transition" },
    { 0x8215, "setup_lighting_training_2_transition_volume" },
    { 0x8216, "setup_lighting_training_begin_start" },
    { 0x8217, "setup_lighting_training_end_character_sequence" },
    { 0x8218, "setup_lighting_training_end_start" },
    { 0x8219, "setup_lighting_training_golf_course_start" },
    { 0x821A, "setup_lighting_training_lodge_begin_start" },
    { 0x821B, "setup_lighting_training_lodge_breach_start" },
    { 0x821C, "setup_lighting_training_lodge_exit_start" },
    { 0x821D, "setup_lighting_turbine_start" },
    { 0x821E, "setup_lighting_underwater" },
    { 0x821F, "setup_lighting_underwater_lights" },
    { 0x8220, "setup_lighting_underwater_start" },
    { 0x8221, "setup_lighting_underwater_sunlerp" },
    { 0x8222, "setup_lighting_underwater_volume" },
    { 0x8223, "setup_lighting_van_takedown" },
    { 0x8224, "setup_lighting_van_takedown_start" },
    { 0x8225, "setup_lighting_weapons_platform_area" },
    { 0x8226, "setup_lighting_weapons_platform_area_volume" },
    { 0x8227, "setup_lightning_transition" },
    { 0x8228, "setup_lights_pre_elevator" },
    { 0x8229, "setup_lower_atmosphere_fall" },
    { 0x822A, "setup_m_turret" },
    { 0x822B, "setup_mag_glove_anims" },
    { 0x822C, "setup_main_missile" },
    { 0x822D, "setup_mall_sizeup_anims" },
    { 0x822E, "setup_mech_for_drop" },
    { 0x822F, "setup_mech_grapple_kill_anims" },
    { 0x8230, "setup_mechs" },
    { 0x8231, "setup_meet_cormack_pt2_objective" },
    { 0x8232, "setup_mg_turrets" },
    { 0x8233, "setup_middle_notetracks" },
    { 0x8234, "setup_mig29_waits" },
    { 0x8235, "setup_miniguns" },
    { 0x8236, "setup_missile_launchers" },
    { 0x8237, "setup_mob_turret" },
    { 0x8238, "setup_mob_turret_targets" },
    { 0x8239, "setup_mobile_turret" },
    { 0x823A, "setup_mobile_turret_gameplay" },
    { 0x823B, "setup_motion_blur_chase_start" },
    { 0x823C, "setup_motion_blur_oncoming" },
    { 0x823D, "setup_motorpool" },
    { 0x823E, "setup_move_chase_van" },
    { 0x823F, "setup_move_friendly_pitbull" },
    { 0x8240, "setup_move_player_pitbull" },
    { 0x8241, "setup_names" },
    { 0x8242, "setup_narrow_cave_anims" },
    { 0x8243, "setup_new_eq_settings" },
    { 0x8244, "setup_night_lighting_pool_volume" },
    { 0x8245, "setup_night_lighting_volume" },
    { 0x8246, "setup_nightclub_notetracks" },
    { 0x8247, "setup_nothing" },
    { 0x8248, "setup_npc_cloak_button_anims" },
    { 0x8249, "setup_npc_paths" },
    { 0x824A, "setup_npc_pod_landings" },
    { 0x824B, "setup_objective_flags" },
    { 0x824C, "setup_objectives" },
    { 0x824D, "setup_openning_vista" },
    { 0x824E, "setup_orange_room_enter" },
    { 0x824F, "setup_orange_room_enter_volume" },
    { 0x8250, "setup_orange_room_exit" },
    { 0x8251, "setup_orange_room_exit_volume" },
    { 0x8252, "setup_orbital_entry" },
    { 0x8253, "setup_outerspacelighting_interior" },
    { 0x8254, "setup_outro" },
    { 0x8255, "setup_outro_notetracks" },
    { 0x8256, "setup_park_rpg_barrage" },
    { 0x8257, "setup_pdrone_animations" },
    { 0x8258, "setup_pdrone_type" },
    { 0x8259, "setup_personal_drone" },
    { 0x825A, "setup_personalities" },
    { 0x825B, "setup_physical_dof_fob" },
    { 0x825C, "setup_pitbull_vfx_lights" },
    { 0x825D, "setup_player" },
    { 0x825E, "setup_player_blocking_shot_vo" },
    { 0x825F, "setup_player_driving_anims" },
    { 0x8260, "setup_player_fall" },
    { 0x8261, "setup_player_fall_fog" },
    { 0x8262, "setup_player_for_animated_sequence" },
    { 0x8263, "setup_player_for_gameplay" },
    { 0x8264, "setup_player_for_scene" },
    { 0x8265, "setup_player_pitbull" },
    { 0x8266, "setup_player_pod" },
    { 0x8267, "setup_player_pod_b" },
    { 0x8268, "setup_player_pod_exit" },
    { 0x8269, "setup_player_takedown_notetracks" },
    { 0x826A, "setup_pm_rescue_anims" },
    { 0x826B, "setup_pod_eject_anims" },
    { 0x826C, "setup_pod_exit_anims" },
    { 0x826D, "setup_poison_gas_death" },
    { 0x826E, "setup_portal_scripting" },
    { 0x826F, "setup_post_refuel" },
    { 0x8270, "setup_post_refuel_old_controls" },
    { 0x8271, "setup_post_tower" },
    { 0x8272, "setup_precache" },
    { 0x8273, "setup_queen_drone" },
    { 0x8274, "setup_rappel_marker" },
    { 0x8275, "setup_reentry" },
    { 0x8276, "setup_refugee_camp_soldiers" },
    { 0x8277, "setup_refugee_camp_soldiers_group_1" },
    { 0x8278, "setup_refugee_stage_audience" },
    { 0x8279, "setup_refugee_stage_speaker" },
    { 0x827A, "setup_regroup_obj" },
    { 0x827B, "setup_reminder_volumes" },
    { 0x827C, "setup_repair_hangar_lighting" },
    { 0x827D, "setup_rider_anims" },
    { 0x827E, "setup_rocket_pieces" },
    { 0x827F, "setup_roof_breach_anims" },
    { 0x8280, "setup_roundabout_point_source_dambs" },
    { 0x8281, "setup_roundabout_rpg_fire_emitters" },
    { 0x8282, "setup_roundabout_tanker_proxy_fire_emitters" },
    { 0x8283, "setup_run_n_gun" },
    { 0x8284, "setup_s2_ally_squad_member" },
    { 0x8285, "setup_safe_vols_near_cardoors" },
    { 0x8286, "setup_school" },
    { 0x8287, "setup_school_bodies" },
    { 0x8288, "setup_school_notetracks" },
    { 0x8289, "setup_school_shimmy_anims" },
    { 0x828A, "setup_school_stealth" },
    { 0x828B, "setup_script_gatetrigger" },
    { 0x828C, "setup_scriptable_primary_light" },
    { 0x828D, "setup_se" },
    { 0x828E, "setup_sentinel_reveal_anims" },
    { 0x828F, "setup_seoul_building_jump_sequence_lighting" },
    { 0x8290, "setup_seoul_canal_start_lighting" },
    { 0x8291, "setup_seoul_drone_swarm_intro_lighting" },
    { 0x8292, "setup_seoul_fob_lighting" },
    { 0x8293, "setup_seoul_hotel_entrance_lighting" },
    { 0x8294, "setup_seoul_hotel_lighting" },
    { 0x8295, "setup_seoul_intro_lighting" },
    { 0x8296, "setup_seoul_jump_lighting" },
    { 0x8297, "setup_seoul_shopping_district_start_lighting" },
    { 0x8298, "setup_seoul_sinkhole_start_lighting" },
    { 0x8299, "setup_seoul_space_entry_lighting" },
    { 0x829A, "setup_seoul_subway_start_lighting" },
    { 0x829B, "setup_server_room_door_open_lighting" },
    { 0x829C, "setup_server_room_lighting" },
    { 0x829D, "setup_server_room_scene_notetracks" },
    { 0x829E, "setup_shg_fx" },
    { 0x829F, "setup_shuffle_anim_array" },
    { 0x82A0, "setup_side_missile" },
    { 0x82A1, "setup_side_missile_prefab" },
    { 0x82A2, "setup_skyjack_anims" },
    { 0x82A3, "setup_skyjack_mag_glove_anims" },
    { 0x82A4, "setup_smart_grenade_pickups" },
    { 0x82A5, "setup_smash_nodes" },
    { 0x82A6, "setup_sniper_debug_hud_elem" },
    { 0x82A7, "setup_sniper_spawns" },
    { 0x82A8, "setup_snipers" },
    { 0x82A9, "setup_social_groups" },
    { 0x82AA, "setup_space_transport" },
    { 0x82AB, "setup_spawn_functions" },
    { 0x82AC, "setup_spawners" },
    { 0x82AD, "setup_squad_for_gameplay" },
    { 0x82AE, "setup_squad_for_scene" },
    { 0x82AF, "setup_squad_member_for_gameplay" },
    { 0x82B0, "setup_squad_member_for_scene" },
    { 0x82B1, "setup_standing_anim_array" },
    { 0x82B2, "setup_start_points" },
    { 0x82B3, "setup_start_points_for_transients" },
    { 0x82B4, "setup_start_transients" },
    { 0x82B5, "setup_start_vehicle_on_path" },
    { 0x82B6, "setup_street_reunion_spawners" },
    { 0x82B7, "setup_subsurface_scatter" },
    { 0x82B8, "setup_sunlight_off" },
    { 0x82B9, "setup_sunlight_off_volume" },
    { 0x82BA, "setup_tank" },
    { 0x82BB, "setup_tank_battle" },
    { 0x82BC, "setup_tanker_crash_notetrack" },
    { 0x82BD, "setup_team" },
    { 0x82BE, "setup_tff_cleanups" },
    { 0x82BF, "setup_tff_transitions" },
    { 0x82C0, "setup_threat_bias_groups" },
    { 0x82C1, "setup_threat_grenade_pickups" },
    { 0x82C2, "setup_threatbias_combat" },
    { 0x82C3, "setup_tour" },
    { 0x82C4, "setup_tour_hangar_doors_lighting" },
    { 0x82C5, "setup_tour_hangar_opening" },
    { 0x82C6, "setup_tour_ride_skin_spec_fix" },
    { 0x82C7, "setup_tracks_1" },
    { 0x82C8, "setup_tracks_2" },
    { 0x82C9, "setup_traffic_group" },
    { 0x82CA, "setup_traffic_path" },
    { 0x82CB, "setup_traffic_path_with_options" },
    { 0x82CC, "setup_traffic_spawner" },
    { 0x82CD, "setup_training_01_end_ambi_swap" },
    { 0x82CE, "setup_training_01_end_compound_ambi_emitter" },
    { 0x82CF, "setup_training_02_breach_smartglass" },
    { 0x82D0, "setup_training_2_breach" },
    { 0x82D1, "setup_training_2_drone" },
    { 0x82D2, "setup_training_2_heli_dof" },
    { 0x82D3, "setup_training_2_heli_lighting" },
    { 0x82D4, "setup_training_2_start_area_lighting" },
    { 0x82D5, "setup_training_2_suv_dof" },
    { 0x82D6, "setup_training_2_suv_fires" },
    { 0x82D7, "setup_training_sequence_1" },
    { 0x82D8, "setup_training_sequence_2" },
    { 0x82D9, "setup_training_start_area_dof" },
    { 0x82DA, "setup_training_start_area_lighting" },
    { 0x82DB, "setup_transient_transitions" },
    { 0x82DC, "setup_triggers" },
    { 0x82DD, "setup_triggers_street_battle" },
    { 0x82DE, "setup_turbine_room_outerspace_lighting" },
    { 0x82DF, "setup_turbine_room_pulsing_lights" },
    { 0x82E0, "setup_turret_anims" },
    { 0x82E1, "setup_underwater_dof" },
    { 0x82E2, "setup_vehicle_for_damage" },
    { 0x82E3, "setup_vehicle_spawners" },
    { 0x82E4, "setup_vehicles" },
    { 0x82E5, "setup_vehicles_for_middle_takedown" },
    { 0x82E6, "setup_vehicles_for_takedown" },
    { 0x82E7, "setup_vfx_lighting" },
    { 0x82E8, "setup_vfx_sunflare" },
    { 0x82E9, "setup_vignette" },
    { 0x82EA, "setup_vo" },
    { 0x82EB, "setup_vols" },
    { 0x82EC, "setup_wake_volumes" },
    { 0x82ED, "setup_wall_climb_foley" },
    { 0x82EE, "setup_wall_pull_anims" },
    { 0x82EF, "setup_wallpull" },
    { 0x82F0, "setup_warbird" },
    { 0x82F1, "setup_warbird_grapple_kill_anims" },
    { 0x82F2, "setup_water_crash" },
    { 0x82F3, "setup_window_explosion_wait" },
    { 0x82F4, "setup_worldhands_anims" },
    { 0x82F5, "setup_zipline_gun" },
    { 0x82F6, "setupaiforanimsequence" },
    { 0x82F7, "setupaiforendinganim" },
    { 0x82F8, "setupaim" },
    { 0x82F9, "setupaitargetmarkingvariables" },
    { 0x82FA, "setupalleysvo" },
    { 0x82FB, "setupamplifierdamagemonitor" },
    { 0x82FC, "setupapproachnode" },
    { 0x82FD, "setupbetrayalportalscripting" },
    { 0x82FE, "setupbigfinaleguys" },
    { 0x82FF, "setupbombsquad" },
    { 0x8300, "setupbotsformapkillstreak" },
    { 0x8301, "setupcallbacks" },
    { 0x8302, "setupcarepackagedrone" },
    { 0x8303, "setupcloaking" },
    { 0x8304, "setupcommonassaultdroneproperties" },
    { 0x8305, "setupconfcentervo" },
    { 0x8306, "setupconvoycrashedvehicles" },
    { 0x8307, "setupcoopturret" },
    { 0x8308, "setupcqbpointsofinterest" },
    { 0x8309, "setupcranechem" },
    { 0x830A, "setupdamagecallback" },
    { 0x830B, "setupdamagecallbackinternal" },
    { 0x830C, "setupdamageflags" },
    { 0x830D, "setupdebughudelem" },
    { 0x830E, "setupdestructiblekillcaments" },
    { 0x830F, "setupdialogue" },
    { 0x8310, "setupdogstate" },
    { 0x8311, "setupdynamicevent" },
    { 0x8312, "setupenemygoalvolumesettings" },
    { 0x8313, "setupexploders" },
    { 0x8314, "setupexposedcombatloop" },
    { 0x8315, "setupfinalebarrier" },
    { 0x8316, "setupflightsounds" },
    { 0x8317, "setupfog" },
    { 0x8318, "setupforrandomspawn" },
    { 0x8319, "setupgaragedoor" },
    { 0x831A, "setupgates" },
    { 0x831B, "setuphadescrashedvehicle" },
    { 0x831C, "setupheavyresistancemodel" },
    { 0x831D, "setupholograms" },
    { 0x831E, "setupkillcament" },
    { 0x831F, "setupkillstreakdevgui" },
    { 0x8320, "setupledgefx" },
    { 0x8321, "setuplongpunch" },
    { 0x8322, "setupmaniac" },
    { 0x8323, "setupmeetingcivilians" },
    { 0x8324, "setupminimap" },
    { 0x8325, "setupmovement" },
    { 0x8326, "setupnearbyspawns" },
    { 0x8327, "setupoceanfoam" },
    { 0x8328, "setuporbitalstrike" },
    { 0x8329, "setupparkinginvestigators" },
    { 0x832A, "setupplayercommands" },
    { 0x832B, "setupplayerdeath" },
    { 0x832C, "setupplayerhud" },
    { 0x832D, "setupplayerinventory" },
    { 0x832E, "setupplayersduringstreak" },
    { 0x832F, "setupplayertargets" },
    { 0x8330, "setuppoolallytargets" },
    { 0x8331, "setuppoolkillvictim" },
    { 0x8332, "setupprisonturrets" },
    { 0x8333, "setupproneaim" },
    { 0x8334, "setupradar" },
    { 0x8335, "setuprandomtable" },
    { 0x8336, "setupriotsuppresionsystem" },
    { 0x8337, "setuprippablemodel" },
    { 0x8338, "setuprobotarmnotetracks" },
    { 0x8339, "setuprockets" },
    { 0x833A, "setuprocketswarm" },
    { 0x833B, "setupsavedactionslots" },
    { 0x833C, "setupshotgunkva" },
    { 0x833D, "setupsniperdebughudelem" },
    { 0x833E, "setupsuperexo" },
    { 0x833F, "setuptrophy" },
    { 0x8340, "setupuniqueanims" },
    { 0x8341, "setupvalidtargetsbyarray" },
    { 0x8342, "setupvalidtargetsbyname" },
    { 0x8343, "setupvehicleanims" },
    { 0x8344, "setupvfxgroup" },
    { 0x8345, "setupwarbirdhud" },
    { 0x8346, "setupwarbirdkillstreak" },
    { 0x8347, "setupwaves" },
    { 0x8348, "setupzones" },
    { 0x8349, "setusablebyteam" },
    { 0x834A, "setusehinttext" },
    { 0x834B, "setusetext" },
    { 0x834C, "setusetime" },
    { 0x834D, "setusingremote" },
    { 0x834E, "setvehgoalpos_wrap" },
    { 0x834F, "setvehgoalposauto" },
    { 0x8350, "setvehiclefx" },
    { 0x8351, "setvirtuallobbypresentable" },
    { 0x8352, "setvisibleteam" },
    { 0x8353, "setvulcanvisionandlightsetpermap" },
    { 0x8354, "setwaitingicons" },
    { 0x8355, "setwarbirdvisionsetpermap" },
    { 0x8356, "setweaponstat" },
    { 0x8357, "setweaponusagevariables" },
    { 0x8358, "setwidth" },
    { 0x8359, "setxenonranks" },
    { 0x835A, "severed_arm_anim" },
    { 0x835B, "sewer_exit_monitor_player_weapon_fire" },
    { 0x835C, "sewer_scene_backtrack_fail_send_in_flyers" },
    { 0x835D, "sewer_scene_backtrack_failure" },
    { 0x835E, "sewer_scene_checkpoint_fail_conditions" },
    { 0x835F, "sewer_scene_checkpoint_failed_player_jumped_down" },
    { 0x8360, "sewer_scene_checkpoint_failed_player_shot" },
    { 0x8361, "sewer_scene_checkpoint_failed_player_stayed_behind" },
    { 0x8362, "sewer_scene_checkpoint_failed_player_too_close" },
    { 0x8363, "sewer_scene_checkpoint_failed_player_went_back" },
    { 0x8364, "sewer_scene_checkpoint_guard_wakeup" },
    { 0x8365, "sewer_scene_checkpoint_handle_guard_wakeup" },
    { 0x8366, "sewer_scene_checkpoint_player_killvol_handling" },
    { 0x8367, "sewer_scene_chkpt_fail_extra_hunters" },
    { 0x8368, "sewer_scene_chkpt_fail_extra_hunters_setup" },
    { 0x8369, "sewer_scene_chkpt_fail_warbird" },
    { 0x836A, "sewer_scene_cleanup" },
    { 0x836B, "sewer_scene_dialogue_manager" },
    { 0x836C, "sewer_scene_drone_oppresion_fly" },
    { 0x836D, "sewer_scene_drone_surprise_ilona" },
    { 0x836E, "sewer_scene_drone_vehicle_setup" },
    { 0x836F, "sewer_scene_guards_alerted_wake_up_scene" },
    { 0x8370, "sewer_scene_handle_opression_event" },
    { 0x8371, "sewer_scene_ilona_movement_manager" },
    { 0x8372, "sewer_scene_manhole_backtrack_failure" },
    { 0x8373, "sewer_scene_manhole_interaction" },
    { 0x8374, "sewer_scene_manhole_spawn_swim_swarm" },
    { 0x8375, "sewer_scene_market_atlas_oppression_setup" },
    { 0x8376, "sewer_scene_market_bystander_oppression_setup" },
    { 0x8377, "sewer_scene_market_section" },
    { 0x8378, "sewer_scene_market_section_handle_ilona_move" },
    { 0x8379, "sewer_scene_market_vig_civ_init" },
    { 0x837A, "sewer_scene_master_handler" },
    { 0x837B, "sewer_scene_oppresion_guys" },
    { 0x837C, "sewer_scene_oppression_civ01" },
    { 0x837D, "sewer_scene_oppression_civ02" },
    { 0x837E, "sewer_scene_oppression_guard" },
    { 0x837F, "sewer_scene_scripted_objects" },
    { 0x8380, "sewer_scene_setup" },
    { 0x8381, "sewer_scene_setup_manholde_vignette_civs" },
    { 0x8382, "sewer_scene_spawn_guards_at_market_checkpoint" },
    { 0x8383, "sewer_scene_store_oppresion_guy" },
    { 0x8384, "sewer_scene_swim_cleanup" },
    { 0x8385, "sewer_scene_teleport_ilona_to_sewer_exit" },
    { 0x8386, "sewer_scene_vignette_actor_flee" },
    { 0x8387, "sewer_scene_vignette_bystander_react" },
    { 0x8388, "sf_b_bridge_burk" },
    { 0x8389, "sf_b_bridge_cormack" },
    { 0x838A, "sf_b_bridge_maddox" },
    { 0x838B, "sf_b_videolog" },
    { 0x838C, "sfa_generic_traffic_constructor" },
    { 0x838D, "sfb_end_logo" },
    { 0x838E, "sfb_intro_burke_foley" },
    { 0x838F, "sfb_intro_car_explode" },
    { 0x8390, "shack_explode" },
    { 0x8391, "shack_roof_damage_fx" },
    { 0x8392, "shader" },
    { 0x8393, "shader_height" },
    { 0x8394, "shader_width" },
    { 0x8395, "shadow_bar2_enter" },
    { 0x8396, "shadow_bar2_exit" },
    { 0x8397, "shadow_card" },
    { 0x8398, "shadow_destroyed_trigger_think" },
    { 0x8399, "shadow_godray_window_large_dim_think" },
    { 0x839A, "shadow_godray_window_large_think" },
    { 0x839B, "shadow_pos" },
    { 0x839C, "shadow_shopping_walkway_enter" },
    { 0x839D, "shadow_shopping_walkway_exit" },
    { 0x839E, "shadow_shopping_walkway_pre_enter" },
    { 0x839F, "shadow_tag" },
    { 0x83A0, "shadow_tag_01" },
    { 0x83A1, "shadow_tag_02" },
    { 0x83A2, "shadow_tag_03" },
    { 0x83A3, "shadow_tag_05" },
    { 0x83A4, "shadow_tag_06" },
    { 0x83A5, "shadow_tag_07" },
    { 0x83A6, "shadow_tag_08" },
    { 0x83A7, "shadow_tag_09" },
    { 0x83A8, "shadow_tag_11" },
    { 0x83A9, "shaft_descent_end" },
    { 0x83AA, "shaft_descent_speed_update" },
    { 0x83AB, "shaft_descent_start" },
    { 0x83AC, "shaft_descent_state_change" },
    { 0x83AD, "shake_dist_threshold_" },
    { 0x83AE, "shake_duration" },
    { 0x83AF, "shake_durration_" },
    { 0x83B0, "shake_envelope_" },
    { 0x83B1, "shake_in_progress" },
    { 0x83B2, "shallow_water_weapon" },
    { 0x83B3, "shared_portable_turrets" },
    { 0x83B4, "shared_turrets" },
    { 0x83B5, "sharedevent" },
    { 0x83B6, "shark_functions" },
    { 0x83B7, "shelf" },
    { 0x83B8, "shell_fx" },
    { 0x83B9, "shell_sound" },
    { 0x83BA, "shell_sound_enabled" },
    { 0x83BB, "shellshock_audio_disabled" },
    { 0x83BC, "shellshock_time" },
    { 0x83BD, "shellshocked" },
    { 0x83BE, "shellshockondamage" },
    { 0x83BF, "shg_exploder_tendrils" },
    { 0x83C0, "shg_spawn_tendrils" },
    { 0x83C1, "shieldbroken" },
    { 0x83C2, "shieldbulletblockcount" },
    { 0x83C3, "shieldbulletblocklimit" },
    { 0x83C4, "shieldbulletblocktime" },
    { 0x83C5, "shieldbullethits" },
    { 0x83C6, "shielddamage" },
    { 0x83C7, "shieldmodelvariant" },
    { 0x83C8, "shift_car" },
    { 0x83C9, "ship" },
    { 0x83CA, "ship_explosion_rumble" },
    { 0x83CB, "ship_explosion_screenblur" },
    { 0x83CC, "ship_pos_wait_delay" },
    { 0x83CD, "shit_blocked_upstairs" },
    { 0x83CE, "shitloc" },
    { 0x83CF, "shock_distance" },
    { 0x83D0, "shock_ondeath" },
    { 0x83D1, "shocking_target" },
    { 0x83D2, "shockthink" },
    { 0x83D3, "shockwave_begin" },
    { 0x83D4, "shoot_at_ambulance" },
    { 0x83D5, "shoot_at_chopper" },
    { 0x83D6, "shoot_at_sentinel_agents" },
    { 0x83D7, "shoot_at_spots" },
    { 0x83D8, "shoot_at_these_targets" },
    { 0x83D9, "shoot_charge_bar" },
    { 0x83DA, "shoot_drone_at_ally" },
    { 0x83DB, "shoot_dude_through_window" },
    { 0x83DC, "shoot_enemy_until_he_hides_then_shoot_wall" },
    { 0x83DD, "shoot_mg42_script_targets" },
    { 0x83DE, "shoot_out_exo_windows_scaffolding_think" },
    { 0x83DF, "shoot_out_windows" },
    { 0x83E0, "shoot_player_if_facing" },
    { 0x83E1, "shoot_point_array" },
    { 0x83E2, "shoot_sam_missile" },
    { 0x83E3, "shoot_sam_missiles" },
    { 0x83E4, "shoot_tag" },
    { 0x83E5, "shoot_target_till_dead" },
    { 0x83E6, "shoot_while_driving_thread" },
    { 0x83E7, "shoot_while_moving_thread" },
    { 0x83E8, "shoot_while_ziplining" },
    { 0x83E9, "shootanimtime" },
    { 0x83EA, "shootastold" },
    { 0x83EB, "shootatshootentorpos" },
    { 0x83EC, "shootblankthread" },
    { 0x83ED, "shootcineturrets" },
    { 0x83EE, "shootdowncarepackage" },
    { 0x83EF, "shootenemy" },
    { 0x83F0, "shootenemytarget_bullets" },
    { 0x83F1, "shootenemytarget_bullets_debugline" },
    { 0x83F2, "shootenemywrapper" },
    { 0x83F3, "shootenemywrapper_func" },
    { 0x83F4, "shootenemywrapper_normal" },
    { 0x83F5, "shootenemywrapper_shootnotify" },
    { 0x83F6, "shootent" },
    { 0x83F7, "shootentvelocity" },
    { 0x83F8, "shootguy" },
    { 0x83F9, "shootguytargetmustdie" },
    { 0x83FA, "shooting_head_sway" },
    { 0x83FB, "shooting_range_enemy_shot" },
    { 0x83FC, "shooting_range_enemy_spawn" },
    { 0x83FD, "shooting_range_floor_panels_off" },
    { 0x83FE, "shooting_range_floor_panels_on" },
    { 0x83FF, "shooting_range_friendly_shot" },
    { 0x8400, "shooting_range_friendly_spawn" },
    { 0x8401, "shooting_range_overdrive_watcher" },
    { 0x8402, "shooting_range_panels_down" },
    { 0x8403, "shooting_range_panels_up" },
    { 0x8404, "shooting_range_ramp_down_lighting" },
    { 0x8405, "shooting_range_ramp_up_lighting" },
    { 0x8406, "shooting_range_target_despawn" },
    { 0x8407, "shooting_range_transition1" },
    { 0x8408, "shooting_range_transition2" },
    { 0x8409, "shooting_range_transition3" },
    { 0x840A, "shootingrangeleaderboard" },
    { 0x840B, "shootkva" },
    { 0x840C, "shootkva_enemyindexer" },
    { 0x840D, "shootnotetrack" },
    { 0x840E, "shootobjective" },
    { 0x840F, "shootpos" },
    { 0x8410, "shootposoutsidelegalyawrange" },
    { 0x8411, "shootposoverride" },
    { 0x8412, "shootposwrapper" },
    { 0x8413, "shootposwrapper_func" },
    { 0x8414, "shootrateoverride" },
    { 0x8415, "shootstyle" },
    { 0x8416, "shootuntilneedtoturn" },
    { 0x8417, "shootuntilshootbehaviorchange" },
    { 0x8418, "shootuntilshootbehaviorchange_corner" },
    { 0x8419, "shootuntilshootbehaviorchange_coverwall" },
    { 0x841A, "shootuntilshootbehaviorchangefortime" },
    { 0x841B, "shootwhilemoving" },
    { 0x841C, "shootwhileturning" },
    { 0x841D, "shoping_district_ambientfx_aa_explosion" },
    { 0x841E, "shoping_district_ambientfx_midair_explosion" },
    { 0x841F, "shoping_district_ambientfx_windowglass_explosion" },
    { 0x8420, "shopping_district_glass_hit_after_smashed" },
    { 0x8421, "shopping_district_glass_smashed" },
    { 0x8422, "shopping_district_main" },
    { 0x8423, "shopping_district_objectives" },
    { 0x8424, "shopping_district_panel_smashed" },
    { 0x8425, "shopping_district_panel_swing" },
    { 0x8426, "shopping_district_turret_truck" },
    { 0x8427, "shore_ajani_run_in" },
    { 0x8428, "shore_ajani_walks_away" },
    { 0x8429, "shore_ending" },
    { 0x842A, "shore_gideon_grab_plr" },
    { 0x842B, "shore_gideon_moneys_worth" },
    { 0x842C, "shore_gideon_nudge" },
    { 0x842D, "shore_gideon_pickup_wpn" },
    { 0x842E, "shore_gideon_slap_plr" },
    { 0x842F, "shore_gideon_stand" },
    { 0x8430, "shore_gideon_turn" },
    { 0x8431, "shore_joker_helps_with_hostage" },
    { 0x8432, "shore_joker_nudges_hostage" },
    { 0x8433, "shore_joker_run_in" },
    { 0x8434, "shore_pcap" },
    { 0x8435, "shore_pcap_notetrack_setup" },
    { 0x8436, "shore_plr_grab_wpn" },
    { 0x8437, "shore_plr_slapped" },
    { 0x8438, "shore_plr_tries_to_get_up" },
    { 0x8439, "shortencolor" },
    { 0x843A, "shot_at_player" },
    { 0x843B, "shot_delay" },
    { 0x843C, "shot_endangers_any_player" },
    { 0x843D, "shot_endangers_player" },
    { 0x843E, "shotcount" },
    { 0x843F, "shotfired" },
    { 0x8440, "shotfiredphysicssphere" },
    { 0x8441, "shotgunabortdefendgoalonflag" },
    { 0x8442, "shotgunfirerate" },
    { 0x8443, "shotgunpumpsound" },
    { 0x8444, "shotgunswitchfinish" },
    { 0x8445, "shotgunswitchstandruninternal" },
    { 0x8446, "shots_fired" },
    { 0x8447, "shots_fired_recorder" },
    { 0x8448, "shots_hit" },
    { 0x8449, "shotsafterplayerbecomesinvul" },
    { 0x844A, "shotsatzerospeed" },
/* 1 gap
    "shotsfired",
    "shotshit",
    "should_abort",
    "should_be_vehicle",
    "should_break_boost_jump_hint",
    "should_break_crouch_hint",
    "should_break_disable_nvg_print",
    "should_break_dont_leave",
    "should_break_dont_leave_squad",
    "should_break_end_jump_hint",
    "should_break_leave_mission_hint",
    "should_break_move_hint",
    "should_break_on_throw",
    "should_break_recover_hint",
    "should_break_recover_hint_command",
    "should_break_recover_hint_movement",
    "should_break_release_mt_missiles",
    "should_break_swim_hint",
    "should_break_tappy_hint",
    "should_break_threat_hint",
    "should_break_use_mt_fire",
    "should_break_use_mt_missiles",
    "should_delay_flag_decision",
    "should_display_melee_hint",
    "should_do_car_alarm",
    "should_end_align_hint",
    "should_end_fastzip_fire_hint",
    "should_end_fastzip_hint",
    "should_end_laser_hint",
    "should_end_pdrone_fail_hint",
    "should_end_pdrone_hint",
    "should_end_sonar_hint",
    "should_give_orghealth",
    "should_growl",
    "should_hide_bullet_immunity_hint",
    "should_hide_melee_hint",
    "should_hide_missiles_hint",
    "should_hide_turret_hint",
    "should_pause_yaw_anim",
    "should_play_animations",
    "should_record_final_score_cam",
    "should_register_kills_for_vehicle_occupants",
    "should_reverse_controls",
    "should_select_new_ambush_point",
    "should_show_cover_warning",
    "should_show_hud_element",
    "should_show_prompt",
    "should_squelch",
    "should_start_cautious_approach_default",
    "should_start_cautious_approach_dom",
    "should_start_cautious_approach_hp",
    "should_start_cautious_approach_sd",
    "should_stop_seeking_weapon",
    "should_take_selfie",
    "should_topoff_breach_weapon",
    "shouldaffectclaymore",
    "shouldattackidle",
    "shouldattemptstumblingpain",
    "shouldaveragetotal",
    "shouldbeajerk",
    "shouldbreaknvghintprint",
    "shouldchangestanceforfun",
    "shouldconserveammotime",
    "shouldcoveridle",
    "shouldcqb",
    "shoulddamagerocket",
    "shoulddoarrivals",
    "shoulddodirectedenergydeath",
    "shoulddoextendedkill",
    "shoulddorunningforwarddeath",
    "shoulddosemiforvariety",
    "shoulddosharpturns",
    "shoulddostrongbulletdamage",
    "shoulddostrongmeleedamage",
    "shoulddroprocketlauncher",
    "shouldfacenodedir",
    "shouldfade",
    "shouldfireattarget",
    "shouldfirewhilechangingpose",
    "shouldforcedisablelaser",
    "shouldforcesnipermissshot",
    "shouldhelpadvancingteammate",
    "shouldkeepcrawling",
    "shouldlean",
    "shouldloopdamagefeedback",
    "shouldnt_spawn_because_of_script_difficulty",
    "shouldpingobject",
    "shouldplayhitreaction",
    "shouldplaysplash",
    "shouldpreventearlyuse",
    "shouldresetgiveuponsuppressiontimer",
    "shouldreturntocover",
    "shouldrunserversideeffects",
    "shouldshootenemyent",
    "shouldshowcompassduetoradar",
    "shouldsighttracewait",
    "shouldsniff",
    "shouldsortscoresinascendingorder",
    "shouldspawnbots",
    "shouldspawntags",
    "shouldsplash",
    "shouldsprint",
    "shouldsprintforvariation",
    "shouldstayalive",
    "shouldstopambushing",
    "shouldstopproximityalarm",
    "shouldsuppress",
    "shouldswapshotgun",
    "shouldswitchweaponafterraiseanimation",
    "shouldswitchweaponpostkillstreak",
    "shouldupdateluadisplay",
    "shoulduseteamstartspawn",
    "shouldwaitincombatidle",
*/
    { 0x84BD, "shouldweaponfeedback" },
    { 0x84BE, "show_attached_clone_model" },
    { 0x84BF, "show_avatar" },
    { 0x84C0, "show_avatars" },
    { 0x84C1, "show_bad_path" },
    { 0x84C2, "show_blurry_rotors" },
    { 0x84C3, "show_brake_hint" },
    { 0x84C4, "show_city_vista" },
    { 0x84C5, "show_cloaked_warbird" },
    { 0x84C6, "show_crash_traffic" },
    { 0x84C7, "show_decloaking_warbird" },
    { 0x84C8, "show_detailed_cloak_enemy_state" },
    { 0x84C9, "show_down_arrow" },
    { 0x84CA, "show_entity" },
    { 0x84CB, "show_ents_by_targetname" },
    { 0x84CC, "show_exec_title_credits" },
    { 0x84CD, "show_exo_cloak_hint" },
    { 0x84CE, "show_exploder_models" },
    { 0x84CF, "show_exploder_models_proc" },
    { 0x84D0, "show_fail_range_hint_1" },
    { 0x84D1, "show_fail_range_hint_2" },
    { 0x84D2, "show_fallen_bridge" },
    { 0x84D3, "show_far_bridge" },
    { 0x84D4, "show_finale_jet" },
    { 0x84D5, "show_glowy_handles" },
    { 0x84D6, "show_grenade_hint" },
    { 0x84D7, "show_help" },
    { 0x84D8, "show_hidden_rail" },
    { 0x84D9, "show_hide_plant_vista" },
    { 0x84DA, "show_hide_plant_vista_intro" },
    { 0x84DB, "show_hint" },
    { 0x84DC, "show_hologram" },
    { 0x84DD, "show_hologram_reveal" },
    { 0x84DE, "show_icon" },
    { 0x84DF, "show_land_assist_help" },
    { 0x84E0, "show_left_arrow" },
    { 0x84E1, "show_me_now" },
    { 0x84E2, "show_mech_screen" },
    { 0x84E3, "show_middle_civs_now" },
    { 0x84E4, "show_navy_boats" },
    { 0x84E5, "show_non_owner_avatars" },
    { 0x84E6, "show_normal_handles" },
    { 0x84E7, "show_plant_vista_intro" },
    { 0x84E8, "show_plant_vista_via_trigger" },
    { 0x84E9, "show_player_hud" },
    { 0x84EA, "show_primer_fx" },
    { 0x84EB, "show_reverse_tutorial" },
    { 0x84EC, "show_reverse_tutorial_check" },
    { 0x84ED, "show_right_arrow" },
    { 0x84EE, "show_shg_title_credits" },
    { 0x84EF, "show_solid" },
    { 0x84F0, "show_static_rotors" },
    { 0x84F1, "show_stuck_fanfare" },
    { 0x84F2, "show_subtitles" },
    { 0x84F3, "show_throw_hint_close_to_turret" },
    { 0x84F4, "show_turret" },
    { 0x84F5, "show_up_arrow" },
    { 0x84F6, "show_uplink" },
    { 0x84F7, "show_video_on_driverside" },
    { 0x84F8, "show_water_final" },
    { 0x84F9, "show_water_intro" },
    { 0x84FA, "show_weaponhud" },
    { 0x84FB, "showaerialmarker" },
    { 0x84FC, "showakimbodelayed" },
    { 0x84FD, "showammocount" },
    { 0x84FE, "showapart" },
    { 0x84FF, "showattachmentsaftercloak" },
    { 0x8500, "showblockedhud" },
    { 0x8501, "showboatshadows" },
    { 0x8502, "showclaimed" },
    { 0x8503, "showdebugline" },
    { 0x8504, "showdebugproc" },
    { 0x8505, "showdebugradius" },
    { 0x8506, "showdebugtoggle" },
    { 0x8507, "showdebugtrace" },
    { 0x8508, "showdroppodbadspawnoverlay" },
    { 0x8509, "showdroppodfx" },
    { 0x850A, "showelem" },
    { 0x850B, "showentnotetrack" },
    { 0x850C, "showfirehideaimidle" },
    { 0x850D, "showfriendicon" },
    { 0x850E, "showfxtoteam" },
    { 0x850F, "showgascloud" },
    { 0x8510, "showgenericmenuonmatchstart" },
    { 0x8511, "showgeo" },
    { 0x8512, "showheadicon" },
    { 0x8513, "showhint" },
    { 0x8514, "showhintprint_struct" },
    { 0x8515, "showing_damage" },
    { 0x8516, "showingfinalkillcam" },
    { 0x8517, "showintermissiontimer" },
    { 0x8518, "showlastenemysightpos" },
    { 0x8519, "showline" },
    { 0x851A, "showlines" },
    { 0x851B, "showlist" },
    { 0x851C, "showloadoutmenu" },
    { 0x851D, "showmainmenuforteam" },
    { 0x851E, "showmodels" },
    { 0x851F, "shownextroundmessage" },
    { 0x8520, "showninfected" },
    { 0x8521, "shownotifymessage" },
    { 0x8522, "showorbitalstrikehud" },
    { 0x8523, "showoverlaystoplayer" },
    { 0x8524, "showplacedmodel" },
    { 0x8525, "showplayericons" },
    { 0x8526, "showpoddroppingfxtoplayer" },
    { 0x8527, "showpodgroundfxtoplayer" },
    { 0x8528, "showprimarydelayed" },
    { 0x8529, "showreticletoenemies" },
    { 0x852A, "showroundmeshmesh" },
    { 0x852B, "showsetbacksplash" },
    { 0x852C, "showspawnnotifies" },
    { 0x852D, "showstart" },
    { 0x852E, "showstate" },
    { 0x852F, "showstatic" },
    { 0x8530, "showteamsplashhorde" },
    { 0x8531, "showthreat" },
    { 0x8532, "showthreathintagainifplayerisbeingdumb" },
    { 0x8533, "showthreatmarker" },
    { 0x8534, "showtimer" },
    { 0x8535, "showtoteam" },
    { 0x8536, "showtransition" },
    { 0x8537, "showtransition_cg" },
    { 0x8538, "showtransitionrev" },
    { 0x8539, "shrike_contact" },
    { 0x853A, "shrike_flyby" },
    { 0x853B, "shrike_flyby_03" },
    { 0x853C, "shrike_flyby_pair_01" },
    { 0x853D, "shrike_flyby_pair_02" },
    { 0x853E, "shrike_flyby_pair_04" },
    { 0x853F, "shrike_hanger_flyby" },
    { 0x8540, "shrike_railgun_flyby_01" },
    { 0x8541, "shrike_railgun_flyby_02" },
    { 0x8542, "shrike_railgun_flyby_03" },
    { 0x8543, "shrike_takeoff" },
    { 0x8544, "shrike_takeoff_cg" },
    { 0x8545, "shufflekillstreaksdown" },
    { 0x8546, "shufflekillstreaksup" },
    { 0x8547, "shufflemove" },
    { 0x8548, "shufflemoveinterrupted" },
    { 0x8549, "shufflenode" },
    { 0x854A, "shufflezones" },
    { 0x854B, "shutdown_battlechatter" },
    { 0x854C, "shutdown_fx_enemy" },
    { 0x854D, "shutdown_fx_friendly" },
    { 0x854E, "shutdown_squadbattlechatter" },
    { 0x854F, "shutdowncontact" },
    { 0x8550, "shutdownround" },
    { 0x8551, "shutoffallplayersexobuffs" },
    { 0x8552, "shutoffamplifyobjectvfx" },
    { 0x8553, "shutoffexobuffs" },
    { 0x8554, "shutofffx" },
    { 0x8555, "shutoffhealth" },
    { 0x8556, "shutoffplayerhudoutline" },
    { 0x8557, "shutoffslam" },
    { 0x8558, "shutoffspeed" },
    { 0x8559, "shutterwanderleft" },
    { 0x855A, "shutterwanderright" },
    { 0x855B, "side_arm_array" },
    { 0x855C, "side_b_visionset_reset" },
    { 0x855D, "sidearm" },
    { 0x855E, "sideisleftright" },
    { 0x855F, "sidesteprate" },
    { 0x8560, "sidewinder_explode_impact" },
    { 0x8561, "sidewinder_missile" },
    { 0x8562, "sight_check" },
    { 0x8563, "sight_distsqrd" },
    { 0x8564, "sight_ignore" },
    { 0x8565, "sight_lost_time" },
    { 0x8566, "sighting_think" },
    { 0x8567, "sightpos" },
    { 0x8568, "sightposleft" },
    { 0x8569, "sightpostime" },
    { 0x856A, "sighttime" },
    { 0x856B, "sighttracepoint" },
    { 0x856C, "sigmoid" },
    { 0x856D, "sign" },
    { 0x856E, "sign_explosion_flash_damage" },
    { 0x856F, "sign_flash_damage" },
    { 0x8570, "signal_turn_guy" },
    { 0x8571, "signed_distance_to_plane" },
    { 0x8572, "silentplant" },
    { 0x8573, "silo_approach_logic" },
    { 0x8574, "silo_autosaves" },
    { 0x8575, "silo_autosaves_safety" },
    { 0x8576, "silo_catwalk_clip" },
    { 0x8577, "silo_catwalks" },
    { 0x8578, "silo_catwalks_open" },
    { 0x8579, "silo_collapse_plr_stunned" },
    { 0x857A, "silo_door_kick" },
    { 0x857B, "silo_door_kick_logic" },
    { 0x857C, "silo_exhaust_entrance_logic" },
    { 0x857D, "silo_floor_03_logic" },
    { 0x857E, "silo_lobby_logic" },
    { 0x857F, "silo_p1" },
    { 0x8580, "silo_rocket_blowup" },
    { 0x8581, "silo_sky_bridge_logic" },
    { 0x8582, "simcurrentgendynamicexpossure" },
    { 0x8583, "simple_and_lazy_flank_check" },
    { 0x8584, "simple_anim_at_struct" },
    { 0x8585, "simple_drone_health" },
    { 0x8586, "simple_player_rumble_heavy" },
    { 0x8587, "simple_player_rumble_light" },
    { 0x8588, "simple_player_rumble_medium" },
    { 0x8589, "single_ally_heli" },
    { 0x858A, "single_heli_tower" },
    { 0x858B, "single_loop_handle_index" },
    { 0x858C, "single_loops" },
    { 0x858D, "single_zone_spawns" },
    { 0x858E, "singleanimation" },
    { 0x858F, "singlebreacher" },
    { 0x8590, "sinkhole_ambientfx_aa_explosions" },
    { 0x8591, "sinkhole_ambientfx_midair_explosions" },
    { 0x8592, "sinkhole_ambientfx_windowglass_explosions" },
    { 0x8593, "sinkhole_civ_vicitim_group" },
    { 0x8594, "sinkhole_crashed_truck_rotation" },
    { 0x8595, "sinkhole_drone_intro" },
    { 0x8596, "sinkhole_drones" },
    { 0x8597, "sinkhole_drones_attack_civilians" },
    { 0x8598, "sinkhole_drones_group2" },
    { 0x8599, "sinkhole_drones_group4_spawn" },
    { 0x859A, "sinkhole_drones_start" },
    { 0x859B, "sinkhole_fracture" },
    { 0x859C, "sinkhole_jets" },
    { 0x859D, "sinkhole_make_piece_break" },
    { 0x859E, "sinkhole_make_piece_break_and_sink" },
    { 0x859F, "sinkhole_make_piece_fall" },
    { 0x85A0, "sinkhole_section" },
    { 0x85A1, "sinkhole_smoke_ambush_enemy_think" },
    { 0x85A2, "sinkhole_smoke_ambush_event" },
    { 0x85A3, "sinkhole_smoke_grenade_loop" },
    { 0x85A4, "sinkhole_spawn_attack_drones" },
    { 0x85A5, "sinkhole_subway_vo_think" },
    { 0x85A6, "sinkhole_threat_hint" },
    { 0x85A7, "sinkhole_truck_explode" },
    { 0x85A8, "sinkhole_truck_fall" },
    { 0x85A9, "sinkhole_truck_fall_badly" },
    { 0x85AA, "sinkhole_weapon_platform" },
    { 0x85AB, "sinkhole_weapons_platform_scene" },
    { 0x85AC, "siren_distant" },
    { 0x85AD, "sirentag" },
    { 0x85AE, "sittag" },
    { 0x85AF, "sittag_offset" },
    { 0x85B0, "sittag_on_turret" },
    { 0x85B1, "skip_breach" },
    { 0x85B2, "skip_foam_corridor" },
    { 0x85B3, "skip_helicopter_death_logic" },
    { 0x85B4, "skip_juggernaut_intro_sound" },
    { 0x85B5, "skip_moves" },
    { 0x85B6, "skip_pilot_kill_count" },
    { 0x85B7, "skip_start_transition" },
    { 0x85B8, "skipanimbaseddeath" },
    { 0x85B9, "skipbloodpool" },
    { 0x85BA, "skipdeathanim" },
    { 0x85BB, "skipendingidle" },
    { 0x85BC, "skiplivesxpscalar" },
    { 0x85BD, "skipmodelswapdeath" },
    { 0x85BE, "skipoceanspawns" },
    { 0x85BF, "skippedkillcam" },
    { 0x85C0, "skippointdisplayxp" },
    { 0x85C1, "skiprocketemp" },
    { 0x85C2, "skipssuccess" },
    { 0x85C3, "skipstartmove" },
    { 0x85C4, "skr_distant_pull_up_and_scan" },
    { 0x85C5, "sky_booms" },
    { 0x85C6, "sky_bridge_dof" },
    { 0x85C7, "sky_nodes" },
    { 0x85C8, "skybox_manager" },
    { 0x85C9, "skybridge" },
    { 0x85CA, "skybridge_ambient_aa_explosions" },
    { 0x85CB, "skybridge_ambient_explosions" },
    { 0x85CC, "skycolor" },
    { 0x85CD, "skyfogintensity" },
    { 0x85CE, "skyfogmaxangle" },
    { 0x85CF, "skyfogminangle" },
    { 0x85D0, "skyintensityscaleev" },
    { 0x85D1, "skyj_intro_black" },
    { 0x85D2, "skyj_part_1" },
    { 0x85D3, "skyj_part_2" },
    { 0x85D4, "skyj_part_3" },
    { 0x85D5, "skyj_part_4" },
    { 0x85D6, "skyjack_animnode" },
    { 0x85D7, "skyjack_atlas_jet_fx" },
    { 0x85D8, "skyjack_charge_activate" },
    { 0x85D9, "skyjack_charge_fx" },
    { 0x85DA, "skyjack_charge_impact" },
    { 0x85DB, "skyjack_charge_laser_guide" },
    { 0x85DC, "skyjack_charge_laser_turn" },
    { 0x85DD, "skyjack_charge_legs" },
    { 0x85DE, "skyjack_charge_opens" },
    { 0x85DF, "skyjack_charges" },
    { 0x85E0, "skyjack_charges_nag_vo" },
    { 0x85E1, "skyjack_cormack" },
    { 0x85E2, "skyjack_cormack_impact_plane" },
    { 0x85E3, "skyjack_cormack_jetpack_boost" },
    { 0x85E4, "skyjack_cormack_jetpack_off" },
    { 0x85E5, "skyjack_cormack_jetpack_on" },
    { 0x85E6, "skyjack_cormack_land_on_plane" },
    { 0x85E7, "skyjack_cormack_left_knee" },
    { 0x85E8, "skyjack_cormack_mag_hand_left" },
    { 0x85E9, "skyjack_cormack_mag_hand_right" },
    { 0x85EA, "skyjack_cormack_push_off_plane" },
    { 0x85EB, "skyjack_cormack_right_knee" },
    { 0x85EC, "skyjack_dialogue" },
    { 0x85ED, "skyjack_drone_chutes" },
    { 0x85EE, "skyjack_drone_fx" },
    { 0x85EF, "skyjack_drone_jets_off" },
    { 0x85F0, "skyjack_drone_jets_on" },
    { 0x85F1, "skyjack_drone_pod" },
    { 0x85F2, "skyjack_expl_start" },
    { 0x85F3, "skyjack_gloveoff" },
    { 0x85F4, "skyjack_gloveon" },
    { 0x85F5, "skyjack_objective" },
    { 0x85F6, "skyjack_plane" },
    { 0x85F7, "skyjack_plane_contrails" },
    { 0x85F8, "skyjack_plane_cut" },
    { 0x85F9, "skyjack_plane_debris" },
    { 0x85FA, "skyjack_plane_explosion" },
    { 0x85FB, "skyjack_player" },
    { 0x85FC, "skyjack_player_activate_charge" },
    { 0x85FD, "skyjack_player_charge_planted" },
    { 0x85FE, "skyjack_player_fall" },
    { 0x85FF, "skyjack_player_hand_on_charge" },
    { 0x8600, "skyjack_player_impact_plane" },
    { 0x8601, "skyjack_player_open_charge" },
    { 0x8602, "skyjack_player_push_off_plane" },
    { 0x8603, "skyjack_player_set_charge" },
    { 0x8604, "skyjack_player_wrist" },
    { 0x8605, "skyjack_wing_explosion" },
    { 0x8606, "skylight" },
    { 0x8607, "skylighthdr" },
    { 0x8608, "slam_hint_breakout" },
    { 0x8609, "slam_ragdoll_vel" },
    { 0x860A, "slate_fin_gideon_bar_break" },
    { 0x860B, "slate_fin_gideon_hatch_grab" },
    { 0x860C, "slate_fin_gideon_hatch_open" },
    { 0x860D, "slate_fin_gideon_hatch_push" },
    { 0x860E, "slate_fin_piston_l_break" },
    { 0x860F, "slate_fin_piston_r_break" },
    { 0x8610, "slate_fin_vm_bar_break" },
    { 0x8611, "slate_fin_vm_hatch_grab" },
    { 0x8612, "slate_fin_vm_hatch_pull" },
    { 0x8613, "slate_fin_vm_hatch_pull_loop" },
    { 0x8614, "slate_fin_vm_pull_relax" },
    { 0x8615, "slate_finale_gideon_hatch_pull_1" },
    { 0x8616, "slate_finale_gideon_hatch_pull_2" },
    { 0x8617, "slate_finale_gideon_hatch_pull_3" },
    { 0x8618, "slate_finale_gideon_hatch_regrip_1" },
    { 0x8619, "slate_finale_gideon_hatch_regrip_2" },
    { 0x861A, "slate_finale_gideon_hatch_regrip_3" },
    { 0x861B, "slate_gideon_wave_hand_plant" },
    { 0x861C, "slate_gideon_wave_hand_raise" },
    { 0x861D, "slate_gideon_wave_hand_regrip" },
    { 0x861E, "sleepingguardcustombloodspray" },
    { 0x861F, "slide_across_car_dog" },
    { 0x8620, "slide_across_car_human" },
    { 0x8621, "slide_dampening" },
    { 0x8622, "slide_gate_destroyed" },
    { 0x8623, "slide_gate_left" },
    { 0x8624, "slide_gate_right" },
    { 0x8625, "slidefortime" },
    { 0x8626, "slidemodel" },
    { 0x8627, "slidetriggerplayerthink" },
    { 0x8628, "sliding_door" },
    { 0x8629, "sliding_door_state" },
    { 0x862A, "slomo_breach_vision_change" },
    { 0x862B, "slomo_difficulty_dvars" },
    { 0x862C, "slomo_sound_scale_setup" },
    { 0x862D, "slomobasevision" },
    { 0x862E, "slomobreachduration" },
    { 0x862F, "slomobreachplayerspeed" },
    { 0x8630, "sloppy_kill_vo" },
    { 0x8631, "slot" },
    { 0x8632, "slow_allies_while_videolog_plays" },
    { 0x8633, "slow_plane_controls" },
    { 0x8634, "slow_player_inside" },
    { 0x8635, "slow_player_scaler" },
    { 0x8636, "slow_trig" },
    { 0x8637, "slowmo" },
    { 0x8638, "slowmo_begins" },
    { 0x8639, "slowmo_breach_damage_trigger_think" },
    { 0x863A, "slowmo_breach_disable_stancemod" },
    { 0x863B, "slowmo_breach_init" },
    { 0x863C, "slowmo_breach_start_delay" },
    { 0x863D, "slowmo_breach_think" },
    { 0x863E, "slowmo_end" },
    { 0x863F, "slowmo_in_wait_function" },
    { 0x8640, "slowmo_lerp_in" },
    { 0x8641, "slowmo_lerp_out" },
    { 0x8642, "slowmo_player_cleanup" },
    { 0x8643, "slowmo_setlerptime_in" },
    { 0x8644, "slowmo_setlerptime_out" },
    { 0x8645, "slowmo_setspeed_norm" },
    { 0x8646, "slowmo_setspeed_slow" },
    { 0x8647, "slowmo_speed" },
    { 0x8648, "slowmo_start" },
    { 0x8649, "slowmo_system_defaults" },
    { 0x864A, "slowmo_system_init" },
    { 0x864B, "slowmo_viewhands" },
    { 0x864C, "slowmodelay" },
    { 0x864D, "slowmodelta" },
    { 0x864E, "slowmospeed" },
    { 0x864F, "slowmostop" },
    { 0x8650, "slowmotiontowerdestruction" },
    { 0x8651, "sm_get_current_ambience_name" },
    { 0x8652, "sm_get_current_music_name" },
    { 0x8653, "sm_init" },
    { 0x8654, "sm_mix_ambience" },
    { 0x8655, "sm_start_music" },
    { 0x8656, "sm_start_preset" },
    { 0x8657, "sm_stop_ambience" },
    { 0x8658, "sm_stop_ambient_alias" },
    { 0x8659, "sm_stop_music" },
    { 0x865A, "sm_stop_music_alias" },
    { 0x865B, "smallesthole" },
    { 0x865C, "smallestoccluder" },
    { 0x865D, "smart_dialogue" },
    { 0x865E, "smart_dialogue_generic" },
    { 0x865F, "smart_drone_think" },
    { 0x8660, "smart_grenade_detonate" },
    { 0x8661, "smart_grenade_target_expire" },
    { 0x8662, "smart_grenade_target_flip" },
    { 0x8663, "smart_grenade_target_flip_down" },
    { 0x8664, "smart_grenade_target_hit" },
    { 0x8665, "smart_grenade_target_move" },
    { 0x8666, "smart_grenade_target_move_back" },
    { 0x8667, "smart_grenade_target_shot" },
    { 0x8668, "smart_grenade_training" },
    { 0x8669, "smart_hint" },
    { 0x866A, "smart_hint_breakout" },
    { 0x866B, "smart_hint_think" },
    { 0x866C, "smart_radio_dialogue" },
    { 0x866D, "smart_radio_dialogue_interrupt" },
    { 0x866E, "smart_radio_dialogue_mb" },
    { 0x866F, "smart_radio_dialogue_overlap" },
    { 0x8670, "smartlasersystem" },
    { 0x8671, "smartstance" },
    { 0x8672, "smash_obj" },
    { 0x8673, "smash_spot" },
    { 0x8674, "smash_surface_float" },
    { 0x8675, "smash_throw" },
    { 0x8676, "smash_throw_2" },
    { 0x8677, "smash_throw_active" },
    { 0x8678, "smash_throw_solo" },
    { 0x8679, "smashed" },
    { 0x867A, "smaw_laser_think" },
    { 0x867B, "smaw_location" },
    { 0x867C, "smeansofdeath" },
    { 0x867D, "smoke_ambush_enemies" },
    { 0x867E, "smoke_clear_basement_bones" },
    { 0x867F, "smoke_detect" },
    { 0x8680, "smoke_exhale" },
    { 0x8681, "smoke_grenade_death" },
    { 0x8682, "smoke_puff" },
    { 0x8683, "smoke_thrown" },
    { 0x8684, "smokegrenades" },
    { 0x8685, "smokepillar1" },
    { 0x8686, "smokepillar2" },
    { 0x8687, "smokepillar3" },
    { 0x8688, "smokescreenemitterfx" },
    { 0x8689, "smokethrown" },
    { 0x868A, "smoking_civ" },
    { 0x868B, "smoking_civ_panic" },
    { 0x868C, "smooth_down" },
    { 0x868D, "smooth_limit" },
    { 0x868E, "smooth_player_link" },
    { 0x868F, "smooth_target_position" },
    { 0x8690, "smooth_target_velocity" },
    { 0x8691, "smooth_up" },
    { 0x8692, "smooth_veh_play" },
    { 0x8693, "smooth_vehicle_animation_play" },
    { 0x8694, "smooth_vehicle_animation_wait" },
    { 0x8695, "smoothed_input" },
    { 0x8696, "smoothness" },
    { 0x8697, "smx_clear_struct" },
    { 0x8698, "smx_create_struct" },
    { 0x8699, "smx_set_values_for_struct" },
    { 0x869A, "snake_cheap_death" },
    { 0x869B, "snake_choose_next_point" },
    { 0x869C, "snake_cloud" },
    { 0x869D, "snake_cloud_get_target_boids" },
    { 0x869E, "snake_cloud_goto_points" },
    { 0x869F, "snake_cloud_pester_helicopter" },
    { 0x86A0, "snake_cloud_resume_dynamic_control" },
    { 0x86A1, "snake_cloud_set_boid_settings" },
    { 0x86A2, "snake_cloud_stop_dynamic_control" },
    { 0x86A3, "snake_cloud_teleport_to_point" },
    { 0x86A4, "snake_crash_into_player" },
    { 0x86A5, "snake_crash_into_player_after_timeout" },
    { 0x86A6, "snake_dyanamic_control" },
    { 0x86A7, "snake_fight_before_turret" },
    { 0x86A8, "snake_fight_walker_tank" },
    { 0x86A9, "snake_follow_player" },
    { 0x86AA, "snake_gameplay_for_turret" },
    { 0x86AB, "snake_goal_origin" },
    { 0x86AC, "snake_kamikaze_control" },
    { 0x86AD, "snake_pester_helicopter" },
    { 0x86AE, "snake_pick_intro_path" },
    { 0x86AF, "snake_points" },
    { 0x86B0, "snake_points_center" },
    { 0x86B1, "snake_set_boid_settings" },
    { 0x86B2, "snake_set_points" },
    { 0x86B3, "snake_shoot_allies" },
    { 0x86B4, "snake_shoot_ambient" },
    { 0x86B5, "snake_speed_override" },
    { 0x86B6, "snake_strafe_player_gets_cardoor" },
    { 0x86B7, "snake_swarm_attack_vehicle" },
    { 0x86B8, "snake_swarm_speed_scale" },
    { 0x86B9, "snakeisinfrontofplayer" },
    { 0x86BA, "snakes" },
    { 0x86BB, "snakes_attacking_turret" },
    { 0x86BC, "snap_lock_turret_onto_target" },
    { 0x86BD, "snap2normal" },
    { 0x86BE, "snap90deg" },
    { 0x86BF, "snd_advanced_flyby_system" },
    { 0x86C0, "snd_air_vehicle_smart_flyby" },
    { 0x86C1, "snd_ambient_explosion" },
    { 0x86C2, "snd_clear_filter" },
    { 0x86C3, "snd_cloak_init" },
    { 0x86C4, "snd_common_init" },
    { 0x86C5, "snd_cover_drone_constructor" },
    { 0x86C6, "snd_debug_init" },
    { 0x86C7, "snd_debug_timer" },
    { 0x86C8, "snd_debug_value_add" },
    { 0x86C9, "snd_debug_value_delete" },
    { 0x86CA, "snd_debug_value_update" },
    { 0x86CB, "snd_disable_occlusion" },
    { 0x86CC, "snd_disable_occlusion_threaded" },
    { 0x86CD, "snd_disable_soundcontextoverride" },
    { 0x86CE, "snd_disable_vehicle_system" },
    { 0x86CF, "snd_disable_zone_filters" },
    { 0x86D0, "snd_disable_zone_occlusion_and_filtering" },
    { 0x86D1, "snd_dpad_functions" },
    { 0x86D2, "snd_enable_occlusion" },
    { 0x86D3, "snd_enable_soundcontextoverride" },
    { 0x86D4, "snd_enable_zone_filters" },
    { 0x86D5, "snd_enable_zone_occlusion_and_filtering" },
    { 0x86D6, "snd_end_01" },
    { 0x86D7, "snd_enemies_can_see_player" },
    { 0x86D8, "snd_ent" },
    { 0x86D9, "snd_ents" },
    { 0x86DA, "snd_fade_and_stop_sound" },
    { 0x86DB, "snd_fade_in_filter" },
    { 0x86DC, "snd_fade_out_filter" },
    { 0x86DD, "snd_filters_init" },
    { 0x86DE, "snd_final_music_think" },
    { 0x86DF, "snd_flash_white" },
    { 0x86E0, "snd_foley_init" },
    { 0x86E1, "snd_gaz_dshk_constructor" },
    { 0x86E2, "snd_get_current_filter_lerp" },
    { 0x86E3, "snd_get_current_filter_name" },
    { 0x86E4, "snd_get_current_occlusion_name" },
    { 0x86E5, "snd_get_current_timescale_preset_name" },
    { 0x86E6, "snd_get_dsp_buses" },
    { 0x86E7, "snd_get_dsp_filename" },
    { 0x86E8, "snd_get_filter_preset" },
    { 0x86E9, "snd_get_num_enemies_aware" },
    { 0x86EA, "snd_get_occlusion_preset" },
    { 0x86EB, "snd_get_secs" },
    { 0x86EC, "snd_get_soundtable_name" },
    { 0x86ED, "snd_get_tagarg" },
    { 0x86EE, "snd_get_throttler" },
    { 0x86EF, "snd_get_timescale_preset" },
    { 0x86F0, "snd_get_zone_filters_enabled" },
    { 0x86F1, "snd_guid" },
    { 0x86F2, "snd_hud_init" },
    { 0x86F3, "snd_impact" },
    { 0x86F4, "snd_init" },
    { 0x86F5, "snd_init_cover_drone" },
    { 0x86F6, "snd_init_current_filters" },
    { 0x86F7, "snd_init_current_occlusion" },
    { 0x86F8, "snd_init_done" },
    { 0x86F9, "snd_init_gaz" },
    { 0x86FA, "snd_init_mi17" },
    { 0x86FB, "snd_init_x4_walker_wheels" },
    { 0x86FC, "snd_init_x4_walker_wheels_turret" },
    { 0x86FD, "snd_init_x4_walker_wheels_turret_closed" },
    { 0x86FE, "snd_instance" },
    { 0x86FF, "snd_is_dsp_bus" },
    { 0x8700, "snd_is_first_frame" },
    { 0x8701, "snd_is_loop" },
    { 0x8702, "snd_is_one_shot" },
    { 0x8703, "snd_is_valid_surface" },
    { 0x8704, "snd_load_dsp_buses" },
    { 0x8705, "snd_load_filter_presets" },
    { 0x8706, "snd_load_occlusion_presets" },
    { 0x8707, "snd_load_timescale_presets" },
    { 0x8708, "snd_map" },
    { 0x8709, "snd_mech_add_rocketpack_lower" },
    { 0x870A, "snd_mech_add_rocketpack_raise" },
    { 0x870B, "snd_mech_emp_restart" },
    { 0x870C, "snd_message" },
    { 0x870D, "snd_message_init" },
    { 0x870E, "snd_mi17_constructor" },
    { 0x870F, "snd_monitor_about_to_stop" },
    { 0x8710, "snd_monitor_about_to_unload" },
    { 0x8711, "snd_monitor_new_path" },
    { 0x8712, "snd_mp_mix_init" },
    { 0x8713, "snd_mp_mix_post_event" },
    { 0x8714, "snd_mp_player_join" },
    { 0x8715, "snd_music_handler" },
    { 0x8716, "snd_music_message" },
    { 0x8717, "snd_mute_device" },
    { 0x8718, "snd_new_guid" },
    { 0x8719, "snd_notify_within_radius" },
    { 0x871A, "snd_parse_preset_header" },
    { 0x871B, "snd_parse_soundtables" },
    { 0x871C, "snd_pcap_add_notetrack_mapping" },
    { 0x871D, "snd_pcap_play_radio_vo" },
    { 0x871E, "snd_pcap_play_radio_vo_30fps" },
    { 0x871F, "snd_pcap_play_radio_vo_60fps" },
    { 0x8720, "snd_pcap_play_vo" },
    { 0x8721, "snd_pcap_play_vo_20fps" },
    { 0x8722, "snd_pcap_play_vo_30fps" },
    { 0x8723, "snd_pdrone_atlas_constructor" },
    { 0x8724, "snd_pdrone_atlas_large_constructor" },
    { 0x8725, "snd_pdrone_constructor" },
    { 0x8726, "snd_pdrone_player_constructor" },
    { 0x8727, "snd_pdrone_security_constructor" },
    { 0x8728, "snd_pdrone_swarm_constructor" },
    { 0x8729, "snd_pitbull_constructor" },
    { 0x872A, "snd_play" },
    { 0x872B, "snd_play_2d" },
    { 0x872C, "snd_play_2d_sound" },
    { 0x872D, "snd_play_amb_loop" },
    { 0x872E, "snd_play_at" },
    { 0x872F, "snd_play_delayed_2d" },
    { 0x8730, "snd_play_delayed_at" },
    { 0x8731, "snd_play_delayed_linked" },
    { 0x8732, "snd_play_delayed_linked_nocull" },
    { 0x8733, "snd_play_delayed_loop_2d" },
    { 0x8734, "snd_play_delayed_loop_at" },
    { 0x8735, "snd_play_delayed_loop_linked" },
    { 0x8736, "snd_play_in_space" },
    { 0x8737, "snd_play_in_space_delayed" },
    { 0x8738, "snd_play_linked" },
    { 0x8739, "snd_play_linked_firingrange" },
    { 0x873A, "snd_play_linked_loop" },
    { 0x873B, "snd_play_linked_notify_ent" },
    { 0x873C, "snd_play_linked_notify_on_ent" },
    { 0x873D, "snd_play_linked_notify_on_ent_thread" },
    { 0x873E, "snd_play_loop" },
    { 0x873F, "snd_play_loop_2d" },
    { 0x8740, "snd_play_loop_at" },
    { 0x8741, "snd_play_loop_in_space" },
    { 0x8742, "snd_play_loop_linked" },
    { 0x8743, "snd_play_on_notetrack" },
    { 0x8744, "snd_play_on_notetrack_timer" },
    { 0x8745, "snd_play_set_cleanup_msg" },
    { 0x8746, "snd_play_team_splash" },
    { 0x8747, "snd_play_vehicle_collision" },
    { 0x8748, "snd_player_drone_deploy" },
    { 0x8749, "snd_player_drone_enter_drone_pov" },
    { 0x874A, "snd_player_drone_wrist_panel" },
    { 0x874B, "snd_println" },
    { 0x874C, "snd_printlnbold" },
    { 0x874D, "snd_register_message" },
    { 0x874E, "snd_register_vehicle" },
    { 0x874F, "snd_scalevo_flame_logic" },
    { 0x8750, "snd_script_timer" },
    { 0x8751, "snd_set_current_filter_name" },
    { 0x8752, "snd_set_current_occlusion_name" },
    { 0x8753, "snd_set_current_timescale_preset_name" },
    { 0x8754, "snd_set_filter" },
    { 0x8755, "snd_set_filter_lerp" },
    { 0x8756, "snd_set_filter_threaded" },
    { 0x8757, "snd_set_occlusion" },
    { 0x8758, "snd_set_occlusion_threaded" },
    { 0x8759, "snd_set_soundtable_name" },
    { 0x875A, "snd_set_timescale" },
    { 0x875B, "snd_set_timescale_all" },
    { 0x875C, "snd_set_timescale_all_threaded" },
    { 0x875D, "snd_set_timescale_array_to_value" },
    { 0x875E, "snd_set_timescale_array_to_value_threaded" },
    { 0x875F, "snd_set_timescale_threaded" },
    { 0x8760, "snd_slate" },
    { 0x8761, "snd_sniper_drone_constructor" },
    { 0x8762, "snd_start_approachdna" },
    { 0x8763, "snd_start_barracks" },
    { 0x8764, "snd_start_canyon" },
    { 0x8765, "snd_start_canyon_dam" },
    { 0x8766, "snd_start_canyon_exit" },
    { 0x8767, "snd_start_canyon_intro" },
    { 0x8768, "snd_start_canyon2" },
    { 0x8769, "snd_start_canyon3" },
    { 0x876A, "snd_start_dnabomb" },
    { 0x876B, "snd_start_gaz" },
    { 0x876C, "snd_start_intro" },
    { 0x876D, "snd_start_mi17" },
    { 0x876E, "snd_start_post_tower" },
    { 0x876F, "snd_start_snipers" },
    { 0x8770, "snd_start_tank" },
    { 0x8771, "snd_start_vehicle" },
    { 0x8772, "snd_start_x4_walker_wheels" },
    { 0x8773, "snd_start_x4_walker_wheels_turret" },
    { 0x8774, "snd_start_x4_walker_wheels_turret_closed" },
    { 0x8775, "snd_stop_cover_drone" },
    { 0x8776, "snd_stop_gaz" },
    { 0x8777, "snd_stop_mi17" },
    { 0x8778, "snd_stop_sound" },
    { 0x8779, "snd_stop_vehicle" },
    { 0x877A, "snd_throttle_wait" },
    { 0x877B, "snd_throttler_reset" },
    { 0x877C, "snd_timescale_init" },
    { 0x877D, "snd_trench_fire_off" },
    { 0x877E, "snd_veh_play_loops" },
    { 0x877F, "snd_vehicle_mp" },
    { 0x8780, "snd_wait_for_enemies_aware" },
    { 0x8781, "snd_wait_for_enemies_see_player" },
    { 0x8782, "snd_waittill_within_radius" },
    { 0x8783, "snd_x4walker_wheels_constructor" },
    { 0x8784, "snd_x4walker_wheels_turret_constructor" },
    { 0x8785, "snd_zone_handler" },
    { 0x8786, "sndx_advanced_flyby_cleanup" },
    { 0x8787, "sndx_advanced_flyby_construct_alias" },
    { 0x8788, "sndx_advanced_flyby_deathspin" },
    { 0x8789, "sndx_advanced_flyby_destruct" },
    { 0x878A, "sndx_advanced_flyby_dist_check" },
    { 0x878B, "sndx_advanced_flyby_playsound" },
    { 0x878C, "sndx_advanced_flyby_retrigger_wait" },
    { 0x878D, "sndx_advanced_flyby_spawn_sound" },
    { 0x878E, "sndx_air_vehicle_smart_flyby_deathspin" },
    { 0x878F, "sndx_air_vehicle_smart_flyby_sounddone" },
    { 0x8790, "sndx_ambient_explosion_args_validation" },
    { 0x8791, "sndx_ambient_explosion_internal" },
    { 0x8792, "sndx_boost_land_get_impact_size" },
    { 0x8793, "sndx_boost_land_get_impact_vol" },
    { 0x8794, "sndx_debug_value_add" },
    { 0x8795, "sndx_debug_value_destroy" },
    { 0x8796, "sndx_debug_value_reorder" },
    { 0x8797, "sndx_dpad_function_watch" },
    { 0x8798, "sndx_fade_and_stop_sound" },
    { 0x8799, "sndx_fade_in_filter_lerp" },
    { 0x879A, "sndx_fade_out_filter_lerp" },
    { 0x879B, "sndx_get_dsp_filter_setting" },
    { 0x879C, "sndx_mute_device_bubble_fx" },
    { 0x879D, "sndx_mute_device_bubble_off_fx" },
    { 0x879E, "sndx_mute_device_debug_timer" },
    { 0x879F, "sndx_mute_device_delay_notify" },
    { 0x87A0, "sndx_mute_device_kill" },
    { 0x87A1, "sndx_mute_device_stop" },
    { 0x87A2, "sndx_mute_device_stopper" },
    { 0x87A3, "sndx_mute_device_wait_to_play" },
    { 0x87A4, "sndx_notify_within_radius" },
    { 0x87A5, "sndx_pcap_find_anime_and_animname" },
    { 0x87A6, "sndx_pcap_play_radio_vo_thread" },
    { 0x87A7, "sndx_pcap_play_vo_fade_delete" },
    { 0x87A8, "sndx_pcap_play_vo_monitor_stopnotify" },
    { 0x87A9, "sndx_pcap_play_vo_thread" },
    { 0x87AA, "sndx_pcap_wait" },
    { 0x87AB, "sndx_play_2d_sound" },
    { 0x87AC, "sndx_play_alias" },
    { 0x87AD, "sndx_play_alias_fade_delete" },
    { 0x87AE, "sndx_play_alias_monitor_linkdeath" },
    { 0x87AF, "sndx_play_alias_monitor_sounddone" },
    { 0x87B0, "sndx_play_alias_monitor_stopnotify" },
    { 0x87B1, "sndx_play_alias_thread" },
    { 0x87B2, "sndx_play_in_space_delayed_internal" },
    { 0x87B3, "sndx_play_in_space_internal" },
    { 0x87B4, "sndx_play_linked_internal" },
    { 0x87B5, "sndx_play_linked_loop_internal" },
    { 0x87B6, "sndx_play_loop_in_space_internal" },
    { 0x87B7, "sndx_play_on_notetrack_internal" },
    { 0x87B8, "sndx_play_vehicle_collision_internal" },
    { 0x87B9, "sndx_vehicle_collision_args_setup" },
    { 0x87BA, "sndx_vehicle_collision_dpad_down" },
    { 0x87BB, "sndx_vehicle_collision_dpad_left" },
    { 0x87BC, "sndx_vehicle_collision_dpad_right" },
    { 0x87BD, "sndx_vehicle_collision_dpad_up" },
    { 0x87BE, "sndx_vehicle_collision_get_impact_size" },
    { 0x87BF, "sndx_vehicle_collision_get_impact_vol" },
    { 0x87C0, "sndx_vehicle_collision_print_impact" },
    { 0x87C1, "sndx_vehicle_collision_print_stats" },
    { 0x87C2, "sndx_vehicle_collision_scrape" },
    { 0x87C3, "sndx_vehicle_collision_scrape_timer" },
    { 0x87C4, "sndx_vehicle_collision_stop_scrapes" },
    { 0x87C5, "sndxt_fastzip_fire" },
    { 0x87C6, "sneaky_reload" },
    { 0x87C7, "sniped" },
    { 0x87C8, "sniper" },
    { 0x87C9, "sniper_combat_setup" },
    { 0x87CA, "sniper_drone_callback_look" },
    { 0x87CB, "sniper_drone_condition_callback_to_state_flying" },
    { 0x87CC, "sniper_drone_condition_callback_to_state_hover" },
    { 0x87CD, "sniper_drone_condition_callback_to_state_idle" },
    { 0x87CE, "sniper_drone_condition_callback_to_state_looking" },
    { 0x87CF, "sniper_drone_dmg_fire" },
    { 0x87D0, "sniper_drone_dry_fire" },
    { 0x87D1, "sniper_drone_init" },
    { 0x87D2, "sniper_dvar" },
    { 0x87D3, "sniper_finale" },
    { 0x87D4, "sniper_fx_base" },
    { 0x87D5, "sniper_glint_behavior" },
    { 0x87D6, "sniper_interior_trigger_think" },
    { 0x87D7, "sniper_kva_dead_body" },
    { 0x87D8, "sniper_marked_cars" },
    { 0x87D9, "sniper_objectives" },
    { 0x87DA, "sniper_reinforce" },
    { 0x87DB, "sniper_rifle_objective_logic" },
    { 0x87DC, "sniper_scramble_data" },
    { 0x87DD, "sniper_suppression_hit_alert" },
    { 0x87DE, "sniper_target_location" },
    { 0x87DF, "sniper_turret1" },
    { 0x87E0, "sniper_turret2" },
    { 0x87E1, "sniper_turret3" },
    { 0x87E2, "sniper_zoom_hint_hud" },
    { 0x87E3, "sniperalltargets" },
    { 0x87E4, "sniperbloodsprayexitwoundtrace" },
    { 0x87E5, "snipercafewallburstfx" },
    { 0x87E6, "sniperdashburstfx1" },
    { 0x87E7, "sniperdashburstfx2" },
    { 0x87E8, "sniperdashburstfx3" },
    { 0x87E9, "sniperdashburstfx4" },
    { 0x87EA, "sniperdashburstfx5" },
    { 0x87EB, "sniperdashburstfx6" },
    { 0x87EC, "sniperdeath" },
    { 0x87ED, "sniperdeathinternal" },
    { 0x87EE, "sniperdestroyglass" },
    { 0x87EF, "sniperdoorhitfx1" },
    { 0x87F0, "sniperdoorhitfx2" },
    { 0x87F1, "sniperdronebadfire" },
    { 0x87F2, "sniperdronecloak" },
    { 0x87F3, "sniperdronedata" },
    { 0x87F4, "sniperdronedeathshowstatic" },
    { 0x87F5, "sniperdronedeathwatch" },
    { 0x87F6, "sniperdronedryfire" },
    { 0x87F7, "sniperdronedryfiremsg" },
    { 0x87F8, "sniperdroneflyin" },
    { 0x87F9, "sniperdroneflyintogglezoomnotetrack" },
    { 0x87FA, "sniperdronelaunchanims" },
    { 0x87FB, "sniperdronelensdamaged" },
    { 0x87FC, "sniperdronelink" },
    { 0x87FD, "sniperdronemissilewarnmsg" },
    { 0x87FE, "sniperdroneoverlays" },
    { 0x87FF, "sniperdroneprep" },
    { 0x8800, "sniperdustwatcher" },
    { 0x8801, "snipergettargetpos" },
    { 0x8802, "snipergroup" },
    { 0x8803, "sniperhitcount" },
    { 0x8804, "sniperhoteltargetilanafirst" },
    { 0x8805, "sniperhoteltargetplayerfirst" },
    { 0x8806, "sniperintro" },
    { 0x8807, "sniperissuppressed" },
    { 0x8808, "snipernearshotshake" },
    { 0x8809, "sniperpos" },
    { 0x880A, "snipers_defenders" },
    { 0x880B, "snipers_drone_spawners" },
    { 0x880C, "snipers_drones" },
    { 0x880D, "sniperscramblebegin" },
    { 0x880E, "sniperscrambledronesdialogue" },
    { 0x880F, "sniperscrambleexittruckanimations" },
    { 0x8810, "sniperscramblefinaledialogue" },
    { 0x8811, "sniperscramblefishanimations" },
    { 0x8812, "sniperscrambleflaginit" },
    { 0x8813, "sniperscramblegameskillmultiplier" },
    { 0x8814, "sniperscrambleglobalsetup" },
    { 0x8815, "sniperscrambleglobalvars" },
    { 0x8816, "sniperscramblegondolaanimations" },
    { 0x8817, "sniperscramblehoteldialogue" },
    { 0x8818, "sniperscrambleinit" },
    { 0x8819, "sniperscrambleintrodialogue" },
    { 0x881A, "sniperscrambleintrodooranimations" },
    { 0x881B, "sniperscrambleobjectivesetup" },
    { 0x881C, "sniperscrambleprecache" },
    { 0x881D, "sniperscrambleragdollkill" },
    { 0x881E, "sniperscramblesetcompletedobjflags" },
    { 0x881F, "sniperscramblestartpoints" },
    { 0x8820, "sniperscramblewindmilldestructionanimations" },
    { 0x8821, "snipersettargetent" },
    { 0x8822, "snipersetupglass" },
    { 0x8823, "snipershoot" },
    { 0x8824, "snipershootcafejump" },
    { 0x8825, "snipershootcafewall" },
    { 0x8826, "snipershootfirstcivilian" },
    { 0x8827, "snipershootgapjump" },
    { 0x8828, "snipershoothoteljump" },
    { 0x8829, "snipershoothothall" },
    { 0x882A, "snipershootilana" },
    { 0x882B, "snipershootintrodoor" },
    { 0x882C, "snipershootnearhotelciv" },
    { 0x882D, "snipershootrestaurantfishtank" },
    { 0x882E, "snipershootstingerpot" },
    { 0x882F, "snipershootwoundedsoldier" },
    { 0x8830, "snipershot" },
    { 0x8831, "snipershot_multi" },
    { 0x8832, "snipershotcount" },
/* 1 gap
    "snipershotphysicsimpulse",
    "snipertargetent",
    "snipertargetgettagpos",
    "snipertowerexplosionfx",
    "snipertowerresidualfx",
    "snipervisibletargets",
    "snowmobile_collide_death",
    "snowmobile_death_launchslide",
    "snowmobile_decide_shoot",
    "snowmobile_decide_shoot_internal",
    "snowmobile_do_event",
    "snowmobile_get_death_anim",
    "snowmobile_getoff",
    "snowmobile_geton",
    "snowmobile_handle_events",
    "snowmobile_loop_driver",
    "snowmobile_loop_driver_shooting",
    "snowmobile_loop_passenger",
    "snowmobile_loop_passenger_shooting",
    "snowmobile_mount_anims",
    "snowmobile_normal_death",
    "snowmobile_reload",
    "snowmobile_reload_internal",
    "snowmobile_setanim_common",
    "snowmobile_setanim_driver",
    "snowmobile_setanim_passenger",
    "snowmobile_shoot",
    "snowmobile_start_shooting",
    "snowmobile_stop_shooting",
    "snowmobile_trackshootentorpos_driver",
    "snowmobile_trackshootentorpos_passenger",
    "snowmobile_waitfor_end",
    "snowmobile_waitfor_start_aim",
    "snowmobile_waitfor_start_lean",
    "snowmobileshootbehavior",
    "so_can_player_see_dog",
    "so_dog_death_quote",
    "so_msg_handler",
    "soda_array",
    "soda_can_drop",
    "soda_can_eject",
    "soda_count",
    "soda_slot",
    "soften_player_damage",
    "softlanding",
    "softlandingtriggers",
    "softlandingwaiter",
    "softsighttest",
    "solar_fire_fx",
    "solar_killstreak_duration",
    "solar_reflector_cam_tag",
    "solar_reflector_player",
    "solar_reflector_sfx",
    "solar_reflector_target_sfx",
    "solarcustomkillstreakfunc",
    "solarimmunefire",
    "solarpaladinoverrides",
    "solarrelectortimer",
    "soldiers_go_through_tunnel",
    "solid_ents_by_targetname",
    "solidify_on_player_decon",
    "solo_fires",
*/
    { 0x8872, "solo_firing" },
    { 0x8873, "solo_player_in_coop_gameskill_settings" },
    { 0x8874, "solo_player_in_special_ops" },
    { 0x8875, "some_wheels_slipping" },
    { 0x8876, "sonar_hint" },
    { 0x8877, "sonar_hint_2" },
    { 0x8878, "sonar_off" },
    { 0x8879, "sonar_on" },
    { 0x887A, "sonar_reset_dvars" },
    { 0x887B, "sonar_save_and_set_dvars" },
    { 0x887C, "sonar_vision" },
    { 0x887D, "sonar_vision_off" },
    { 0x887E, "sonar_vision_on" },
    { 0x887F, "sonarvisionsaveddvars" },
    { 0x8880, "sonic_aoe_thread" },
    { 0x8881, "sonic_blast" },
    { 0x8882, "sonic_blast_aftershock" },
    { 0x8883, "sonic_blast_done" },
    { 0x8884, "sonic_blast_started" },
    { 0x8885, "sonic_destruct" },
    { 0x8886, "sonic_stop_scripted_anim" },
    { 0x8887, "sonicaoeactive" },
    { 0x8888, "sonicaoeready" },
    { 0x8889, "sonics_hint" },
    { 0x888A, "sonics_use_hint" },
    { 0x888B, "sonics_use_monitor" },
    { 0x888C, "sort_breachers" },
    { 0x888D, "sort_buttons_by_angle" },
    { 0x888E, "sort_by_startingpos" },
    { 0x888F, "sort_destructible_frame_queue" },
    { 0x8890, "sort_drone_attacks" },
    { 0x8891, "sort_drone_moves" },
    { 0x8892, "sort_reactive_ents" },
    { 0x8893, "sortbydistanceauto" },
    { 0x8894, "sortdroplocations" },
    { 0x8895, "sortinstinctdogspawnpoints" },
    { 0x8896, "sortlowermessages" },
    { 0x8897, "sortnodetransitionangles" },
    { 0x8898, "sortplayersandgivepowers" },
    { 0x8899, "sound" },
    { 0x889A, "sound_col" },
/* 1 gap
    "sound_csv_include",
    "sound_effect",
    "sound_effect_play",
    "sound_explode",
    "sound_launch",
    "sound_lock",
    "sound_offset",
    "sound_org",
    "sound_played",
    "sound_prefix",
    "sound_reset_time",
    "sound_suffix",
    "sound_tag",
    "sound_tag_dupe",
    "soundaliases",
    "sounddone",
    "soundents",
    "soundfx",
    "soundfxdelete",
    "soundonly",
*/
    { 0x88B0, "soundstate" },
    { 0x88B1, "soundtable" },
    { 0x88B2, "soundwatcher" },
    { 0x88B3, "sp_stat_tracking_func" },
    { 0x88B4, "space_arrival_turnrate_delay" },
    { 0x88B5, "space_getdefaultturnrate" },
    { 0x88B6, "space_getorientturnrate" },
    { 0x88B7, "spacing" },
    { 0x88B8, "spam_group_hudelems" },
    { 0x88B9, "spam_model_current_group" },
    { 0x88BA, "spamdelay" },
    { 0x88BB, "sparkgreenloop" },
    { 0x88BC, "sparks" },
    { 0x88BD, "sparks1" },
    { 0x88BE, "spawn_a_backline_guy" },
    { 0x88BF, "spawn_a_guy" },
    { 0x88C0, "spawn_a_school_train" },
    { 0x88C1, "spawn_a_second_line_guy" },
    { 0x88C2, "spawn_agent_player" },
    { 0x88C3, "spawn_ai" },
    { 0x88C4, "spawn_ai_flashlight" },
    { 0x88C5, "spawn_ai_from_targetname" },
    { 0x88C6, "spawn_ai_from_targetname_single" },
    { 0x88C7, "spawn_allies" },
    { 0x88C8, "spawn_allies_for_swarm_turret_segment" },
    { 0x88C9, "spawn_ally" },
    { 0x88CA, "spawn_ally_at_struct" },
    { 0x88CB, "spawn_ally_ground_vehicles" },
    { 0x88CC, "spawn_ally_walker_02" },
    { 0x88CD, "spawn_ambient_warbird" },
    { 0x88CE, "spawn_an_avatar" },
    { 0x88CF, "spawn_and_handle_looping_helicopters" },
    { 0x88D0, "spawn_angles" },
    { 0x88D1, "spawn_anim_model" },
    { 0x88D2, "spawn_array" },
    { 0x88D3, "spawn_atlas_intercept" },
    { 0x88D4, "spawn_attack_drone" },
    { 0x88D5, "spawn_back_left_scaffold_guys" },
    { 0x88D6, "spawn_bikes" },
    { 0x88D7, "spawn_bot_latent" },
    { 0x88D8, "spawn_bots" },
    { 0x88D9, "spawn_burke_common" },
    { 0x88DA, "spawn_button_released" },
    { 0x88DB, "spawn_cargo_crater" },
    { 0x88DC, "spawn_cbdr_missile" },
    { 0x88DD, "spawn_chance_override" },
    { 0x88DE, "spawn_civ_loop" },
    { 0x88DF, "spawn_controllable_drone_cloud" },
    { 0x88E0, "spawn_core_snipers_guys" },
    { 0x88E1, "spawn_cormack_common" },
    { 0x88E2, "spawn_correct_player_rig" },
    { 0x88E3, "spawn_crashing_pods" },
    { 0x88E4, "spawn_doctor" },
    { 0x88E5, "spawn_dog" },
    { 0x88E6, "spawn_driving_police_car" },
    { 0x88E7, "spawn_drone_physics" },
    { 0x88E8, "spawn_drone_street_allies_and_reinforce" },
    { 0x88E9, "spawn_drone_street_ally" },
    { 0x88EA, "spawn_ending_pcap_warbird" },
    { 0x88EB, "spawn_enemy_array_at_structs" },
    { 0x88EC, "spawn_enemy_group" },
    { 0x88ED, "spawn_enemy_jets" },
    { 0x88EE, "spawn_exfil_enemies" },
    { 0x88EF, "spawn_exit_jetbike" },
    { 0x88F0, "spawn_exp_tendril" },
    { 0x88F1, "spawn_failed" },
    { 0x88F2, "spawn_few_nightclub_guys" },
    { 0x88F3, "spawn_flag_projector" },
    { 0x88F4, "spawn_fly_in_missile" },
    { 0x88F5, "spawn_fly_in_missile_00" },
    { 0x88F6, "spawn_fly_in_missile_01" },
    { 0x88F7, "spawn_fly_in_missile_02" },
    { 0x88F8, "spawn_fly_in_missile_03" },
    { 0x88F9, "spawn_fly_in_missile_04" },
    { 0x88FA, "spawn_fly_in_missile_05" },
    { 0x88FB, "spawn_fly_in_missile_06" },
    { 0x88FC, "spawn_friendlies" },
    { 0x88FD, "spawn_func_respawn_on_death" },
    { 0x88FE, "spawn_funcs" },
    { 0x88FF, "spawn_function" },
    { 0x8900, "spawn_functions" },
    { 0x8901, "spawn_fx" },
    { 0x8902, "spawn_gideon" },
    { 0x8903, "spawn_gideon_mech" },
    { 0x8904, "spawn_grenade" },
    { 0x8905, "spawn_grenade_bag" },
    { 0x8906, "spawn_group" },
    { 0x8907, "spawn_groups" },
    { 0x8908, "spawn_guy_and_firstframe" },
    { 0x8909, "spawn_guy_loopers" },
    { 0x890A, "spawn_guys_until_death_or_no_count" },
    { 0x890B, "spawn_hidden_reinforcement" },
    { 0x890C, "spawn_hospital_roof_guys" },
    { 0x890D, "spawn_initial_forces_tanks" },
    { 0x890E, "spawn_initial_forces_warbirds" },
    { 0x890F, "spawn_intro_heroes" },
    { 0x8910, "spawn_intro_pilots" },
    { 0x8911, "spawn_knox_common" },
    { 0x8912, "spawn_kva_downstairs" },
    { 0x8913, "spawn_last_two_guys" },
    { 0x8914, "spawn_left_building_scaffolding_guy" },
    { 0x8915, "spawn_left_hospital_train" },
    { 0x8916, "spawn_looping_ambient_vehicle_single" },
    { 0x8917, "spawn_looping_ambient_vehicles" },
    { 0x8918, "spawn_looping_jets" },
    { 0x8919, "spawn_looping_street_jets" },
    { 0x891A, "spawn_mech_baghdad" },
    { 0x891B, "spawn_mech_rig" },
    { 0x891C, "spawn_metrics_death_count" },
    { 0x891D, "spawn_metrics_death_watcher" },
    { 0x891E, "spawn_metrics_init" },
    { 0x891F, "spawn_metrics_init_for_noteworthy" },
    { 0x8920, "spawn_metrics_number_alive" },
    { 0x8921, "spawn_metrics_number_died" },
    { 0x8922, "spawn_metrics_number_spawned" },
    { 0x8923, "spawn_metrics_spawn_count" },
    { 0x8924, "spawn_metrics_spawn_func" },
    { 0x8925, "spawn_metrics_waittill_count_reaches" },
    { 0x8926, "spawn_metrics_waittill_deaths_reach" },
    { 0x8927, "spawn_model_from_struct" },
    { 0x8928, "spawn_more_allies" },
    { 0x8929, "spawn_name" },
    { 0x892A, "spawn_new_ally" },
    { 0x892B, "spawn_new_traffic_entity_at_node" },
    { 0x892C, "spawn_new_traffic_entity_at_node_override" },
    { 0x892D, "spawn_new_traffic_model" },
    { 0x892E, "spawn_new_traffic_vehicle" },
    { 0x892F, "spawn_next_zone" },
    { 0x8930, "spawn_npc_and_use_scripted_zipline" },
    { 0x8931, "spawn_parked_police_car" },
    { 0x8932, "spawn_patroller_guide_floor2" },
    { 0x8933, "spawn_pdrone" },
    { 0x8934, "spawn_placed_alleyway_guys" },
    { 0x8935, "spawn_player_anim_rig" },
    { 0x8936, "spawn_player_checkpoint" },
    { 0x8937, "spawn_player_drone_think" },
    { 0x8938, "spawn_player_prisoner_hands" },
    { 0x8939, "spawn_player_rig" },
    { 0x893A, "spawn_player_rig_for_carshield" },
    { 0x893B, "spawn_police_drone" },
    { 0x893C, "spawn_police_drone_with_anim" },
    { 0x893D, "spawn_pool_copy_function" },
    { 0x893E, "spawn_pool_enabled" },
    { 0x893F, "spawn_preplaced_guys" },
    { 0x8940, "spawn_president" },
    { 0x8941, "spawn_president_s2" },
    { 0x8942, "spawn_prethink" },
    { 0x8943, "spawn_queen_drone_and_drive" },
    { 0x8944, "spawn_reinforcement" },
    { 0x8945, "spawn_reverse_school_train" },
    { 0x8946, "spawn_reverse_street_train" },
    { 0x8947, "spawn_right_hospital_train" },
    { 0x8948, "spawn_route_full_with_traffic_at" },
    { 0x8949, "spawn_scaffolding_to_floor_right" },
    { 0x894A, "spawn_script_model_turret" },
    { 0x894B, "spawn_script_noteworthy" },
    { 0x894C, "spawn_security_drones" },
    { 0x894D, "spawn_setcharacter" },
    { 0x894E, "spawn_single_vehicle_for_lane" },
    { 0x894F, "spawn_snake" },
    { 0x8950, "spawn_snake_cloud" },
    { 0x8951, "spawn_snake_no_drones" },
    { 0x8952, "spawn_snake_queen" },
    { 0x8953, "spawn_sniper_guy" },
    { 0x8954, "spawn_soda" },
    { 0x8955, "spawn_squad" },
    { 0x8956, "spawn_squad_member" },
    { 0x8957, "spawn_street_train" },
    { 0x8958, "spawn_struct_array" },
    { 0x8959, "spawn_tag_origin" },
/*
    "spawn_tag_origin_monitor",
    "spawn_takedown_01_guys",
    "spawn_tank_column",
    "spawn_targetname",
    "spawn_targetname_at_struct_targetname",
    "spawn_team_allies",
    "spawn_team_axis",
    "spawn_team_neutral",
    "spawn_team_team3",
    "spawn_tendril",
    "spawn_the_rest",
*/
    { 0x8965, "spawn_think" },
    { 0x8966, "spawn_think_action" },
    { 0x8967, "spawn_think_game_skill_related" },
    { 0x8968, "spawn_think_script_inits" },
    { 0x8969, "spawn_third_floor_guy_for_assistance" },
    { 0x896A, "spawn_time" },
    { 0x896B, "spawn_traffic_helicopter" },
    { 0x896C, "spawn_trains_track1" },
    { 0x896D, "spawn_trains_track2" },
    { 0x896E, "spawn_tram_turret" },
    { 0x896F, "spawn_transport_flying_01" },
    { 0x8970, "spawn_transport_flying_02" },
    { 0x8971, "spawn_turbine_enemies_tidal_wave" },
    { 0x8972, "spawn_turret_model" },
    { 0x8973, "spawn_unload_group" },
    { 0x8974, "spawn_veh" },
    { 0x8975, "spawn_vehicle" },
    { 0x8976, "spawn_vehicle_and_attach_to_free_path" },
    { 0x8977, "spawn_vehicle_and_gopath" },
    { 0x8978, "spawn_vehicle_from_targetname" },
    { 0x8979, "spawn_vehicle_from_targetname_and_drive" },
    { 0x897A, "spawn_vehicle_from_targetname_and_setup_jump_targets" },
    { 0x897B, "spawn_vehicle_lane" },
    { 0x897C, "spawn_vehicles_from_targetname" },
    { 0x897D, "spawn_vehicles_from_targetname_and_drive" },
    { 0x897E, "spawn_vehicles_from_targetname_newstyle" },
    { 0x897F, "spawn_version" },
    { 0x8980, "spawn_vista_vehicle" },
    { 0x8981, "spawn_walker_mobile_turret_deploy" },
    { 0x8982, "spawn_warbird_spotlight_gag" },
    { 0x8983, "spawn_warbird_turret" },
    { 0x8984, "spawn_was_good" },
    { 0x8985, "spawn_wave_stagger" },
    { 0x8986, "spawn_wave_upkeep_and_block" },
    { 0x8987, "spawn_wave_upkeep_and_flag" },
    { 0x8988, "spawn_wave1b" },
    { 0x8989, "spawn_zipline_turret" },
    { 0x898A, "spawnaddwalker" },
    { 0x898B, "spawnaddwalkers" },
    { 0x898C, "spawnairstrikeplane" },
    { 0x898D, "spawnallyinfiltrators" },
    { 0x898E, "spawnandinitnamedally" },
    { 0x898F, "spawnangle" },
    { 0x8990, "spawnanglemax" },
    { 0x8991, "spawnanglemin" },
    { 0x8992, "spawnattachment" },
    { 0x8993, "spawnattachmenteffect" },
    { 0x8994, "spawnbreachhostiles" },
    { 0x8995, "spawncivilians" },
    { 0x8996, "spawncivilians_flank_alley" },
    { 0x8997, "spawncivilians_roundabout" },
    { 0x8998, "spawnclient" },
    { 0x8999, "spawnclusterchildren" },
    { 0x899A, "spawnconfcenterai" },
    { 0x899B, "spawncopter" },
    { 0x899C, "spawncrane" },
    { 0x899D, "spawndecoycivilians" },
    { 0x899E, "spawndogtags" },
    { 0x899F, "spawned_avatar" },
    { 0x89A0, "spawned_bike_rider" },
    { 0x89A1, "spawned_boats" },
    { 0x89A2, "spawned_count" },
    { 0x89A3, "spawned_kamikaze_drones" },
    { 0x89A4, "spawned_turret" },
    { 0x89A5, "spawnedfoamglobs" },
    { 0x89A6, "spawnedkillcamcleanup" },
    { 0x89A7, "spawnedwarbirds" },
    { 0x89A8, "spawneffectonplayerview" },
    { 0x89A9, "spawnendingenemies" },
    { 0x89AA, "spawnendingenemies01" },
    { 0x89AB, "spawnendingenemies01flood" },
    { 0x89AC, "spawnendingenemies02" },
    { 0x89AD, "spawnendingenemies02flood" },
    { 0x89AE, "spawnendingenemies03" },
    { 0x89AF, "spawnendingenemies04" },
    { 0x89B0, "spawnendingenemies04flood" },
    { 0x89B1, "spawnendingenemies05" },
    { 0x89B2, "spawnendingenemies06" },
    { 0x89B3, "spawnendingheli" },
    { 0x89B4, "spawnendingshotguna" },
    { 0x89B5, "spawnendingshotgunb" },
    { 0x89B6, "spawnendofgame" },
    { 0x89B7, "spawnenemiesambusherseast" },
    { 0x89B8, "spawnenemiesambusherssouth" },
    { 0x89B9, "spawnenemiesextra" },
    { 0x89BA, "spawnenemiespatrollersa" },
    { 0x89BB, "spawnenemiespatrollersb" },
    { 0x89BC, "spawnenemiespatrollersc" },
    { 0x89BD, "spawnenemyambushvehicle" },
    { 0x89BE, "spawnenemyreinforcementsvehicles" },
    { 0x89BF, "spawnenemystruggle" },
    { 0x89C0, "spawner_deathflag" },
    { 0x89C1, "spawner_dronespawn" },
    { 0x89C2, "spawner_fallbackers" },
    { 0x89C3, "spawner_force_laser_on" },
    { 0x89C4, "spawner_id" },
    { 0x89C5, "spawner_name" },
    { 0x89C6, "spawner_number" },
    { 0x89C7, "spawner_pool" },
    { 0x89C8, "spawner_swap_ai_to_drone" },
    { 0x89C9, "spawner_swap_drone_to_ai" },
    { 0x89CA, "spawner_vision_checker" },
    { 0x89CB, "spawnercallbackthread" },
    { 0x89CC, "spawnercount" },
    { 0x89CD, "spawners" },
    { 0x89CE, "spawnerwave" },
    { 0x89CF, "spawnfemalecivilians" },
    { 0x89D0, "spawnfemalecivilians_roundabout" },
    { 0x89D1, "spawnfire" },
    { 0x89D2, "spawnfunc_ally" },
    { 0x89D3, "spawnfunc_mb" },
    { 0x89D4, "spawnfunc_mb_civilians" },
    { 0x89D5, "spawnfunc_mb_drone" },
    { 0x89D6, "spawnfunc_mb_enemies" },
    { 0x89D7, "spawnfunc_mb1_tower" },
    { 0x89D8, "spawnfunc_mb1_vrap" },
    { 0x89D9, "spawnfunc_mb2_final" },
    { 0x89DA, "spawnfunc_mb2_mech" },
    { 0x89DB, "spawnfunc_mb2_vrap" },
    { 0x89DC, "spawnfunc_mech_crush" },
    { 0x89DD, "spawnfxshowtoteam" },
    { 0x89DE, "spawnglow" },
    { 0x89DF, "spawnglowmodel" },
    { 0x89E0, "spawnhadesescapevehicle" },
    { 0x89E1, "spawnhangardoors" },
    { 0x89E2, "spawnheight" },
    { 0x89E3, "spawnhostile" },
    { 0x89E4, "spawninfo" },
    { 0x89E5, "spawningafterremotedeath" },
    { 0x89E6, "spawningclientthisframereset" },
    { 0x89E7, "spawninstinctdogs" },
    { 0x89E8, "spawnintelpickup" },
    { 0x89E9, "spawnintermission" },
    { 0x89EA, "spawnkvafollowtarget" },
    { 0x89EB, "spawnkvasafehouseguards" },
    { 0x89EC, "spawnlinkedfxshowtoteam" },
    { 0x89ED, "spawnlogicteam" },
    { 0x89EE, "spawnlogictraceheight" },
    { 0x89EF, "spawnlogictracehieght" },
    { 0x89F0, "spawnmalecivilians" },
    { 0x89F1, "spawnmalecivilians_roundabout" },
    { 0x89F2, "spawnmalecivilianswithface" },
    { 0x89F3, "spawnmaxs" },
    { 0x89F4, "spawnmgturret" },
    { 0x89F5, "spawnmine" },
    { 0x89F6, "spawnmins" },
    { 0x89F7, "spawnorbitalsupportturret" },
    { 0x89F8, "spawnorigin" },
    { 0x89F9, "spawnperk" },
    { 0x89FA, "spawnpickup" },
    { 0x89FB, "spawnplayer" },
    { 0x89FC, "spawnplayerinorbital" },
    { 0x89FD, "spawnpoint" },
    { 0x89FE, "spawnpointarray" },
    { 0x89FF, "spawnpointdistanceupdate" },
    { 0x8A00, "spawnpointinit" },
    { 0x8A01, "spawnpoints" },
    { 0x8A02, "spawnpointsightupdate" },
    { 0x8A03, "spawnpointupdate" },
    { 0x8A04, "spawnposttakedowncivilians" },
    { 0x8A05, "spawnpotentialtargets" },
    { 0x8A06, "spawnradius" },
    { 0x8A07, "spawnrestaurantfishswimming" },
    { 0x8A08, "spawnriotshieldcollision" },
    { 0x8A09, "spawnriotshieldcover" },
    { 0x8A0A, "spawnsafehousepatroller" },
    { 0x8A0B, "spawnscore" },
    { 0x8A0C, "spawnsetup" },
    { 0x8A0D, "spawnshieldlights" },
    { 0x8A0E, "spawnspectator" },
    { 0x8A0F, "spawnsquadfunc" },
    { 0x8A10, "spawntarget" },
    { 0x8A11, "spawntempcivilians" },
    { 0x8A12, "spawntimedecisecondsfrommatchstart" },
    { 0x8A13, "spawntracelocation" },
    { 0x8A14, "spawnwalkingcivilians" },
    { 0x8A15, "spawnwalkingcivilians_roundabout" },
    { 0x8A16, "spawnwavestoptrigger" },
    { 0x8A17, "spawnwaypointfriendlies" },
    { 0x8A18, "speaker_distance" },
    { 0x8A19, "speakers" },
    { 0x8A1A, "special" },
    { 0x8A1B, "special_array_remove" },
    { 0x8A1C, "special_autosavecondition" },
    { 0x8A1D, "special_death_anim" },
    { 0x8A1E, "special_death_hint" },
    { 0x8A1F, "special_death_proc" },
    { 0x8A20, "special_flyby_jet" },
    { 0x8A21, "special_gulag_adjustment" },
    { 0x8A22, "special_kva" },
    { 0x8A23, "special_loopingidleanimation" },
    { 0x8A24, "special_weapon_dof_funcs" },
    { 0x8A25, "specialaicount" },
    { 0x8A26, "specialaistats" },
    { 0x8A27, "specialaitypes" },
    { 0x8A28, "specialcheck" },
    { 0x8A29, "specialcleanupfunc" },
    { 0x8A2A, "specialdamage" },
    { 0x8A2B, "specialdeath" },
    { 0x8A2C, "specialdeathfunc" },
    { 0x8A2D, "specialflashedfunc" },
    { 0x8A2E, "specialgametypescript" },
    { 0x8A2F, "specialidleanim" },
    { 0x8A30, "specialidleloop" },
    { 0x8A31, "specialmelee_standard" },
    { 0x8A32, "specialmeleechooseaction" },
    { 0x8A33, "specialpain" },
    { 0x8A34, "specialpainblocker" },
    { 0x8A35, "specialreloadanimfunc" },
    { 0x8A36, "specialshootbehavior" },
    { 0x8A37, "specialstruct" },
    { 0x8A38, "specialty_blackbox_bonus" },
    { 0x8A39, "specialty_blastshield_bonus" },
    { 0x8A3A, "specialty_c4_death_icon" },
    { 0x8A3B, "specialty_compassping_revenge_icon" },
    { 0x8A3C, "specialty_finalstand_icon" },
    { 0x8A3D, "specialty_juiced_icon" },
    { 0x8A3E, "specialty_paint_time" },
    { 0x8A3F, "specialty_unwrapper_care_bonus" },
    { 0x8A40, "species" },
    { 0x8A41, "specific_combat" },
    { 0x8A42, "specific_warbird_deathflag" },
    { 0x8A43, "specific_warbird_deathflag1" },
    { 0x8A44, "specific_warbird_deathflag2" },
    { 0x8A45, "specific_warbird_deathflag3" },
    { 0x8A46, "specops" },
    { 0x8A47, "specops_dmg" },
    { 0x8A48, "specops_reward_gameskill" },
    { 0x8A49, "specops_think" },
    { 0x8A4A, "spectateoverride" },
    { 0x8A4B, "spectating_actively" },
    { 0x8A4C, "spectatorviewloadout" },
    { 0x8A4D, "specular_default" },
    { 0x8A4E, "speechcommands" },
    { 0x8A4F, "speed_calc" },
    { 0x8A50, "speed_control_pathnodes" },
    { 0x8A51, "speed_control_pathnodes_dist" },
    { 0x8A52, "speed_display" },
    { 0x8A53, "speed_norm" },
    { 0x8A54, "speed_of_sound_" },
    { 0x8A55, "speed_scale" },
    { 0x8A56, "speed_slow" },
    { 0x8A57, "speed_to_anim_rate" },
    { 0x8A58, "speed_up_building_jump_anim" },
    { 0x8A59, "speed_up_gideon_when_u_cant_see_him" },
    { 0x8A5A, "speed_up_missile_load" },
    { 0x8A5B, "spider_tank_deaths" },
    { 0x8A5C, "spikelist" },
    { 0x8A5D, "spikelistindex" },
    { 0x8A5E, "spinalarmsstart" },
    { 0x8A5F, "spinalarmsstop" },
    { 0x8A60, "spinnerarray" },
    { 0x8A61, "spinsoundshortly" },
    { 0x8A62, "spinthelasers" },
    { 0x8A63, "spinuptime" },
    { 0x8A64, "splash_pos_for_speed" },
    { 0x8A65, "splashattachmentname" },
    { 0x8A66, "splashing_water" },
    { 0x8A67, "splashname" },
    { 0x8A68, "splashnotify" },
    { 0x8A69, "splashnotifydelayed" },
    { 0x8A6A, "splashnotifyurgent" },
    { 0x8A6B, "splashqueue" },
    { 0x8A6C, "splashref" },
    { 0x8A6D, "splashusedname" },
    { 0x8A6E, "splashweakenedname" },
    { 0x8A6F, "spline_accel" },
    { 0x8A70, "spline_decel" },
    { 0x8A71, "spline_fast_decel" },
    { 0x8A72, "spline_speed" },
    { 0x8A73, "split_lane" },
    { 0x8A74, "split_lane_extra_handling" },
    { 0x8A75, "split_rocket" },
    { 0x8A76, "split_rocket_hellfire" },
    { 0x8A77, "split_rocket_spiral" },
    { 0x8A78, "splitarrivalsleft" },
    { 0x8A79, "splitarrivalsright" },
    { 0x8A7A, "splitexitsleft" },
    { 0x8A7B, "splitexitsright" },
    { 0x8A7C, "splitscreen" },
    { 0x8A7D, "spot" },
    { 0x8A7E, "spot_exhaust_fail_angles" },
    { 0x8A7F, "spot_exhaust_fail_orig" },
    { 0x8A80, "spot_main" },
    { 0x8A81, "spot_tag" },
    { 0x8A82, "spot_tag2" },
    { 0x8A83, "spot_tag3" },
    { 0x8A84, "spot_tag4" },
    { 0x8A85, "spotlight" },
    { 0x8A86, "spotlight_aim_ents" },
    { 0x8A87, "spotlight_fizzles_out" },
    { 0x8A88, "spotlight_light_motion" },
    { 0x8A89, "spotlight_owner" },
    { 0x8A8A, "spotlight_tag" },
    { 0x8A8B, "spotlight_tag_origin_cleanup" },
    { 0x8A8C, "spotlight_target" },
    { 0x8A8D, "spotlight_think" },
    { 0x8A8E, "spotlights" },
    { 0x8A8F, "spotlimit" },
    { 0x8A90, "spottarget" },
    { 0x8A91, "spotted_an_enemy" },
    { 0x8A92, "spotted_enemy" },
    { 0x8A93, "spotted_list" },
    { 0x8A94, "spottedorigin" },
    { 0x8A95, "spottedstance" },
    { 0x8A96, "spottedvisibledistance" },
    { 0x8A97, "spotter" },
    { 0x8A98, "spotterangles" },
    { 0x8A99, "spotterfov" },
    { 0x8A9A, "spotterviewpoint" },
    { 0x8A9B, "spraycans" },
    { 0x8A9C, "sprayerdrip" },
    { 0x8A9D, "sprayerdriparray" },
    { 0x8A9E, "spraymachine" },
    { 0x8A9F, "spraymachinedrips" },
    { 0x8AA0, "spraypaint_chaser" },
    { 0x8AA1, "spraypaint_gag" },
    { 0x8AA2, "spraypaint_runner" },
    { 0x8AA3, "spraysheetstate" },
    { 0x8AA4, "spread_width" },
    { 0x8AA5, "sprimaryweapon" },
    { 0x8AA6, "sprinkler_origin" },
    { 0x8AA7, "sprinkler_sound_proximity_toggle" },
    { 0x8AA8, "sprint" },
    { 0x8AA9, "sprint_hint_reminder" },
    { 0x8AAA, "sprint_speed" },
    { 0x8AAB, "sprintdistthissprint" },
    { 0x8AAC, "sprintslidekillevent" },
    { 0x8AAD, "sprinttracking" },
    { 0x8AAE, "spupdatetotal" },
    { 0x8AAF, "spwan_vehicle_loopers" },
    { 0x8AB0, "squad" },
    { 0x8AB1, "squad_becomes_aware_after_intro" },
    { 0x8AB2, "squad_careful_all_start" },
    { 0x8AB3, "squad_careful_all_stop" },
    { 0x8AB4, "squad_exo_door_goto" },
    { 0x8AB5, "squad_gestures_burke" },
    { 0x8AB6, "squad_gestures_idle_count" },
    { 0x8AB7, "squad_gestures_joker" },
    { 0x8AB8, "squad_gestures_wait_count" },
    { 0x8AB9, "squad_heli_zip" },
    { 0x8ABA, "squad_ignore_all_start" },
    { 0x8ABB, "squad_ignore_all_stop" },
    { 0x8ABC, "squad_intro_anim_ajani" },
    { 0x8ABD, "squad_intro_anim_burke" },
    { 0x8ABE, "squad_intro_anim_joker" },
    { 0x8ABF, "squad_intro_fov_shift_off" },
    { 0x8AC0, "squad_intro_fov_shift_on" },
    { 0x8AC1, "squad_intro_walkway_goto" },
    { 0x8AC2, "squad_move_interior" },
    { 0x8AC3, "squad_move_out_dialogue" },
    { 0x8AC4, "squad_opening" },
    { 0x8AC5, "squad_opening_names" },
    { 0x8AC6, "squad_opening_warbird" },
    { 0x8AC7, "squadcanburst" },
    { 0x8AC8, "squadchange" },
    { 0x8AC9, "squadcreatefuncs" },
    { 0x8ACA, "squadcreatestrings" },
    { 0x8ACB, "squadflavorbursttransmissions" },
    { 0x8ACC, "squadhasofficer" },
    { 0x8ACD, "squadid" },
    { 0x8ACE, "squadindex" },
    { 0x8ACF, "squadinitialized" },
    { 0x8AD0, "squadlist" },
    { 0x8AD1, "squadmate_agent_think" },
    { 0x8AD2, "squadnum" },
    { 0x8AD3, "squadofficerwaiter" },
    { 0x8AD4, "squadrand" },
    { 0x8AD5, "squads" },
    { 0x8AD6, "squadstates" },
    { 0x8AD7, "squadthreatwaiter" },
    { 0x8AD8, "squadtracker" },
    { 0x8AD9, "squadupdatefuncs" },
    { 0x8ADA, "squadupdatestrings" },
    { 0x8ADB, "sr_ally_near_tag" },
    { 0x8ADC, "sr_camp_tag" },
    { 0x8ADD, "sr_pick_up_tag" },
    { 0x8ADE, "sr_respawn" },
    { 0x8ADF, "ssao_set_target_over_time_internal" },
    { 0x8AE0, "sscr_goaltime" },
    { 0x8AE1, "st_driving" },
    { 0x8AE2, "stable_unlink" },
    { 0x8AE3, "stabs" },
    { 0x8AE4, "stack" },
    { 0x8AE5, "stack_make" },
    { 0x8AE6, "stack_peek" },
    { 0x8AE7, "stack_pop" },
    { 0x8AE8, "stack_push" },
    { 0x8AE9, "stage_guy" },
    { 0x8AEA, "stage1_ambush" },
    { 0x8AEB, "stage2_ambush" },
    { 0x8AEC, "stagger_env_fx" },
    { 0x8AED, "stair_state_loop" },
    { 0x8AEE, "stair_wait" },
    { 0x8AEF, "stairwell_doors" },
    { 0x8AF0, "stalactite_fall" },
    { 0x8AF1, "stalemate" },
    { 0x8AF2, "stance" },
    { 0x8AF3, "stance_carry" },
    { 0x8AF4, "stance_carry_icon_disable" },
    { 0x8AF5, "stance_carry_icon_enable" },
    { 0x8AF6, "stance_change" },
    { 0x8AF7, "stance_change_time" },
    { 0x8AF8, "stance_handler" },
    { 0x8AF9, "stance_num" },
    { 0x8AFA, "stance_up" },
    { 0x8AFB, "stancecrouchmovement" },
    { 0x8AFC, "stancerecoiladjuster" },
    { 0x8AFD, "stancestatelistener" },
    { 0x8AFE, "stand_to_run_overrideanim" },
    { 0x8AFF, "stand_up_if_necessary" },
    { 0x8B00, "standard_plane_controls" },
    { 0x8B01, "standard_siren_01" },
    { 0x8B02, "standard_siren_setup" },
    { 0x8B03, "standard_text_list" },
    { 0x8B04, "standardmaxhealth" },
    { 0x8B05, "standattack" },
    { 0x8B06, "standdown" },
    { 0x8B07, "standidle" },
    { 0x8B08, "standifmakesenemyvisible" },
    { 0x8B09, "standing" },
    { 0x8B0A, "standing_actor_01" },
    { 0x8B0B, "standingaimblendtime" },
    { 0x8B0C, "standingaimlimits" },
    { 0x8B0D, "standingmechblendtime" },
    { 0x8B0E, "standingturnrate" },
    { 0x8B0F, "standrun_begin" },
    { 0x8B10, "standrun_checkchangeweapon" },
    { 0x8B11, "standrun_checkreload" },
    { 0x8B12, "standrun_combatnormal" },
    { 0x8B13, "standrun_noncombatnormal" },
    { 0x8B14, "standrun_reloadinternal" },
    { 0x8B15, "standruntocrouch" },
    { 0x8B16, "standruntostand" },
    { 0x8B17, "standstop_begin" },
    { 0x8B18, "standtocrouch" },
    { 0x8B19, "standtoprone" },
    { 0x8B1A, "standtopronerun" },
    { 0x8B1B, "standtopronewalk" },
    { 0x8B1C, "standwalk_begin" },
    { 0x8B1D, "standwalktocrouch" },
    { 0x8B1E, "standwalktostand" },
    { 0x8B1F, "star" },
    { 0x8B20, "start" },
    { 0x8B21, "start_after_crash_traffic" },
    { 0x8B22, "start_airlock_anim_notetracks" },
    { 0x8B23, "start_alarm_post_reactor" },
    { 0x8B24, "start_alias_data" },
    { 0x8B25, "start_alley1" },
    { 0x8B26, "start_alley2" },
    { 0x8B27, "start_alleys_checkpoint" },
    { 0x8B28, "start_alleys_combat_music" },
    { 0x8B29, "start_alleys_music" },
    { 0x8B2A, "start_alleys_transition_checkpoint" },
    { 0x8B2B, "start_alleyway" },
    { 0x8B2C, "start_ambient_event" },
    { 0x8B2D, "start_ambient_jet" },
    { 0x8B2E, "start_ambient_pair_kick" },
    { 0x8B2F, "start_ams" },
    { 0x8B30, "start_ams_thread" },
    { 0x8B31, "start_angle" },
    { 0x8B32, "start_angles" },
    { 0x8B33, "start_anim" },
    { 0x8B34, "start_arrays" },
    { 0x8B35, "start_atrium_breach_music" },
    { 0x8B36, "start_atrium_fight" },
    { 0x8B37, "start_attack_heli" },
    { 0x8B38, "start_autopsy" },
    { 0x8B39, "start_autopsy_alarm" },
    { 0x8B3A, "start_autopsy_halls" },
    { 0x8B3B, "start_avalanche" },
    { 0x8B3C, "start_battle_to_heli" },
    { 0x8B3D, "start_bedroom" },
    { 0x8B3E, "start_big_cave" },
    { 0x8B3F, "start_billboard_ads" },
    { 0x8B40, "start_blocking_police" },
    { 0x8B41, "start_boat" },
    { 0x8B42, "start_boatcrash" },
    { 0x8B43, "start_boatjump" },
    { 0x8B44, "start_boatmall" },
    { 0x8B45, "start_boatwarbird" },
    { 0x8B46, "start_bobbing" },
    { 0x8B47, "start_bobbing_single" },
    { 0x8B48, "start_boost" },
    { 0x8B49, "start_bridge" },
    { 0x8B4A, "start_bridge_after_loop" },
    { 0x8B4B, "start_bridge_capture" },
    { 0x8B4C, "start_bridge_end_foley" },
    { 0x8B4D, "start_bridge_heli" },
    { 0x8B4E, "start_bridge_helis" },
    { 0x8B4F, "start_bridge_overwatch_heli" },
    { 0x8B50, "start_briefing" },
    { 0x8B51, "start_burke_ambush_slomo" },
    { 0x8B52, "start_burke_boost_kick" },
    { 0x8B53, "start_burke_elevator_slide" },
    { 0x8B54, "start_burke_foley" },
    { 0x8B55, "start_bus_moving_before_anim_ends" },
    { 0x8B56, "start_cafe_cam_mvmnt_loops" },
    { 0x8B57, "start_camera_static" },
    { 0x8B58, "start_canal" },
    { 0x8B59, "start_cao_anims" },
    { 0x8B5A, "start_car_alarm" },
    { 0x8B5B, "start_cave_entry" },
    { 0x8B5C, "start_cave_hallway" },
    { 0x8B5D, "start_cc_open_combat" },
    { 0x8B5E, "start_circling_heli" },
    { 0x8B5F, "start_civilian_group" },
    { 0x8B60, "start_civilian_loop_anims" },
    { 0x8B61, "start_cliff_rappel" },
    { 0x8B62, "start_climb" },
    { 0x8B63, "start_climbcrates" },
    { 0x8B64, "start_climbroof" },
    { 0x8B65, "start_climbskybridge" },
    { 0x8B66, "start_color" },
    { 0x8B67, "start_combat_cave" },
    { 0x8B68, "start_conf_center_combat_checkpoint" },
    { 0x8B69, "start_conf_center_intro_checkpoint" },
    { 0x8B6A, "start_conf_center_kill_checkpoint" },
    { 0x8B6B, "start_conf_center_outro_checkpoint" },
    { 0x8B6C, "start_conf_center_support1_checkpoint" },
    { 0x8B6D, "start_conf_center_support2_checkpoint" },
    { 0x8B6E, "start_conf_center_support3_checkpoint" },
    { 0x8B6F, "start_confrontation" },
    { 0x8B70, "start_confrontation_qte" },
    { 0x8B71, "start_construction_heli" },
    { 0x8B72, "start_control_room" },
    { 0x8B73, "start_control_room_alarms" },
    { 0x8B74, "start_control_room_entrance" },
    { 0x8B75, "start_control_room_exit" },
    { 0x8B76, "start_control_room_explo" },
    { 0x8B77, "start_cooling_tower" },
    { 0x8B78, "start_courtyard" },
    { 0x8B79, "start_courtyard_alarms" },
    { 0x8B7A, "start_courtyard_jammer" },
    { 0x8B7B, "start_cqb_when_near" },
    { 0x8B7C, "start_crash" },
    { 0x8B7D, "start_crash_bus" },
    { 0x8B7E, "start_crash_site" },
    { 0x8B7F, "start_crash_suvs" },
    { 0x8B80, "start_dead_guy_foley" },
    { 0x8B81, "start_deck" },
    { 0x8B82, "start_demo_with_itiot" },
    { 0x8B83, "start_description" },
    { 0x8B84, "start_det_catch_guy_01" },
    { 0x8B85, "start_det_catch_guy_02" },
    { 0x8B86, "start_dialogue_threads" },
    { 0x8B87, "start_display_cleanup" },
    { 0x8B88, "start_dist" },
    { 0x8B89, "start_docks" },
    { 0x8B8A, "start_door_kick" },
    { 0x8B8B, "start_drive_in" },
    { 0x8B8C, "start_drone_barrage_submix" },
    { 0x8B8D, "start_drone_death_static" },
    { 0x8B8E, "start_drone_deploy_anim" },
    { 0x8B8F, "start_drone_spawns" },
    { 0x8B90, "start_elevator_zone_audio" },
    { 0x8B91, "start_end_escape" },
    { 0x8B92, "start_end_takedown_highway_path_player_side" },
    { 0x8B93, "start_end_takedown_traffic_done" },
    { 0x8B94, "start_ending_ambush_checkpoint" },
    { 0x8B95, "start_ending_fight_checkpoint" },
    { 0x8B96, "start_ending_hades_checkpoint" },
    { 0x8B97, "start_enemy_callout_vo" },
    { 0x8B98, "start_ent_count" },
    { 0x8B99, "start_ents" },
    { 0x8B9A, "start_escape" },
    { 0x8B9B, "start_exfil" },
    { 0x8B9C, "start_exit_drive" },
    { 0x8B9D, "start_exo_mute" },
    { 0x8B9E, "start_exo_ping" },
    { 0x8B9F, "start_exo_sonic_attack_fail" },
    { 0x8BA0, "start_exopush" },
    { 0x8BA1, "start_facility_breach" },
    { 0x8BA2, "start_fardist" },
    { 0x8BA3, "start_finale_fight_music" },
    { 0x8BA4, "start_finale_h2h_music" },
    { 0x8BA5, "start_finale_suv_damage" },
    { 0x8BA6, "start_finale_transition_music" },
    { 0x8BA7, "start_fire_steam_loops" },
    { 0x8BA8, "start_fire_suppression_group" },
    { 0x8BA9, "start_firing" },
    { 0x8BAA, "start_fixed_scanner_audio" },
    { 0x8BAB, "start_flank" },
    { 0x8BAC, "start_flank_alley" },
    { 0x8BAD, "start_fly" },
    { 0x8BAE, "start_flying_attack_drone" },
    { 0x8BAF, "start_flying_attack_drones" },
    { 0x8BB0, "start_foam_room" },
    { 0x8BB1, "start_forest" },
    { 0x8BB2, "start_forest_takedown" },
    { 0x8BB3, "start_freeway_music" },
    { 0x8BB4, "start_frogger" },
    { 0x8BB5, "start_functions" },
    { 0x8BB6, "start_funeral" },
    { 0x8BB7, "start_fuorescent_light_hum" },
    { 0x8BB8, "start_fx_by_view" },
    { 0x8BB9, "start_fx_by_view_failsafe" },
    { 0x8BBA, "start_gate_breach_music" },
    { 0x8BBB, "start_gatedoor" },
    { 0x8BBC, "start_gaz_02_retreat" },
    { 0x8BBD, "start_gaz_03_retreat" },
    { 0x8BBE, "start_glow" },
    { 0x8BBF, "start_government_building" },
    { 0x8BC0, "start_government_courtyard" },
    { 0x8BC1, "start_grapple" },
    { 0x8BC2, "start_hack_security" },
    { 0x8BC3, "start_hades_breach" },
    { 0x8BC4, "start_hades_breach_door" },
    { 0x8BC5, "start_hades_breach_guard" },
    { 0x8BC6, "start_hades_breach_npc" },
    { 0x8BC7, "start_hades_breach_npc1" },
    { 0x8BC8, "start_hades_breach_npc2" },
    { 0x8BC9, "start_hades_double_stinger" },
    { 0x8BCA, "start_hades_flashbang" },
    { 0x8BCB, "start_hades_kill_interact_fail" },
    { 0x8BCC, "start_hades_suv_extraction" },
    { 0x8BCD, "start_hades_transition" },
    { 0x8BCE, "start_halls_to_autopsy" },
    { 0x8BCF, "start_hangar" },
    { 0x8BD0, "start_hdrcolorintensity" },
    { 0x8BD1, "start_hdrsuncolorintensity" },
    { 0x8BD2, "start_heli_custom_aim" },
    { 0x8BD3, "start_heliride" },
    { 0x8BD4, "start_hologram_audio" },
    { 0x8BD5, "start_hospital" },
    { 0x8BD6, "start_hospital_capture_animation" },
    { 0x8BD7, "start_ice_bridge" },
    { 0x8BD8, "start_idle_shooting" },
    { 0x8BD9, "start_ied_convoy_ambush_expl" },
    { 0x8BDA, "start_ied_convoy_slomo_end" },
    { 0x8BDB, "start_incinerator" },
    { 0x8BDC, "start_infil" },
    { 0x8BDD, "start_information_center" },
    { 0x8BDE, "start_intel" },
    { 0x8BDF, "start_interior" },
    { 0x8BE0, "start_interior_alarms" },
    { 0x8BE1, "start_intro" },
    { 0x8BE2, "start_intro_ambience" },
    { 0x8BE3, "start_intro_drive" },
    { 0x8BE4, "start_intro_drone" },
    { 0x8BE5, "start_intro_fly_in" },
    { 0x8BE6, "start_intro_fly_in_part2" },
    { 0x8BE7, "start_intro_npc_foley" },
    { 0x8BE8, "start_intro_skip" },
    { 0x8BE9, "start_intro_squad" },
    { 0x8BEA, "start_introdrive" },
    { 0x8BEB, "start_irons_chase" },
    { 0x8BEC, "start_jerk_driver" },
    { 0x8BED, "start_jerk_driver_car" },
    { 0x8BEE, "start_jump_grapple" },
    { 0x8BEF, "start_kdrone_launch" },
    { 0x8BF0, "start_kdrone_loop" },
    { 0x8BF1, "start_knocked_to_oncoming" },
    { 0x8BF2, "start_kva_assault_music" },
    { 0x8BF3, "start_kva_follow_music" },
    { 0x8BF4, "start_lab" },
    { 0x8BF5, "start_lab_alarms" },
    { 0x8BF6, "start_lake" },
    { 0x8BF7, "start_lake_cinema" },
    { 0x8BF8, "start_list_menu" },
    { 0x8BF9, "start_list_settext" },
    { 0x8BFA, "start_loading_bay_alarms" },
    { 0x8BFB, "start_lobby" },
    { 0x8BFC, "start_lobby_anims" },
    { 0x8BFD, "start_logging_road" },
    { 0x8BFE, "start_look" },
    { 0x8BFF, "start_looping_intro_alarm_sounds" },
    { 0x8C00, "start_looping_outro_alarm_sounds" },
    { 0x8C01, "start_mb1" },
    { 0x8C02, "start_mb1_intro" },
    { 0x8C03, "start_mb1_jump" },
    { 0x8C04, "start_mb1_mech" },
    { 0x8C05, "start_mb2" },
    { 0x8C06, "start_mb2_gatesmash" },
    { 0x8C07, "start_mech" },
    { 0x8C08, "start_mech_march" },
    { 0x8C09, "start_meet_cormack_pt2" },
    { 0x8C0A, "start_menu" },
    { 0x8C0B, "start_menu_update" },
    { 0x8C0C, "start_middle_takedown" },
    { 0x8C0D, "start_middle_takedown_highway_path_player_side" },
    { 0x8C0E, "start_mocap_ar" },
    { 0x8C0F, "start_monitor_escape_artist" },
    { 0x8C10, "start_monitor_microwave_grenades" },
    { 0x8C11, "start_movie_capture" },
    { 0x8C12, "start_moving" },
    { 0x8C13, "start_moving_with_bob" },
    { 0x8C14, "start_narrow_cave" },
    { 0x8C15, "start_neardist" },
    { 0x8C16, "start_nogame" },
    { 0x8C17, "start_notetrack_wait" },
    { 0x8C18, "start_off_running" },
    { 0x8C19, "start_office" },
    { 0x8C1A, "start_oldtown" },
    { 0x8C1B, "start_oncoming" },
    { 0x8C1C, "start_oncoming_alley" },
    { 0x8C1D, "start_oncoming_downhill" },
    { 0x8C1E, "start_one_handed_gunplay" },
    { 0x8C1F, "start_opacity" },
    { 0x8C20, "start_origin" },
    { 0x8C21, "start_outro" },
    { 0x8C22, "start_outside_alarm" },
    { 0x8C23, "start_overlay" },
    { 0x8C24, "start_overlook" },
    { 0x8C25, "start_pa_airlockclosing" },
    { 0x8C26, "start_pa_codered" },
    { 0x8C27, "start_pa_emergency_exit" },
    { 0x8C28, "start_pa_emergency_turbine" },
    { 0x8C29, "start_parked_police_car_radio" },
    { 0x8C2A, "start_penthouse" },
    { 0x8C2B, "start_pitbull" },
    { 0x8C2C, "start_pitbull_skirmish" },
    { 0x8C2D, "start_pitch" },
    { 0x8C2E, "start_plant_tracker" },
    { 0x8C2F, "start_player_diveboat_ride" },
    { 0x8C30, "start_player_elevator_jump" },
    { 0x8C31, "start_player_elevator_slide" },
    { 0x8C32, "start_player_office_scene_walk_sway" },
    { 0x8C33, "start_player_pdrone_audio" },
    { 0x8C34, "start_player_walk_sway" },
    { 0x8C35, "start_pod_sequence" },
    { 0x8C36, "start_point" },
    { 0x8C37, "start_point_check" },
    { 0x8C38, "start_point_grapple" },
    { 0x8C39, "start_point_intro" },
    { 0x8C3A, "start_point_is_after" },
    { 0x8C3B, "start_point_is_before" },
    { 0x8C3C, "start_point_is_between" },
    { 0x8C3D, "start_point_scripted" },
    { 0x8C3E, "start_point_source_dambs" },
    { 0x8C3F, "start_police" },
    { 0x8C40, "start_police_standoff" },
    { 0x8C41, "start_pos" },
    { 0x8C42, "start_position" },
    { 0x8C43, "start_post_courtyard_ext_alarms" },
    { 0x8C44, "start_post_courtyard_ext_alarms_2" },
    { 0x8C45, "start_post_courtyard_interior_alarms" },
    { 0x8C46, "start_post_h_breach" },
    { 0x8C47, "start_post_middle_takedown" },
    { 0x8C48, "start_pre_h_breach" },
    { 0x8C49, "start_pre_loading_bay" },
    { 0x8C4A, "start_pre_reactor_alarms" },
    { 0x8C4B, "start_prelobby_anims" },
    { 0x8C4C, "start_railgun_hud" },
    { 0x8C4D, "start_reactor" },
    { 0x8C4E, "start_reactor_airlock_open" },
    { 0x8C4F, "start_reactor_burke_attack" },
    { 0x8C50, "start_reactor_exit" },
    { 0x8C51, "start_reactor_zone_audio" },
    { 0x8C52, "start_recon" },
    { 0x8C53, "start_refugee_camp" },
    { 0x8C54, "start_repulsor" },
    { 0x8C55, "start_research_facility_bridge" },
    { 0x8C56, "start_reverse_hint" },
    { 0x8C57, "start_roof" },
    { 0x8C58, "start_rooftop_combat" },
    { 0x8C59, "start_rough_tide" },
    { 0x8C5A, "start_roundabout" },
    { 0x8C5B, "start_run_to_heli" },
    { 0x8C5C, "start_s1_elevator" },
    { 0x8C5D, "start_s1elevator" },
    { 0x8C5E, "start_s2_elevator" },
    { 0x8C5F, "start_s2_walk" },
    { 0x8C60, "start_s2elevator" },
    { 0x8C61, "start_s2walk" },
    { 0x8C62, "start_s3escape" },
    { 0x8C63, "start_s3interrogate" },
    { 0x8C64, "start_s3trolley" },
    { 0x8C65, "start_safehouse_clear_checkpoint" },
    { 0x8C66, "start_safehouse_exit_checkpoint" },
    { 0x8C67, "start_safehouse_exo_trans_music" },
    { 0x8C68, "start_safehouse_follow_checkpoint" },
    { 0x8C69, "start_safehouse_guard_03_music" },
    { 0x8C6A, "start_safehouse_intro_checkpoint" },
    { 0x8C6B, "start_safehouse_stairs_music" },
    { 0x8C6C, "start_safehouse_stealth_music" },
    { 0x8C6D, "start_safehouse_transition_checkpoint" },
    { 0x8C6E, "start_safehouse_xslice_checkpoint" },
    { 0x8C6F, "start_school" },
    { 0x8C70, "start_school_basement" },
    { 0x8C71, "start_school_before_fall" },
    { 0x8C72, "start_school_interior" },
    { 0x8C73, "start_school_wall_grab" },
    { 0x8C74, "start_search_drone_behavior_when_pdrone_follower_spawned" },
    { 0x8C75, "start_security_center" },
    { 0x8C76, "start_security_room" },
    { 0x8C77, "start_seeker_audio" },
    { 0x8C78, "start_sentinel_reveal" },
    { 0x8C79, "start_seoul_building_jump_sequence" },
    { 0x8C7A, "start_seoul_canal_combat_pt2" },
    { 0x8C7B, "start_seoul_canal_combat_start" },
    { 0x8C7C, "start_seoul_canal_intro" },
    { 0x8C7D, "start_seoul_cover_art" },
    { 0x8C7E, "start_seoul_drone_swarm_intro" },
    { 0x8C7F, "start_seoul_e3_presentation" },
    { 0x8C80, "start_seoul_enemy_encounter_01" },
    { 0x8C81, "start_seoul_finale_scene_start" },
    { 0x8C82, "start_seoul_first_land_assist" },
    { 0x8C83, "start_seoul_forward_operating_base" },
    { 0x8C84, "start_seoul_hotel_entrance" },
    { 0x8C85, "start_seoul_intro" },
    { 0x8C86, "start_seoul_missle_evade_sequence" },
    { 0x8C87, "start_seoul_shopping_district_flee_swarm" },
    { 0x8C88, "start_seoul_shopping_district_start" },
    { 0x8C89, "start_seoul_sinkhole_start" },
    { 0x8C8A, "start_seoul_subway_start" },
    { 0x8C8B, "start_seoul_truck_push" },
    { 0x8C8C, "start_server_room" },
    { 0x8C8D, "start_sewer" },
    { 0x8C8E, "start_shooting_rail" },
    { 0x8C8F, "start_shore_pcap" },
    { 0x8C90, "start_silo_approach" },
    { 0x8C91, "start_silo_exhaust_entrance" },
    { 0x8C92, "start_silo_floor_03" },
    { 0x8C93, "start_sky_bridge" },
    { 0x8C94, "start_skyfogintensity" },
    { 0x8C95, "start_skyfogmaxangle" },
    { 0x8C96, "start_skyfogminangle" },
    { 0x8C97, "start_slow_mo" },
    { 0x8C98, "start_smoke_pillar_black_large_fast_fx" },
    { 0x8C99, "start_smoke_pillar_black_large_slow_fx" },
    { 0x8C9A, "start_smoke_pillar_gray_large_fast_fx" },
    { 0x8C9B, "start_sniper_drone" },
    { 0x8C9C, "start_sniper_drone_audio" },
    { 0x8C9D, "start_sniper_drone_death" },
    { 0x8C9E, "start_sniper_drone_deploy" },
    { 0x8C9F, "start_sniper_drone_loops" },
    { 0x8CA0, "start_sniper_drone_zoom" },
    { 0x8CA1, "start_sniper_scramble_drones_checkpoint" },
    { 0x8CA2, "start_sniper_scramble_finale_checkpoint" },
    { 0x8CA3, "start_sniper_scramble_hotel_checkpoint" },
    { 0x8CA4, "start_sniper_scramble_intro_checkpoint" },
    { 0x8CA5, "start_sniper_scramble_music" },
    { 0x8CA6, "start_sonic_attack_mix" },
    { 0x8CA7, "start_spawn_allies" },
    { 0x8CA8, "start_spawn_axis" },
    { 0x8CA9, "start_spawn_prefix" },
    { 0x8CAA, "start_spawns_near_attackers" },
    { 0x8CAB, "start_squad_member_at_start" },
    { 0x8CAC, "start_stage_dialog" },
    { 0x8CAD, "start_stealth_music" },
    { 0x8CAE, "start_street" },
    { 0x8CAF, "start_street_heli" },
    { 0x8CB0, "start_struct" },
    { 0x8CB1, "start_sunbeginfadeangle" },
    { 0x8CB2, "start_suncolor" },
    { 0x8CB3, "start_sundir" },
    { 0x8CB4, "start_sunendfadeangle" },
    { 0x8CB5, "start_sunfogscale" },
    { 0x8CB6, "start_swarm_drones_context" },
    { 0x8CB7, "start_sweep_mode_func" },
    { 0x8CB8, "start_swim" },
    { 0x8CB9, "start_tank_board" },
    { 0x8CBA, "start_tank_field" },
    { 0x8CBB, "start_tank_hangar" },
    { 0x8CBC, "start_tank_road" },
    { 0x8CBD, "start_tanker_explosion" },
    { 0x8CBE, "start_tanker_fire" },
    { 0x8CBF, "start_tanker_on_ramp_traffic" },
    { 0x8CC0, "start_teleport" },
    { 0x8CC1, "start_tennis_court_alert" },
    { 0x8CC2, "start_test_chamber" },
    { 0x8CC3, "start_thread" },
    { 0x8CC4, "start_threat_grenade_mixer" },
    { 0x8CC5, "start_time" },
    { 0x8CC6, "start_tour_augmented_reality" },
    { 0x8CC7, "start_tour_end" },
    { 0x8CC8, "start_tour_exo" },
    { 0x8CC9, "start_tour_exo_exit" },
    { 0x8CCA, "start_tour_firing_range" },
    { 0x8CCB, "start_tour_ride" },
    { 0x8CCC, "start_tower_bells" },
    { 0x8CCD, "start_track_irons" },
    { 0x8CCE, "start_traffic_frogger" },
    { 0x8CCF, "start_traffic_lane" },
    { 0x8CD0, "start_traffic_traverse" },
    { 0x8CD1, "start_training_01" },
    { 0x8CD2, "start_training_01_end" },
    { 0x8CD3, "start_training_01_golf_course" },
    { 0x8CD4, "start_training_01_lodge" },
    { 0x8CD5, "start_training_01_lodge_breach" },
    { 0x8CD6, "start_training_01_lodge_exit" },
    { 0x8CD7, "start_training_02" },
    { 0x8CD8, "start_training_02_end" },
    { 0x8CD9, "start_training_02_golf_course" },
    { 0x8CDA, "start_training_02_lodge" },
    { 0x8CDB, "start_training_02_lodge_breach" },
    { 0x8CDC, "start_training_02_lodge_exit" },
    { 0x8CDD, "start_trans_to_alleys_panic" },
    { 0x8CDE, "start_transients" },
    { 0x8CDF, "start_traverse" },
    { 0x8CE0, "start_trolley" },
    { 0x8CE1, "start_tunnel" },
    { 0x8CE2, "start_turbine_door_breach" },
    { 0x8CE3, "start_turbine_door_impt" },
    { 0x8CE4, "start_turbine_elevator" },
    { 0x8CE5, "start_turbine_elevator_alarm" },
    { 0x8CE6, "start_turbine_loop" },
    { 0x8CE7, "start_turbine_room" },
    { 0x8CE8, "start_van" },
    { 0x8CE9, "start_van_takedown" },
    { 0x8CEA, "start_van_takedown_underwater" },
    { 0x8CEB, "start_veh_moving_truck" },
    { 0x8CEC, "start_vehicle_traffic" },
    { 0x8CED, "start_vehicle_traffic_highway_traverse" },
    { 0x8CEE, "start_vehicle_traffic_highway_traverse_player_side" },
    { 0x8CEF, "start_vehicle_traffic_roundabout_straightways" },
    { 0x8CF0, "start_videochat_screen_turn_off" },
    { 0x8CF1, "start_videochat_screen_turn_on" },
    { 0x8CF2, "start_vtol_crash" },
    { 0x8CF3, "start_vtol_takedown" },
    { 0x8CF4, "start_wasp_death_explo" },
    { 0x8CF5, "start_wasp_flicker" },
    { 0x8CF6, "start_wasp_missile_warning" },
    { 0x8CF7, "start_water_breach" },
    { 0x8CF8, "start_wave_mist_fx" },
    { 0x8CF9, "start_will_room" },
    { 0x8CFA, "start_x" },
    { 0x8CFB, "startadrenaline" },
    { 0x8CFC, "startaiming" },
    { 0x8CFD, "startalleysdialoguethreads" },
    { 0x8CFE, "startamplifyobjectvfx" },
    { 0x8CFF, "startangles" },
    { 0x8D00, "startcanisterfx" },
    { 0x8D01, "startclientspawnpointtraces" },
    { 0x8D02, "startcloakingbinksequence" },
    { 0x8D03, "startcloakingbinksequence_debug" },
    { 0x8D04, "startcombat" },
    { 0x8D05, "startconfcenterdialoguethreads" },
    { 0x8D06, "startcoverapproach" },
    { 0x8D07, "startdialoguethreads" },
    { 0x8D08, "startdist" },
    { 0x8D09, "startdnadronelights" },
    { 0x8D0A, "startdot_group" },
    { 0x8D0B, "startdot_player" },
    { 0x8D0C, "startdrivenmovement" },
    { 0x8D0D, "startdronecontrol" },
    { 0x8D0E, "startdyingcrawlbackaimsoon" },
    { 0x8D0F, "started_bank" },
    { 0x8D10, "started_moving" },
    { 0x8D11, "started_to_grapple_to_vtol_but_aborted_watcher" },
    { 0x8D12, "startexorecoverykillstreak" },
    { 0x8D13, "startexplosivedrone" },
    { 0x8D14, "startexteriordnadrones" },
    { 0x8D15, "startextrahealth" },
    { 0x8D16, "startfastheal" },
    { 0x8D17, "startfireandaimidlethread" },
    { 0x8D18, "startflashing" },
    { 0x8D19, "startgame" },
    { 0x8D1A, "startgrenadelightfx" },
    { 0x8D1B, "startharmonicbreach" },
    { 0x8D1C, "startheavylifterfx" },
    { 0x8D1D, "startheligroundfx" },
    { 0x8D1E, "starthighlightingplayer" },
    { 0x8D1F, "starthighlightingplayerexplosive" },
    { 0x8D20, "startidletransitionanim" },
    { 0x8D21, "starting_bridge_collapse" },
    { 0x8D22, "starting_fire_01" },
    { 0x8D23, "starting_origin" },
    { 0x8D24, "starting_side_fx" },
    { 0x8D25, "starting_speed" },
    { 0x8D26, "startingorigin" },
    { 0x8D27, "startinteriordnadrones" },
    { 0x8D28, "startlaserlights" },
    { 0x8D29, "startlasersounds" },
    { 0x8D2A, "startmanhandling" },
    { 0x8D2B, "startmonitoringflash" },
    { 0x8D2C, "startmove" },
    { 0x8D2D, "startmove_updateangle" },
    { 0x8D2E, "startmovetransition" },
    { 0x8D2F, "startmovetransitionanim" },
    { 0x8D30, "startmutebomb" },
    { 0x8D31, "startnoncombat" },
    { 0x8D32, "startnotelisten" },
    { 0x8D33, "startorigin" },
    { 0x8D34, "startospbuddyexitcommand" },
    { 0x8D35, "startpath_with_currentnode_update" },
    { 0x8D36, "startpoint1" },
    { 0x8D37, "startpoint2" },
    { 0x8D38, "startpos" },
    { 0x8D39, "startposoffset" },
    { 0x8D3A, "startriotshielddeploy" },
    { 0x8D3B, "startriotsuppressionsystem" },
    { 0x8D3C, "startround" },
    { 0x8D3D, "startspawnpoints" },
    { 0x8D3E, "startspectatemode" },
    { 0x8D3F, "startstreaksupportprompt" },
    { 0x8D40, "startthreadstorunwhilemoving" },
    { 0x8D41, "starttime" },
    { 0x8D42, "starttimepassed" },
    { 0x8D43, "starttotargetcornerangles" },
    { 0x8D44, "starttrackingdrone" },
    { 0x8D45, "startturntoangle" },
    { 0x8D46, "startusingreconvehicle" },
    { 0x8D47, "startusingremoteturret" },
    { 0x8D48, "startwarbirdbuddyexitcommand" },
    { 0x8D49, "startwave" },
    { 0x8D4A, "startyaw" },
    { 0x8D4B, "stat_notify" },
    { 0x8D4C, "stat_notify_func" },
    { 0x8D4D, "stat_notify_register_func" },
    { 0x8D4E, "stat_track_damage_func" },
    { 0x8D4F, "stat_track_kill_func" },
    { 0x8D50, "statadd" },
    { 0x8D51, "stataddbuffered" },
    { 0x8D52, "stataddbufferedwithmax" },
    { 0x8D53, "stataddchild" },
    { 0x8D54, "stataddchildbuffered" },
    { 0x8D55, "stataddchildbufferedwithmax" },
    { 0x8D56, "state" },
    { 0x8D57, "state_chaingun_pump" },
    { 0x8D58, "state_change" },
    { 0x8D59, "state_data" },
    { 0x8D5A, "state_group_list" },
    { 0x8D5B, "state_groups" },
    { 0x8D5C, "state_last" },
    { 0x8D5D, "state_loop" },
    { 0x8D5E, "state_main_pump" },
    { 0x8D5F, "state_num" },
    { 0x8D60, "state_print_priority" },
    { 0x8D61, "state_rocket_pump" },
    { 0x8D62, "state_swarm_pump" },
    { 0x8D63, "state_timer" },
    { 0x8D64, "state_under_construction" },
    { 0x8D65, "statefns" },
    { 0x8D66, "statements" },
    { 0x8D67, "states" },
    { 0x8D68, "statget" },
    { 0x8D69, "statgetbuffered" },
    { 0x8D6A, "statgetchild" },
    { 0x8D6B, "statgetchildbuffered" },
    { 0x8D6C, "static" },
    { 0x8D6D, "static_length" },
    { 0x8D6E, "static_origin" },
    { 0x8D6F, "static_overlay" },
    { 0x8D70, "static_sight_blocker" },
    { 0x8D71, "static_sphere_center" },
    { 0x8D72, "static_sphere_radius" },
    { 0x8D73, "staticlevel" },
    { 0x8D74, "staticlevelwaittime" },
    { 0x8D75, "stationary" },
    { 0x8D76, "stationary_anim_pose" },
    { 0x8D77, "stats" },
    { 0x8D78, "statset" },
    { 0x8D79, "statsetbuffered" },
    { 0x8D7A, "statsetchild" },
    { 0x8D7B, "statsetchildbuffered" },
    { 0x8D7C, "status" },
    { 0x8D7D, "statusdialog" },
    { 0x8D7E, "statvaluechanged" },
    { 0x8D7F, "stay_low_nags" },
    { 0x8D80, "stay_on_mission" },
    { 0x8D81, "stayontag" },
    { 0x8D82, "stealth_accuracy_friendly_main" },
    { 0x8D83, "stealth_accuracy_state_custom" },
    { 0x8D84, "stealth_accuracy_state_default" },
    { 0x8D85, "stealth_ai_clear_custom_idle_and_react" },
    { 0x8D86, "stealth_ai_clear_custom_react" },
    { 0x8D87, "stealth_ai_event_dist_custom" },
    { 0x8D88, "stealth_ai_event_dist_default" },
    { 0x8D89, "stealth_ai_idle_and_react" },
    { 0x8D8A, "stealth_ai_idle_and_react_custom" },
    { 0x8D8B, "stealth_ai_reach_and_arrive_idle_and_react" },
    { 0x8D8C, "stealth_ai_reach_and_arrive_idle_and_react_proc" },
    { 0x8D8D, "stealth_ai_reach_idle_and_react" },
    { 0x8D8E, "stealth_ai_reach_idle_and_react_proc" },
    { 0x8D8F, "stealth_ai_react" },
    { 0x8D90, "stealth_alert_level_duration" },
    { 0x8D91, "stealth_alerted_drone_monitor" },
    { 0x8D92, "stealth_anim" },
    { 0x8D93, "stealth_anim_custom_animmode" },
    { 0x8D94, "stealth_basic_states_custom" },
    { 0x8D95, "stealth_basic_states_default" },
    { 0x8D96, "stealth_behavior_enemy_main" },
    { 0x8D97, "stealth_behavior_friendly_main" },
    { 0x8D98, "stealth_behavior_system_init" },
    { 0x8D99, "stealth_behavior_system_main" },
    { 0x8D9A, "stealth_broken_dialogue" },
    { 0x8D9B, "stealth_can_be_seen" },
    { 0x8D9C, "stealth_color_friendly_main" },
    { 0x8D9D, "stealth_color_state_custom" },
    { 0x8D9E, "stealth_color_state_default" },
    { 0x8D9F, "stealth_corpse_behavior_custom" },
    { 0x8DA0, "stealth_corpse_behavior_default" },
    { 0x8DA1, "stealth_corpse_collect_func" },
    { 0x8DA2, "stealth_corpse_default_collect_func" },
    { 0x8DA3, "stealth_corpse_default_distances" },
    { 0x8DA4, "stealth_corpse_default_forget_time" },
    { 0x8DA5, "stealth_corpse_default_reset_time" },
    { 0x8DA6, "stealth_corpse_enemy_main" },
    { 0x8DA7, "stealth_corpse_forget_time_custom" },
    { 0x8DA8, "stealth_corpse_forget_time_default" },
    { 0x8DA9, "stealth_corpse_ranges_custom" },
    { 0x8DAA, "stealth_corpse_ranges_default" },
    { 0x8DAB, "stealth_corpse_reset_collect_func" },
    { 0x8DAC, "stealth_corpse_reset_time_custom" },
    { 0x8DAD, "stealth_corpse_reset_time_default" },
    { 0x8DAE, "stealth_corpse_set_collect_func" },
    { 0x8DAF, "stealth_corpse_set_distances" },
    { 0x8DB0, "stealth_corpse_set_forget_time" },
    { 0x8DB1, "stealth_corpse_set_reset_time" },
    { 0x8DB2, "stealth_corpse_system_init" },
    { 0x8DB3, "stealth_corpse_system_main" },
    { 0x8DB4, "stealth_debug_print" },
    { 0x8DB5, "stealth_default" },
    { 0x8DB6, "stealth_default_func" },
    { 0x8DB7, "stealth_delete_at_goal" },
    { 0x8DB8, "stealth_detect_ranges_default" },
    { 0x8DB9, "stealth_detect_ranges_set" },
    { 0x8DBA, "stealth_disable_seek_player_on_spotted" },
    { 0x8DBB, "stealth_disabled" },
    { 0x8DBC, "stealth_display" },
    { 0x8DBD, "stealth_display_active" },
    { 0x8DBE, "stealth_display_count" },
    { 0x8DBF, "stealth_display_hint" },
    { 0x8DC0, "stealth_display_max" },
    { 0x8DC1, "stealth_display_off" },
    { 0x8DC2, "stealth_display_on" },
    { 0x8DC3, "stealth_display_seed" },
    { 0x8DC4, "stealth_display_seed_angle" },
    { 0x8DC5, "stealth_display_thread" },
    { 0x8DC6, "stealth_display_tutorial" },
    { 0x8DC7, "stealth_display_tutorial_spawner_setup" },
    { 0x8DC8, "stealth_enable_seek_player_on_spotted" },
    { 0x8DC9, "stealth_enemy_debug_monitor" },
    { 0x8DCA, "stealth_enemy_endon_alert" },
    { 0x8DCB, "stealth_enemy_minimal_debug_monitor" },
    { 0x8DCC, "stealth_enemy_waittill_alert" },
    { 0x8DCD, "stealth_event_anim_defaults" },
    { 0x8DCE, "stealth_event_defaults" },
    { 0x8DCF, "stealth_event_enemy_main" },
    { 0x8DD0, "stealth_event_handler" },
    { 0x8DD1, "stealth_event_listener_defaults" },
    { 0x8DD2, "stealth_event_mod" },
    { 0x8DD3, "stealth_event_mod_all" },
    { 0x8DD4, "stealth_event_validate" },
    { 0x8DD5, "stealth_fail_fast" },
    { 0x8DD6, "stealth_first_alert_new_patrol_path" },
    { 0x8DD7, "stealth_flag_debug_print" },
    { 0x8DD8, "stealth_friendly_movespeed_scale_default" },
    { 0x8DD9, "stealth_friendly_movespeed_scale_set" },
    { 0x8DDA, "stealth_friendly_stance_handler_distances_default" },
    { 0x8DDB, "stealth_friendly_stance_handler_distances_set" },
    { 0x8DDC, "stealth_get_group" },
    { 0x8DDD, "stealth_get_group_corpse_flag" },
    { 0x8DDE, "stealth_get_group_spotted_flag" },
    { 0x8DDF, "stealth_group_corpse_flag" },
    { 0x8DE0, "stealth_group_corpse_flag_wait" },
    { 0x8DE1, "stealth_group_corpse_flag_waitopen" },
    { 0x8DE2, "stealth_group_return_ai_with_corpse_flag" },
    { 0x8DE3, "stealth_group_return_ai_with_event_flag" },
    { 0x8DE4, "stealth_group_return_ai_with_spotted_flag" },
    { 0x8DE5, "stealth_group_return_groups_with_corpse_flag" },
    { 0x8DE6, "stealth_group_return_groups_with_event_flag" },
    { 0x8DE7, "stealth_group_return_groups_with_spotted_flag" },
    { 0x8DE8, "stealth_group_spotted_flag" },
    { 0x8DE9, "stealth_group_spotted_flag_wait" },
    { 0x8DEA, "stealth_group_spotted_flag_waitopen" },
    { 0x8DEB, "stealth_guy_think" },
    { 0x8DEC, "stealth_guy_think_on_flag" },
    { 0x8DED, "stealth_insure_enabled" },
    { 0x8DEE, "stealth_is_everything_normal" },
    { 0x8DEF, "stealth_last_alert" },
    { 0x8DF0, "stealth_music_control_p1" },
    { 0x8DF1, "stealth_music_control_p2" },
    { 0x8DF2, "stealth_plugin_accuracy" },
    { 0x8DF3, "stealth_plugin_aicolor" },
    { 0x8DF4, "stealth_plugin_basic" },
    { 0x8DF5, "stealth_plugin_corpse" },
    { 0x8DF6, "stealth_plugin_event_all" },
    { 0x8DF7, "stealth_plugin_event_custom" },
    { 0x8DF8, "stealth_plugin_event_explosion" },
    { 0x8DF9, "stealth_plugin_event_flashbang" },
    { 0x8DFA, "stealth_plugin_event_heard_scream" },
    { 0x8DFB, "stealth_plugin_event_main" },
    { 0x8DFC, "stealth_plugin_smart_stance" },
    { 0x8DFD, "stealth_plugin_threat" },
    { 0x8DFE, "stealth_pre_spotted_function_custom" },
    { 0x8DFF, "stealth_pre_spotted_function_default" },
    { 0x8E00, "stealth_reset_awareness" },
    { 0x8E01, "stealth_set_default_stealth_function" },
    { 0x8E02, "stealth_set_group" },
    { 0x8E03, "stealth_set_group_default" },
    { 0x8E04, "stealth_set_group_proc" },
    { 0x8E05, "stealth_set_idle_anim" },
    { 0x8E06, "stealth_set_run_anim" },
    { 0x8E07, "stealth_shadow_ai_in_volume" },
    { 0x8E08, "stealth_shadow_volumes" },
    { 0x8E09, "stealth_smartstance_friendly_main" },
    { 0x8E0A, "stealth_spawn_function" },
    { 0x8E0B, "stealth_spotted_drone_death_monitor" },
    { 0x8E0C, "stealth_spotted_drone_monitor" },
    { 0x8E0D, "stealth_spotted_drones" },
    { 0x8E0E, "stealth_threat_behavior_custom" },
    { 0x8E0F, "stealth_threat_behavior_default" },
    { 0x8E10, "stealth_threat_behavior_default_no_warnings" },
    { 0x8E11, "stealth_threat_behavior_replace" },
    { 0x8E12, "stealth_threat_enemy_main" },
    { 0x8E13, "stealth_vis_threat" },
    { 0x8E14, "stealth_visibility_enemy_main" },
    { 0x8E15, "stealth_visibility_friendly_main" },
    { 0x8E16, "stealth_visibility_system_main" },
    { 0x8E17, "stealthairstrike_earthquake" },
    { 0x8E18, "stealthbomber_killcam" },
    { 0x8E19, "stealthkillvictim" },
    { 0x8E1A, "stealthnewenemyreactanim" },
    { 0x8E1B, "steam_burst_function" },
    { 0x8E1C, "steam_burst_valve_started" },
    { 0x8E1D, "steam_elevator_fx" },
    { 0x8E1E, "steam_spray_custom_function" },
    { 0x8E1F, "steam_vent_burst_fx" },
    { 0x8E20, "stecil_when_in_view" },
    { 0x8E21, "steering" },
    { 0x8E22, "steering_enable" },
    { 0x8E23, "steering_hack" },
    { 0x8E24, "steering_maxdelta" },
    { 0x8E25, "steering_maxroll" },
    { 0x8E26, "stencil_when_cardoor_in_range" },
    { 0x8E27, "stepout" },
    { 0x8E28, "stepoutandhidespeed" },
    { 0x8E29, "stepoutandshootenemy" },
    { 0x8E2A, "stepoutyaw" },
    { 0x8E2B, "stepup_112" },
    { 0x8E2C, "stepup_112_over_32" },
    { 0x8E2D, "stick_to_shadows" },
    { 0x8E2E, "stickexplosivegel" },
    { 0x8E2F, "stickhorizontalinputlength" },
    { 0x8E30, "stickinputindeadzone" },
    { 0x8E31, "sticky_fx" },
    { 0x8E32, "sticky_threat" },
    { 0x8E33, "sticky_timer" },
    { 0x8E34, "stickyhandlemovers" },
    { 0x8E35, "stickymovingplatformdetonate" },
    { 0x8E36, "still_pressing_use" },
    { 0x8E37, "still_pressing_use_button" },
    { 0x8E38, "stillvalidstingerlock" },
    { 0x8E39, "stim_fx_l" },
    { 0x8E3A, "stim_fx_r" },
    { 0x8E3B, "stinger_add_hit" },
    { 0x8E3C, "stinger_delayed_lock" },
    { 0x8E3D, "stinger_fire" },
    { 0x8E3E, "stinger_ignore" },
    { 0x8E3F, "stinger_no_ai" },
    { 0x8E40, "stinger_override_tags" },
    { 0x8E41, "stinger_targets" },
    { 0x8E42, "stinger_track_ent_cleanup" },
    { 0x8E43, "stinger_vo" },
    { 0x8E44, "stinger_weapon" },
    { 0x8E45, "stingerdebugdraw" },
    { 0x8E46, "stingerfxid" },
    { 0x8E47, "stingerlockonentsfunc" },
    { 0x8E48, "stingerlockstarttime" },
    { 0x8E49, "stingerlostsightlinetime" },
    { 0x8E4A, "stingerm7_get_target_ignore" },
    { 0x8E4B, "stingerm7_get_target_offset" },
    { 0x8E4C, "stingerm7_get_target_pos" },
    { 0x8E4D, "stingerm7_get_target_tag" },
    { 0x8E4E, "stingerm7_info" },
    { 0x8E4F, "stingerm7_lock_los" },
    { 0x8E50, "stingerm7_lock_range" },
    { 0x8E51, "stingerm7_monitor_fire" },
    { 0x8E52, "stingerm7_shoot_tower" },
    { 0x8E53, "stingerm7_targeting" },
    { 0x8E54, "stingerm7_targeting_contains" },
    { 0x8E55, "stingerm7_targeting_remove_dead" },
    { 0x8E56, "stingerm7_think" },
    { 0x8E57, "stingerpronestatemonitor" },
    { 0x8E58, "stingerproximitydetonate" },
    { 0x8E59, "stingerstage" },
    { 0x8E5A, "stingertarget" },
    { 0x8E5B, "stingerusageloop" },
    { 0x8E5C, "stingeruseentered" },
    { 0x8E5D, "stock_think" },
    { 0x8E5E, "stockammo" },
    { 0x8E5F, "stop_aiming_for_reload" },
    { 0x8E60, "stop_alias_data" },
    { 0x8E61, "stop_all_replace_on_death" },
    { 0x8E62, "stop_all_rumble_on_time" },
    { 0x8E63, "stop_alleys_emergency_audio" },
    { 0x8E64, "stop_ambient_flare_fx" },
    { 0x8E65, "stop_ams" },
    { 0x8E66, "stop_animating_player_rig_on_flag" },
    { 0x8E67, "stop_animating_when_exopush_over" },
    { 0x8E68, "stop_animating_when_kva2_dead" },
    { 0x8E69, "stop_atrium_fight" },
    { 0x8E6A, "stop_audio_intro_fly_drone_idle" },
    { 0x8E6B, "stop_back_thruster_light_rz" },
    { 0x8E6C, "stop_blend" },
    { 0x8E6D, "stop_bobbing" },
    { 0x8E6E, "stop_burke_ambush_slomo" },
    { 0x8E6F, "stop_cafe_market_damb" },
    { 0x8E70, "stop_camshake" },
    { 0x8E71, "stop_car_alarm" },
    { 0x8E72, "stop_civilian_conversation" },
    { 0x8E73, "stop_constant_quake" },
    { 0x8E74, "stop_crane_audio" },
    { 0x8E75, "stop_current_animations" },
    { 0x8E76, "stop_diveboat_threads" },
    { 0x8E77, "stop_drone_death_static" },
    { 0x8E78, "stop_dynamic_run_speed" },
    { 0x8E79, "stop_dynamic_run_speed_wait" },
    { 0x8E7A, "stop_ent_count" },
    { 0x8E7B, "stop_ents" },
    { 0x8E7C, "stop_exo_mute" },
    { 0x8E7D, "stop_exo_ping" },
    { 0x8E7E, "stop_exploder" },
    { 0x8E7F, "stop_exploder_proc" },
    { 0x8E80, "stop_fall_foley_audio" },
    { 0x8E81, "stop_falling_debris_by_player" },
    { 0x8E82, "stop_finale_fight_music" },
    { 0x8E83, "stop_finale_h2h_music" },
    { 0x8E84, "stop_firing" },
    { 0x8E85, "stop_firing_for_death_anim" },
    { 0x8E86, "stop_flickering_fire_light" },
    { 0x8E87, "stop_flickering_hanger_light" },
    { 0x8E88, "stop_flickering_info_hallway_light" },
    { 0x8E89, "stop_flickering_info_light" },
    { 0x8E8A, "stop_flickering_interior_light" },
    { 0x8E8B, "stop_flickerlight" },
    { 0x8E8C, "stop_fly" },
    { 0x8E8D, "stop_front_thruster_light_rz" },
    { 0x8E8E, "stop_fx_looper" },
    { 0x8E8F, "stop_fx_on_death" },
    { 0x8E90, "stop_generic_enemy_vo_chatter" },
    { 0x8E91, "stop_generic_vo_chatter" },
    { 0x8E92, "stop_hades_suv_extraction" },
    { 0x8E93, "stop_handling_moving_platforms" },
    { 0x8E94, "stop_hint" },
    { 0x8E95, "stop_hint_mission_fail" },
    { 0x8E96, "stop_hovering_on_player_death" },
    { 0x8E97, "stop_hovering_on_unload" },
    { 0x8E98, "stop_idle_back_thruster_rz" },
    { 0x8E99, "stop_idle_front_thruster_rz" },
    { 0x8E9A, "stop_idle_tread_front_rz" },
    { 0x8E9B, "stop_ied_convoy_ambush_expl" },
    { 0x8E9C, "stop_jammer_movie" },
    { 0x8E9D, "stop_jetbike_handle_viewmodel_anims" },
    { 0x8E9E, "stop_load" },
    { 0x8E9F, "stop_look" },
    { 0x8EA0, "stop_loop_and_react" },
    { 0x8EA1, "stop_loop_sound_on_entity" },
    { 0x8EA2, "stop_looping_beep_on_player" },
    { 0x8EA3, "stop_loopsound" },
    { 0x8EA4, "stop_magic_bullet_shield" },
    { 0x8EA5, "stop_mg_behavior_if_flanked" },
    { 0x8EA6, "stop_monitor_cinematic" },
    { 0x8EA7, "stop_moving" },
    { 0x8EA8, "stop_notify" },
    { 0x8EA9, "stop_notify_string" },
    { 0x8EAA, "stop_player_climbing" },
    { 0x8EAB, "stop_player_mag_gloves" },
    { 0x8EAC, "stop_player_pushed_kill" },
    { 0x8EAD, "stop_player_scuba" },
    { 0x8EAE, "stop_player_underwater_breath" },
    { 0x8EAF, "stop_playerwatch_unresolved_collision" },
    { 0x8EB0, "stop_post_courtyard_ext_alarms_2" },
    { 0x8EB1, "stop_pulse_light" },
    { 0x8EB2, "stop_railgun_hud" },
    { 0x8EB3, "stop_reflector_effect" },
    { 0x8EB4, "stop_regular_back_thruster_rz" },
    { 0x8EB5, "stop_regular_front_thruster_rz" },
    { 0x8EB6, "stop_regular_tail_thruster_rz" },
    { 0x8EB7, "stop_regular_tread_back_rz" },
    { 0x8EB8, "stop_regular_tread_front_rz" },
    { 0x8EB9, "stop_replace_on_death" },
    { 0x8EBA, "stop_repulsor" },
    { 0x8EBB, "stop_reviving" },
    { 0x8EBC, "stop_rumble_on_notify" },
    { 0x8EBD, "stop_scramble_emergency_audio" },
    { 0x8EBE, "stop_scriptable_primary_light" },
    { 0x8EBF, "stop_scripted_move_and_attack" },
    { 0x8EC0, "stop_seeker_audio" },
    { 0x8EC1, "stop_shooting_ambulance_timer" },
    { 0x8EC2, "stop_shooting_timer" },
    { 0x8EC3, "stop_slow_mo" },
    { 0x8EC4, "stop_smoke_pillar_black_large_fast_fx" },
    { 0x8EC5, "stop_smoke_pillar_black_large_slow_fx" },
    { 0x8EC6, "stop_smoke_pillar_gray_large_fast_fx" },
    { 0x8EC7, "stop_sniper_drone" },
    { 0x8EC8, "stop_sniper_drone_zoom" },
    { 0x8EC9, "stop_sound" },
    { 0x8ECA, "stop_sparks" },
    { 0x8ECB, "stop_speaking" },
    { 0x8ECC, "stop_swarm_drones_context" },
    { 0x8ECD, "stop_the_fighting" },
    { 0x8ECE, "stop_trans_to_alleys_panic" },
    { 0x8ECF, "stop_turbine_elevator" },
    { 0x8ED0, "stop_turret_on_gunner_death" },
    { 0x8ED1, "stop_using_crate" },
    { 0x8ED2, "stop_vehicle_traffic_roundabout_straightways" },
    { 0x8ED3, "stop_videolog" },
    { 0x8ED4, "stop_vo_on_entity" },
    { 0x8ED5, "stop_vo_on_radio" },
    { 0x8ED6, "stop_wakefx" },
    { 0x8ED7, "stop_walk_and_clear_dialogue" },
    { 0x8ED8, "stop_wasp_missile_warning" },
    { 0x8ED9, "stop_water_warning" },
    { 0x8EDA, "stop_wave_mist_fx" },
    { 0x8EDB, "stop_zip_idle_anim" },
    { 0x8EDC, "stopadrenaline" },
    { 0x8EDD, "stopaiming" },
    { 0x8EDE, "stopbeameffects" },
    { 0x8EDF, "stopcontrail" },
    { 0x8EE0, "stopcranesound" },
    { 0x8EE1, "stopdamagefunc" },
    { 0x8EE2, "stopdnadronelights" },
    { 0x8EE3, "stopeffectonplayerview" },
    { 0x8EE4, "stopextrahealth" },
    { 0x8EE5, "stopfireeffects" },
    { 0x8EE6, "stopflashing" },
    { 0x8EE7, "stopfx_fordrop" },
    { 0x8EE8, "stopfxonattachment" },
    { 0x8EE9, "stopfxonnotify" },
    { 0x8EEA, "stopfxontag_functionhack" },
    { 0x8EEB, "stopfxontagdelay" },
    { 0x8EEC, "stopglow" },
    { 0x8EED, "stopheligroundfx" },
    { 0x8EEE, "stophighlightingplayer" },
    { 0x8EEF, "stophighlightingplayerexplosive" },
    { 0x8EF0, "stopidlesound" },
    { 0x8EF1, "stoplasercontainmentend" },
    { 0x8EF2, "stoplasercontainmentswap" },
    { 0x8EF3, "stoplasercoreevent" },
    { 0x8EF4, "stoplaserlights" },
    { 0x8EF5, "stoplasersounds" },
    { 0x8EF6, "stoplocationselection" },
    { 0x8EF7, "stoplookatidle" },
    { 0x8EF8, "stopmissileboostsounds" },
    { 0x8EF9, "stopmonitordamage" },
    { 0x8EFA, "stopmonitoringflash" },
    { 0x8EFB, "stopmovementsparks" },
    { 0x8EFC, "stopmovesound" },
    { 0x8EFD, "stoponback" },
    { 0x8EFE, "stopped" },
    { 0x8EFF, "stoppromptforstreaksupport" },
    { 0x8F00, "stoprunngun" },
    { 0x8F01, "stopscriptedanimations" },
    { 0x8F02, "stopshortly" },
    { 0x8F03, "stopshotgunpumpaftertime" },
    { 0x8F04, "stopsounds_on_death" },
    { 0x8F05, "stopthreateventtype" },
    { 0x8F06, "stoptickingsound" },
    { 0x8F07, "stopturret" },
    { 0x8F08, "stopusingremoteturret" },
    { 0x8F09, "stopusingturretwhennodelost" },
    { 0x8F0A, "stopwarbirdenginefx" },
    { 0x8F0B, "stopwarmupeffects" },
    { 0x8F0C, "stopwarmupsounds" },
    { 0x8F0D, "stopwatch" },
    { 0x8F0E, "storage_vo" },
    { 0x8F0F, "store_offsets_for_link" },
    { 0x8F10, "store_players_weapons" },
    { 0x8F11, "store_speed" },
    { 0x8F12, "storecameratargets" },
    { 0x8F13, "stored_clipsize" },
    { 0x8F14, "stored_ents" },
    { 0x8F15, "stored_stock" },
    { 0x8F16, "stored_variable_grenade" },
    { 0x8F17, "stored_variable_grenade_ui_type" },
    { 0x8F18, "stored_weapon" },
    { 0x8F19, "stored_weapons" },
    { 0x8F1A, "storedangley" },
    { 0x8F1B, "storedrightsticky" },
    { 0x8F1C, "storependingreinforcement" },
    { 0x8F1D, "str" },
    { 0x8F1E, "strafeblendtimes" },
    { 0x8F1F, "strafing_run_airstrike" },
    { 0x8F20, "straighten_ship" },
    { 0x8F21, "strain_accel_last_trigger" },
    { 0x8F22, "strain_accel_time_since_trigger" },
    { 0x8F23, "strategy_level" },
    { 0x8F24, "streak_trams" },
    { 0x8F25, "streakcustomization" },
    { 0x8F26, "streakname" },
    { 0x8F27, "streaknotifytracker" },
    { 0x8F28, "streakplayer" },
    { 0x8F29, "streakref" },
    { 0x8F2A, "streakselectdowntracker" },
    { 0x8F2B, "streakselectuptracker" },
    { 0x8F2C, "streaksuppordisabledcount" },
    { 0x8F2D, "streaksupportqueueallies" },
    { 0x8F2E, "streaksupportqueueaxis" },
    { 0x8F2F, "stream" },
    { 0x8F30, "streamclassweapons" },
    { 0x8F31, "streamprimaryweapons" },
    { 0x8F32, "streamweapons" },
    { 0x8F33, "street_battle_dialogue" },
    { 0x8F34, "street_civilian_clean_up" },
    { 0x8F35, "street_cleanup" },
    { 0x8F36, "street_enemy_blown_building_think" },
    { 0x8F37, "street_enemy_building_east_think" },
    { 0x8F38, "street_enemy_building_west_think" },
    { 0x8F39, "street_enemy_movement" },
    { 0x8F3A, "street_enemy_tank_battle_think" },
    { 0x8F3B, "street_enemy_tank_damaged_think" },
    { 0x8F3C, "street_enemy_think" },
    { 0x8F3D, "street_fight_after_snipe" },
    { 0x8F3E, "street_fighter_check_function" },
    { 0x8F3F, "street_fighters_gone_yet" },
    { 0x8F40, "street_hanging_pipes_anim" },
    { 0x8F41, "street_mechs" },
    { 0x8F42, "street_mobile_cover_guys" },
    { 0x8F43, "street_set_volume_from_pair" },
    { 0x8F44, "street_train_function" },
    { 0x8F45, "street_update_my_volume_think" },
    { 0x8F46, "street_volume_manager" },
    { 0x8F47, "street_wall_1_explode" },
    { 0x8F48, "street1_ingame" },
    { 0x8F49, "street1_teleportplayer" },
    { 0x8F4A, "streetfighters_notify" },
    { 0x8F4B, "streetmechs" },
    { 0x8F4C, "streets_dialogue_manager" },
    { 0x8F4D, "streets_main" },
    { 0x8F4E, "strikegastrackingoverlay" },
    { 0x8F4F, "strikerocketstoredangles" },
    { 0x8F50, "strikerocketstoredposition" },
    { 0x8F51, "strikespawnpoint" },
    { 0x8F52, "strikewhitefade" },
    { 0x8F53, "string" },
    { 0x8F54, "string_explosive_bullet_shield" },
    { 0x8F55, "string_find" },
    { 0x8F56, "string_is_single_digit_integer" },
    { 0x8F57, "string_starts_with" },
    { 0x8F58, "strings" },
    { 0x8F59, "stringtables" },
    { 0x8F5A, "stringtofloat" },
    { 0x8F5B, "strip_prefix" },
    { 0x8F5C, "strip_suffix" },
    { 0x8F5D, "strips" },
    { 0x8F5E, "strips_disabled" },
    { 0x8F5F, "strobelight" },
    { 0x8F60, "struct" },
    { 0x8F61, "struct_array_index" },
    { 0x8F62, "struct_arrayspawn" },
    { 0x8F63, "struct_class_init" },
    { 0x8F64, "struct_class_names" },
    { 0x8F65, "structarray_add" },
    { 0x8F66, "structarray_remove" },
    { 0x8F67, "structarray_remove_index" },
    { 0x8F68, "structarray_remove_undefined" },
    { 0x8F69, "structarray_shuffle" },
    { 0x8F6A, "structarray_swap" },
    { 0x8F6B, "structarray_swaptolast" },
    { 0x8F6C, "stuckenemyentity" },
    { 0x8F6D, "stuckmesh" },
    { 0x8F6E, "stumbleonfirefx" },
    { 0x8F6F, "stumblingpain" },
    { 0x8F70, "stumblingpainanimseq" },
    { 0x8F71, "stumblingpainnotetrackhandler" },
    { 0x8F72, "stun_drone" },
    { 0x8F73, "stun_duration" },
    { 0x8F74, "stunned" },
    { 0x8F75, "stunnedanimnumber" },
    { 0x8F76, "stunnedtime" },
    { 0x8F77, "stunscaler" },
    { 0x8F78, "style" },
    { 0x8F79, "stylized_center_text" },
    { 0x8F7A, "stylized_fadeout" },
    { 0x8F7B, "stylized_line" },
    { 0x8F7C, "sub_line" },
    { 0x8F7D, "subclass" },
    { 0x8F7E, "subclass_elite" },
    { 0x8F7F, "subclass_juggernaut" },
    { 0x8F80, "subclass_mech" },
    { 0x8F81, "subclass_regular" },
    { 0x8F82, "subclass_riotshield" },
    { 0x8F83, "subclass_spawn_functions" },
    { 0x8F84, "subtitle_entry_num" },
    { 0x8F85, "subtitles" },
    { 0x8F86, "subway_atlas_ceiling_breach" },
    { 0x8F87, "subway_atlas_cleanup" },
    { 0x8F88, "subway_atlas_post_scene" },
    { 0x8F89, "subway_auto_doors_init" },
    { 0x8F8A, "subway_bomb_shake" },
    { 0x8F8B, "subway_bombshakes" },
    { 0x8F8C, "subway_civ_speaking_groups_setup" },
    { 0x8F8D, "subway_civ_speaking_groups_setup_cg" },
    { 0x8F8E, "subway_civilian_attach_props" },
    { 0x8F8F, "subway_civilian_detach_props" },
    { 0x8F90, "subway_civilian_init_props" },
    { 0x8F91, "subway_civilians" },
    { 0x8F92, "subway_close_all_doors" },
    { 0x8F93, "subway_doors_closing" },
    { 0x8F94, "subway_doors_opening" },
    { 0x8F95, "subway_enter_spawn_civilians" },
    { 0x8F96, "subway_execution_scene" },
    { 0x8F97, "subway_execution_scene_cg" },
    { 0x8F98, "subway_exit_delete_civilians" },
    { 0x8F99, "subway_exit_lights" },
    { 0x8F9A, "subway_gate_atlas_meetup_close" },
    { 0x8F9B, "subway_gate_triggered" },
    { 0x8F9C, "subway_handle_open_gate" },
    { 0x8F9D, "subway_handle_player_weapon_in_scene" },
    { 0x8F9E, "subway_meet_atlas_fov_shift_off" },
    { 0x8F9F, "subway_meet_atlas_fov_shift_on" },
    { 0x8FA0, "subway_meet_atlas_show_hole_geo" },
    { 0x8FA1, "subway_open_all_cg_doors" },
    { 0x8FA2, "subway_open_all_doors" },
    { 0x8FA3, "subway_open_door" },
    { 0x8FA4, "subway_pa_message" },
    { 0x8FA5, "subway_roof_breach_end_slomo" },
    { 0x8FA6, "subway_roof_breach_start_slowmo" },
    { 0x8FA7, "subway_rotating_automatic_doors" },
    { 0x8FA8, "subway_section" },
    { 0x8FA9, "subway_setup_civilians" },
    { 0x8FAA, "subway_setup_civilians_cg" },
    { 0x8FAB, "subway_setup_dead_civilians_cg" },
    { 0x8FAC, "success" },
    { 0x8FAD, "successdetonateambushinteract" },
    { 0x8FAE, "successsetupambushtimer" },
    { 0x8FAF, "suicides" },
    { 0x8FB0, "suit" },
    { 0x8FB1, "sulfur_door_fx" },
    { 0x8FB2, "sulfursmokefx" },
    { 0x8FB3, "sun_flare" },
    { 0x8FB4, "sun_flare_funeral" },
    { 0x8FB5, "sun_flare_position" },
    { 0x8FB6, "sun_light_fade" },
    { 0x8FB7, "sun_light_reset" },
    { 0x8FB8, "sun_shad_cooling_tower_area" },
    { 0x8FB9, "sun_shad_cooling_tower_start" },
    { 0x8FBA, "sun_shad_exposure_control_room" },
    { 0x8FBB, "sun_shad_vision_fly_in" },
    { 0x8FBC, "sun_shadow_trigger" },
    { 0x8FBD, "sunbeginfadeangle" },
    { 0x8FBE, "sunbeginfadeangle_start" },
    { 0x8FBF, "sunblue" },
    { 0x8FC0, "sunblue_start" },
    { 0x8FC1, "sunbouncehdr" },
    { 0x8FC2, "sundark_call" },
    { 0x8FC3, "sundark_manage" },
    { 0x8FC4, "sundark_touched" },
    { 0x8FC5, "sundark_volume" },
    { 0x8FC6, "sundir" },
    { 0x8FC7, "sundir_start" },
    { 0x8FC8, "sunenable" },
    { 0x8FC9, "sunendfadeangle" },
    { 0x8FCA, "sunendfadeangle_start" },
    { 0x8FCB, "sunendfageangle" },
    { 0x8FCC, "sunflare" },
    { 0x8FCD, "sunflare_changes" },
    { 0x8FCE, "sunflare_settings" },
    { 0x8FCF, "sunflareswap" },
    { 0x8FD0, "sunfog_enabled" },
    { 0x8FD1, "sunfogenabled" },
    { 0x8FD2, "sungreen" },
    { 0x8FD3, "sungreen_start" },
    { 0x8FD4, "sunisprimary" },
    { 0x8FD5, "sunisprimarylight" },
    { 0x8FD6, "sunlighthdr" },
    { 0x8FD7, "sunradiosity" },
    { 0x8FD8, "sunradiosityhdr" },
    { 0x8FD9, "sunred" },
    { 0x8FDA, "sunred_start" },
    { 0x8FDB, "sunsamplesizenear" },
    { 0x8FDC, "sunshadowscale" },
    { 0x8FDD, "superexosettings" },
    { 0x8FDE, "superstarchallenge" },
    { 0x8FDF, "support_01_checkpoint" },
    { 0x8FE0, "supportbarsize" },
    { 0x8FE1, "supportbuddyspawn" },
    { 0x8FE2, "supportintel" },
    { 0x8FE3, "suppresionfire" },
    { 0x8FE4, "suppressed" },
    { 0x8FE5, "suppressed_exo_hover_vfx" },
    { 0x8FE6, "suppressedbehavior" },
    { 0x8FE7, "suppressedtime" },
    { 0x8FE8, "suppressingenemy" },
    { 0x8FE9, "suppressingfiretracking" },
    { 0x8FEA, "suppression_time" },
    { 0x8FEB, "suppressionstart" },
    { 0x8FEC, "suppressionthreshold" },
    { 0x8FED, "suppressionwait_old" },
    { 0x8FEE, "suppresstimeout" },
    { 0x8FEF, "suppresswaiter" },
    { 0x8FF0, "surface" },
    { 0x8FF1, "surface_state" },
    { 0x8FF2, "surfaces" },
    { 0x8FF3, "surprise_ambush_kva_team" },
    { 0x8FF4, "surprise_attack" },
    { 0x8FF5, "surprise_enemy" },
    { 0x8FF6, "surveillance_post_anims" },
    { 0x8FF7, "survivalistchallenge" },
    { 0x8FF8, "survivalstarttime" },
    { 0x8FF9, "survive" },
    { 0x8FFA, "surviveanimallowed" },
    { 0x8FFB, "surviveanimname" },
    { 0x8FFC, "survivorevent" },
    { 0x8FFD, "suspend_drive_anims" },
    { 0x8FFE, "suspend_driveanims" },
    { 0x8FFF, "suspend_sd_role" },
    { 0x9000, "suspensemusic" },
    { 0x9001, "swap" },
    { 0x9002, "swap_ai_to_drone" },
    { 0x9003, "swap_bike_to_static" },
    { 0x9004, "swap_brigde_anim_to_real" },
    { 0x9005, "swap_brigde_anim_to_real_far" },
    { 0x9006, "swap_cockpit_model" },
    { 0x9007, "swap_drone_to_ai" },
    { 0x9008, "swap_drones_attack_player" },
    { 0x9009, "swap_head_model" },
    { 0x900A, "swap_num" },
    { 0x900B, "swap_to_climbing_weapon" },
    { 0x900C, "swap_to_real_weapon" },
    { 0x900D, "swap_tree" },
    { 0x900E, "swap_world_model" },
    { 0x900F, "swapanim" },
    { 0x9010, "swapfogandfx" },
    { 0x9011, "swapfx" },
    { 0x9012, "swaptolastweapon" },
    { 0x9013, "swapwalldelayed" },
    { 0x9014, "swarm" },
    { 0x9015, "swarm_dot_override" },
    { 0x9016, "swarm_drone_hud_change" },
    { 0x9017, "swarm_drone_hud_off" },
    { 0x9018, "swarm_drone_hud_on" },
    { 0x9019, "swarm_last_player_pos" },
    { 0x901A, "swarm_los_body_behind_cover" },
    { 0x901B, "swarm_los_lock_duration_endtime" },
    { 0x901C, "swarm_los_overhead_blocked" },
    { 0x901D, "swarm_repulsor_body" },
    { 0x901E, "swarm_repulsor_foot" },
    { 0x901F, "swarm_repulsor_head" },
    { 0x9020, "swarm_scantime_override" },
    { 0x9021, "swarm_shoot_random_drone_at_ent" },
    { 0x9022, "swarm_spawned" },
    { 0x9023, "swarm_target_list" },
    { 0x9024, "sweapon" },
    { 0x9025, "sweep_range" },
    { 0x9026, "swim" },
    { 0x9027, "swim_anim_drown" },
    { 0x9028, "swim_anim_idle_loop" },
    { 0x9029, "swim_anim_loop" },
    { 0x902A, "swim_anim_loop_into" },
    { 0x902B, "swim_anim_offscreen" },
    { 0x902C, "swim_approachnode" },
    { 0x902D, "swim_approachpos" },
    { 0x902E, "swim_arms_model" },
    { 0x902F, "swim_begin" },
    { 0x9030, "swim_bounds_fail" },
    { 0x9031, "swim_cancelcurrentapproach" },
    { 0x9032, "swim_choosestart" },
    { 0x9033, "swim_cleanupturnanim" },
    { 0x9034, "swim_clearleananims" },
    { 0x9035, "swim_coverarrival_main" },
    { 0x9036, "swim_determineapproachanim" },
    { 0x9037, "swim_determineapproachanim3d" },
    { 0x9038, "swim_dofinalarrival" },
    { 0x9039, "swim_doposarrival" },
    { 0x903A, "swim_dostrafe" },
    { 0x903B, "swim_end" },
    { 0x903C, "swim_end_hide_viewarms" },
    { 0x903D, "swim_getangleindex" },
    { 0x903E, "swim_getanimstartpos" },
    { 0x903F, "swim_getapproachtype" },
    { 0x9040, "swim_getmaxanimdist" },
    { 0x9041, "swim_getstrafeblendtime" },
    { 0x9042, "swim_handlestartcoveraim" },
    { 0x9043, "swim_isapproachablenode" },
    { 0x9044, "swim_maymovefrompointtopoint" },
    { 0x9045, "swim_movebegin" },
    { 0x9046, "swim_moveend" },
    { 0x9047, "swim_null" },
    { 0x9048, "swim_path_targetname" },
    { 0x9049, "swim_pathchange_getturnanim" },
    { 0x904A, "swim_restartapproachlistener" },
    { 0x904B, "swim_scene_boat_sink" },
    { 0x904C, "swim_scene_boat_sink_bob" },
    { 0x904D, "swim_scene_boats" },
    { 0x904E, "swim_scene_chase_littlebird_patrol" },
    { 0x904F, "swim_scene_cleanup" },
    { 0x9050, "swim_scene_climb_out_water" },
    { 0x9051, "swim_scene_dock_destroy" },
    { 0x9052, "swim_scene_dock_guard_goal" },
    { 0x9053, "swim_scene_dock_guard_removal" },
    { 0x9054, "swim_scene_dock_guards" },
    { 0x9055, "swim_scene_handle_current" },
    { 0x9056, "swim_scene_handle_player_containment" },
    { 0x9057, "swim_scene_ilana_swim_on_path_behavior" },
    { 0x9058, "swim_scene_master_handler" },
    { 0x9059, "swim_scene_pre_setup" },
    { 0x905A, "swim_scene_scripted_destroyed_dock_hide" },
    { 0x905B, "swim_scene_setup" },
    { 0x905C, "swim_scene_swarm_kamikaze_attack" },
    { 0x905D, "swim_scene_swarm_movement" },
    { 0x905E, "swim_scene_swarm_setup" },
    { 0x905F, "swim_scene_warbird_fire_at_target_for_duration" },
    { 0x9060, "swim_setleananims" },
    { 0x9061, "swim_setstrafeaimset" },
    { 0x9062, "swim_setstrafeaimweights" },
    { 0x9063, "swim_setstrafeweights" },
    { 0x9064, "swim_setupapproach" },
    { 0x9065, "swim_shoulddonodeexit" },
    { 0x9066, "swim_startcoveraim" },
    { 0x9067, "swim_time_fail" },
    { 0x9068, "swim_track_forward_enter" },
    { 0x9069, "swim_track_forward_exit" },
    { 0x906A, "swim_track_set" },
    { 0x906B, "swim_track_strafe_enter" },
    { 0x906C, "swim_track_strafe_exit" },
    { 0x906D, "swim_updateleananim" },
    { 0x906E, "swim_updatestrafeaimanim" },
    { 0x906F, "swim_updatestrafeanim" },
    { 0x9070, "swim_waitforapproachpos" },
    { 0x9071, "swim_warbird" },
    { 0x9072, "swimming" },
    { 0x9073, "swimming_arms" },
    { 0x9074, "swimming_depth" },
    { 0x9075, "swimming_gravity_vel" },
    { 0x9076, "switch_back_to_player_weapon" },
    { 0x9077, "switch_node_now" },
    { 0x9078, "switch_path" },
    { 0x9079, "switch_rpg_weapon" },
    { 0x907A, "switch_to_last_weapon" },
    { 0x907B, "switch_to_melee" },
    { 0x907C, "switch_to_previous_weapon" },
    { 0x907D, "switchedweapons" },
    { 0x907E, "switching_teams" },
    { 0x907F, "switchtocloaked" },
    { 0x9080, "switchtolastweapon" },
    { 0x9081, "switchtosidearm" },
    { 0x9082, "switchtovisible" },
    { 0x9083, "switchweaponafterraiseanimation" },
    { 0x9084, "sync_anim_times_with_carrier" },
    { 0x9085, "sync_entity_damage" },
    { 0x9086, "sync_transients_after_time" },
    { 0x9087, "syncedmeleetarget2" },
    { 0x9088, "syncnotetrackent" },
    { 0x9089, "syncxpstat" },
/* 1 gap
    "system_default_detect_ranges",
    "system_default_event_distances",
    "system_event_change",
    "system_handle_clipbrush",
    "system_init",
    "system_init_shadows",
    "system_message_loop",
    "system_save_processes",
    "system_set_detect_ranges",
    "system_set_event_distances",
    "system_state_check_no_enemy",
    "system_state_spotted",
    "system_state_try_clear_flag",
    "t",
    "t2e_clip_cleanup",
    "t2e_walk_push_damage",
*/
    { 0x909B, "table_combine" },
    { 0x909C, "table_getequipment" },
    { 0x909D, "table_getequipmentextra" },
    { 0x909E, "table_getkillstreak" },
    { 0x909F, "table_getkillstreakmodule" },
    { 0x90A0, "table_getoffhand" },
    { 0x90A1, "table_getoffhandextra" },
    { 0x90A2, "table_getperk" },
    { 0x90A3, "table_getteamperk" },
    { 0x90A4, "table_getweapon" },
    { 0x90A5, "table_getweaponattachment" },
    { 0x90A6, "table_getweaponbuff" },
    { 0x90A7, "table_getweaponcamo" },
    { 0x90A8, "table_getweaponreticle" },
    { 0x90A9, "table_getwildcard" },
    { 0x90AA, "table_origins" },
    { 0x90AB, "table_pulldown" },
    { 0x90AC, "table_pulldown_distance_check" },
    { 0x90AD, "tablelookupweaponoffsets" },
    { 0x90AE, "tackle_handle_hint_display" },
    { 0x90AF, "tactical_goals" },
    { 0x90B0, "tactical_location" },
    { 0x90B1, "tactical_move_to_goal_pos" },
    { 0x90B2, "tactical_picker_enabled" },
    { 0x90B3, "tactics_model" },
    { 0x90B4, "tactics_objectives" },
    { 0x90B5, "tactics_objects" },
    { 0x90B6, "tactics_tools" },
    { 0x90B7, "tactics_type" },
    { 0x90B8, "tag_array" },
    { 0x90B9, "tag_bar_end_early" },
    { 0x90BA, "tag_current" },
    { 0x90BB, "tag_driver" },
    { 0x90BC, "tag_enemy" },
    { 0x90BD, "tag_ent" },
    { 0x90BE, "tag_getting" },
    { 0x90BF, "tag_idx" },
    { 0x90C0, "tag_left_foot" },
    { 0x90C1, "tag_left_hand" },
    { 0x90C2, "tag_monitor" },
    { 0x90C3, "tag_name" },
    { 0x90C4, "tag_offset" },
    { 0x90C5, "tag_outline_enemy" },
    { 0x90C6, "tag_player_view" },
    { 0x90C7, "tag_progress_bar" },
    { 0x90C8, "tag_project" },
    { 0x90C9, "tag_project_player" },
    { 0x90CA, "tag_right_foot" },
    { 0x90CB, "tag_right_hand" },
    { 0x90CC, "tag_scan_update" },
    { 0x90CD, "tag_screen_load" },
    { 0x90CE, "tag_screen_off" },
    { 0x90CF, "tag_screen_on" },
    { 0x90D0, "tag_shutdown_hp_threshold_array" },
    { 0x90D1, "tag_shutdown_order_array" },
    { 0x90D2, "tag_sound" },
    { 0x90D3, "tag_stowed_hip" },
    { 0x90D4, "tag_targ" },
    { 0x90D5, "tag_threat_detection" },
    { 0x90D6, "tag_trace_pulse" },
    { 0x90D7, "tag_trace_sound" },
    { 0x90D8, "tag_trace_state" },
    { 0x90D9, "tag_trace_track" },
    { 0x90DA, "tag_trace_update" },
    { 0x90DB, "tag_update_enemy_in_sights" },
    { 0x90DC, "tag_watcher" },
    { 0x90DD, "tag1" },
    { 0x90DE, "tag2" },
    { 0x90DF, "tagavailable" },
    { 0x90E0, "tagcollectorevent" },
    { 0x90E1, "tagcollectortotal" },
    { 0x90E2, "tagged" },
    { 0x90E3, "tagged_enemy_death_cleanup" },
    { 0x90E4, "tagged_enemy_update" },
    { 0x90E5, "tagged_status_hide" },
    { 0x90E6, "tagged_status_show" },
    { 0x90E7, "tagged_status_update" },
    { 0x90E8, "tagging" },
    { 0x90E9, "tagging_color" },
    { 0x90EA, "tagging_create_hud" },
    { 0x90EB, "tagging_create_hud_crosshair" },
    { 0x90EC, "tagging_enemy_list" },
    { 0x90ED, "tagging_highlight_hud_effect_apply" },
    { 0x90EE, "tagging_highlight_hud_effect_remove" },
    { 0x90EF, "tagging_hud_show_all" },
    { 0x90F0, "tagging_hud_show_minimal" },
    { 0x90F1, "tagging_hud_show_none" },
    { 0x90F2, "tagging_hud_shutdown" },
    { 0x90F3, "tagging_init_player" },
    { 0x90F4, "tagging_mode_begin" },
    { 0x90F5, "tagging_mode_end" },
    { 0x90F6, "tagging_mode_watcher" },
    { 0x90F7, "tagging_set_binocs_enabled" },
    { 0x90F8, "tagging_set_enabled" },
    { 0x90F9, "tagging_set_forced_mode" },
    { 0x90FA, "tagging_set_hint" },
    { 0x90FB, "tagging_set_hud_outline_style" },
    { 0x90FC, "tagging_set_marking_enabled" },
    { 0x90FD, "tagging_shutdown_player" },
    { 0x90FE, "tagging_sight_trace_passed" },
    { 0x90FF, "tagging_sight_trace_queue" },
    { 0x9100, "tagging_sight_traced_queued" },
    { 0x9101, "tagging_think" },
    { 0x9102, "tagging_zoom_monitor" },
    { 0x9103, "tagging_zoom_sound" },
    { 0x9104, "tagging_zoom_transition" },
    { 0x9105, "tagmarkedby" },
    { 0x9106, "tags" },
    { 0x9107, "tags_seen" },
    { 0x9108, "tags_seen_by_owner" },
    { 0x9109, "tagtarget" },
    { 0x910A, "tagteamupdater" },
    { 0x910B, "take_car_door_shields" },
    { 0x910C, "take_color_node" },
    { 0x910D, "take_color_node_until_death" },
    { 0x910E, "take_cover_warning" },
    { 0x910F, "take_cover_warning_loop" },
    { 0x9110, "take_cover_warnings_enabled" },
    { 0x9111, "take_every_grenade_now" },
    { 0x9112, "take_exo_cloak" },
    { 0x9113, "take_exo_health" },
    { 0x9114, "take_exo_hover" },
    { 0x9115, "take_exo_mute" },
    { 0x9116, "take_exo_overclock" },
    { 0x9117, "take_exo_ping" },
    { 0x9118, "take_exo_repulsor" },
    { 0x9119, "take_exo_shield" },
    { 0x911A, "take_knife_when_done" },
    { 0x911B, "take_prebreach_weapons" },
    { 0x911C, "take_selfie" },
    { 0x911D, "take_water_weapon" },
    { 0x911E, "take_weapon_delayed" },
    { 0x911F, "takeandkillevent" },
    { 0x9120, "takedown_01_complete" },
    { 0x9121, "takedown_01_complete_dialogue" },
    { 0x9122, "takedown_01_dialogue" },
    { 0x9123, "takedown_button" },
    { 0x9124, "takedown_door" },
    { 0x9125, "takedown_hint_off" },
    { 0x9126, "takedown_qte" },
    { 0x9127, "takedown_qte_middle" },
    { 0x9128, "takedown_truck_lights_off" },
    { 0x9129, "takedown_trunk" },
    { 0x912A, "takedown_underwater_portion" },
    { 0x912B, "takedownenemy1" },
    { 0x912C, "takekillstreakweaponifnodupe" },
    { 0x912D, "takekillstreakweapons" },
    { 0x912E, "takeobject" },
    { 0x912F, "takeoffhand" },
    { 0x9130, "takeover_warbird_turret_buddy" },
    { 0x9131, "takeuseweapon" },
    { 0x9132, "talk_for_time" },
    { 0x9133, "talker" },
    { 0x9134, "talker_is_talking_currently" },
    { 0x9135, "talker_origin" },
    { 0x9136, "tangent" },
    { 0x9137, "tank" },
    { 0x9138, "tank_ascent" },
    { 0x9139, "tank_ascent_dialogue" },
    { 0x913A, "tank_ascent_logic" },
    { 0x913B, "tank_attack" },
    { 0x913C, "tank_battle_rpg_enemy_think" },
    { 0x913D, "tank_board" },
    { 0x913E, "tank_board_dialogue" },
    { 0x913F, "tank_board_enter" },
    { 0x9140, "tank_board_enter_top_lights" },
    { 0x9141, "tank_board_logic" },
    { 0x9142, "tank_checkpoint_engine" },
    { 0x9143, "tank_clearing_dialogue" },
    { 0x9144, "tank_clearing2_littlebird" },
    { 0x9145, "tank_clearing3_littlebird" },
    { 0x9146, "tank_combat_littlebird_damage_function" },
    { 0x9147, "tank_combat_littlebird_think" },
    { 0x9148, "tank_combat_vehicle_damage_feedback" },
    { 0x9149, "tank_combat_vrap" },
    { 0x914A, "tank_combat_vrap_deactivate_on_unload" },
    { 0x914B, "tank_combat_warbird_damage_function" },
    { 0x914C, "tank_combat_warbird_kill_is_crew_killed" },
    { 0x914D, "tank_combat_warbird_liftoff_think" },
    { 0x914E, "tank_combat_warbird_orient_to_open_fire" },
    { 0x914F, "tank_combat_warbird_think" },
    { 0x9150, "tank_count" },
    { 0x9151, "tank_courtyard_dialogue" },
    { 0x9152, "tank_courtyard_gate_dialogue" },
    { 0x9153, "tank_damage_detection" },
    { 0x9154, "tank_disabled" },
    { 0x9155, "tank_end" },
    { 0x9156, "tank_exfil_charges_going_off" },
    { 0x9157, "tank_exfil_detonate" },
    { 0x9158, "tank_exit" },
    { 0x9159, "tank_exit_dialogue" },
    { 0x915A, "tank_exit_dof_reset" },
    { 0x915B, "tank_field" },
    { 0x915C, "tank_field_choppers_dialogue" },
    { 0x915D, "tank_field_dialogue" },
    { 0x915E, "tank_field_lft_frk" },
    { 0x915F, "tank_field_logic" },
    { 0x9160, "tank_field_nightvision" },
    { 0x9161, "tank_field_rgt_frk" },
    { 0x9162, "tank_field_vraps_dialogue" },
    { 0x9163, "tank_fire_missile" },
    { 0x9164, "tank_hangar" },
    { 0x9165, "tank_hangar_dialogue" },
    { 0x9166, "tank_hangar_door_close" },
    { 0x9167, "tank_hangar_door_open" },
    { 0x9168, "tank_hangar_logic" },
    { 0x9169, "tank_hangar_pas_dialogue" },
    { 0x916A, "tank_hide_icon" },
    { 0x916B, "tank_idle" },
    { 0x916C, "tank_missile_react" },
    { 0x916D, "tank_missile_set_target" },
    { 0x916E, "tank_no_target_time" },
    { 0x916F, "tank_queue" },
    { 0x9170, "tank_reloading_dialogue" },
    { 0x9171, "tank_reveal_lighting" },
    { 0x9172, "tank_reveal_models" },
    { 0x9173, "tank_reveal_models_start_point" },
    { 0x9174, "tank_road" },
    { 0x9175, "tank_road_dialogue" },
    { 0x9176, "tank_road_enemy_tank_dialogue" },
    { 0x9177, "tank_road_enemy_think" },
    { 0x9178, "tank_road_littlebird" },
    { 0x9179, "tank_road_logic" },
    { 0x917A, "tank_road_tank_killed_dialogue" },
    { 0x917B, "tank_run" },
    { 0x917C, "tank_screens_boot_up" },
    { 0x917D, "tank_section_vehicles_spawned" },
    { 0x917E, "tank_shack_destruct" },
    { 0x917F, "tank_shoot_generic" },
    { 0x9180, "tank_shoot_time" },
    { 0x9181, "tank_show_icon" },
    { 0x9182, "tank_status_dialogue" },
    { 0x9183, "tank_systems_dialogue" },
    { 0x9184, "tank_trail" },
    { 0x9185, "tank_turrent_reflection" },
    { 0x9186, "tank_wait_flag_time" },
    { 0x9187, "tanker_crash" },
    { 0x9188, "tanker_drone_flood" },
    { 0x9189, "tanker_exploded" },
    { 0x918A, "tanker_fire_hurt_trigger" },
    { 0x918B, "tanker_fireball" },
    { 0x918C, "tanker_mountain_crash" },
    { 0x918D, "tanker_mountain_crash2" },
    { 0x918E, "tanker_roll_explosion" },
    { 0x918F, "tanker_skid_impacts" },
    { 0x9190, "tankgetout" },
    { 0x9191, "tankkilled" },
    { 0x9192, "tanks" },
    { 0x9193, "tanksquish" },
    { 0x9194, "tanksquish_damage_check" },
    { 0x9195, "tanktrail" },
    { 0x9196, "tappackagethink" },
    { 0x9197, "targent" },
    { 0x9198, "target_air_space" },
    { 0x9199, "target_array" },
    { 0x919A, "target_blink_out" },
    { 0x919B, "target_center_off" },
    { 0x919C, "target_confirm" },
    { 0x919D, "target_cycleshader" },
    { 0x919E, "target_drone_damager" },
    { 0x919F, "target_enhancer_think" },
    { 0x91A0, "target_ent" },
    { 0x91A1, "target_ent_cleanup" },
    { 0x91A2, "target_entity" },
    { 0x91A3, "target_fov" },
    { 0x91A4, "target_from_avatar" },
    { 0x91A5, "target_handle_death" },
    { 0x91A6, "target_handle_stop" },
    { 0x91A7, "target_handler" },
    { 0x91A8, "target_is_in_front" },
    { 0x91A9, "target_lifetime" },
    { 0x91AA, "target_list" },
    { 0x91AB, "target_lock_change_func" },
    { 0x91AC, "target_lock_targets" },
    { 0x91AD, "target_logic" },
    { 0x91AE, "target_marked" },
    { 0x91AF, "target_min_range" },
    { 0x91B0, "target_move_dist" },
    { 0x91B1, "target_name" },
    { 0x91B2, "target_org" },
    { 0x91B3, "target_position" },
    { 0x91B4, "target_radius" },
    { 0x91B5, "target_reset" },
    { 0x91B6, "target_score" },
    { 0x91B7, "target_setsafe" },
    { 0x91B8, "target_setshadersafe" },
    { 0x91B9, "target_spawn_in" },
    { 0x91BA, "target_spawn_out" },
    { 0x91BB, "target_stencil" },
    { 0x91BC, "target_still_valid" },
    { 0x91BD, "target_swarm" },
    { 0x91BE, "target_track" },
    { 0x91BF, "target_units_per_second" },
    { 0x91C0, "target_valid_targets" },
    { 0x91C1, "targetangularacceleration" },
    { 0x91C2, "targetattacker" },
    { 0x91C3, "targetavatar" },
    { 0x91C4, "targetdefault" },
    { 0x91C5, "targetdest" },
    { 0x91C6, "targetdot" },
    { 0x91C7, "targetedent" },
    { 0x91C8, "targetenemy" },
    { 0x91C9, "targetent" },
    { 0x91CA, "targetentpos" },
    { 0x91CB, "targetgetdist" },
    { 0x91CC, "targeting_delay" },
    { 0x91CD, "targeting_hud_destroy" },
    { 0x91CE, "targeting_hud_init" },
    { 0x91CF, "targeting_hud_think" },
    { 0x91D0, "targetinsafevolume" },
    { 0x91D1, "targetisclose" },
    { 0x91D2, "targetisinfront" },
    { 0x91D3, "targetlist" },
    { 0x91D4, "targetmarked" },
    { 0x91D5, "targetmonitor" },
    { 0x91D6, "targetplaydeath" },
    { 0x91D7, "targetplayer" },
    { 0x91D8, "targetpos" },
    { 0x91D9, "targets" },
    { 0x91DA, "targets_and_uses_turret" },
    { 0x91DB, "targetspreadshooting" },
    { 0x91DC, "targetzoff" },
    { 0x91DD, "tc_ai_clip_blocker" },
    { 0x91DE, "tc_door_to_stairs_closer" },
    { 0x91DF, "tc_manticore_ally_traverse" },
    { 0x91E0, "tc_setup_door" },
    { 0x91E1, "tc_side_door_movement" },
    { 0x91E2, "tc_uv_rumble" },
    { 0x91E3, "tcah_doors" },
    { 0x91E4, "tcah_node" },
    { 0x91E5, "team_move_hospital" },
    { 0x91E6, "team_specific_spawn_functions" },
    { 0x91E7, "team1" },
    { 0x91E8, "team2" },
    { 0x91E9, "teambalance" },
    { 0x91EA, "teambase" },
    { 0x91EB, "teambased" },
    { 0x91EC, "teamchangedthisframe" },
    { 0x91ED, "teamcount" },
    { 0x91EE, "teamemped" },
    { 0x91EF, "teamflags" },
    { 0x91F0, "teamflashbangimmune" },
    { 0x91F1, "teamflashbangimmunity" },
    { 0x91F2, "teamkilldelay" },
    { 0x91F3, "teamkillsthisround" },
    { 0x91F4, "teamlimit" },
    { 0x91F5, "teamlist" },
    { 0x91F6, "teamname" },
    { 0x91F7, "teamnamelist" },
    { 0x91F8, "teamnukeemped" },
    { 0x91F9, "teamoutcomenotify" },
    { 0x91FA, "teamplayercardsplash" },
    { 0x91FB, "teamprogressbarfontsize" },
    { 0x91FC, "teamprogressbarheight" },
    { 0x91FD, "teamprogressbartexty" },
    { 0x91FE, "teamprogressbarwidth" },
    { 0x91FF, "teamprogressbary" },
    { 0x9200, "teams" },
    { 0x9201, "teamspawnpoints" },
    { 0x9202, "teamsplash" },
    { 0x9203, "teamswap" },
    { 0x9204, "teamthreatcalloutlimittimeout" },
    { 0x9205, "teamtweaks" },
    { 0x9206, "teamusetexts" },
    { 0x9207, "teamusetimes" },
    { 0x9208, "technical_pain" },
    { 0x9209, "tele_orgs" },
    { 0x920A, "telefrag_behavior" },
    { 0x920B, "teleport_add_delta" },
    { 0x920C, "teleport_add_delta_targets" },
    { 0x920D, "teleport_ahead" },
    { 0x920E, "teleport_ai" },
    { 0x920F, "teleport_ai_rooftop" },
    { 0x9210, "teleport_allowed" },
    { 0x9211, "teleport_bones_and_joker" },
    { 0x9212, "teleport_building_jump" },
    { 0x9213, "teleport_burke_to_alley" },
    { 0x9214, "teleport_change_targetname" },
    { 0x9215, "teleport_closest_zone" },
    { 0x9216, "teleport_delta_this_frame" },
    { 0x9217, "teleport_dom_finished_initializing" },
    { 0x9218, "teleport_dom_post_bot_cleanup" },
    { 0x9219, "teleport_ent" },
    { 0x921A, "teleport_filter_spawn_point" },
    { 0x921B, "teleport_gamemode_disable_teleport" },
    { 0x921C, "teleport_gamemode_func" },
    { 0x921D, "teleport_get_active_nodes" },
    { 0x921E, "teleport_get_active_pathnode_zones" },
    { 0x921F, "teleport_get_care_packages" },
    { 0x9220, "teleport_get_deployable_boxes" },
    { 0x9221, "teleport_get_matching_dom_flag" },
    { 0x9222, "teleport_get_safe_node_near" },
    { 0x9223, "teleport_include_killsteaks" },
    { 0x9224, "teleport_include_killstreaks" },
    { 0x9225, "teleport_include_players" },
    { 0x9226, "teleport_init" },
    { 0x9227, "teleport_init_spawn_info" },
    { 0x9228, "teleport_is_valid_zone" },
    { 0x9229, "teleport_minimaps" },
    { 0x922A, "teleport_nodes_in_zone" },
    { 0x922B, "teleport_notify_death" },
    { 0x922C, "teleport_onstartgameball" },
    { 0x922D, "teleport_onstartgameconf" },
    { 0x922E, "teleport_onstartgamectf" },
    { 0x922F, "teleport_onstartgamedom" },
    { 0x9230, "teleport_onstartgamehorde" },
    { 0x9231, "teleport_onstartgamehp" },
    { 0x9232, "teleport_onstartgametype" },
    { 0x9233, "teleport_onteleportball" },
    { 0x9234, "teleport_onteleportconf" },
    { 0x9235, "teleport_onteleportctf" },
    { 0x9236, "teleport_onteleportdom" },
    { 0x9237, "teleport_onteleporthp" },
    { 0x9238, "teleport_origin_use_nodes" },
    { 0x9239, "teleport_origin_use_offset" },
    { 0x923A, "teleport_origins" },
    { 0x923B, "teleport_parse_zone_targets" },
    { 0x923C, "teleport_pathnode_zones" },
    { 0x923D, "teleport_place_on_ground" },
    { 0x923E, "teleport_player" },
    { 0x923F, "teleport_players" },
    { 0x9240, "teleport_post_funcs" },
    { 0x9241, "teleport_pre_funcs" },
    { 0x9242, "teleport_pre_onstartgamesd" },
    { 0x9243, "teleport_pre_onstartgamesd_and_sr" },
    { 0x9244, "teleport_pre_onstartgamesr" },
    { 0x9245, "teleport_restore_targetname" },
    { 0x9246, "teleport_self_add_delta" },
    { 0x9247, "teleport_self_add_delta_targets" },
    { 0x9248, "teleport_set_current_zone" },
    { 0x9249, "teleport_set_minimap_for_zone" },
    { 0x924A, "teleport_set_post_func" },
    { 0x924B, "teleport_set_pre_func" },
    { 0x924C, "teleport_spawn_info" },
    { 0x924D, "teleport_to_ent_tag" },
    { 0x924E, "teleport_to_nodes" },
    { 0x924F, "teleport_to_offset" },
    { 0x9250, "teleport_to_scriptstruct" },
    { 0x9251, "teleport_to_struct" },
    { 0x9252, "teleport_to_zone" },
    { 0x9253, "teleport_to_zone_agents" },
    { 0x9254, "teleport_to_zone_character" },
    { 0x9255, "teleport_to_zone_killstreaks" },
    { 0x9256, "teleport_to_zone_players" },
    { 0x9257, "teleport_validate_success" },
    { 0x9258, "teleport_zone" },
    { 0x9259, "teleport_zone_current" },
    { 0x925A, "teleport_zones" },
    { 0x925B, "teleported_to_path_section" },
    { 0x925C, "teleportgetactivenodesfunc" },
    { 0x925D, "teleportgetactivepathnodezonesfunc" },
    { 0x925E, "teleportthread" },
    { 0x925F, "teleportthreadex" },
    { 0x9260, "television" },
    { 0x9261, "temp_bink_stuff" },
    { 0x9262, "temp_clip_delete" },
    { 0x9263, "temp_cloak_gauge" },
    { 0x9264, "temp_dialogue" },
    { 0x9265, "temp_dialogue_fade" },
    { 0x9266, "temp_diveboat_weapon_gauge" },
    { 0x9267, "temp_dog_bark" },
    { 0x9268, "temp_dog_sfx" },
    { 0x9269, "temp_exoclimb_hud" },
    { 0x926A, "temp_exoclimb_hud_check_array" },
    { 0x926B, "temp_exoclimb_hud_hide" },
    { 0x926C, "temp_exoclimb_hud_init" },
    { 0x926D, "temp_exoclimb_hud_precache" },
    { 0x926E, "temp_exoclimb_hud_thread" },
    { 0x926F, "temp_friendly_squad_casual_walk" },
    { 0x9270, "temp_handle_fob_anim_scene" },
    { 0x9271, "temp_noise" },
    { 0x9272, "temp_subtitle" },
    { 0x9273, "temp_tag" },
    { 0x9274, "temp_think" },
    { 0x9275, "temperature_deep_caves" },
    { 0x9276, "temperature_high_alt" },
    { 0x9277, "temperature_high_alt_wind" },
    { 0x9278, "temperature_indoor" },
    { 0x9279, "temperature_outdoor" },
    { 0x927A, "temperature_water" },
    { 0x927B, "template_level" },
    { 0x927C, "template_script" },
    { 0x927D, "template_so_level" },
    { 0x927E, "templates" },
    { 0x927F, "temporary_disable_pain" },
    { 0x9280, "temporary_sentinel_reveal_timing" },
    { 0x9281, "temptarget" },
    { 0x9282, "tennis_court" },
    { 0x9283, "tennis_court_alert_vo" },
    { 0x9284, "tennis_court_ball_cleanup" },
    { 0x9285, "tennis_court_ball_launcher" },
    { 0x9286, "tennis_court_ball_launcher_logic" },
    { 0x9287, "tennis_court_computer_line_done" },
    { 0x9288, "tennis_court_computer_talking" },
    { 0x9289, "tennis_court_floor" },
    { 0x928A, "tennis_court_lights_dimmed" },
    { 0x928B, "tennis_court_lights_intial" },
    { 0x928C, "tennis_court_lights_on" },
    { 0x928D, "tennis_court_nags" },
    { 0x928E, "tennis_court_origin" },
    { 0x928F, "tennis_court_player_brackets" },
    { 0x9290, "tennis_court_player_brackets_internal" },
    { 0x9291, "tennis_court_trigger" },
    { 0x9292, "tent_scene_civilians_01" },
    { 0x9293, "tent_scene_civilians_02" },
    { 0x9294, "ter_op" },
    { 0x9295, "terminal_hum_01" },
    { 0x9296, "terminal_hum_02" },
    { 0x9297, "terrace_turret_fx" },
    { 0x9298, "terracecustomkillstreakfunc" },
    { 0x9299, "terracecustomospfunc" },
    { 0x929A, "tess" },
    { 0x929B, "tess_init" },
    { 0x929C, "tess_set_goal" },
    { 0x929D, "tess_update" },
    { 0x929E, "test" },
    { 0x929F, "test_chamber_body_pushes" },
    { 0x92A0, "test_chamber_exit_door" },
    { 0x92A1, "test_chamber_exit_door_notetrack" },
    { 0x92A2, "test_chamber_stairs_up_door" },
    { 0x92A3, "test_chamber_stairs_up_door_notetrack" },
    { 0x92A4, "test_chamber_stairs_up_door_swipe_sfx_notetrack" },
    { 0x92A5, "test_col_points_in_segment" },
    { 0x92A6, "test_lines" },
    { 0x92A7, "test_look_b" },
    { 0x92A8, "test_look_c" },
    { 0x92A9, "test_pathing" },
    { 0x92AA, "test_sun_flare" },
    { 0x92AB, "test_tag" },
    { 0x92AC, "test_trace" },
    { 0x92AD, "test_trace_tag" },
    { 0x92AE, "test_zipline" },
    { 0x92AF, "testfx" },
    { 0x92B0, "testmenu" },
    { 0x92B1, "testshock" },
    { 0x92B2, "text" },
    { 0x92B3, "text_glow_adjust" },
    { 0x92B4, "text_incoming" },
    { 0x92B5, "text_incoming_x" },
    { 0x92B6, "text_incoming_y" },
    { 0x92B7, "text_list" },
    { 0x92B8, "text_x" },
    { 0x92B9, "text_y" },
    { 0x92BA, "text2label" },
    { 0x92BB, "textalpha" },
    { 0x92BC, "textglowcolor" },
    { 0x92BD, "textid" },
    { 0x92BE, "textisstring" },
    { 0x92BF, "textlabel" },
    { 0x92C0, "textoffline" },
    { 0x92C1, "textscale" },
    { 0x92C2, "textstring" },
    { 0x92C3, "tff_ally_check" },
    { 0x92C4, "tff_blocker_caves" },
    { 0x92C5, "tff_blocker_incinerator" },
    { 0x92C6, "tff_blocker_incinerator_to_helipad" },
    { 0x92C7, "tff_blockers" },
    { 0x92C8, "tff_cleanup_canal_boats" },
    { 0x92C9, "tff_cleanup_tour_ride_ambient_vehicles" },
    { 0x92CA, "tff_cleanup_vehicle" },
    { 0x92CB, "tff_get_zone_cleanup_notify" },
    { 0x92CC, "tff_get_zone_unload_notify" },
    { 0x92CD, "tff_setup_blocker_hangar_backtrack" },
    { 0x92CE, "tff_setup_blocker_hangar_load" },
    { 0x92CF, "tff_setup_blockers" },
    { 0x92D0, "tff_setup_start_points" },
    { 0x92D1, "tff_setup_transitions" },
    { 0x92D2, "tff_setups" },
    { 0x92D3, "tff_spawn_vehicles_conf_center" },
    { 0x92D4, "tff_start_points" },
    { 0x92D5, "tff_sync" },
    { 0x92D6, "tff_sync_notetrack" },
    { 0x92D7, "tff_sync_setup" },
    { 0x92D8, "tff_trans_ally_check_active" },
    { 0x92D9, "tff_trans_ally_check_count" },
    { 0x92DA, "tff_trans_ally_check_touching" },
    { 0x92DB, "tff_trans_atlas_building_to_old_town" },
    { 0x92DC, "tff_trans_autopsy_halls_to_autopsy" },
    { 0x92DD, "tff_trans_briefing_to_cliffs" },
    { 0x92DE, "tff_trans_canals_to_finale" },
    { 0x92DF, "tff_trans_caves_to_lake" },
    { 0x92E0, "tff_trans_cliffs_to_lower" },
    { 0x92E1, "tff_trans_escape_to_test_chamber" },
    { 0x92E2, "tff_trans_incinerator_to_helipad" },
    { 0x92E3, "tff_trans_intro_drive_to_s2walk" },
    { 0x92E4, "tff_trans_intro_to_middle" },
    { 0x92E5, "tff_trans_load_autopsy_halls" },
    { 0x92E6, "tff_trans_load_bigm" },
    { 0x92E7, "tff_trans_load_escape" },
    { 0x92E8, "tff_trans_lower_to_upper" },
    { 0x92E9, "tff_trans_middle_to_outro" },
    { 0x92EA, "tff_trans_middle_to_outro_ally_check" },
    { 0x92EB, "tff_trans_middle_to_outro_ally_touching" },
    { 0x92EC, "tff_trans_old_town_to_canals" },
    { 0x92ED, "tff_trans_s2walk_to_interrogate" },
    { 0x92EE, "tff_trans_site_to_caves" },
    { 0x92EF, "tff_trans_tour_augmented_reality_to_training" },
    { 0x92F0, "tff_trans_tour_exo_to_tour_firing_range" },
    { 0x92F1, "tff_trans_tour_firing_range_to_tour_augmented_reality" },
    { 0x92F2, "tff_trans_tour_ride_to_tour_exo" },
    { 0x92F3, "tff_trans_training_to_tour_ride" },
    { 0x92F4, "tff_trans_unload_interrogate" },
    { 0x92F5, "tff_trans_unload_test_chamber" },
    { 0x92F6, "tff_trans_upper_to_lower_cliffs" },
    { 0x92F7, "tff_transitions" },
    { 0x92F8, "tff_vehicles" },
    { 0x92F9, "tgt_camoffset_ratio" },
    { 0x92FA, "tgt_values" },
    { 0x92FB, "tgtdangle" },
    { 0x92FC, "tgtdelta" },
    { 0x92FD, "theres_the_convoy_vo" },
    { 0x92FE, "thermal_effectsoff" },
    { 0x92FF, "thermal_effectson" },
    { 0x9300, "thermal_tracker" },
    { 0x9301, "thermal_with_nvg" },
    { 0x9302, "thermaldrawenabledrone" },
    { 0x9303, "thermaloff_vianotify" },
    { 0x9304, "thermalvision" },
    { 0x9305, "thermite_grenade_1_fx" },
    { 0x9306, "thermite_grenade_2_fx" },
    { 0x9307, "thermite_grenade_3_fx" },
    { 0x9308, "thermite_servers_explosion" },
    { 0x9309, "thin_out_navy_guys" },
    { 0x930A, "thin_the_herd" },
    { 0x930B, "thing" },
    { 0x930C, "think" },
    { 0x930D, "think_player_blast_walk_anims" },
    { 0x930E, "thinkallyinfiltrator" },
    { 0x930F, "thinkambushenemy" },
    { 0x9310, "thinkfastevent" },
    { 0x9311, "thinkmeetingcivilian" },
    { 0x9312, "thinkpatrolenemy" },
    { 0x9313, "thread_delay_s" },
    { 0x9314, "threaded_anim_roundabout_rappel" },
    { 0x9315, "threadedsetweaponstatbyname" },
    { 0x9316, "threads" },
    { 0x9317, "threat" },
    { 0x9318, "threat_attack" },
    { 0x9319, "threat_bias_canal_think" },
    { 0x931A, "threat_bias_remove_delay" },
    { 0x931B, "threat_bias_silo_think" },
    { 0x931C, "threat_detection_style" },
    { 0x931D, "threat_grenade_response_is_on" },
    { 0x931E, "threat_init" },
    { 0x931F, "threat_level" },
    { 0x9320, "threat_list" },
    { 0x9321, "threat_paint_highlight_hud_effect" },
    { 0x9322, "threat_paint_hud_effect" },
    { 0x9323, "threat_scan" },
    { 0x9324, "threat_stance" },
    { 0x9325, "threat_visible_time" },
    { 0x9326, "threatbiasgroupname" },
    { 0x9327, "threatcallouts" },
    { 0x9328, "threatcallouttracking" },
    { 0x9329, "threatdog" },
    { 0x932A, "threatent" },
    { 0x932B, "threatinfantry" },
    { 0x932C, "threatinfantry_docalloutlocation" },
    { 0x932D, "threatinfantryexposed" },
    { 0x932E, "threatinfantryrpg" },
    { 0x932F, "threatisviable" },
    { 0x9330, "threatnotificationoverlayflash" },
    { 0x9331, "threats" },
    { 0x9332, "threatsightdelay" },
    { 0x9333, "threattype" },
    { 0x9334, "threatwasalreadycalledout" },
    { 0x9335, "threecaptime" },
    { 0x9336, "threw_ninebang" },
    { 0x9337, "threwback" },
    { 0x9338, "throttle_input" },
    { 0x9339, "throwbackkillevent" },
    { 0x933A, "throwdownweapon" },
    { 0x933B, "throwgrenadeatplayerasap" },
    { 0x933C, "throwgrenadeatplayerasap_combat_utility" },
    { 0x933D, "throwgun" },
    { 0x933E, "throwinggrenade" },
    { 0x933F, "thrown_semtex_grenades" },
    { 0x9340, "thrusters_angle_current" },
    { 0x9341, "thrusters_angle_goal" },
    { 0x9342, "thrusters_fx_amount" },
    { 0x9343, "thunder" },
    { 0x9344, "ti_spawn" },
    { 0x9345, "tickingobject" },
    { 0x9346, "ticks" },
    { 0x9347, "tidal_wave_notetracks" },
    { 0x9348, "tigger_hurt_rotor" },
    { 0x9349, "tilt_boat" },
    { 0x934A, "time_accel" },
    { 0x934B, "time_and_distance_of_closest_approach" },
    { 0x934C, "time_array" },
    { 0x934D, "time_before_attack" },
    { 0x934E, "time_before_move" },
    { 0x934F, "time_between_attacks" },
    { 0x9350, "time_breaking" },
    { 0x9351, "time_constant" },
    { 0x9352, "time_display_array" },
    { 0x9353, "time_last_turret_accel" },
    { 0x9354, "time_of_hovertank_fire" },
    { 0x9355, "time_passed" },
    { 0x9356, "time_pitching_hard" },
    { 0x9357, "time_remaining" },
    { 0x9358, "time_spent_hiding" },
    { 0x9359, "time_turret_accel_started" },
    { 0x935A, "time_turret_accelerating" },
    { 0x935B, "time_turret_rotating" },
    { 0x935C, "time_turret_started_rotating" },
    { 0x935D, "timebetweenshots" },
    { 0x935E, "timebomb" },
    { 0x935F, "timebombparticle" },
    { 0x9360, "timed_charges_vo" },
    { 0x9361, "timed_out" },
    { 0x9362, "timednotify" },
    { 0x9363, "timehack" },
    { 0x9364, "timelimitclock" },
    { 0x9365, "timelimitclock_intermission" },
    { 0x9366, "timelimitoverride" },
    { 0x9367, "timelimitthread" },
    { 0x9368, "timeoflastdamage" },
    { 0x9369, "timeofmaincqbupdate" },
    { 0x936A, "timeofnextsound" },
    { 0x936B, "timeout" },
    { 0x936C, "timeout_and_flag" },
    { 0x936D, "timeout_reset" },
    { 0x936E, "timeoutent" },
    { 0x936F, "timeoutstarted" },
    { 0x9370, "timepaused" },
    { 0x9371, "timepercentagecutoff" },
    { 0x9372, "timeplayed" },
    { 0x9373, "timer" },
    { 0x9374, "timer_cancel" },
    { 0x9375, "timer_fail" },
    { 0x9376, "timer_number" },
    { 0x9377, "timer_run" },
    { 0x9378, "timername" },
    { 0x9379, "timeromnvars" },
    { 0x937A, "timerpausetime" },
    { 0x937B, "timerstopped" },
    { 0x937C, "timerstoppedforgamemode" },
    { 0x937D, "timescale" },
    { 0x937E, "timestartedtowait" },
    { 0x937F, "timetoadd" },
    { 0x9380, "timetodelete" },
    { 0x9381, "timeuntilroundend" },
    { 0x9382, "timeuntilspawn" },
    { 0x9383, "timeuntilwavespawn" },
    { 0x9384, "timing_offset_finale_cine_lighting" },
    { 0x9385, "tireskidprobability" },
    { 0x9386, "tispawndelay" },
    { 0x9387, "tispawnposition" },
    { 0x9388, "titan_camera_shake" },
    { 0x9389, "titan_death" },
    { 0x938A, "titan_engine" },
    { 0x938B, "titan_enter" },
    { 0x938C, "titan_fire_wait" },
    { 0x938D, "titan_footstep_front_left" },
    { 0x938E, "titan_footstep_front_right" },
    { 0x938F, "titan_footstep_rear_left" },
    { 0x9390, "titan_footstep_rear_right" },
    { 0x9391, "titan_gate_tread_fx" },
    { 0x9392, "titan_impact_fx_fl" },
    { 0x9393, "titan_impact_fx_fr" },
    { 0x9394, "titan_impact_fx_rl" },
    { 0x9395, "titan_impact_fx_rr" },
    { 0x9396, "titan_init" },
    { 0x9397, "titan_missile" },
    { 0x9398, "titan_take_damage_from_smaw" },
    { 0x9399, "titan_tank_tread" },
    { 0x939A, "titan_walker_explo" },
    { 0x939B, "titan_walker_explosions" },
    { 0x939C, "titan_walker_weapon_fire" },
    { 0x939D, "title" },
    { 0x939E, "title_line" },
    { 0x939F, "titleisstring" },
    { 0x93A0, "titlelabel" },
    { 0x93A1, "titlemap" },
    { 0x93A2, "titletext" },
    { 0x93A3, "tivalidationcheck" },
    { 0x93A4, "tmodel" },
    { 0x93A5, "tmp_subtitle" },
    { 0x93A6, "to_ball_pitch_idle" },
    { 0x93A7, "to_ball_pitch_moving" },
    { 0x93A8, "to_ball_pitch_start_move" },
    { 0x93A9, "to_ball_pitch_stop_move" },
    { 0x93AA, "to_ball_roll_idle" },
    { 0x93AB, "to_ball_roll_moving" },
    { 0x93AC, "to_ball_roll_start_move" },
    { 0x93AD, "to_ball_roll_stop_move" },
    { 0x93AE, "to_refugee_camp" },
    { 0x93AF, "to_school1" },
    { 0x93B0, "to_school2" },
    { 0x93B1, "to_school3" },
    { 0x93B2, "to_second_land_assist_idles" },
    { 0x93B3, "to_second_land_assist_idles_cormack" },
    { 0x93B4, "to_vehicle_off" },
    { 0x93B5, "to_vehicle_on" },
    { 0x93B6, "to_vehicle_shutdown" },
    { 0x93B7, "to_vehicle_startup" },
    { 0x93B8, "to_wheel_left_idle" },
    { 0x93B9, "to_wheel_left_moving" },
    { 0x93BA, "to_wheel_left_start_move" },
    { 0x93BB, "to_wheel_left_stop_move" },
    { 0x93BC, "to_wheel_right_idle" },
    { 0x93BD, "to_wheel_right_moving" },
    { 0x93BE, "to_wheel_right_start_move" },
    { 0x93BF, "to_wheel_right_stop_move" },
    { 0x93C0, "toggle" },
    { 0x93C1, "toggle_all_boats_off" },
    { 0x93C2, "toggle_all_boats_on" },
    { 0x93C3, "toggle_all_boats_on_trigger" },
    { 0x93C4, "toggle_axismode" },
    { 0x93C5, "toggle_battle_chatter" },
    { 0x93C6, "toggle_boat_visibility" },
    { 0x93C7, "toggle_boat_visibility_group" },
    { 0x93C8, "toggle_chase_cam" },
    { 0x93C9, "toggle_createfx_drawing" },
    { 0x93CA, "toggle_entity_selection" },
    { 0x93CB, "toggle_exo_ping" },
    { 0x93CC, "toggle_fov" },
    { 0x93CD, "toggle_grenade_range_settings" },
    { 0x93CE, "toggle_has_trackrounds" },
    { 0x93CF, "toggle_hide" },
    { 0x93D0, "toggle_hide_guy" },
    { 0x93D1, "toggle_lighting_spot01_lightning" },
    { 0x93D2, "toggle_lighting_spot01_on" },
    { 0x93D3, "toggle_lighting_spot01_on_checkpoint" },
    { 0x93D4, "toggle_localrot" },
    { 0x93D5, "toggle_mount_mag_trigger_off" },
    { 0x93D6, "toggle_mount_mag_trigger_on" },
    { 0x93D7, "toggle_off_real_mob" },
    { 0x93D8, "toggle_on_real_mob" },
    { 0x93D9, "toggle_register_kills_for_vehicle_occupants" },
    { 0x93DA, "toggle_school_exterior_light_off" },
    { 0x93DB, "toggle_school_exterior_light_on" },
    { 0x93DC, "toggle_snap2normal" },
    { 0x93DD, "toggle_snap90deg" },
    { 0x93DE, "toggle_tactical_picker" },
    { 0x93DF, "togglebreachslomo" },
    { 0x93E0, "tolerance" },
    { 0x93E1, "tonemapkey_call" },
    { 0x93E2, "tonemapkey_call_control_room" },
    { 0x93E3, "tonemapkey_control_room_volume" },
    { 0x93E4, "tonemapkey_cooling_towers_volume" },
    { 0x93E5, "too_close_distance" },
    { 0x93E6, "too_close_to_leader" },
    { 0x93E7, "toogle_burke_fall_light" },
    { 0x93E8, "tookweaponfrom" },
    { 0x93E9, "tool_hud" },
    { 0x93EA, "tool_hud_visible" },
    { 0x93EB, "tool_hudelems" },
    { 0x93EC, "top_guy_spawn" },
    { 0x93ED, "top_level_kva_guys" },
    { 0x93EE, "torch" },
    { 0x93EF, "torresblood" },
    { 0x93F0, "toss_security_drone" },
    { 0x93F1, "tostr" },
    { 0x93F2, "tostring" },
    { 0x93F3, "total" },
    { 0x93F4, "total_dist" },
    { 0x93F5, "total_time" },
    { 0x93F6, "totalallweaponvariants" },
    { 0x93F7, "totalchemcanhealth" },
    { 0x93F8, "totaldamage" },
    { 0x93F9, "totalfriends" },
    { 0x93FA, "totalheavyclasstime" },
    { 0x93FB, "totallifetime" },
    { 0x93FC, "totallightclasstime" },
    { 0x93FD, "totally_fake_drone_death" },
    { 0x93FE, "totalplayers" },
    { 0x93FF, "totalpossiblescore" },
    { 0x9400, "totalscore" },
    { 0x9401, "totalspawned" },
    { 0x9402, "totalspecialistclasstime" },
    { 0x9403, "totaltime" },
    { 0x9404, "touchdownevent" },
    { 0x9405, "touched" },
    { 0x9406, "touched_trigger_runs_func" },
    { 0x9407, "touching_border" },
    { 0x9408, "touching_trigger_ent" },
    { 0x9409, "touchingbadtrigger" },
    { 0x940A, "touchingplatformvalid" },
    { 0x940B, "touchingplayers" },
    { 0x940C, "touchingwatertriggers" },
    { 0x940D, "touchlist" },
    { 0x940E, "touchtest" },
    { 0x940F, "touchtriggers" },
    { 0x9410, "tour_ambient_00" },
    { 0x9411, "tour_ambient_01" },
    { 0x9412, "tour_ambient_02" },
    { 0x9413, "tour_ambient_choppers" },
    { 0x9414, "tour_ambient_drone_lifetime" },
    { 0x9415, "tour_ambient_people" },
    { 0x9416, "tour_augmented_reality" },
    { 0x9417, "tour_base_ambient_vehicle_01" },
    { 0x9418, "tour_base_ambient_vehicle_02" },
    { 0x9419, "tour_boost_jumper_lifetime" },
    { 0x941A, "tour_boost_jumpers_initial" },
    { 0x941B, "tour_boost_jumpers_overhead" },
    { 0x941C, "tour_brave_warrior_01" },
    { 0x941D, "tour_brave_warrior_03" },
    { 0x941E, "tour_cleanup_01" },
    { 0x941F, "tour_doors" },
    { 0x9420, "tour_drone_control" },
    { 0x9421, "tour_drone_interact_clear" },
    { 0x9422, "tour_drone_range_interact_manager" },
    { 0x9423, "tour_drone_range_target_lifetime" },
    { 0x9424, "tour_drone_range_targets" },
    { 0x9425, "tour_drone_range_timer" },
    { 0x9426, "tour_drone_range_use_triggers" },
    { 0x9427, "tour_drones_advanced_warfare" },
    { 0x9428, "tour_drones_fly_by" },
    { 0x9429, "tour_end" },
    { 0x942A, "tour_end_gate" },
    { 0x942B, "tour_exo_arm_repair_test_seq" },
    { 0x942C, "tour_exo_arm_repair_test_seq_internal" },
    { 0x942D, "tour_exo_begin" },
    { 0x942E, "tour_exo_boost" },
    { 0x942F, "tour_exo_boost_lifetime_ccw" },
    { 0x9430, "tour_exo_boost_lifetime_cw" },
    { 0x9431, "tour_exo_climb" },
    { 0x9432, "tour_exo_demo_gideon" },
    { 0x9433, "tour_exo_exit" },
    { 0x9434, "tour_exo_observe" },
    { 0x9435, "tour_exo_push" },
    { 0x9436, "tour_exo_push_motion_tracker" },
    { 0x9437, "tour_exo_repair_desk" },
    { 0x9438, "tour_exo_repair_player" },
    { 0x9439, "tour_exo_repair_tech_1" },
    { 0x943A, "tour_exo_repair_tech_1_branch" },
    { 0x943B, "tour_exo_repair_tech_2" },
    { 0x943C, "tour_exo_shield" },
    { 0x943D, "tour_exo_shield_model_swap" },
    { 0x943E, "tour_exo_shield_turret" },
    { 0x943F, "tour_exo_spar" },
    { 0x9440, "tour_fans" },
    { 0x9441, "tour_firing_range" },
    { 0x9442, "tour_giant_doors" },
    { 0x9443, "tour_gideon_movement_manager_exo_spar" },
    { 0x9444, "tour_glass_door_01" },
    { 0x9445, "tour_glass_door_02" },
    { 0x9446, "tour_glass_door_03" },
    { 0x9447, "tour_glass_door_04" },
    { 0x9448, "tour_glass_door_04_lighting" },
    { 0x9449, "tour_glass_door_05" },
    { 0x944A, "tour_grenade_range_drone_lifetime" },
    { 0x944B, "tour_grenade_range_drone_lifetime_minigame" },
    { 0x944C, "tour_grenade_range_drone_lifetime_tutorial" },
    { 0x944D, "tour_grenade_range_drone_spawn_with_spawner" },
    { 0x944E, "tour_grenade_range_gideon" },
    { 0x944F, "tour_grenade_range_interact_manager" },
    { 0x9450, "tour_grenade_range_minigame_drone_spawn_with_spawner" },
    { 0x9451, "tour_grenade_range_minigame_sequence" },
    { 0x9452, "tour_grenade_range_refills_highlight" },
    { 0x9453, "tour_grenade_range_score_feedback" },
    { 0x9454, "tour_grenade_range_score_manager" },
    { 0x9455, "tour_grenade_range_score_reset" },
    { 0x9456, "tour_grenade_range_screen_info_update" },
    { 0x9457, "tour_grenade_range_screen_toggle" },
    { 0x9458, "tour_grenade_range_tutorial_drone_spawn_with_spawner" },
    { 0x9459, "tour_grenade_range_use_triggers" },
    { 0x945A, "tour_hangar_ambient_people" },
    { 0x945B, "tour_hangar_door_01" },
    { 0x945C, "tour_hangar_drone_lifetime" },
    { 0x945D, "tour_hangar_drones" },
    { 0x945E, "tour_jeep_startup" },
    { 0x945F, "tour_jeep_tread" },
    { 0x9460, "tour_jets" },
    { 0x9461, "tour_lander_01" },
    { 0x9462, "tour_littlebird_ambient" },
    { 0x9463, "tour_littlebird_lander" },
    { 0x9464, "tour_military_ambient_people" },
    { 0x9465, "tour_range_door_01" },
    { 0x9466, "tour_range_door_02" },
    { 0x9467, "tour_ready_room_techs" },
    { 0x9468, "tour_ride" },
    { 0x9469, "tour_ride_begin" },
    { 0x946A, "tour_ride_gideon" },
    { 0x946B, "tour_ride_look_anims" },
    { 0x946C, "tour_ride_passengers" },
    { 0x946D, "tour_ride_player" },
    { 0x946E, "tour_shooting_range" },
    { 0x946F, "tour_shooting_range_gideon" },
    { 0x9470, "tour_shooting_range_ilona" },
    { 0x9471, "tour_shooting_range_interact_manager" },
    { 0x9472, "tour_shooting_range_screen_info_update_handler" },
    { 0x9473, "tour_shooting_range_screen_toggle" },
    { 0x9474, "tour_shooting_range_sequence" },
    { 0x9475, "tour_shooting_range_use_triggers" },
    { 0x9476, "tour_solid_door_01" },
    { 0x9477, "tour_solid_door_02" },
    { 0x9478, "tour_spawn_vtol" },
    { 0x9479, "tour_titan_01" },
    { 0x947A, "tour_titan_02" },
    { 0x947B, "tour_variable_grenade_auto_fill" },
    { 0x947C, "tour_variable_grenade_initial_acquisition" },
    { 0x947D, "tour_variable_grenade_refill_manager" },
    { 0x947E, "tour_windsock" },
    { 0x947F, "tour_yellow_door_01" },
    { 0x9480, "tour_yellow_door_02" },
    { 0x9481, "tour_yellow_door_03" },
    { 0x9482, "tower_collapse_dialog" },
    { 0x9483, "tower_collapse_knockback_disable_sonar" },
    { 0x9484, "tower_collapse_player_knockback" },
    { 0x9485, "tower_collapse_player_stumble" },
    { 0x9486, "tower_collapse_prep" },
    { 0x9487, "tower_collapse_start" },
    { 0x9488, "tower_combat_wave3" },
    { 0x9489, "tower_combat_wave4" },
    { 0x948A, "tower_vo" },
    { 0x948B, "toy_chicken_common" },
    { 0x948C, "toy_model" },
    { 0x948D, "tprintln" },
    { 0x948E, "trace" },
    { 0x948F, "trace_distance" },
    { 0x9490, "trace_end_position" },
    { 0x9491, "trace_fx" },
    { 0x9492, "trace_part_for_efx" },
    { 0x9493, "trace_part_for_efx_cancel" },
    { 0x9494, "trace_to_enemy" },
    { 0x9495, "trace2d" },
    { 0x9496, "tracecollisionwarn" },
    { 0x9497, "tracedonerecently" },
    { 0x9498, "tracefx" },
    { 0x9499, "tracefx_on_tag" },
    { 0x949A, "tracelocation" },
    { 0x949B, "traceshow" },
    { 0x949C, "tracestart" },
    { 0x949D, "tracevalidation" },
    { 0x949E, "track" },
    { 0x949F, "track_bone_origins" },
    { 0x94A0, "track_bridge_drone_deaths" },
    { 0x94A1, "track_concussion_grenade" },
    { 0x94A2, "track_damage_info" },
    { 0x94A3, "track_end" },
    { 0x94A4, "track_entered_vehicle" },
    { 0x94A5, "track_health_damage_function" },
    { 0x94A6, "track_inner" },
    { 0x94A7, "track_irons_begin" },
    { 0x94A8, "track_irons_main" },
    { 0x94A9, "track_irons_start" },
    { 0x94AA, "track_kills_over_time" },
    { 0x94AB, "track_loud_enough_achievement" },
    { 0x94AC, "track_outer" },
    { 0x94AD, "track_player" },
    { 0x94AE, "track_player_height" },
    { 0x94AF, "track_player_movement" },
    { 0x94B0, "track_player_velocity" },
    { 0x94B1, "track_reinforcement_location" },
    { 0x94B2, "track_semtex_grenade" },
    { 0x94B3, "track_smaw" },
    { 0x94B4, "track_start" },
    { 0x94B5, "trackailifespawn" },
    { 0x94B6, "trackattackerleaderboarddeathstats" },
    { 0x94B7, "trackcarepackages" },
    { 0x94B8, "trackcarrier" },
    { 0x94B9, "tracked" },
    { 0x94BA, "tracked_ent" },
    { 0x94BB, "tracked_ents" },
    { 0x94BC, "trackedbyplayer" },
    { 0x94BD, "trackedplayer" },
    { 0x94BE, "trackent" },
    { 0x94BF, "trackfreeplayedtime" },
    { 0x94C0, "trackgrenades" },
    { 0x94C1, "trackhostmigrationend" },
    { 0x94C2, "tracking" },
    { 0x94C3, "tracking_device" },
    { 0x94C4, "tracking_device_waits" },
    { 0x94C5, "tracking_grenade_beep" },
    { 0x94C6, "tracking_grenade_detonate" },
    { 0x94C7, "tracking_grenade_dud" },
    { 0x94C8, "tracking_grenade_get_target" },
    { 0x94C9, "tracking_grenade_handle_autosave" },
    { 0x94CA, "tracking_grenade_handle_damage" },
    { 0x94CB, "tracking_grenade_hover" },
    { 0x94CC, "tracking_grenade_jump" },
    { 0x94CD, "tracking_grenade_pickup" },
    { 0x94CE, "tracking_grenade_scare_enemies" },
    { 0x94CF, "tracking_grenade_strike" },
    { 0x94D0, "tracking_grenade_think" },
    { 0x94D1, "tracking_grenade_thrust_effect" },
    { 0x94D2, "tracking_init" },
    { 0x94D3, "trackingdrone" },
    { 0x94D4, "trackingdrone_changeowner" },
    { 0x94D5, "trackingdrone_enemy_lightfx" },
    { 0x94D6, "trackingdrone_followtarget" },
    { 0x94D7, "trackingdrone_friendly_lightfx" },
    { 0x94D8, "trackingdrone_highlighttarget" },
    { 0x94D9, "trackingdrone_leave" },
    { 0x94DA, "trackingdrone_lightfx" },
    { 0x94DB, "trackingdrone_movetoplayer" },
    { 0x94DC, "trackingdrone_stopmovement" },
    { 0x94DD, "trackingdrone_stunbegin" },
    { 0x94DE, "trackingdrone_stunend" },
    { 0x94DF, "trackingdrone_stunned" },
    { 0x94E0, "trackingdrone_watchdeath" },
    { 0x94E1, "trackingdrone_watchdisable" },
    { 0x94E2, "trackingdrone_watchforgoal" },
    { 0x94E3, "trackingdrone_watchhostmigration" },
    { 0x94E4, "trackingdrone_watchownerdeath" },
    { 0x94E5, "trackingdrone_watchownerloss" },
    { 0x94E6, "trackingdrone_watchroundend" },
    { 0x94E7, "trackingdrone_watchtargetdisconnect" },
    { 0x94E8, "trackingdrone_watchtimeout" },
    { 0x94E9, "trackingdronearray" },
    { 0x94EA, "trackingdronedebugposition" },
    { 0x94EB, "trackingdronedebugpositionforward" },
    { 0x94EC, "trackingdronedebugpositionheight" },
    { 0x94ED, "trackingdronedestroyed" },
    { 0x94EE, "trackingdroneexplode" },
    { 0x94EF, "trackingdroneinit" },
    { 0x94F0, "trackingdronemaxperplayer" },
    { 0x94F1, "trackingdrones" },
    { 0x94F2, "trackingdronesettings" },
    { 0x94F3, "trackingdronestartangles" },
    { 0x94F4, "trackingdronestartposition" },
    { 0x94F5, "trackingdronetimeout" },
    { 0x94F6, "trackingweapondeaths" },
    { 0x94F7, "trackingweaponheadshots" },
    { 0x94F8, "trackingweaponhipfirekills" },
    { 0x94F9, "trackingweaponhits" },
    { 0x94FA, "trackingweaponkills" },
    { 0x94FB, "trackingweaponname" },
    { 0x94FC, "trackingweaponshots" },
    { 0x94FD, "trackingweaponusetime" },
    { 0x94FE, "trackintelkills" },
    { 0x94FF, "trackkillordelete" },
    { 0x9500, "tracklaststandchanges" },
    { 0x9501, "trackleaderboarddeathstats" },
    { 0x9502, "trackloop" },
    { 0x9503, "trackloop_anglesfornoshootpos" },
    { 0x9504, "trackloop_clampangles" },
    { 0x9505, "trackloop_cqbshootpos" },
    { 0x9506, "trackloop_getdesiredangles" },
    { 0x9507, "trackloop_setanimweights" },
    { 0x9508, "trackmissiles" },
    { 0x9509, "tracknoneditfx" },
    { 0x950A, "trackobject" },
    { 0x950B, "trackplayedtime" },
    { 0x950C, "trackriotshield" },
    { 0x950D, "trackrocket" },
    { 0x950E, "trackrounds" },
    { 0x950F, "trackrounds_death" },
    { 0x9510, "trackrounds_mark_till_death" },
    { 0x9511, "trackrounds_think" },
    { 0x9512, "trackshootentorpos" },
    { 0x9513, "trackstate" },
    { 0x9514, "trackteamchanges" },
    { 0x9515, "traffic_anim_bus_1" },
    { 0x9516, "traffic_burke_jump_bus_2" },
    { 0x9517, "traffic_burke_jump_bus_3" },
    { 0x9518, "traffic_burke_jump_bus_4" },
    { 0x9519, "traffic_burke_jump_bus_5" },
    { 0x951A, "traffic_burke_jump_settings" },
    { 0x951B, "traffic_burke_miss_failsafe" },
    { 0x951C, "traffic_burke_recover_failed_jump" },
    { 0x951D, "traffic_bus_3_flag_check" },
    { 0x951E, "traffic_bus_start_check_old" },
    { 0x951F, "traffic_camera_shake_after_middle_td" },
    { 0x9520, "traffic_camera_shake_before_middle_td" },
    { 0x9521, "traffic_cars" },
    { 0x9522, "traffic_cars_scriptmodel_only_count" },
    { 0x9523, "traffic_change_lane" },
    { 0x9524, "traffic_change_lane_speed" },
    { 0x9525, "traffic_collision_fx_func" },
    { 0x9526, "traffic_collision_hit_func" },
    { 0x9527, "traffic_crashed_vehicles" },
    { 0x9528, "traffic_damage_part_watcher" },
    { 0x9529, "traffic_drive_vehicle" },
    { 0x952A, "traffic_follower" },
    { 0x952B, "traffic_force_script_models_only" },
    { 0x952C, "traffic_fx_init" },
    { 0x952D, "traffic_handle_messages" },
    { 0x952E, "traffic_head_veh" },
    { 0x952F, "traffic_helicopter" },
    { 0x9530, "traffic_helicopter_magic_bullet_fire" },
    { 0x9531, "traffic_init" },
    { 0x9532, "traffic_lanes" },
    { 0x9533, "traffic_leader" },
    { 0x9534, "traffic_leader_pending" },
    { 0x9535, "traffic_leader_pending_check" },
    { 0x9536, "traffic_ledge_burke_loop_wait" },
    { 0x9537, "traffic_ledge_jump_trigger_use" },
    { 0x9538, "traffic_link_luggage" },
    { 0x9539, "traffic_locked" },
    { 0x953A, "traffic_manager" },
    { 0x953B, "traffic_old_speed" },
    { 0x953C, "traffic_path_all_cars_helper" },
    { 0x953D, "traffic_path_all_cars_set_command_single_lane" },
    { 0x953E, "traffic_path_all_cars_set_force_stop" },
    { 0x953F, "traffic_path_all_cars_set_script_brush" },
    { 0x9540, "traffic_path_head_car_random_stops" },
    { 0x9541, "traffic_path_head_car_set_force_script_model" },
    { 0x9542, "traffic_path_head_car_set_force_stop" },
    { 0x9543, "traffic_path_head_car_traffic_jam" },
    { 0x9544, "traffic_path_head_car_traffic_jam_end_thread" },
    { 0x9545, "traffic_path_remove_cars_at_node" },
    { 0x9546, "traffic_path_set_cars_at_node_ai_path_blocker" },
    { 0x9547, "traffic_player_hostage_truck_jump_passed" },
    { 0x9548, "traffic_pre_merge_follower" },
    { 0x9549, "traffic_rooftop_traverse" },
    { 0x954A, "traffic_set_traffic_tuning" },
    { 0x954B, "traffic_set_traffic_tuning_lagos_highway" },
    { 0x954C, "traffic_spawn_mode" },
    { 0x954D, "traffic_spawner" },
    { 0x954E, "traffic_spawners" },
    { 0x954F, "traffic_speed" },
    { 0x9550, "traffic_speed_override" },
    { 0x9551, "traffic_speed_status" },
    { 0x9552, "traffic_speed_status_prev" },
    { 0x9553, "traffic_start_camera_shake" },
    { 0x9554, "traffic_stop_waittime" },
    { 0x9555, "traffic_suv_group_a" },
    { 0x9556, "traffic_suv_group_b" },
    { 0x9557, "traffic_suv_group_c" },
    { 0x9558, "traffic_suv_group_d" },
    { 0x9559, "traffic_suv_group_e" },
    { 0x955A, "traffic_suv_takedown" },
    { 0x955B, "traffic_tail" },
    { 0x955C, "traffic_takedown" },
    { 0x955D, "traffic_traverse_fail_check" },
    { 0x955E, "traffic_traverse_fence_rip" },
    { 0x955F, "traffic_traverse_final_takedown_burke_start" },
    { 0x9560, "traffic_traverse_final_takedown_start_player_input" },
    { 0x9561, "traffic_traverse_final_takedown_start_player_validation" },
    { 0x9562, "traffic_traverse_final_takedown_truck_start" },
    { 0x9563, "traffic_traverse_ledge_player_input" },
    { 0x9564, "traffic_traverse_ledge_player_validation" },
    { 0x9565, "traffic_traverse_start" },
    { 0x9566, "traffic_traverse_start_player_input" },
    { 0x9567, "traffic_traverse_start_player_validation" },
    { 0x9568, "traffic_tune_extreme_near_car_dist" },
    { 0x9569, "traffic_tune_extreme_near_car_dist_sq" },
    { 0x956A, "traffic_tune_fill_spawn_dist_between_cars" },
    { 0x956B, "traffic_tune_fill_spawn_dist_between_cars_sq" },
    { 0x956C, "traffic_tune_follow_speed_scale" },
    { 0x956D, "traffic_tune_lane_change_angle" },
    { 0x956E, "traffic_tune_lane_change_cosangle" },
    { 0x956F, "traffic_tune_min_follow_dist" },
    { 0x9570, "traffic_tune_min_follow_dist_sq" },
    { 0x9571, "traffic_tune_min_speedup_dist" },
    { 0x9572, "traffic_tune_min_speedup_dist_sq" },
    { 0x9573, "traffic_tune_min_stop_dist" },
    { 0x9574, "traffic_tune_min_stop_dist_sq" },
    { 0x9575, "traffic_tune_no_spawn" },
    { 0x9576, "traffic_tune_single_spawn_dist_between_cars" },
    { 0x9577, "traffic_tune_single_spawn_dist_between_cars_sq" },
    { 0x9578, "traffic_tune_speedup_speed_scale" },
    { 0x9579, "traffic_tune_start_spawn_rand_chance" },
    { 0x957A, "traffic_type_swap" },
    { 0x957B, "traffic_vehicle_lights_off" },
    { 0x957C, "traffic_vehicle_lights_on" },
    { 0x957D, "traffic_vehicle_start_check" },
    { 0x957E, "trailing_jets_move_up_on_airbrake" },
    { 0x957F, "train_bridge_light_on" },
    { 0x9580, "train_gopath" },
    { 0x9581, "train_lighting" },
    { 0x9582, "train_radiosity" },
    { 0x9583, "train_rumble" },
    { 0x9584, "train_scare" },
    { 0x9585, "train_spotlight_lerp" },
    { 0x9586, "training_01_end_driver_gear_shift" },
    { 0x9587, "training_01_end_driver_seat_movement" },
    { 0x9588, "training_01_end_gideon_enter_jeep" },
    { 0x9589, "training_01_end_gideon_grabs_arm" },
    { 0x958A, "training_01_end_gideon_gun_away" },
    { 0x958B, "training_01_end_gideon_helps_up_plr" },
    { 0x958C, "training_01_end_gideon_idles" },
    { 0x958D, "training_01_end_gideon_mask" },
    { 0x958E, "training_01_end_gideon_pulls_gun" },
    { 0x958F, "training_01_end_gideon_punch" },
    { 0x9590, "training_01_end_gideon_shoots_potus" },
    { 0x9591, "training_01_end_gideon_to_player" },
    { 0x9592, "training_01_end_gideon_walk" },
    { 0x9593, "training_01_end_gideon_walks_away" },
    { 0x9594, "training_01_end_irons_enter_jeep" },
    { 0x9595, "training_01_end_irons_exit_jeep" },
    { 0x9596, "training_01_end_irons_hand_on_shoulder" },
    { 0x9597, "training_01_end_irons_walk_away" },
    { 0x9598, "training_01_end_player_arm_malfunction" },
    { 0x9599, "training_01_end_player_arm_up" },
    { 0x959A, "training_01_end_player_enters_jeep" },
    { 0x959B, "training_01_end_player_helped_up" },
    { 0x959C, "training_01_end_player_moves_to_seat" },
    { 0x959D, "training_01_end_player_punched" },
    { 0x959E, "training_01_end_player_sits" },
    { 0x959F, "training_01_end_potus_gets_up" },
    { 0x95A0, "training_01_end_potus_shot" },
    { 0x95A1, "training_01_end_potus_threatened" },
    { 0x95A2, "training_2_begin" },
    { 0x95A3, "training_2_end" },
    { 0x95A4, "training_2_golf_course" },
    { 0x95A5, "training_2_irons_ending" },
    { 0x95A6, "training_2_lodge_begin" },
    { 0x95A7, "training_2_lodge_breach" },
    { 0x95A8, "training_2_lodge_exit" },
    { 0x95A9, "training_begin" },
    { 0x95AA, "training_door_cover_cloak_think" },
    { 0x95AB, "training_end" },
    { 0x95AC, "training_escape_gideon_punch" },
    { 0x95AD, "training_escape_vehicle_1_fx" },
    { 0x95AE, "training_escape_vehicle_2_fx" },
    { 0x95AF, "training_golf_course" },
    { 0x95B0, "training_lodge_begin" },
    { 0x95B1, "training_lodge_breach" },
    { 0x95B2, "training_lodge_exit" },
    { 0x95B3, "training_prone_hint_monitor" },
    { 0x95B4, "training_prone_hint_text" },
    { 0x95B5, "training_reset_stealth_settings" },
    { 0x95B6, "training_s1_alert" },
    { 0x95B7, "training_s1_alert_check" },
    { 0x95B8, "training_s1_alert_drones" },
    { 0x95B9, "training_s1_allies_advance" },
    { 0x95BA, "training_s1_allies_setup" },
    { 0x95BB, "training_s1_ambush_vehicles_think" },
    { 0x95BC, "training_s1_anim_gun_examine" },
    { 0x95BD, "training_s1_bathroom_breach_door" },
    { 0x95BE, "training_s1_bathroom_door_breach_anim" },
    { 0x95BF, "training_s1_bathroom_enemy_dialog" },
    { 0x95C0, "training_s1_bathroom_enemy_flag_death" },
    { 0x95C1, "training_s1_bathroom_enemy_monitor_death" },
    { 0x95C2, "training_s1_bathroom_enemy_think" },
    { 0x95C3, "training_s1_bathroom_force_death" },
    { 0x95C4, "training_s1_bedroom_spawners_think" },
    { 0x95C5, "training_s1_breach_encounter" },
    { 0x95C6, "training_s1_breach_enemy_death_check" },
    { 0x95C7, "training_s1_breach_enemy_monitor_death" },
    { 0x95C8, "training_s1_breach_enemy_stop_death_check" },
    { 0x95C9, "training_s1_breach_enemy_think" },
    { 0x95CA, "training_s1_breach_gun_up" },
    { 0x95CB, "training_s1_breach_kva_think" },
    { 0x95CC, "training_s1_breach_save" },
    { 0x95CD, "training_s1_breach_slomo_end" },
    { 0x95CE, "training_s1_breach_slowmo_start" },
    { 0x95CF, "training_s1_breack_tv_screen" },
    { 0x95D0, "training_s1_check_snipers" },
    { 0x95D1, "training_s1_cleanup" },
    { 0x95D2, "training_s1_clear_bedrooms" },
    { 0x95D3, "training_s1_door_breach_anim" },
    { 0x95D4, "training_s1_door_cover" },
    { 0x95D5, "training_s1_drone_ambush_scene" },
    { 0x95D6, "training_s1_drone_attack" },
    { 0x95D7, "training_s1_drone_attack_think" },
    { 0x95D8, "training_s1_drone_blinds_destroy_think" },
    { 0x95D9, "training_s1_drone_search" },
    { 0x95DA, "training_s1_end_breach_logic" },
    { 0x95DB, "training_s1_end_fov_end" },
    { 0x95DC, "training_s1_end_fov_start" },
    { 0x95DD, "training_s1_ending" },
    { 0x95DE, "training_s1_enemies_ambush_think" },
    { 0x95DF, "training_s1_enemies_living_room_think" },
    { 0x95E0, "training_s1_escape_vehicle" },
    { 0x95E1, "training_s1_escape_vehicle_driver" },
    { 0x95E2, "training_s1_escape_vehicle_think" },
    { 0x95E3, "training_s1_exo_breach_monitor_enemy_group_death" },
    { 0x95E4, "training_s1_flash_death_check" },
    { 0x95E5, "training_s1_flash_door" },
    { 0x95E6, "training_s1_flash_enemies_think" },
    { 0x95E7, "training_s1_flash_monitor" },
    { 0x95E8, "training_s1_golf_course_alert" },
    { 0x95E9, "training_s1_golf_course_custom_stealth" },
    { 0x95EA, "training_s1_golf_course_encounter" },
    { 0x95EB, "training_s1_golf_course_encounter_track_deaths" },
    { 0x95EC, "training_s1_golf_course_vehicles" },
    { 0x95ED, "training_s1_guard_house_doors" },
    { 0x95EE, "training_s1_handle_tour_cart" },
    { 0x95EF, "training_s1_head_shot1" },
    { 0x95F0, "training_s1_head_shot2" },
    { 0x95F1, "training_s1_hide_from_patrols" },
    { 0x95F2, "training_s1_intro_gun_up" },
    { 0x95F3, "training_s1_joker_move" },
    { 0x95F4, "training_s1_joker_mute_breach_start" },
    { 0x95F5, "training_s1_kill_surprise_enemy" },
    { 0x95F6, "training_s1_kill_threat_enemies" },
    { 0x95F7, "training_s1_kva_ambush1_think" },
    { 0x95F8, "training_s1_kva_ambush2_think" },
    { 0x95F9, "training_s1_kva_dead" },
    { 0x95FA, "training_s1_kva_shot" },
    { 0x95FB, "training_s1_living_room_check" },
    { 0x95FC, "training_s1_living_room_scene" },
    { 0x95FD, "training_s1_living_room_scene_joker_open_door" },
    { 0x95FE, "training_s1_living_room_timer" },
    { 0x95FF, "training_s1_livingroom_ambush" },
    { 0x9600, "training_s1_monitor_surprise_enemy_death" },
    { 0x9601, "training_s1_opening" },
    { 0x9602, "training_s1_opening_guy_think" },
    { 0x9603, "training_s1_patio_door_breach" },
    { 0x9604, "training_s1_patio_door_breach_monitor" },
    { 0x9605, "training_s1_patio_door_clip" },
    { 0x9606, "training_s1_patio_doors" },
    { 0x9607, "training_s1_patio_enemies" },
    { 0x9608, "training_s1_patio_enemies_alert" },
    { 0x9609, "training_s1_patio_enemies_alert_check" },
    { 0x960A, "training_s1_patio_enemies_clear" },
    { 0x960B, "training_s1_patio_enemies_think" },
    { 0x960C, "training_s1_patio_joker_loc_check" },
    { 0x960D, "training_s1_patio_spawn_reinforcements" },
    { 0x960E, "training_s1_player_breach" },
    { 0x960F, "training_s1_pool_house_doors" },
    { 0x9610, "training_s1_popping_smoke" },
    { 0x9611, "training_s1_prep_breach_room" },
    { 0x9612, "training_s1_prepare_to_breach" },
    { 0x9613, "training_s1_president_blood" },
    { 0x9614, "training_s1_president_breach_monitor_death" },
    { 0x9615, "training_s1_president_breach_setup" },
    { 0x9616, "training_s1_president_dead" },
    { 0x9617, "training_s1_president_setup" },
    { 0x9618, "training_s1_president_shot" },
    { 0x9619, "training_s1_refill_threat_grenades" },
    { 0x961A, "training_s1_remove_player_weapons" },
    { 0x961B, "training_s1_runner_enemy_found_corpse" },
    { 0x961C, "training_s1_runner_enemy_think" },
    { 0x961D, "training_s1_runner_enemy_think_cleanup" },
    { 0x961E, "training_s1_search_drones_cleanup" },
    { 0x961F, "training_s1_search_drones_damage_check" },
    { 0x9620, "training_s1_search_drones_death_check" },
    { 0x9621, "training_s1_search_drones_play_ainm" },
    { 0x9622, "training_s1_set_sqaud_cqb_disable" },
    { 0x9623, "training_s1_set_sqaud_cqb_enable" },
    { 0x9624, "training_s1_set_squad_active_and_target" },
    { 0x9625, "training_s1_set_squad_passive_and_ignore" },
    { 0x9626, "training_s1_set_up_search_drones" },
    { 0x9627, "training_s1_setup_breach_marker" },
    { 0x9628, "training_s1_setup_cart" },
    { 0x9629, "training_s1_setup_driver" },
    { 0x962A, "training_s1_setup_gideon" },
    { 0x962B, "training_s1_setup_irons" },
    { 0x962C, "training_s1_setup_president" },
    { 0x962D, "training_s1_shoot_monitor" },
    { 0x962E, "training_s1_show_threat_text" },
    { 0x962F, "training_s1_show_threat_text_ender" },
    { 0x9630, "training_s1_sniper_enemies_think" },
    { 0x9631, "training_s1_snipers" },
    { 0x9632, "training_s1_squad_allow_run" },
    { 0x9633, "training_s1_start_stealth_watch" },
    { 0x9634, "training_s1_starting_enemies" },
    { 0x9635, "training_s1_starting_enemies_alerted" },
    { 0x9636, "training_s1_starting_enemies_charge" },
    { 0x9637, "training_s1_starting_enemies_think" },
    { 0x9638, "training_s1_startpoint_guy_think" },
    { 0x9639, "training_s1_surprise_enemy_alert" },
    { 0x963A, "training_s1_surprise_enemy_go" },
    { 0x963B, "training_s1_surprise_enemy_think" },
    { 0x963C, "training_s1_terrace_enemies_think" },
    { 0x963D, "training_s1_terrace_vehicles" },
    { 0x963E, "training_s1_terrace_vehicles_cleanup" },
    { 0x963F, "training_s1_terrace_vehicles_riders_cleanup" },
    { 0x9640, "training_s1_terrace_vehicles_riders_think" },
    { 0x9641, "training_s1_terrace_vehicles_think" },
    { 0x9642, "training_s1_threat_death_check" },
    { 0x9643, "training_s1_threat_door" },
    { 0x9644, "training_s1_threat_enemies" },
    { 0x9645, "training_s1_threat_enemies_react" },
    { 0x9646, "training_s1_tour_jeep_board_fail" },
    { 0x9647, "training_s1_tour_jeep_board_warn" },
    { 0x9648, "training_s1_unload1_think" },
    { 0x9649, "training_s1_windy_trees" },
    { 0x964A, "training_s1_windy_trees_think" },
    { 0x964B, "training_s2_allies_setup" },
    { 0x964C, "training_s2_ambush_vehicles_think" },
    { 0x964D, "training_s2_bedroom_1_door_scene" },
    { 0x964E, "training_s2_bedroom_2_scene" },
    { 0x964F, "training_s2_breach_encounter" },
    { 0x9650, "training_s2_breach_enemies_monitor" },
    { 0x9651, "training_s2_breach_enemy_death_check" },
    { 0x9652, "training_s2_breach_enemy_monitor_death" },
    { 0x9653, "training_s2_breach_enemy_stop_death_check" },
    { 0x9654, "training_s2_breach_enemy_think" },
    { 0x9655, "training_s2_breach_kva_think" },
    { 0x9656, "training_s2_breach_president_setup" },
    { 0x9657, "training_s2_breach_slowmo_start" },
    { 0x9658, "training_s2_door_breach_anim" },
    { 0x9659, "training_s2_drone_ambush_attack" },
    { 0x965A, "training_s2_drone_ambush_attack_think" },
    { 0x965B, "training_s2_drone_attack" },
    { 0x965C, "training_s2_drone_attack_death" },
    { 0x965D, "training_s2_drone_attack_think" },
    { 0x965E, "training_s2_drone_attack_vehicles_think" },
    { 0x965F, "training_s2_drone_blinds_destroy_think" },
    { 0x9660, "training_s2_drone_damaged" },
    { 0x9661, "training_s2_drone_end_think" },
    { 0x9662, "training_s2_drone_manager" },
    { 0x9663, "training_s2_ending" },
    { 0x9664, "training_s2_enemies_ambush_think" },
    { 0x9665, "training_s2_enemies_hall_think" },
    { 0x9666, "training_s2_enemies_living_room_think" },
    { 0x9667, "training_s2_enemies_patio_think" },
    { 0x9668, "training_s2_enemies_patrol_think" },
    { 0x9669, "training_s2_enemies_patrol_think_alerted" },
    { 0x966A, "training_s2_enemies_start_think" },
    { 0x966B, "training_s2_enemies_start_think_alerted" },
    { 0x966C, "training_s2_enemies_start2_think" },
    { 0x966D, "training_s2_enemies_start2_think_alerted" },
    { 0x966E, "training_s2_enemy_notify" },
    { 0x966F, "training_s2_escape_vehicle" },
    { 0x9670, "training_s2_exo_breach_knife" },
    { 0x9671, "training_s2_flash_monitor" },
    { 0x9672, "training_s2_gideon_mitchell_over_nag" },
    { 0x9673, "training_s2_golf_course_hide" },
    { 0x9674, "training_s2_golf_course_vehicles" },
    { 0x9675, "training_s2_guard_house_doors" },
    { 0x9676, "training_s2_helicopter_gideon" },
    { 0x9677, "training_s2_helicopter_irons" },
    { 0x9678, "training_s2_helicopter_player" },
    { 0x9679, "training_s2_kill_threat_enemies" },
    { 0x967A, "training_s2_kva_ambush1_think" },
    { 0x967B, "training_s2_kva_dead" },
    { 0x967C, "training_s2_kva_shot" },
    { 0x967D, "training_s2_living_room_check" },
    { 0x967E, "training_s2_living_room_scene" },
    { 0x967F, "training_s2_living_room_timer" },
    { 0x9680, "training_s2_open_bedroom_door_2" },
    { 0x9681, "training_s2_open_patio_door" },
    { 0x9682, "training_s2_opening" },
    { 0x9683, "training_s2_opening_guy_think" },
    { 0x9684, "training_s2_patio_combat" },
    { 0x9685, "training_s2_patio_doors" },
    { 0x9686, "training_s2_patio_enemies_alert_check" },
    { 0x9687, "training_s2_patio_enemies_alert_think" },
    { 0x9688, "training_s2_patio_enemies_damaged" },
    { 0x9689, "training_s2_player_breach" },
    { 0x968A, "training_s2_player_drone" },
    { 0x968B, "training_s2_player_drone_control" },
    { 0x968C, "training_s2_player_drone_delete" },
    { 0x968D, "training_s2_player_sniper" },
    { 0x968E, "training_s2_prep_breach_room" },
    { 0x968F, "training_s2_president_breach_monitor_death" },
    { 0x9690, "training_s2_president_breach_ready" },
    { 0x9691, "training_s2_president_dead" },
    { 0x9692, "training_s2_president_setup" },
    { 0x9693, "training_s2_president_shot" },
    { 0x9694, "training_s2_scriptables_reset" },
    { 0x9695, "training_s2_set_squad_active_and_target" },
    { 0x9696, "training_s2_set_squad_passive_and_ignore" },
    { 0x9697, "training_s2_setup_president" },
    { 0x9698, "training_s2_shield_tutorial" },
    { 0x9699, "training_s2_show_drone_text" },
    { 0x969A, "training_s2_spawn_search_vehicle" },
    { 0x969B, "training_s2_squad_allow_run" },
    { 0x969C, "training_s2_start_set_up_player" },
    { 0x969D, "training_s2_start_squad_attack" },
    { 0x969E, "training_s2_starting_enemies" },
    { 0x969F, "training_s2_starting_enemy_charge" },
    { 0x96A0, "training_s2_startpoint_guy_think" },
    { 0x96A1, "training_s2_threat_death_check" },
    { 0x96A2, "training_s2_threat_door" },
    { 0x96A3, "training_s2_unload_drone_attack_think" },
    { 0x96A4, "training_s2_unload1_think" },
    { 0x96A5, "training_s2_wait_for_bedrooms_dead" },
    { 0x96A6, "training_s2_wait_for_hallway_dead" },
    { 0x96A7, "training_s2_wait_for_living_room_dead" },
    { 0x96A8, "training_s2_wait_for_suprise_dead" },
    { 0x96A9, "training_set_up_player" },
    { 0x96AA, "training_stealth_spotted" },
    { 0x96AB, "training_surprise_enemy_move_to_patio" },
    { 0x96AC, "training_surprise_enemy_think" },
    { 0x96AD, "training_unlock_doors" },
    { 0x96AE, "trajectory_kill" },
    { 0x96AF, "tram_animate" },
    { 0x96B0, "tram_hide_icon" },
    { 0x96B1, "tram_init" },
    { 0x96B2, "tram_killstreak_cancel_watch" },
    { 0x96B3, "tram_killstreak_exit_watch" },
    { 0x96B4, "tram_killstreak_init" },
    { 0x96B5, "tram_killstreak_match_ended" },
    { 0x96B6, "tram_killstreak_move" },
    { 0x96B7, "tram_killstreak_team_change_watch" },
    { 0x96B8, "tram_move" },
    { 0x96B9, "tram_node_notify" },
    { 0x96BA, "tram_reset" },
    { 0x96BB, "tram_set_forward" },
    { 0x96BC, "tram_set_reverse" },
    { 0x96BD, "tram_show_icon" },
    { 0x96BE, "tram_spline_debug" },
    { 0x96BF, "tram_spline_leave" },
    { 0x96C0, "tram_spline_move" },
    { 0x96C1, "tram_spline_stay_in_playspace" },
    { 0x96C2, "tram_spline_vehicle_spawn" },
    { 0x96C3, "tram_start_player_control" },
    { 0x96C4, "tram_stinger_target_pos" },
    { 0x96C5, "tram_stop_player_control" },
    { 0x96C6, "tram_update_player_spline_control" },
    { 0x96C7, "tram_update_shooting_location" },
    { 0x96C8, "tramby_id" },
    { 0x96C9, "tramlockonentsforteam" },
    { 0x96CA, "tramondeath" },
    { 0x96CB, "trams" },
    { 0x96CC, "trans_alleys_corner" },
    { 0x96CD, "trans_alleys_corner_shot" },
    { 0x96CE, "trans_alleys_end_alley_trigger" },
    { 0x96CF, "trans_alleys_end_corner_trigger" },
    { 0x96D0, "trans_alleys_end_scripted_enemy_gunshots" },
    { 0x96D1, "trans_alleys_female_scream" },
    { 0x96D2, "trans_alleys_scripted_female_scream" },
    { 0x96D3, "trans_civ_01_flee_kva" },
    { 0x96D4, "trans_civ_03_flee_kva" },
    { 0x96D5, "trans_time" },
    { 0x96D6, "trans2alleysbackdoorciv" },
    { 0x96D7, "trans2alleysbegin" },
    { 0x96D8, "trans2alleysbridgecivilians" },
    { 0x96D9, "trans2alleyscafecivilians" },
    { 0x96DA, "trans2alleyscivcafe" },
    { 0x96DB, "trans2alleyscivdying" },
    { 0x96DC, "trans2alleyscivilians" },
    { 0x96DD, "trans2alleysciviliansvskva" },
    { 0x96DE, "trans2alleyscivrunner" },
    { 0x96DF, "trans2alleyscivvictim" },
    { 0x96E0, "trans2alleyscivwindowpeek" },
    { 0x96E1, "trans2alleyscombat" },
    { 0x96E2, "trans2alleysdoorpeek" },
    { 0x96E3, "trans2alleysdoorrunin" },
    { 0x96E4, "trans2alleysexecutioner" },
    { 0x96E5, "trans2alleysilanagatebash" },
    { 0x96E6, "trans2alleysmagicdisappearingworldevent" },
    { 0x96E7, "trans2alleysobjectivesetup" },
    { 0x96E8, "trans2alleyssitsmoke" },
    { 0x96E9, "trans2alleysslowplayer" },
    { 0x96EA, "trans2alleysstandupcivcafe" },
    { 0x96EB, "trans2alleystunnelrunners" },
    { 0x96EC, "trans2alleysunblockplayer" },
    { 0x96ED, "transfer_grenade_ownership" },
    { 0x96EE, "transfer_primer_to_corpse" },
    { 0x96EF, "transformpoint" },
    { 0x96F0, "transformpointbyentity" },
    { 0x96F1, "transient_add_gatetrans_entry" },
    { 0x96F2, "transient_cleanup" },
    { 0x96F3, "transient_hide_intro_vista_buildings" },
    { 0x96F4, "transient_init" },
    { 0x96F5, "transient_intro_to_middle" },
    { 0x96F6, "transient_intro_to_middle_begin" },
    { 0x96F7, "transient_load" },
    { 0x96F8, "transient_middle_add_hospital_interior_begin" },
    { 0x96F9, "transient_middle_add_nighclub_interior_begin" },
    { 0x96FA, "transient_middle_add_school_interior_begin" },
    { 0x96FB, "transient_middle_remove_hospital_interior_begin" },
    { 0x96FC, "transient_middle_remove_nightclub_interior_begin" },
    { 0x96FD, "transient_middle_remove_school_interior_begin" },
    { 0x96FE, "transient_notetracks_bigm" },
    { 0x96FF, "transient_notetracks_intro" },
    { 0x9700, "transient_notetracks_outro" },
    { 0x9701, "transient_switch" },
    { 0x9702, "transient_transition_alley_to_outro" },
    { 0x9703, "transient_transition_intro_to_middle" },
    { 0x9704, "transient_transition_load_alley" },
    { 0x9705, "transient_transition_middle_to_outro" },
    { 0x9706, "transient_transition_unload_lobby" },
    { 0x9707, "transient_transition_unload_middle" },
    { 0x9708, "transient_transitions" },
    { 0x9709, "transient_unload" },
    { 0x970A, "transient_unloadall_and_load" },
    { 0x970B, "transient_zone" },
    { 0x970C, "transindex" },
    { 0x970D, "transition_has_inverse" },
    { 0x970E, "transition_off" },
    { 0x970F, "transition_on" },
    { 0x9710, "transition_to_hovertank_fov" },
    { 0x9711, "transition_unload_then_load_safely" },
    { 0x9712, "transitionfadein" },
    { 0x9713, "transitionfadeout" },
    { 0x9714, "transitioning" },
    { 0x9715, "transitionmeshes" },
    { 0x9716, "transitionmeshesrev" },
    { 0x9717, "transitionpulsefxin" },
    { 0x9718, "transitionreset" },
    { 0x9719, "transitions" },
    { 0x971A, "transitionslidein" },
    { 0x971B, "transitionslideout" },
    { 0x971C, "transitiontime" },
    { 0x971D, "transitionto" },
    { 0x971E, "transitiontocombat" },
    { 0x971F, "transitiontoidle" },
    { 0x9720, "transitiontostance" },
    { 0x9721, "transitionzoomin" },
    { 0x9722, "transitionzoomout" },
    { 0x9723, "translate_local" },
    { 0x9724, "translate_local_on_ent" },
    { 0x9725, "translateenttosliders" },
    { 0x9726, "trap_createbombsquadmodel" },
    { 0x9727, "trapkillcament" },
    { 0x9728, "travel_time" },
    { 0x9729, "travel_view_fx" },
    { 0x972A, "traverse_height" },
    { 0x972B, "traverse_height_delta" },
    { 0x972C, "traverse_start_damn_no_clear_shot" },
    { 0x972D, "traverse_start_fuck_it" },
    { 0x972E, "traverse_start_i_see_it" },
    { 0x972F, "traverse_start_jump_end_prompt" },
    { 0x9730, "traverse_start_jump_end_slowmo" },
    { 0x9731, "traverse_start_jump_player_looking" },
    { 0x9732, "traverse_start_jump_start_prompt" },
    { 0x9733, "traverse_start_jump_start_slowmo" },
    { 0x9734, "traverse_start_you_should_have_eyes" },
    { 0x9735, "traverseanim" },
    { 0x9736, "traverseanimroot" },
    { 0x9737, "traversedata" },
    { 0x9738, "traversedeath" },
    { 0x9739, "traversedeathanim" },
    { 0x973A, "traversedeathindex" },
    { 0x973B, "traverseendnode" },
    { 0x973C, "traversefall" },
    { 0x973D, "traverseheight" },
    { 0x973E, "traverseinfo" },
    { 0x973F, "traversestartnode" },
    { 0x9740, "traversestartz" },
    { 0x9741, "traversethink" },
    { 0x9742, "tread" },
    { 0x9743, "tread_override_thread" },
    { 0x9744, "tread_wait" },
    { 0x9745, "treadfx_ai_boats_taxi" },
    { 0x9746, "treadfx_ai_boats_taxi_vista" },
    { 0x9747, "treadfx_ai_boats_yacht" },
    { 0x9748, "treadfx_ai_boats_yacht_vista" },
    { 0x9749, "treadfx_freq_scale" },
    { 0x974A, "treadfx_maxheight" },
    { 0x974B, "treadfx_of_logging_road" },
    { 0x974C, "treadfx_override" },
    { 0x974D, "tree_head_impact" },
    { 0x974E, "tree_roots_lighting" },
    { 0x974F, "tricklebridgecivilians" },
    { 0x9750, "tridroneammo" },
    { 0x9751, "tridroneammoinit" },
    { 0x9752, "tridronedeployed" },
    { 0x9753, "tridronesettings" },
    { 0x9754, "trig" },
/* 1 gap here
"trigarraywait",
"trigarraywait2",
"trigger_alarm_on_street_combat_started",
"trigger_autosave",
"trigger_autosave_immediate",
"trigger_autosave_stealth",
"trigger_autosave_tactical",
"trigger_battlechatter",
"trigger_bomb_shake",
"trigger_bridge_small",
"trigger_bus_traverse_5_flag_in",
"trigger_bus_traverse_5_looking",
"trigger_bus_traverse_5_threaded",
"trigger_canal_p1",
"trigger_canal_p2",
"trigger_cansee",
"trigger_chopper_spotlight_follow",
"trigger_chopper_spotlight_straight",
"trigger_control_room_gas_leak",
"trigger_courtyard_point_sounds",
"trigger_createart_transient",
"trigger_damage_player_flag_set",
"trigger_darkness",
"trigger_delete_link_chain",
"trigger_delete_on_touch",
"trigger_delete_target_chain",
"trigger_door",
"trigger_dooropen",
"trigger_ending",
"trigger_ending2",
"trigger_enemy_respawn",
"trigger_enemy_stop_respawn",
"trigger_enter_canal",
"trigger_enter_finale_low_burn",
"trigger_enter_finale_silo_blue",
"trigger_enter_finale_silo_center",
"trigger_enter_finale_silo_orange",
"trigger_enter_finale_silo_orange_approach",
"trigger_enter_finale_silo_round_tunnel",
"trigger_enter_hotel",
"trigger_enter_hotel_lobby",
"trigger_enter_hotel_lrg",
"trigger_enter_jb1_s_flicker",
"trigger_enter_jb2_s_flicker",
"trigger_enter_lensflare_subway_int_off",
"trigger_enter_lensflare_subway_int_on",
"trigger_enter_sinkhole",
"trigger_enter_sinkhole_s_flicker",
"trigger_enter_subway",
"trigger_enter_vision_light_fog_normal",
"trigger_exit_hotel",
"trigger_exit_tunnel",
"trigger_exterior_fog",
"trigger_fall_to_hotel_lobby",
"trigger_fallingwatervolume_think",
"trigger_flag_clear",
"trigger_flag_on_cleared",
"trigger_flag_set",
"trigger_flag_set_coop",
"trigger_flag_set_player",
"trigger_flag_set_specialops",
"trigger_flag_set_specialops_clear",
"trigger_flag_set_touching",
"trigger_flags",
"trigger_flashlight_off",
"trigger_fob_dof_autofocus_disable",
"trigger_fob_dof_autofocus_enable",
"trigger_fob_dof_moment",
"trigger_fog",
"trigger_force_shadow_off_subcarback_firespot",
"trigger_force_shadow_on_subcarback_firespot",
"trigger_friendly_respawn",
"trigger_friendly_stop_respawn",
"trigger_func",
"trigger_function_keys",
"trigger_functions",
"trigger_glass_break",
"trigger_group",
"trigger_group_remove",
"trigger_handle_jump_mount",
"trigger_handle_mag_mount",
"trigger_hint",
"trigger_hint_func",
"trigger_hint_string",
"trigger_hotel_fall",
"trigger_ignore",
"trigger_interior_fog",
"trigger_issues_orders",
"trigger_kill_jb_s_flicker",
"trigger_kill_player",
"trigger_kill_sh_s_flicker",
"trigger_lookat",
"trigger_lookat_think",
"trigger_looking",
"trigger_multiple_audio_blend",
"trigger_multiple_audio_get_target_ent_origin",
"trigger_multiple_audio_get_target_ent_target",
"trigger_multiple_audio_get_target_ent_target_ent",
"trigger_multiple_audio_get_target_ent_target_ent_origin",
"trigger_multiple_audio_get_zone_from",
"trigger_multiple_audio_get_zone_to",
"trigger_multiple_audio_progress",
"trigger_multiple_audio_progress_point",
"trigger_multiple_audio_register_callback",
"trigger_multiple_audio_trigger",
"trigger_multiple_compass",
"trigger_multiple_depthoffield",
"trigger_multiple_fx_trigger_off_think",
"trigger_multiple_fx_trigger_on_think",
"trigger_multiple_fx_volume",
"trigger_multiple_fx_watersheeting",
"trigger_multiple_sunflare",
"trigger_multiple_tessellationcutoff",
"trigger_multiple_visionset",
"trigger_mwp_sinkhole_forceshadows",
"trigger_no_crouch_or_prone",
"trigger_no_prone",
"trigger_nobloodpool",
"trigger_off",
"trigger_off_proc",
"trigger_on",
"trigger_on_proc",
"trigger_origin",
"trigger_pacifist",
"trigger_physics",
"trigger_playerseek",
"trigger_pool_spawners",
"trigger_process",
"trigger_process_optimized",
"trigger_process_set",
"trigger_radio",
"trigger_reinforcement_get_reinforcement_spawner",
"trigger_reinforcement_spawn_guys",
"trigger_requires_player",
"trigger_runs_function_on_touch",
"trigger_s_flicker_fluo_jump2_shadow_on",
"trigger_science_room",
"trigger_script_flag_false",
"trigger_script_flag_true",
"trigger_seoul_art_center_atrium",
"trigger_seoul_building_jump",
"trigger_seoul_exterior",
"trigger_seoul_finale_cinematic_lighting",
"trigger_seoul_hotel_hallway_cg",
"trigger_seoul_shopping",
"trigger_seoul_streets_02",
"trigger_seoul_streets_02_xx",
"trigger_seoul_vista",
"trigger_set_and_clear_flag_think",
"trigger_setup",
"trigger_setup_bar2_enter",
"trigger_setup_bar2_exit",
"trigger_setup_shopping_restaraunt_interior_enter",
"trigger_setup_shopping_restaraunt_interior_exit",
"trigger_setup_shopping_walkway_enter",
"trigger_setup_shopping_walkway_exit",
"trigger_setup_shopping_walkway_pre_enter",
"trigger_silo_centroid_switch_floor3",
"trigger_silo_centroid_switch_top",
"trigger_silo_p1",
"trigger_slide",
"trigger_spawn",
"trigger_spawn_and_set_flag_think",
"trigger_spawner",
"trigger_spawner_reinforcement",
"trigger_spawner_spawns_guys",
"trigger_spawngroup",
"trigger_sprinklervolume_setup",
"trigger_sprinklervolume_think",
"trigger_stats",
"trigger_store_drive_sequence",
"trigger_string",
"trigger_sun_off",
"trigger_sun_on",
"trigger_throw_grenade_at_player",
"trigger_to_flag",
"trigger_to_notify",
"trigger_turns_off",
"trigger_unlock",
"trigger_unlock_death",
"trigger_vehicle_getin_spawn",
"trigger_vehicle_spawn",
"trigger_vehicle_spline_spawn",
"trigger_wait",
"trigger_wait_targetname",
"trigger_wakevolume_think",
"triggeractivate",
"triggered_time",
"triggerhintstring",
"triggerhurtlower",
"triggerhurtupper",
"triggerkillvehiclesbuilding",
"triggerkillvehiclesbuildingoffset",
"triggerkillvehiclesheli",
"triggerkillvehicleshelioffset",
"triggerlowerorigin",
"triggermultiplevisionlightsetinternal",
"triggersenable",
"triggertouchthink",
"triggertype",
"triggerunlocked",
"triggerupperorigin",
*/
    { 0x9820, "trigorigin" },
    { 0x9821, "trigs" },
    { 0x9822, "trigunderwater" },
    { 0x9823, "trigwait" },
    { 0x9824, "triplekillcount" },
    { 0x9825, "trolley_doors_function" },
    { 0x9826, "troop_cache" },
    { 0x9827, "troop_cache_update_next" },
    { 0x9828, "trophies" },
    { 0x9829, "trophy_ammo_counter" },
    { 0x982A, "trophy_cost" },
    { 0x982B, "trophy_count" },
    { 0x982C, "trophy_reload" },
    { 0x982D, "trophy_reload_bar" },
    { 0x982E, "trophy_system" },
    { 0x982F, "trophy_system_backup" },
    { 0x9830, "trophy_system_explosion" },
    { 0x9831, "trophy0" },
    { 0x9832, "trophy60" },
    { 0x9833, "trophy80" },
    { 0x9834, "trophyactive" },
    { 0x9835, "trophyaddlaser" },
    { 0x9836, "trophyammo" },
    { 0x9837, "trophyammomax" },
    { 0x9838, "trophyangleoffset" },
    { 0x9839, "trophyarray" },
    { 0x983A, "trophybreak" },
    { 0x983B, "trophychangeowner" },
    { 0x983C, "trophydamage" },
    { 0x983D, "trophydisconnectwaiter" },
    { 0x983E, "trophyfx_enemy" },
    { 0x983F, "trophyfx_friendly" },
    { 0x9840, "trophyfx_ground_enemy" },
    { 0x9841, "trophyfx_ground_friendly" },
    { 0x9842, "trophyhandlelaser" },
    { 0x9843, "trophymovestunent" },
    { 0x9844, "trophyplayerspawnwaiter" },
    { 0x9845, "trophyremainingammo" },
    { 0x9846, "trophysetmindot" },
    { 0x9847, "trophystunbegin" },
    { 0x9848, "trophystunend" },
    { 0x9849, "trophytags" },
    { 0x984A, "trophyupdatelaser" },
    { 0x984B, "trophyuselistener" },
    { 0x984C, "trophywithinmindot" },
    { 0x984D, "truck" },
    { 0x984E, "truck_cargo_door_open" },
    { 0x984F, "truck_distance_to_end" },
    { 0x9850, "truck_dodge_qte" },
    { 0x9851, "truck_dust_trail" },
    { 0x9852, "truck_headlights_on" },
    { 0x9853, "truck_headon_collision" },
    { 0x9854, "truck_jump_slowmo" },
    { 0x9855, "truck_latch_open_trail" },
    { 0x9856, "truck_latch_rumble" },
    { 0x9857, "truck_middle_dodge_slowmo_end" },
    { 0x9858, "truck_middle_jump_slowmo_end" },
    { 0x9859, "truck_middle_jump2_slowmo_end" },
    { 0x985A, "truck_middle_punch_slowmo_end" },
    { 0x985B, "truck_middle_takedown_failure" },
    { 0x985C, "truck_middle_takedown_gameover" },
    { 0x985D, "truck_middle_takedown_middle_player_free_aim" },
    { 0x985E, "truck_middle_takedown_player_dodge_check" },
    { 0x985F, "truck_middle_takedown_player_jump" },
    { 0x9860, "truck_middle_takedown_player_jump2" },
    { 0x9861, "truck_middle_takedown_player_pull_windshield" },
    { 0x9862, "truck_middle_takedown_player_shot_enemy_check" },
    { 0x9863, "truck_middle_takedown_player_shot_timer" },
    { 0x9864, "truck_middle_takedown_set_normal_time_if_gun_fired" },
    { 0x9865, "truck_org_cords" },
    { 0x9866, "truck_punch_slowmo" },
    { 0x9867, "truck_rail_impact" },
    { 0x9868, "truck_rearview_mirror_snap" },
    { 0x9869, "truck_swap" },
    { 0x986A, "truck_swim_latch_open_player_validation" },
    { 0x986B, "truck_takedown" },
    { 0x986C, "truck_takedown_burke" },
    { 0x986D, "truck_takedown_player_fall" },
    { 0x986E, "truck_takedown_player_hold_check" },
    { 0x986F, "truck_takedown_player_hold_fail" },
    { 0x9870, "truck_takedown_player_pry_open" },
    { 0x9871, "truck_takedown_player_shot_enemy_check" },
    { 0x9872, "truck_takedown_radio" },
    { 0x9873, "truck_to_bus_slowmo" },
    { 0x9874, "truck_to_s1elevator_scene" },
    { 0x9875, "truck_treadfx_skid" },
    { 0x9876, "truck_treadfx_turn" },
    { 0x9877, "truck_treadfx_wheels" },
    { 0x9878, "truck_turret_flank_alley" },
    { 0x9879, "truck_turret_flank_alley_drive_away" },
    { 0x987A, "truck_turret_listener" },
    { 0x987B, "truck_water_impact" },
    { 0x987C, "truck_whipeout_anim_begin" },
    { 0x987D, "truckaudio" },
    { 0x987E, "truckblood" },
    { 0x987F, "truckbodystashanimations" },
    { 0x9880, "truckbrakelights" },
    { 0x9881, "truckdrivein" },
    { 0x9882, "truckjunk" },
    { 0x9883, "truckjunk_dyn" },
    { 0x9884, "truckmovetruck" },
    { 0x9885, "truckstartwalknotetrack" },
    { 0x9886, "truckstashweaponswap" },
    { 0x9887, "truecount" },
    { 0x9888, "truncate_time_ms" },
    { 0x9889, "try_balcony_death" },
    { 0x988A, "try_clear_hide_goal" },
    { 0x988B, "try_forever_spawn" },
    { 0x988C, "try_place_global_badplace" },
    { 0x988D, "try_raise_shield" },
    { 0x988E, "try_respawn_death" },
    { 0x988F, "try_to_autosave_now" },
    { 0x9890, "try_to_dogfight" },
    { 0x9891, "try_to_draw_line_to_node" },
    { 0x9892, "try_to_lock_on" },
    { 0x9893, "try_use_exo_mute" },
    { 0x9894, "tryadddeathanim" },
    { 0x9895, "tryaddfiringdeathanim" },
    { 0x9896, "tryautosave" },
    { 0x9897, "trycornerrightgrenadedeath" },
    { 0x9898, "trydive" },
    { 0x9899, "trydodgewithanim" },
    { 0x989A, "tryexposedreacquire" },
    { 0x989B, "tryexposedthrowgrenade" },
    { 0x989C, "trygivehordeweapon" },
    { 0x989D, "trygrenade" },
    { 0x989E, "trygrenadeposproc" },
    { 0x989F, "trygrenadethrow" },
    { 0x98A0, "tryingtouseks" },
    { 0x98A1, "trymelee" },
    { 0x98A2, "tryorderto" },
    { 0x98A3, "tryreload" },
    { 0x98A4, "tryrunningtoenemy" },
    { 0x98A5, "trythrowinggrenade" },
    { 0x98A6, "trythrowinggrenadestayhidden" },
    { 0x98A7, "trytogetoutofdangeroussituation" },
    { 0x98A8, "trytorepelmissile" },
    { 0x98A9, "tryuseadrenaline" },
    { 0x98AA, "tryuseairstrike" },
    { 0x98AB, "tryuseassaultdrone" },
    { 0x98AC, "tryuseautosentry" },
    { 0x98AD, "tryusedefaultorbitalcarepackage" },
    { 0x98AE, "tryusedog" },
    { 0x98AF, "tryuseexplosivedrone" },
    { 0x98B0, "tryuseexplosivegel" },
    { 0x98B1, "tryuseextrahealth" },
    { 0x98B2, "tryusefastheal" },
    { 0x98B3, "tryuseheavyexosuit" },
    { 0x98B4, "tryusekillstreak" },
    { 0x98B5, "tryusemissilestrike" },
    { 0x98B6, "tryusempinstinct" },
    { 0x98B7, "tryusemplaser" },
    { 0x98B8, "tryusempprison" },
    { 0x98B9, "tryusemprecovery" },
    { 0x98BA, "tryusemprefraction" },
    { 0x98BB, "tryusemutebomb" },
    { 0x98BC, "tryusenuke" },
    { 0x98BD, "tryuseorbitalcarepackage" },
    { 0x98BE, "tryuseorbitaljuggernautexosuit" },
    { 0x98BF, "tryuseorbitalstrike" },
    { 0x98C0, "tryuseorbitalsupport" },
    { 0x98C1, "tryuserecondrone" },
    { 0x98C2, "tryusereconsquadmate" },
    { 0x98C3, "tryusereinforcementcommon" },
    { 0x98C4, "tryusereinforcementpractice" },
    { 0x98C5, "tryusereinforcementrare" },
    { 0x98C6, "tryusereinforcementuncommon" },
    { 0x98C7, "tryuseremotemgsentryturret" },
    { 0x98C8, "tryuseremotemgturret" },
    { 0x98C9, "tryuseremoteturret" },
    { 0x98CA, "tryuserepulsor" },
    { 0x98CB, "tryuserippedturret" },
    { 0x98CC, "tryuserippedturretinternal" },
    { 0x98CD, "tryusesam" },
    { 0x98CE, "tryusesolarreflector" },
    { 0x98CF, "tryusesquadmate" },
    { 0x98D0, "tryusestrafingrunairstrike" },
    { 0x98D1, "tryuseteamammorefill" },
    { 0x98D2, "tryusetrackingdrone" },
    { 0x98D3, "tryusetridrone" },
    { 0x98D4, "tryuseuav" },
    { 0x98D5, "tryusewarbird" },
    { 0x98D6, "tryusingsidearm" },
    { 0x98D7, "tsunami_alarm" },
    { 0x98D8, "tsunami_vo_ext" },
    { 0x98D9, "tsunami_vo_int" },
    { 0x98DA, "tunnel_runner_walla" },
    { 0x98DB, "tunnel_sequence_dof" },
    { 0x98DC, "turbine_combat_mid_checkpoint_1" },
    { 0x98DD, "turbine_enemy_elevator_removal" },
    { 0x98DE, "turbine_explo" },
    { 0x98DF, "turbine_fan_think" },
    { 0x98E0, "turbine_pre_explo" },
    { 0x98E1, "turbine_room" },
    { 0x98E2, "turbine_room_atmosphere" },
    { 0x98E3, "turbine_room_combat" },
    { 0x98E4, "turbine_room_combat_initial" },
    { 0x98E5, "turbine_room_combat_seek_player" },
    { 0x98E6, "turbine_room_elevator" },
    { 0x98E7, "turbine_room_elevator_ascent_time" },
    { 0x98E8, "turbine_room_elevator_button" },
    { 0x98E9, "turbine_room_elevator_button_pressed_anim" },
    { 0x98EA, "turbine_room_elevator_think" },
    { 0x98EB, "turbine_room_enemy_think" },
    { 0x98EC, "turbine_room_entrance_steam" },
    { 0x98ED, "turbine_room_explosion" },
    { 0x98EE, "turbine_room_explosion_flying_blades" },
    { 0x98EF, "turbine_room_explosion_launch_blade" },
    { 0x98F0, "turbine_room_goal_volume" },
    { 0x98F1, "turbine_room_goal_volume_trigger_think" },
    { 0x98F2, "turbine_room_pre_explosion" },
    { 0x98F3, "turbine_room_squibs" },
    { 0x98F4, "turbine_room_steam_player" },
    { 0x98F5, "turbine_room_turbines" },
    { 0x98F6, "turbine_spin" },
    { 0x98F7, "turkey_anim_nag" },
    { 0x98F8, "turkey_boost_assist" },
    { 0x98F9, "turkey_boost_logic" },
    { 0x98FA, "turkey_complain" },
    { 0x98FB, "turkey_drone" },
    { 0x98FC, "turkey_drone_logic" },
    { 0x98FD, "turkey_enemy_anim" },
    { 0x98FE, "turkey_enemy_anim_loop" },
    { 0x98FF, "turkey_listen" },
    { 0x9900, "turkey_patrol_logic" },
    { 0x9901, "turkey_shoot" },
    { 0x9902, "turkey_shoot_anim" },
    { 0x9903, "turkey_shoot_dialog" },
    { 0x9904, "turkey_shoot_drone" },
    { 0x9905, "turkey_shoot_enemies" },
    { 0x9906, "turkey_shoot_enemy_dialog" },
    { 0x9907, "turkey_shoot_open_fire" },
    { 0x9908, "turkey_shoot_patrol" },
    { 0x9909, "turkey_timer" },
    { 0x990A, "turn_180_move_start_func" },
    { 0x990B, "turn_left" },
    { 0x990C, "turn_off_car_alarm" },
    { 0x990D, "turn_off_exploders" },
    { 0x990E, "turn_off_flares" },
    { 0x990F, "turn_off_gold_light" },
    { 0x9910, "turn_off_highlight" },
    { 0x9911, "turn_off_jammer_triggers" },
    { 0x9912, "turn_off_jeep_light" },
    { 0x9913, "turn_off_light" },
    { 0x9914, "turn_off_light_bright" },
    { 0x9915, "turn_off_lighting_fx_post_mini_games" },
    { 0x9916, "turn_off_the_cloak_effect" },
    { 0x9917, "turn_off_the_cloak_effect_when_able" },
    { 0x9918, "turn_off_top_tank_lights" },
    { 0x9919, "turn_on_cheap_flashlight" },
    { 0x991A, "turn_on_helmet_light" },
    { 0x991B, "turn_on_helmet_light_bright" },
    { 0x991C, "turn_on_highlight" },
    { 0x991D, "turn_on_lab_lights" },
    { 0x991E, "turn_on_lab_lights_scriptable" },
    { 0x991F, "turn_on_laser" },
    { 0x9920, "turn_on_laser_group_and_scan" },
    { 0x9921, "turn_on_the_cloak_effect" },
    { 0x9922, "turn_on_the_cloak_effect_wallclimb" },
    { 0x9923, "turn_on_the_cloak_effect_when_able" },
    { 0x9924, "turn_on_weapon_light" },
    { 0x9925, "turn_right" },
    { 0x9926, "turn_self_into_level_notify" },
    { 0x9927, "turn_signal_off" },
    { 0x9928, "turn_signal_on" },
    { 0x9929, "turn_thermal_off" },
    { 0x992A, "turn_thermal_on" },
    { 0x992B, "turn_trig_active_on_flag" },
    { 0x992C, "turn_unloading_drones_to_ai" },
    { 0x992D, "turnanim" },
    { 0x992E, "turnbackon" },
    { 0x992F, "turningaimingoff" },
    { 0x9930, "turningaimingon" },
    { 0x9931, "turnlastresort" },
    { 0x9932, "turnoff" },
    { 0x9933, "turnoffvariablescopehud" },
    { 0x9934, "turnonandhideorbitalhud" },
    { 0x9935, "turnondangerlights" },
    { 0x9936, "turnondangerlightsexplosive" },
    { 0x9937, "turnonplayerhudoutline" },
    { 0x9938, "turnonsuperfx" },
    { 0x9939, "turnonvariablescopehud" },
    { 0x993A, "turnthreshold" },
    { 0x993B, "turntime" },
    { 0x993C, "turntoangle" },
    { 0x993D, "turntofacerelativeyaw" },
    { 0x993E, "turntomatchnode" },
    { 0x993F, "turntomatchnodedirection" },
    { 0x9940, "turret" },
    { 0x9941, "turret_ai" },
    { 0x9942, "turret_aim_restore" },
    { 0x9943, "turret_aim_straight" },
    { 0x9944, "turret_aiming_near_target" },
    { 0x9945, "turret_animate" },
    { 0x9946, "turret_animfirstframe" },
    { 0x9947, "turret_blinky_light" },
    { 0x9948, "turret_can_see_target" },
    { 0x9949, "turret_choose_targets" },
    { 0x994A, "turret_cleanup" },
    { 0x994B, "turret_cleanup_on_unload" },
    { 0x994C, "turret_clearpickuphints" },
    { 0x994D, "turret_coolmonitor" },
    { 0x994E, "turret_createantiintrusionkillcament" },
    { 0x994F, "turret_damage_max" },
    { 0x9950, "turret_damage_min" },
    { 0x9951, "turret_damage_range" },
    { 0x9952, "turret_dead_vo" },
    { 0x9953, "turret_deathsounds" },
    { 0x9954, "turret_default_fire" },
    { 0x9955, "turret_deleteme" },
    { 0x9956, "turret_emp_ready" },
    { 0x9957, "turret_exploding_debug" },
    { 0x9958, "turret_find_user" },
    { 0x9959, "turret_fire_tag" },
    { 0x995A, "turret_firerocket" },
    { 0x995B, "turret_firerockets" },
    { 0x995C, "turret_function" },
    { 0x995D, "turret_gameend" },
    { 0x995E, "turret_get_angle_to_target" },
    { 0x995F, "turret_gunner_custom_anim" },
    { 0x9960, "turret_handledeath" },
    { 0x9961, "turret_handlelaser" },
    { 0x9962, "turret_handleownerdisconnect" },
    { 0x9963, "turret_handlepickup" },
    { 0x9964, "turret_handlepitch" },
    { 0x9965, "turret_handleuse" },
    { 0x9966, "turret_heatmonitor" },
    { 0x9967, "turret_hordeshootdrone" },
    { 0x9968, "turret_hud_clear" },
    { 0x9969, "turret_hud_elem_fadeout" },
    { 0x996A, "turret_hud_elem_init" },
    { 0x996B, "turret_hud_elem_init_nofade" },
    { 0x996C, "turret_hud_init" },
    { 0x996D, "turret_incrementdamagefade" },
    { 0x996E, "turret_is_mine" },
    { 0x996F, "turret_isstunned" },
    { 0x9970, "turret_minigun_fire" },
    { 0x9971, "turret_minigun_target_track" },
    { 0x9972, "turret_models" },
    { 0x9973, "turret_modifydamage" },
    { 0x9974, "turret_monitoruse" },
    { 0x9975, "turret_movedown" },
    { 0x9976, "turret_movement_sound" },
    { 0x9977, "turret_movement2_sound" },
    { 0x9978, "turret_movement3_sound" },
    { 0x9979, "turret_moveup" },
    { 0x997A, "turret_oncarrierchangedteam" },
    { 0x997B, "turret_oncarrierdeath" },
    { 0x997C, "turret_oncarrierdisconnect" },
    { 0x997D, "turret_ongameended" },
    { 0x997E, "turret_overheat_bar" },
    { 0x997F, "turret_player_init" },
    { 0x9980, "turret_playerthread" },
    { 0x9981, "turret_quickdeath" },
    { 0x9982, "turret_recenter" },
    { 0x9983, "turret_rotate_accel" },
    { 0x9984, "turret_rotate_timeout" },
    { 0x9985, "turret_set_default_on_mode" },
    { 0x9986, "turret_setactive" },
    { 0x9987, "turret_setcancelled" },
    { 0x9988, "turret_setcarried" },
    { 0x9989, "turret_setinactive" },
    { 0x998A, "turret_setpickuphints" },
    { 0x998B, "turret_setplaced" },
    { 0x998C, "turret_setup" },
    { 0x998D, "turret_shell_fx" },
    { 0x998E, "turret_shell_sound" },
    { 0x998F, "turret_shoot_missile" },
    { 0x9990, "turret_shoot_vtols" },
    { 0x9991, "turret_shotmonitor" },
    { 0x9992, "turret_startshooting" },
    { 0x9993, "turret_stoprockets" },
    { 0x9994, "turret_stopshooting" },
    { 0x9995, "turret_target_override" },
    { 0x9996, "turret_target_updater" },
    { 0x9997, "turret_target_validate" },
    { 0x9998, "turret_targeting" },
    { 0x9999, "turret_think" },
    { 0x999A, "turret_timeout" },
    { 0x999B, "turret_to_missile_index" },
    { 0x999C, "turret_track_rotatedirection" },
    { 0x999D, "turret_turnleft" },
    { 0x999E, "turret_update_rotatedirection" },
    { 0x999F, "turret_use_time" },
    { 0x99A0, "turret_user_moves" },
    { 0x99A1, "turret_watchdisabled" },
    { 0x99A2, "turret_watchemp" },
    { 0x99A3, "turret1spawns" },
    { 0x99A4, "turret2passenger_anime" },
    { 0x99A5, "turret2spawns" },
    { 0x99A6, "turret3spawns" },
    { 0x99A7, "turretaccmaxs" },
    { 0x99A8, "turretaccmins" },
    { 0x99A9, "turretdeathanim" },
    { 0x99AA, "turretdeathanimroot" },
    { 0x99AB, "turretdeathdetacher" },
    { 0x99AC, "turretdeletesoundents" },
    { 0x99AD, "turretdetacher" },
    { 0x99AE, "turretdoaimanims" },
    { 0x99AF, "turretdoshoot" },
    { 0x99B0, "turretdoshootanims" },
    { 0x99B1, "turretfiretimer" },
    { 0x99B2, "turretflashbangedanim" },
    { 0x99B3, "turretinfo" },
    { 0x99B4, "turretinit" },
    { 0x99B5, "turretmodel" },
    { 0x99B6, "turretonvistarg" },
    { 0x99B7, "turretonvistarg_failed" },
    { 0x99B8, "turretpainanims" },
    { 0x99B9, "turretpitch" },
    { 0x99BA, "turretreloadanim" },
    { 0x99BB, "turrets" },
    { 0x99BC, "turretsettings" },
    { 0x99BD, "turretshoot" },
    { 0x99BE, "turretshootblank" },
    { 0x99BF, "turretspawnsoundents" },
    { 0x99C0, "turretspecialanims" },
    { 0x99C1, "turretspecialanimsroot" },
    { 0x99C2, "turretstate" },
    { 0x99C3, "turrettimer" },
    { 0x99C4, "turrettrackingoverlay" },
    { 0x99C5, "turrettype" },
    { 0x99C6, "tutorial_anim_struct" },
    { 0x99C7, "tutorial_enemy_1" },
    { 0x99C8, "tutorial_enemy_2" },
    { 0x99C9, "tutorial_enemy_3" },
    { 0x99CA, "tutorial_guards_vo" },
    { 0x99CB, "tutorial_vo" },
    { 0x99CC, "tv_broadcast_lp" },
    { 0x99CD, "tv_changes_color" },
    { 0x99CE, "tv_changes_intensity" },
    { 0x99CF, "tv_damage" },
    { 0x99D0, "tv_dest_lp" },
    { 0x99D1, "tv_destroyed" },
    { 0x99D2, "tv_lite_array" },
    { 0x99D3, "tv_logic" },
    { 0x99D4, "tv_movie" },
    { 0x99D5, "tv_movie2" },
    { 0x99D6, "tv_off" },
    { 0x99D7, "twar_dist" },
    { 0x99D8, "twar_spawn_dist" },
    { 0x99D9, "twar_spawn_dot" },
    { 0x99DA, "twar_team_momentum" },
    { 0x99DB, "twar_team_multiplier" },
    { 0x99DC, "twar_use_obj" },
    { 0x99DD, "twar_zone" },
    { 0x99DE, "twar_zones" },
    { 0x99DF, "tweak_enemy_hp" },
    { 0x99E0, "tweakablesinitialized" },
    { 0x99E1, "tweakart" },
    { 0x99E2, "tweakfile" },
    { 0x99E3, "tweaklightset" },
    { 0x99E4, "two_mech_hunt" },
    { 0x99E5, "two_stage_spawner_think" },
    { 0x99E6, "typeid" },
    { 0x99E7, "typelimited" },
    { 0x99E8, "uav_paint_effect" },
    { 0x99E9, "uavmodels" },
    { 0x99EA, "uavondeath" },
    { 0x99EB, "uavrig" },
    { 0x99EC, "uavtracker" },
    { 0x99ED, "uavtype" },
    { 0x99EE, "ugvmarkedarrays" },
    { 0x99EF, "ugvs" },
    { 0x99F0, "ui_action_slot_force_active_off" },
    { 0x99F1, "ui_action_slot_force_active_on" },
    { 0x99F2, "ui_action_slot_force_active_one_time" },
    { 0x99F3, "ui_dog_grenade_logic" },
    { 0x99F4, "uiparent" },
    { 0x99F5, "umbra" },
    { 0x99F6, "umbra_accuracy_tweaks" },
    { 0x99F7, "umbra_accuracy_tweaks_tank_field" },
    { 0x99F8, "umbra_override_tunnel" },
    { 0x99F9, "umbra_tweak_1024" },
    { 0x99FA, "umbra_tweak_128" },
    { 0x99FB, "unarmed" },
    { 0x99FC, "unblockarea" },
    { 0x99FD, "unblockentsinarea" },
    { 0x99FE, "uncloak_ambient_warbird" },
    { 0x99FF, "uncloak_model" },
    { 0x9A00, "uncloak_warbird" },
    { 0x9A01, "under_water_set" },
    { 0x9A02, "underground_pipe_explosion_pickup_truck_vfx" },
    { 0x9A03, "underground_pipe_explosion_utility_truck_vfx" },
    { 0x9A04, "underwater" },
    { 0x9A05, "underwater_ambient_fx" },
    { 0x9A06, "underwater_blood" },
    { 0x9A07, "underwater_boat_visionset_change" },
    { 0x9A08, "underwater_bullets" },
    { 0x9A09, "underwater_bullets_4100" },
    { 0x9A0A, "underwater_bullets_4200" },
    { 0x9A0B, "underwater_bullets_4300" },
    { 0x9A0C, "underwater_bullets_500" },
    { 0x9A0D, "underwater_bullets_530" },
    { 0x9A0E, "underwater_bullets_540" },
    { 0x9A0F, "underwater_bullets_vm" },
    { 0x9A10, "underwater_cloudy" },
    { 0x9A11, "underwater_hud_enable" },
    { 0x9A12, "underwater_lightset" },
    { 0x9A13, "underwater_mech_footsteps" },
    { 0x9A14, "underwater_objective_hack" },
    { 0x9A15, "underwater_reflection" },
    { 0x9A16, "underwater_rescue" },
    { 0x9A17, "underwater_sequence" },
    { 0x9A18, "underwater_sound_ent" },
    { 0x9A19, "underwater_sunrays" },
    { 0x9A1A, "underwater_triggers" },
    { 0x9A1B, "underwater_visionset_callback" },
    { 0x9A1C, "underwater_visionset_change" },
    { 0x9A1D, "underwater_visionset_change_cleanup" },
    { 0x9A1E, "underwater_walk" },
    { 0x9A1F, "underwaterbubbles" },
    { 0x9A20, "underwatercloudy" },
    { 0x9A21, "underwatermotiontype" },
    { 0x9A22, "underwatertriggers" },
    { 0x9A23, "undo" },
    { 0x9A24, "unearned_icon_col" },
    { 0x9A25, "unflash_flag" },
    { 0x9A26, "unfreezecontrolsdelay" },
    { 0x9A27, "unhide_me_on_flag" },
    { 0x9A28, "unignore_everything" },
    { 0x9A29, "unique_id" },
    { 0x9A2A, "units2yards" },
    { 0x9A2B, "unlimit_player_view" },
    { 0x9A2C, "unlimited_ammo" },
    { 0x9A2D, "unlimited_mech_ammo" },
    { 0x9A2E, "unlink_failsafe" },
    { 0x9A2F, "unlink_failsafe_running" },
    { 0x9A30, "unlink_from_zip" },
    { 0x9A31, "unlink_player_from_drone" },
    { 0x9A32, "unlink_player_from_mob_turret" },
    { 0x9A33, "unlink_trigger" },
    { 0x9A34, "unlinkanddelete" },
    { 0x9A35, "unlinknextframe" },
    { 0x9A36, "unlinkplayer" },
    { 0x9A37, "unlinkto_with_world_offset" },
    { 0x9A38, "unlit_model" },
    { 0x9A39, "unlit_models" },
    { 0x9A3A, "unload_anim_height" },
    { 0x9A3B, "unload_delay" },
    { 0x9A3C, "unload_group" },
    { 0x9A3D, "unload_groups" },
    { 0x9A3E, "unload_intro_cinematic_assets" },
    { 0x9A3F, "unload_load_transients" },
    { 0x9A40, "unload_model" },
    { 0x9A41, "unload_model_unload_anim" },
    { 0x9A42, "unload_node" },
    { 0x9A43, "unload_ondeath" },
    { 0x9A44, "unloadque" },
    { 0x9A45, "unlock" },
    { 0x9A46, "unlock_frogger_traffic_spawner" },
    { 0x9A47, "unlock_on_death" },
    { 0x9A48, "unlock_thread" },
    { 0x9A49, "unlock_traffic_spawner" },
    { 0x9A4A, "unlock_wait" },
    { 0x9A4B, "unmake_hero" },
    { 0x9A4C, "unmark_enemy" },
    { 0x9A4D, "unmark_guy" },
    { 0x9A4E, "unmark_guy_fx" },
    { 0x9A4F, "unmark_stencil" },
    { 0x9A50, "unmark_swarm_target" },
    { 0x9A51, "unmarkallies" },
    { 0x9A52, "unmarkandremoveoutline" },
    { 0x9A53, "unmarkdronetarget" },
    { 0x9A54, "unmatched_death_rig_light_waits_for_lights_off" },
    { 0x9A55, "unmute_wasp_oneshots" },
    { 0x9A56, "unpause_flickerlight" },
    { 0x9A57, "unregister_moving_collision_on_nodes" },
    { 0x9A58, "unresolved_collision_count" },
    { 0x9A59, "unresolved_collision_damage" },
    { 0x9A5A, "unresolved_collision_func" },
    { 0x9A5B, "unresolved_collision_kill" },
    { 0x9A5C, "unresolved_collision_nearest_node" },
    { 0x9A5D, "unresolved_collision_nodes" },
    { 0x9A5E, "unresolved_collision_notify_min" },
    { 0x9A5F, "unresolved_collision_owner_damage" },
    { 0x9A60, "unresolved_collision_void" },
    { 0x9A61, "unset_forcegoal" },
    { 0x9A62, "unsetautospot" },
    { 0x9A63, "unsetblackbox" },
    { 0x9A64, "unsetblastshield" },
    { 0x9A65, "unsetboostdash" },
    { 0x9A66, "unsetcarepackage" },
    { 0x9A67, "unsetcrouchmovement" },
    { 0x9A68, "unsetdelaymine" },
    { 0x9A69, "unsetdoubleload" },
    { 0x9A6A, "unsetempimmune" },
    { 0x9A6B, "unsetendgame" },
    { 0x9A6C, "unsetenemydetection" },
    { 0x9A6D, "unsetexomelee" },
    { 0x9A6E, "unsetexoslam" },
    { 0x9A6F, "unsetexoslide" },
    { 0x9A70, "unsetfinalstand" },
    { 0x9A71, "unsetfootstepeffect" },
    { 0x9A72, "unsetfootstepeffectsmall" },
    { 0x9A73, "unsetfreefall" },
    { 0x9A74, "unsetfriendlydetection" },
    { 0x9A75, "unsetfriendlyspawn" },
    { 0x9A76, "unsethighjump" },
    { 0x9A77, "unsetintelmode" },
    { 0x9A78, "unsetjuiced" },
    { 0x9A79, "unsetjuicedondeath" },
    { 0x9A7A, "unsetjuicedonride" },
    { 0x9A7B, "unsetjumpincrease" },
    { 0x9A7C, "unsetlightarmor" },
    { 0x9A7D, "unsetlightweight" },
    { 0x9A7E, "unsetlocaljammer" },
    { 0x9A7F, "unsetmarksman" },
    { 0x9A80, "unsetmovespeedincrease" },
    { 0x9A81, "unsetonemanarmy" },
    { 0x9A82, "unsetoverdrive" },
    { 0x9A83, "unsetoverkillpro" },
    { 0x9A84, "unsetpainted" },
    { 0x9A85, "unsetpersonaluav" },
    { 0x9A86, "unsetrearview" },
    { 0x9A87, "unsetrefractionturretplayer" },
    { 0x9A88, "unsetregenspeed" },
    { 0x9A89, "unsetsaboteur" },
    { 0x9A8A, "unsetsharpfocus" },
    { 0x9A8B, "unsetshield" },
    { 0x9A8C, "unsetshowgrenades" },
    { 0x9A8D, "unsetsiege" },
    { 0x9A8E, "unsetsonicblast" },
    { 0x9A8F, "unsetsteadyaimpro" },
    { 0x9A90, "unsetsteelnerves" },
    { 0x9A91, "unsetstim" },
    { 0x9A92, "unsetstoppingpower" },
    { 0x9A93, "unsetstunresistance" },
    { 0x9A94, "unsetthermal" },
    { 0x9A95, "unsetuav" },
    { 0x9A96, "unstoppable_friendly_fire_shield" },
    { 0x9A97, "unstorable_weapons" },
    { 0x9A98, "unsynchappened" },
    { 0x9A99, "up_arrow" },
    { 0x9A9A, "up_position" },
    { 0x9A9B, "update_actor_damage" },
    { 0x9A9C, "update_aim_offset" },
    { 0x9A9D, "update_aiming" },
    { 0x9A9E, "update_anim_weight" },
    { 0x9A9F, "update_avatars" },
    { 0x9AA0, "update_battery_ability_icons" },
    { 0x9AA1, "update_battlechatter_hud" },
    { 0x9AA2, "update_bcs_locations" },
    { 0x9AA3, "update_boid_settings" },
    { 0x9AA4, "update_bumper_think" },
    { 0x9AA5, "update_button_buffers" },
    { 0x9AA6, "update_calculations" },
    { 0x9AA7, "update_camera_angles_on_path" },
    { 0x9AA8, "update_camera_on_path" },
    { 0x9AA9, "update_camera_params_ratio" },
    { 0x9AAA, "update_camera_position_on_path" },
    { 0x9AAB, "update_cave_drill_anim" },
    { 0x9AAC, "update_cave_drill_anim_inside" },
    { 0x9AAD, "update_deathflag" },
    { 0x9AAE, "update_debug_element_data" },
    { 0x9AAF, "update_debug_friendlycolor" },
    { 0x9AB0, "update_debug_friendlycolor_on_death" },
    { 0x9AB1, "update_dismount" },
    { 0x9AB2, "update_dodge" },
    { 0x9AB3, "update_drone_attacks" },
    { 0x9AB4, "update_drone_moves" },
    { 0x9AB5, "update_drone_tactical_movement" },
    { 0x9AB6, "update_dummy_target_position" },
    { 0x9AB7, "update_em1_heat_omnvar" },
    { 0x9AB8, "update_enemy_target_pos_while_running" },
    { 0x9AB9, "update_exo_battery_hud" },
    { 0x9ABA, "update_exo_shield_icon" },
    { 0x9ABB, "update_flag_outline" },
    { 0x9ABC, "update_flock" },
    { 0x9ABD, "update_flock_goal_positions" },
    { 0x9ABE, "update_flying_attack_drone_goal_pos" },
    { 0x9ABF, "update_func" },
    { 0x9AC0, "update_gamer_profile" },
    { 0x9AC1, "update_grenade_dodger" },
    { 0x9AC2, "update_health_bar" },
    { 0x9AC3, "update_hud_text" },
    { 0x9AC4, "update_local_class" },
    { 0x9AC5, "update_lua_hud" },
    { 0x9AC6, "update_max_players_from_team_agents" },
    { 0x9AC7, "update_minion_hud_outlines" },
    { 0x9AC8, "update_missile_hud" },
    { 0x9AC9, "update_move_anim_type" },
    { 0x9ACA, "update_move_front_bias" },
    { 0x9ACB, "update_moving_collision_on_node" },
    { 0x9ACC, "update_moving_object_volume" },
    { 0x9ACD, "update_nozzle_opening" },
    { 0x9ACE, "update_outlines" },
    { 0x9ACF, "update_overdrive_icon" },
    { 0x9AD0, "update_path_speed" },
    { 0x9AD1, "update_personality_camper" },
    { 0x9AD2, "update_personality_default" },
    { 0x9AD3, "update_player_attacker_accuracy" },
    { 0x9AD4, "update_player_damage" },
    { 0x9AD5, "update_rate" },
    { 0x9AD6, "update_reloading_progress_bar" },
    { 0x9AD7, "update_river_drill_anim" },
    { 0x9AD8, "update_rumble_intensity" },
    { 0x9AD9, "update_scanner_direction_in_track_player_mode" },
    { 0x9ADA, "update_scanner_yaw_in_sweep_mode" },
    { 0x9ADB, "update_scanner_yaw_returning_to_sweep_mode" },
    { 0x9ADC, "update_selected_entities" },
    { 0x9ADD, "update_sonic_aoe_icon" },
    { 0x9ADE, "update_stealth_debug_hud" },
    { 0x9ADF, "update_steering" },
    { 0x9AE0, "update_sun_flare_position" },
    { 0x9AE1, "update_tactical" },
    { 0x9AE2, "update_tactical_picker" },
    { 0x9AE3, "update_target_hud" },
    { 0x9AE4, "update_target_time" },
    { 0x9AE5, "update_thruster_angle" },
    { 0x9AE6, "update_thrusters" },
    { 0x9AE7, "update_time" },
    { 0x9AE8, "update_trigger_based_on_flags" },
    { 0x9AE9, "update_trigger_pos" },
    { 0x9AEA, "update_trophy_reload_progress_bar" },
    { 0x9AEB, "update_ui_timers" },
    { 0x9AEC, "update_vehicle_status" },
    { 0x9AED, "update_vfx_tags" },
    { 0x9AEE, "update_weapon_tag_visibility" },
    { 0x9AEF, "updateachievements" },
    { 0x9AF0, "updateaerialkillstreakmarker" },
    { 0x9AF1, "updateall" },
    { 0x9AF2, "updatealldifficulty" },
    { 0x9AF3, "updateammo" },
    { 0x9AF4, "updateangle" },
    { 0x9AF5, "updateanimpose" },
    { 0x9AF6, "updateattachedweaponmodels" },
    { 0x9AF7, "updatebar" },
    { 0x9AF8, "updatebarscale" },
    { 0x9AF9, "updatebodyroll" },
    { 0x9AFA, "updatebufferedstats" },
    { 0x9AFB, "updatecapsperminute" },
    { 0x9AFC, "updatecaptues" },
    { 0x9AFD, "updatecarryobjectorigin" },
    { 0x9AFE, "updatechallenges" },
    { 0x9AFF, "updatechatter" },
    { 0x9B00, "updatecheckforceragdoll" },
    { 0x9B01, "updatechildren" },
    { 0x9B02, "updatecombat" },
    { 0x9B03, "updatecombatrecord" },
    { 0x9B04, "updatecombatrecordcommondata" },
    { 0x9B05, "updatecombatrecordforplayer" },
    { 0x9B06, "updatecombatrecordforplayergamemodes" },
    { 0x9B07, "updatecombatrecordforplayertrends" },
    { 0x9B08, "updatecompassicon" },
    { 0x9B09, "updatecompassicons" },
    { 0x9B0A, "updatecontact" },
    { 0x9B0B, "updatecpm" },
    { 0x9B0C, "updatedamagefeedback" },
    { 0x9B0D, "updatedamagefeedbackhud" },
    { 0x9B0E, "updatedamagefeedbacksnd" },
    { 0x9B0F, "updateddmscores" },
    { 0x9B10, "updatedeathiconsenabled" },
    { 0x9B11, "updatedefends" },
    { 0x9B12, "updatedomscores" },
    { 0x9B13, "updatedronesattackspeedmultiplier" },
    { 0x9B14, "updateendreasontext" },
    { 0x9B15, "updateenemy" },
    { 0x9B16, "updateenemyuse" },
    { 0x9B17, "updateentityheadicon" },
    { 0x9B18, "updateentityheadiconorigin" },
    { 0x9B19, "updateflyinscopeoverlay" },
    { 0x9B1A, "updatefreeplayedtime" },
    { 0x9B1B, "updatefreeplayertimes" },
    { 0x9B1C, "updatefriendicons" },
    { 0x9B1D, "updatefriendiconsettings" },
    { 0x9B1E, "updatefrontandbackshields" },
    { 0x9B1F, "updategameevents" },
    { 0x9B20, "updategameobjecthudindex" },
    { 0x9B21, "updategameskill" },
    { 0x9B22, "updategametypedvars" },
    { 0x9B23, "updategiveuponsuppressiontimer" },
    { 0x9B24, "updateheadiconorigin" },
    { 0x9B25, "updateheading" },
    { 0x9B26, "updatehordesettings" },
    { 0x9B27, "updatehorizontalvelocity" },
    { 0x9B28, "updatehoveridle" },
    { 0x9B29, "updatehoverspeed" },
    { 0x9B2A, "updateidle" },
    { 0x9B2B, "updateisincombattimer" },
    { 0x9B2C, "updatekillstreaks" },
    { 0x9B2D, "updatelaserstatus" },
    { 0x9B2E, "updatelerppos" },
    { 0x9B2F, "updateloadouts" },
    { 0x9B30, "updatelossstats" },
    { 0x9B31, "updatelowermessage" },
    { 0x9B32, "updatemagshots" },
    { 0x9B33, "updatemainmenu" },
    { 0x9B34, "updatematchbonusscores" },
    { 0x9B35, "updatemelee" },
    { 0x9B36, "updatememberstates" },
    { 0x9B37, "updateminimapsetting" },
    { 0x9B38, "updateminions" },
    { 0x9B39, "updatemlgobjectives" },
    { 0x9B3A, "updatemove" },
    { 0x9B3B, "updatemoveanimweights" },
    { 0x9B3C, "updatemovemode" },
    { 0x9B3D, "updatemovespeedscale" },
    { 0x9B3E, "updatemovestate" },
    { 0x9B3F, "updatenamedally" },
    { 0x9B40, "updateobjectivehintmessage" },
    { 0x9B41, "updateobjectivehintmessages" },
    { 0x9B42, "updateobjectivetext" },
    { 0x9B43, "updateobjectiveui" },
    { 0x9B44, "updateorigin" },
    { 0x9B45, "updateoutlines" },
    { 0x9B46, "updatepaintoutline" },
    { 0x9B47, "updatepersratio" },
    { 0x9B48, "updatepersratiobuffered" },
    { 0x9B49, "updateplacement" },
    { 0x9B4A, "updateplayedtime" },
    { 0x9B4B, "updateplayerradarblocked" },
    { 0x9B4C, "updateplayersuavstatus" },
    { 0x9B4D, "updateplayertimes" },
    { 0x9B4E, "updateprogressbar" },
    { 0x9B4F, "updatepronethread" },
    { 0x9B50, "updatepronewrapper" },
    { 0x9B51, "updateproxbar" },
    { 0x9B52, "updaterank" },
    { 0x9B53, "updaterankannouncehud" },
    { 0x9B54, "updaterate" },
    { 0x9B55, "updaterecentkills" },
    { 0x9B56, "updaterecoiloffset" },
    { 0x9B57, "updatereflectionprobe" },
    { 0x9B58, "updaterespawnsplash" },
    { 0x9B59, "updatereturns" },
    { 0x9B5A, "updateriotshieldattachfornewweapon" },
    { 0x9B5B, "updateroundswon" },
    { 0x9B5C, "updaterumble" },
    { 0x9B5D, "updaterunweightsonce" },
    { 0x9B5E, "updatesavedlastweapon" },
    { 0x9B5F, "updatescanbar" },
    { 0x9B60, "updatescopeglintwarning" },
    { 0x9B61, "updatescopeoverlay" },
    { 0x9B62, "updatescopeoverlayalpha" },
    { 0x9B63, "updatescoreboardctf" },
    { 0x9B64, "updatescoreboarddom" },
    { 0x9B65, "updatescorestatsffa" },
    { 0x9B66, "updateselectedbutton" },
    { 0x9B67, "updatesentryplacement" },
    { 0x9B68, "updateserversettings" },
    { 0x9B69, "updatesessionstate" },
    { 0x9B6A, "updateshootinglocation" },
    { 0x9B6B, "updatesnipershooting" },
    { 0x9B6C, "updatesnipersuppression" },
    { 0x9B6D, "updatesnipertargetentitylocation" },
    { 0x9B6E, "updatesnipertargeting" },
    { 0x9B6F, "updatesnipertargetlocation" },
    { 0x9B70, "updatespectatedloadout" },
    { 0x9B71, "updatespectatedloadoutweapon" },
    { 0x9B72, "updatespectatesettings" },
    { 0x9B73, "updatesppercent" },
    { 0x9B74, "updatesquadlist" },
    { 0x9B75, "updatestairsstate" },
    { 0x9B76, "updatestate" },
    { 0x9B77, "updatestates" },
    { 0x9B78, "updatestreakcount" },
    { 0x9B79, "updatestreakslots" },
    { 0x9B7A, "updatesunshadowcenter" },
    { 0x9B7B, "updatesuppressionduration" },
    { 0x9B7C, "updatesuppressionfeedback" },
    { 0x9B7D, "updatetargetangularacceleration" },
    { 0x9B7E, "updatetargetdetails" },
    { 0x9B7F, "updateteambalance" },
    { 0x9B80, "updateteambalancedvar" },
    { 0x9B81, "updateteampaintoutline" },
    { 0x9B82, "updateteamplacement" },
    { 0x9B83, "updateteamradarblocked" },
    { 0x9B84, "updateteamscore" },
    { 0x9B85, "updateteamscores" },
    { 0x9B86, "updateteamtime" },
    { 0x9B87, "updateteamuavstatus" },
    { 0x9B88, "updateteamuavtype" },
    { 0x9B89, "updatetiestats" },
    { 0x9B8A, "updatetimer" },
    { 0x9B8B, "updatetimeromnvars" },
    { 0x9B8C, "updatetimerpausedness" },
    { 0x9B8D, "updatetispawnposition" },
    { 0x9B8E, "updatetraceentity" },
    { 0x9B8F, "updatetrigger" },
    { 0x9B90, "updatetriggerposition" },
    { 0x9B91, "updateturretplacement" },
    { 0x9B92, "updateuavmodelvisibility" },
    { 0x9B93, "updateuiflagomnvars" },
    { 0x9B94, "updateuiprogress" },
    { 0x9B95, "updateuiscorelimit" },
    { 0x9B96, "updateusablebyteam" },
    { 0x9B97, "updateuserate" },
    { 0x9B98, "updateuserate_internal" },
    { 0x9B99, "updatevelocity" },
    { 0x9B9A, "updateverticalvelocity" },
    { 0x9B9B, "updateviewmodelacceleration" },
    { 0x9B9C, "updateviewmodellookoffset" },
    { 0x9B9D, "updateviewmodelpitchoffset" },
    { 0x9B9E, "updateviewmodelvisibility" },
    { 0x9B9F, "updatevisibilityaccordingtoradar" },
    { 0x9BA0, "updatevisualmarker" },
    { 0x9BA1, "updatevisuals" },
    { 0x9BA2, "updatewaiter" },
    { 0x9BA3, "updatewatcheddvars" },
    { 0x9BA4, "updateweaponbufferedstats" },
    { 0x9BA5, "updateweaponusagestats" },
    { 0x9BA6, "updatewinlossstats" },
    { 0x9BA7, "updatewinstats" },
    { 0x9BA8, "updateworldicon" },
    { 0x9BA9, "updateworldicons" },
    { 0x9BAA, "updatinglootweapon" },
    { 0x9BAB, "upgrade_chal_complete_messages" },
    { 0x9BAC, "upgrade_chal_goal" },
    { 0x9BAD, "upgrade_chal_index" },
    { 0x9BAE, "upgrade_chal_points_trackers" },
    { 0x9BAF, "upgrade_chal_stat_map" },
    { 0x9BB0, "upgrade_challenge_complete" },
    { 0x9BB1, "upgrade_challenge_complete_for_intel" },
    { 0x9BB2, "upgrade_change_monitor" },
    { 0x9BB3, "upgrade_give_perk" },
    { 0x9BB4, "upgrade_init_perks_player" },
    { 0x9BB5, "upgrade_init_perks_players" },
    { 0x9BB6, "upgrade_init_perks_tables" },
    { 0x9BB7, "upgrade_init_player" },
    { 0x9BB8, "upgrade_init_tables" },
    { 0x9BB9, "upgrade_is_purchased" },
    { 0x9BBA, "upgrade_notify_stat" },
    { 0x9BBB, "upgrade_perk_active" },
    { 0x9BBC, "upgrade_perk_active_code" },
    { 0x9BBD, "upgrade_perk_code" },
    { 0x9BBE, "upgrade_perk_code_2" },
    { 0x9BBF, "upgrade_perk_dvar" },
    { 0x9BC0, "upgrade_perk_dvar_2" },
    { 0x9BC1, "upgrade_perk_dvar_newval" },
    { 0x9BC2, "upgrade_perk_dvar_newval_2" },
    { 0x9BC3, "upgrade_perk_dvar_origval" },
    { 0x9BC4, "upgrade_perk_dvar_origval_2" },
    { 0x9BC5, "upgrade_perk_script_code" },
    { 0x9BC6, "upgrade_ref" },
    { 0x9BC7, "upgrade_ref_index" },
    { 0x9BC8, "upgrade_take_perk" },
    { 0x9BC9, "upload_hold" },
    { 0x9BCA, "uploadglobalstatcounters" },
    { 0x9BCB, "ups_to_mph" },
    { 0x9BCC, "upsspeed" },
    { 0x9BCD, "upvec" },
    { 0x9BCE, "usable_turret_trigger" },
    { 0x9BCF, "usableent" },
    { 0x9BD0, "use_a_turret" },
    { 0x9BD1, "use_animstate" },
    { 0x9BD2, "use_big_goal_until_goal_is_safe" },
    { 0x9BD3, "use_boost_jump_dialogue" },
    { 0x9BD4, "use_box" },
    { 0x9BD5, "use_button_stopped_notify" },
    { 0x9BD6, "use_container_death" },
    { 0x9BD7, "use_crate" },
    { 0x9BD8, "use_eq_settings" },
    { 0x9BD9, "use_exo_shield_check" },
    { 0x9BDA, "use_hint" },
    { 0x9BDB, "use_hint_active" },
    { 0x9BDC, "use_hint_blinks" },
    { 0x9BDD, "use_hovertank_chromatic_aberration" },
    { 0x9BDE, "use_level_audio_zones" },
    { 0x9BDF, "use_lookahead" },
    { 0x9BE0, "use_m_turret_dialogue" },
    { 0x9BE1, "use_mobile_cover_dialogue" },
    { 0x9BE2, "use_old_battlechatter" },
    { 0x9BE3, "use_old_dog_attack" },
    { 0x9BE4, "use_pressed" },
    { 0x9BE5, "use_randomized_personality" },
    { 0x9BE6, "use_reverb_settings" },
    { 0x9BE7, "use_string_table_presets" },
    { 0x9BE8, "use_the_turret" },
    { 0x9BE9, "use_time" },
    { 0x9BEA, "use_toggle" },
    { 0x9BEB, "use_trigger" },
    { 0x9BEC, "use_triggers" },
    { 0x9BED, "use_turn_signal" },
    { 0x9BEE, "use_two_stage_swarm" },
    { 0x9BEF, "use_use_trigger" },
    { 0x9BF0, "usebreachapproach" },
    { 0x9BF1, "usebuttonrepressed" },
    { 0x9BF2, "useclip" },
    { 0x9BF3, "usecovernodeifpossible" },
    { 0x9BF4, "used" },
    { 0x9BF5, "used_an_mg42" },
    { 0x9BF6, "used_credits" },
    { 0x9BF7, "used_credits_data1" },
    { 0x9BF8, "used_credits_data2" },
    { 0x9BF9, "usedids" },
    { 0x9BFA, "usedkillstreak" },
    { 0x9BFB, "usednodes" },
    { 0x9BFC, "usedog" },
    { 0x9BFD, "usedpositions" },
    { 0x9BFE, "useent" },
    { 0x9BFF, "usefacialanims" },
    { 0x9C00, "usegoliathupdater" },
    { 0x9C01, "usehardpoint" },
    { 0x9C02, "useholdthink" },
    { 0x9C03, "useholdthinkcleanuponplayerdeath" },
    { 0x9C04, "useholdthinkloop" },
    { 0x9C05, "useholdthinkplayerreset" },
    { 0x9C06, "uselaststandparams" },
    { 0x9C07, "usemuzzleforaim" },
    { 0x9C08, "usemuzzlesideoffset" },
    { 0x9C09, "useobj" },
    { 0x9C0A, "useobject" },
    { 0x9C0B, "useobjectproxthink" },
    { 0x9C0C, "useobjectusethink" },
    { 0x9C0D, "usepostjuggernautupdater" },
    { 0x9C0E, "user_controlled_plane" },
    { 0x9C0F, "user_data" },
    { 0x9C10, "userate" },
    { 0x9C11, "usereadystand" },
    { 0x9C12, "useselfplacedturret" },
    { 0x9C13, "usesquadmate" },
    { 0x9C14, "usestartspawns" },
    { 0x9C15, "usestationaryturret" },
    { 0x9C16, "useteam" },
    { 0x9C17, "usetest" },
    { 0x9C18, "usetext" },
    { 0x9C19, "usetime" },
    { 0x9C1A, "usetrig" },
    { 0x9C1B, "useuav" },
    { 0x9C1C, "useweapon" },
    { 0x9C1D, "useweaponinfo" },
    { 0x9C1E, "using_a_turret" },
    { 0x9C1F, "using_ammo_cache" },
    { 0x9C20, "using_entity" },
    { 0x9C21, "using_hdr_fog" },
    { 0x9C22, "using_illegal_breach_weapon" },
    { 0x9C23, "using_oneshots_or_loops" },
    { 0x9C24, "using_overrides" },
    { 0x9C25, "using_remote_tank" },
    { 0x9C26, "using_remote_turret" },
    { 0x9C27, "using_remote_turret_when_died" },
    { 0x9C28, "using_string_tables" },
    { 0x9C29, "using_uav" },
    { 0x9C2A, "using_variable_grenade" },
    { 0x9C2B, "usingantiairweapon" },
    { 0x9C2C, "usingautomaticweapon" },
    { 0x9C2D, "usingboltactionweapon" },
    { 0x9C2E, "usingmg" },
    { 0x9C2F, "usingnvfx" },
    { 0x9C30, "usingonlinedataoffline" },
    { 0x9C31, "usingpistol" },
    { 0x9C32, "usingplayergrenadetimer" },
    { 0x9C33, "usingprimary" },
    { 0x9C34, "usingremote" },
    { 0x9C35, "usingriflelikeweapon" },
    { 0x9C36, "usingrocketlauncher" },
    { 0x9C37, "usingsecondary" },
    { 0x9C38, "usingsemiautoweapon" },
    { 0x9C39, "usingshotgun" },
    { 0x9C3A, "usingsidearm" },
    { 0x9C3B, "usingsmg" },
    { 0x9C3C, "usingturret" },
    { 0x9C3D, "util_evaluateknownenemylocation" },
    { 0x9C3E, "util_ignorecurrentsightpos" },
    { 0x9C3F, "util_physicspush_watcher" },
    { 0x9C40, "uts19shock" },
    { 0x9C41, "utsshockqueuedtime" },
    { 0x9C42, "v" },
    { 0x9C43, "valid" },
    { 0x9C44, "valid_ball_pickup_weapon" },
    { 0x9C45, "valid_tp_node" },
    { 0x9C46, "validate_drone_test_points" },
    { 0x9C47, "validate_max_value" },
    { 0x9C48, "validate_min_value" },
    { 0x9C49, "validate_target_pos" },
    { 0x9C4A, "validate_tp_orgs" },
    { 0x9C4B, "validateaccuratetouching" },
    { 0x9C4C, "validateflightlocationanddirection" },
    { 0x9C4D, "validateopenconditions" },
    { 0x9C4E, "validateperk" },
    { 0x9C4F, "validateusestreak" },
    { 0x9C50, "validator" },
    { 0x9C51, "validcostume" },
    { 0x9C52, "validplayers" },
    { 0x9C53, "value" },
    { 0x9C54, "value_hudelem" },
    { 0x9C55, "value_last" },
    { 0x9C56, "valueiswithin" },
    { 0x9C57, "values" },
    { 0x9C58, "valve_stop_animating" },
    { 0x9C59, "van_cuts_off_player" },
    { 0x9C5A, "van_knockback_blur" },
    { 0x9C5B, "van_open_bridge_collapse_dof" },
    { 0x9C5C, "van_scene_axis" },
    { 0x9C5D, "var1" },
    { 0x9C5E, "var2" },
    { 0x9C5F, "variable_grenade" },
    { 0x9C60, "variable_grenade_type_switch" },
    { 0x9C61, "variable_grenade_ui_enabled" },
    { 0x9C62, "variable_grenade_ui_type" },
    { 0x9C63, "variable_scope_shadow_center" },
    { 0x9C64, "variable_scope_weapons" },
    { 0x9C65, "variance" },
    { 0x9C66, "variant_limit" },
    { 0x9C67, "vb_anim_org" },
    { 0x9C68, "vdir" },
    { 0x9C69, "vec" },
    { 0x9C6A, "vec_acceleration" },
    { 0x9C6B, "vec_velocity" },
    { 0x9C6C, "vec2dot" },
    { 0x9C6D, "vec3_mult_matrix33" },
    { 0x9C6E, "vecscale" },
    { 0x9C6F, "vector" },
    { 0x9C70, "vector_clamp" },
    { 0x9C71, "vector2d" },
    { 0x9C72, "vectors_are_equal_2d" },
    { 0x9C73, "vegnette" },
    { 0x9C74, "veh" },
    { 0x9C75, "veh_aliases" },
    { 0x9C76, "veh_debug_monitor_3d" },
    { 0x9C77, "veh_debug_monitor_3d_callback" },
    { 0x9C78, "veh_ent" },
    { 0x9C79, "veh_mix_ents" },
    { 0x9C7A, "veh_moving_truck_chkpt" },
    { 0x9C7B, "veh_moving_truck_support_01_chkpt" },
    { 0x9C7C, "vehhelicoptercontrolsaltitude" },
    { 0x9C7D, "vehhelicoptercontrolsystem" },
    { 0x9C7E, "vehicle" },
    { 0x9C7F, "vehicle_ai_event" },
    { 0x9C80, "vehicle_ai_settings" },
    { 0x9C81, "vehicle_aianimcheck" },
    { 0x9C82, "vehicle_aianims" },
    { 0x9C83, "vehicle_aianimthread" },
    { 0x9C84, "vehicle_aim_turret_at_angle" },
    { 0x9C85, "vehicle_allows_driver_death" },
    { 0x9C86, "vehicle_allows_rider_death" },
    { 0x9C87, "vehicle_anim_array" },
    { 0x9C88, "vehicle_animate" },
    { 0x9C89, "vehicle_animpos_get_tag_angles" },
    { 0x9C8A, "vehicle_animpos_get_tag_origin" },
    { 0x9C8B, "vehicle_anims" },
    { 0x9C8C, "vehicle_anims_toload" },
    { 0x9C8D, "vehicle_attachedmodels" },
    { 0x9C8E, "vehicle_attacker" },
    { 0x9C8F, "vehicle_badplace" },
    { 0x9C90, "vehicle_becomes_crashable" },
    { 0x9C91, "vehicle_blocked_check" },
    { 0x9C92, "vehicle_bulletshield" },
    { 0x9C93, "vehicle_chase_target" },
    { 0x9C94, "vehicle_collision_enabled" },
    { 0x9C95, "vehicle_controlling" },
    { 0x9C96, "vehicle_crash_detection" },
    { 0x9C97, "vehicle_crash_now" },
    { 0x9C98, "vehicle_crash_on_death" },
    { 0x9C99, "vehicle_crash_when_blocked" },
    { 0x9C9A, "vehicle_crash_when_driver_dies" },
    { 0x9C9B, "vehicle_crashing_now" },
    { 0x9C9C, "vehicle_crashpaths" },
    { 0x9C9D, "vehicle_crazy_steering" },
    { 0x9C9E, "vehicle_crazy_steering_frogger" },
    { 0x9C9F, "vehicle_crazy_steering_frogger_fail_check" },
    { 0x9CA0, "vehicle_csv_export" },
    { 0x9CA1, "vehicle_death" },
    { 0x9CA2, "vehicle_death_add" },
    { 0x9CA3, "vehicle_death_add_remove_carcass" },
    { 0x9CA4, "vehicle_death_anim" },
    { 0x9CA5, "vehicle_death_badplace" },
    { 0x9CA6, "vehicle_death_earthquake" },
    { 0x9CA7, "vehicle_death_fx" },
    { 0x9CA8, "vehicle_death_fx_override" },
    { 0x9CA9, "vehicle_death_jolt" },
    { 0x9CAA, "vehicle_death_radiusdamage" },
    { 0x9CAB, "vehicle_death_thread" },
    { 0x9CAC, "vehicle_death_watcher" },
    { 0x9CAD, "vehicle_deathflag" },
    { 0x9CAE, "vehicle_deathmodel" },
    { 0x9CAF, "vehicle_deathmodel_delay" },
    { 0x9CB0, "vehicle_deathswitch" },
    { 0x9CB1, "vehicle_deckdust" },
    { 0x9CB2, "vehicle_deletegroup" },
    { 0x9CB3, "vehicle_detachfrompath" },
    { 0x9CB4, "vehicle_detect_crash" },
    { 0x9CB5, "vehicle_detourpaths" },
    { 0x9CB6, "vehicle_do_crash" },
    { 0x9CB7, "vehicle_draw_thermal" },
    { 0x9CB8, "vehicle_driveidle" },
    { 0x9CB9, "vehicle_driveidle_animrate" },
    { 0x9CBA, "vehicle_driveidle_normal_speed" },
    { 0x9CBB, "vehicle_driveidle_r" },
    { 0x9CBC, "vehicle_driver" },
    { 0x9CBD, "vehicle_drives_free_path" },
    { 0x9CBE, "vehicle_duck_once" },
    { 0x9CBF, "vehicle_dynamicpath" },
    { 0x9CC0, "vehicle_easy_crash_die" },
    { 0x9CC1, "vehicle_exhaust" },
    { 0x9CC2, "vehicle_explosions_for_drone_swarm" },
    { 0x9CC3, "vehicle_finish_death" },
    { 0x9CC4, "vehicle_fired_from" },
    { 0x9CC5, "vehicle_firing" },
    { 0x9CC6, "vehicle_free_path" },
    { 0x9CC7, "vehicle_frontarmor" },
    { 0x9CC8, "vehicle_gatetrigger" },
    { 0x9CC9, "vehicle_get_crash_struct" },
    { 0x9CCA, "vehicle_get_driver" },
    { 0x9CCB, "vehicle_get_path_array" },
    { 0x9CCC, "vehicle_get_riders" },
    { 0x9CCD, "vehicle_get_riders_by_group" },
    { 0x9CCE, "vehicle_getanimstart" },
    { 0x9CCF, "vehicle_getcurrentnode_a" },
    { 0x9CD0, "vehicle_getinanim" },
    { 0x9CD1, "vehicle_getinanim_clear" },
    { 0x9CD2, "vehicle_getinsound" },
    { 0x9CD3, "vehicle_getinsoundtag" },
    { 0x9CD4, "vehicle_getinstart" },
    { 0x9CD5, "vehicle_getoutanim" },
    { 0x9CD6, "vehicle_getoutanim_clear" },
    { 0x9CD7, "vehicle_getoutsound" },
    { 0x9CD8, "vehicle_getoutsoundtag" },
    { 0x9CD9, "vehicle_getspeed_a" },
    { 0x9CDA, "vehicle_go_to_end_and_delete" },
    { 0x9CDB, "vehicle_grenadeshield" },
    { 0x9CDC, "vehicle_handle_debugfly" },
    { 0x9CDD, "vehicle_handleunloadevent" },
    { 0x9CDE, "vehicle_has_rocket_death" },
    { 0x9CDF, "vehicle_hasavailablespots" },
    { 0x9CE0, "vehicle_hasmainturret" },
    { 0x9CE1, "vehicle_hasname" },
    { 0x9CE2, "vehicle_heli_default_path_speeds" },
    { 0x9CE3, "vehicle_hide_list" },
    { 0x9CE4, "vehicle_idle" },
    { 0x9CE5, "vehicle_idle_override" },
    { 0x9CE6, "vehicle_idleanim" },
    { 0x9CE7, "vehicle_idling" },
    { 0x9CE8, "vehicle_impact_rumble" },
    { 0x9CE9, "vehicle_in_front_of_node" },
    { 0x9CEA, "vehicle_init" },
    { 0x9CEB, "vehicle_is_crashing" },
    { 0x9CEC, "vehicle_isstationary" },
    { 0x9CED, "vehicle_keeps_going_after_driver_dies" },
    { 0x9CEE, "vehicle_kill" },
    { 0x9CEF, "vehicle_kill_badplace_forever" },
    { 0x9CF0, "vehicle_kill_common" },
    { 0x9CF1, "vehicle_kill_rumble_forever" },
    { 0x9CF2, "vehicle_kill_treads_forever" },
    { 0x9CF3, "vehicle_kill_triggers" },
    { 0x9CF4, "vehicle_killspawn_groups" },
    { 0x9CF5, "vehicle_land" },
    { 0x9CF6, "vehicle_land_beneath_node" },
    { 0x9CF7, "vehicle_landvehicle" },
    { 0x9CF8, "vehicle_levelstuff" },
    { 0x9CF9, "vehicle_life" },
    { 0x9CFA, "vehicle_life_range_high" },
    { 0x9CFB, "vehicle_life_range_low" },
    { 0x9CFC, "vehicle_liftoff" },
    { 0x9CFD, "vehicle_liftoffvehicle" },
    { 0x9CFE, "vehicle_lights" },
    { 0x9CFF, "vehicle_lights_group" },
    { 0x9D00, "vehicle_lights_group_override" },
    { 0x9D01, "vehicle_lights_off" },
    { 0x9D02, "vehicle_lights_on" },
    { 0x9D03, "vehicle_link" },
    { 0x9D04, "vehicle_linked_entities_think" },
    { 0x9D05, "vehicle_load_ai" },
    { 0x9D06, "vehicle_load_ai_single" },
    { 0x9D07, "vehicle_loaded_if_full" },
    { 0x9D08, "vehicle_loaded_notify_size" },
    { 0x9D09, "vehicle_luxurysedan" },
    { 0x9D0A, "vehicle_mainturrets" },
    { 0x9D0B, "vehicle_matchspeed" },
    { 0x9D0C, "vehicle_mgturret" },
    { 0x9D0D, "vehicle_missile_launcher" },
    { 0x9D0E, "vehicle_missile_launcher_count" },
    { 0x9D0F, "vehicle_mute_charge_cleanup" },
    { 0x9D10, "vehicle_mute_charge_failed" },
    { 0x9D11, "vehicle_nodrivers" },
    { 0x9D12, "vehicle_notsolid" },
    { 0x9D13, "vehicle_oscillate_location" },
    { 0x9D14, "vehicle_passenger_2_turret" },
    { 0x9D15, "vehicle_path_name" },
    { 0x9D16, "vehicle_pathdetach" },
    { 0x9D17, "vehicle_paths" },
    { 0x9D18, "vehicle_paths_helicopter" },
    { 0x9D19, "vehicle_paths_non_heli" },
    { 0x9D1A, "vehicle_pos" },
    { 0x9D1B, "vehicle_position" },
    { 0x9D1C, "vehicle_processtriggers" },
    { 0x9D1D, "vehicle_reload" },
    { 0x9D1E, "vehicle_resume_named" },
    { 0x9D1F, "vehicle_resumepath" },
    { 0x9D20, "vehicle_resumepathvehicle" },
    { 0x9D21, "vehicle_ride" },
    { 0x9D22, "vehicle_rideai" },
    { 0x9D23, "vehicle_rider_death_detection" },
    { 0x9D24, "vehicle_rider_death_func" },
    { 0x9D25, "vehicle_ridespawners" },
    { 0x9D26, "vehicle_rubberband" },
    { 0x9D27, "vehicle_rubberband_set_desired_range" },
    { 0x9D28, "vehicle_rubberband_set_fail_range" },
    { 0x9D29, "vehicle_rubberband_set_min_speed" },
    { 0x9D2A, "vehicle_rubberband_stop" },
    { 0x9D2B, "vehicle_rubberband_think" },
    { 0x9D2C, "vehicle_rumble" },
    { 0x9D2D, "vehicle_rumble_override" },
    { 0x9D2E, "vehicle_rumble_unique" },
    { 0x9D2F, "vehicle_script_forcecolor_riders" },
    { 0x9D30, "vehicle_selfremove" },
    { 0x9D31, "vehicle_set_fake_speed" },
    { 0x9D32, "vehicle_set_firing_disabled" },
    { 0x9D33, "vehicle_set_forced_target" },
    { 0x9D34, "vehicle_set_health" },
    { 0x9D35, "vehicle_set_target_tracking_disabled" },
    { 0x9D36, "vehicle_set_threat_grenade_response" },
    { 0x9D37, "vehicle_setteam" },
    { 0x9D38, "vehicle_setup_levelvars" },
    { 0x9D39, "vehicle_shoot_shock" },
    { 0x9D3A, "vehicle_should_do_rocket_death" },
    { 0x9D3B, "vehicle_should_regenerate" },
    { 0x9D3C, "vehicle_should_unload" },
    { 0x9D3D, "vehicle_sights_radius" },
    { 0x9D3E, "vehicle_single_light_off" },
    { 0x9D3F, "vehicle_single_light_on" },
    { 0x9D40, "vehicle_single_tread_list" },
    { 0x9D41, "vehicle_spawn" },
    { 0x9D42, "vehicle_spawn_functions_enable" },
    { 0x9D43, "vehicle_spawn_think" },
    { 0x9D44, "vehicle_spawned_thisframe" },
    { 0x9D45, "vehicle_spawner" },
    { 0x9D46, "vehicle_spawner_deathflag" },
    { 0x9D47, "vehicle_splash_water" },
    { 0x9D48, "vehicle_standattack" },
    { 0x9D49, "vehicle_startmovegroup" },
    { 0x9D4A, "vehicle_startnodes" },
    { 0x9D4B, "vehicle_stays_alive" },
    { 0x9D4C, "vehicle_stop_named" },
    { 0x9D4D, "vehicle_switch_paths" },
    { 0x9D4E, "vehicle_takedown_01_complete" },
    { 0x9D4F, "vehicle_takedown_01_dialogue" },
    { 0x9D50, "vehicle_takedown_01_dof" },
    { 0x9D51, "vehicle_takedown_01_nag_dialogue" },
    { 0x9D52, "vehicle_takedown_rumbles" },
    { 0x9D53, "vehicle_targeting" },
    { 0x9D54, "vehicle_targets" },
    { 0x9D55, "vehicle_team" },
    { 0x9D56, "vehicle_to_crash_struct" },
    { 0x9D57, "vehicle_to_crash_struct_dir" },
    { 0x9D58, "vehicle_to_dummy" },
    { 0x9D59, "vehicle_to_swap" },
    { 0x9D5A, "vehicle_treads" },
    { 0x9D5B, "vehicle_treads_script_model" },
    { 0x9D5C, "vehicle_turn_left" },
    { 0x9D5D, "vehicle_turn_right" },
    { 0x9D5E, "vehicle_turret_default_ai" },
    { 0x9D5F, "vehicle_turret_fire" },
    { 0x9D60, "vehicle_turret_requiresrider" },
    { 0x9D61, "vehicle_turret_scan_off" },
    { 0x9D62, "vehicle_turret_scan_on" },
    { 0x9D63, "vehicle_turret_settings_shoot" },
    { 0x9D64, "vehicle_turret_settings_target" },
    { 0x9D65, "vehicle_types" },
    { 0x9D66, "vehicle_under_construction" },
    { 0x9D67, "vehicle_unload" },
    { 0x9D68, "vehicle_unload_how_at_end" },
    { 0x9D69, "vehicle_unloadgroups" },
    { 0x9D6A, "vehicle_unloadwhenattacked" },
    { 0x9D6B, "vehicle_wait_for_crash" },
    { 0x9D6C, "vehicle_weave" },
    { 0x9D6D, "vehicle_wheels_backward" },
    { 0x9D6E, "vehicle_wheels_forward" },
    { 0x9D6F, "vehicle_would_exceed_limit" },
    { 0x9D70, "vehicleendinganimations" },
    { 0x9D71, "vehicleexplodeondeath" },
    { 0x9D72, "vehiclefireanim" },
    { 0x9D73, "vehiclefireanim_settle" },
    { 0x9D74, "vehicleid" },
    { 0x9D75, "vehicleinfo" },
    { 0x9D76, "vehicleinitthread" },
    { 0x9D77, "vehicleiscloaked" },
/* 1 gap somewhere
    "vehiclekilled",
    "vehiclemodifyflarevector",
    "vehicles",
    "vehicles_anims",
    "vehiclespawncallbackthread",
    "vehicletouchinganytrigger",
    "vehname",
    "vel",
    "velocity_calc",
    "velocity_scripted",
    "velocity_smoothing",
    "vending_machine",
    "vending_machine_damage_monitor",
    "venuscustomospfunc",
    "verify_effects_assignment",
    "verify_effects_assignment_print",
    "verify_jump_mount_points",
    "verify_mag_mount_points",
    "verifydedicatedconfiguration",
    "vert",
    "vertexlit",
    "vertical_cone_range",
    "verticaloffsetlook",
    "verticaloffsetstrafe",
    "very_first_tank",
    "very_first_tank_close",
    "veteran_achievement",
    "vfx_arm_piece_fall",
    "vfx_balcony_break_through",
    "vfx_bridge_chunk_f_piece5_fall",
    "vfx_bridge_crack_start",
    "vfx_bridge_fog_on",
    "vfx_bridge_seagulls_on",
    "vfx_bridge_shake_left",
    "vfx_bridge_shake_right",
    "vfx_bridge_snap",
    "vfx_bridge_traffic_intro",
    "vfx_burst_left_close",
    "vfx_burst_right_close",
    "vfx_bus_slide_spark",
    "vfx_cable_break",
    "vfx_cable_spark_hero",
    "vfx_car_radial_damage",
    "vfx_catwalk_lowering",
    "vfx_control_room_explo",
    "vfx_copcar_left_hitspark1",
    "vfx_copcar01_hitspark1",
    "vfx_copcar02_hitspark",
    "vfx_cutter_ignite",
    "vfx_cutter_spark",
    "vfx_dam_burst",
    "vfx_dam_setup",
    "vfx_dna_bomb_chain_explosion",
    "vfx_dna_bomb_drone_activate",
    "vfx_dna_bomb_drone_explode",
    "vfx_dna_bomb_drone_setup",
    "vfx_dna_bomb_drone_swarm_setup",
    "vfx_dna_bomb_flyby_papers",
    "vfx_dna_bomb_humvee_lights",
    "vfx_dna_bomb_mech_reveal",
    "vfx_drone_explo",
    "vfx_drone_explo_regularfx",
    "vfx_drone_fan_start",
    "vfx_drone_large_fan_start",
    "vfx_explosion_rumble_dust",
    "vfx_falling_debris_start",
    "vfx_foam_room",
    "vfx_gate_crash_open",
    "vfx_gideon_land_roof",
    "vfx_gideon_mech_rolls_over",
    "vfx_gideon_mech_sparks",
    "vfx_gushing_smk",
    "vfx_guy04_shot_blood",
    "vfx_handle_disintegrating_jet",
    "vfx_heli_drop_off_intro_on",
    "vfx_htank_disengage_grnd_smk",
    "vfx_htank_exhaust_electricity_powerup",
    "vfx_htank_exhaust_smk_burst",
    "vfx_htank_explosion",
    "vfx_htank_fake_treadfx_regular",
    "vfx_htank_fake_treadfx_strong",
    "vfx_htank_reveal",
    "vfx_htank_thruster_light_flicker",
    "vfx_htank_thruster_light_flicker_off",
    "vfx_htank_thruster_regular",
    "vfx_htank_thruster_start",
    "vfx_ilana_land_roof",
    "vfx_irons_fail_fall",
    "vfx_irons_fall_death",
    "vfx_irons_reveal_scene",
    "vfx_irons_tackle",
    "vfx_joker_land_roof",
    "vfx_landing_dust_npc",
    "vfx_mech_grapple_fx",
    "vfx_mech_grapple_strain_fx",
    "vfx_missile_docking_end",
    "vfx_missile_loading",
    "vfx_open_vent",
    "vfx_pitbull_atlas_impact",
    "vfx_pitbull_crash_jump_start",
    "vfx_pitbull_mud_spray",
    "vfx_pitbull_roof_impact",
    "vfx_pitbull_slide_sparks_start",
    "vfx_pitbull_slide_sparks_stop",
    "vfx_player_hit_windshield",
    "vfx_player_rolling_pebbles",
    "vfx_push_over_ledge",
    "vfx_raindrop",
    "vfx_razorback_jets_off",
    "vfx_razorback_jets_on",
    "vfx_rb_thruster_back_off",
    "vfx_rb_thruster_back_on",
    "vfx_rb_thruster_front_light_off",
    "vfx_rb_thruster_front_light_on",
    "vfx_rb_thruster_front_off",
    "vfx_rb_thruster_front_on",
    "vfx_reactivate_radius_damage",
    "vfx_red_lights_on",
    "vfx_shore_outro_start",
    "vfx_silo_corridor_lowering",
    "vfx_start_boost_fx",
    "vfx_stop_boost_fx",
    "vfx_sunflare",
    "vfx_van_back_door_open",
    "vfx_van_explosion_start",
    "vfx_van_passenger_door_open",
    "vfx_vm_arm_sever",
    "vfx_vm_arm_stab",
    "vfx_vm_exit_pod_start",
    "vfx_vm_land_crane_edge",
    "vfx_vm_land_roof",
    "vfx_vm_land_roof_hands",
    "vfx_vm_mech_dmg_sparks",
    "vfx_vm_mech_dmg_stop",
    "vfx_vm_mech_sparks",
    "vfx_vm_mech_stop_effects",
    "vfx_vtol_grapple",
    "vfx_warbird_dust_roof",
    "vfx_zipgun_fire",
    "vfxholoedge",
    "vfxtargetspawn",
    "vfxtargetspawnout",
*/
    { 0x9E07, "victim" },
    { 0x9E08, "victimonground" },
    { 0x9E09, "victimpoolkill" },
    { 0x9E0A, "victimteam" },
    { 0x9E0B, "video_cab_count" },
    { 0x9E0C, "video_chrome_ab" },
    { 0x9E0D, "video_idle" },
    { 0x9E0E, "video_warn_count" },
    { 0x9E0F, "videochatpostscreenhide" },
    { 0x9E10, "view_clamping_unlock" },
    { 0x9E11, "view_goal_pos" },
    { 0x9E12, "view_org" },
    { 0x9E13, "view_path_setup" },
    { 0x9E14, "view_paths" },
    { 0x9E15, "view_tag" },
    { 0x9E16, "viewfx" },
    { 0x9E17, "viewhands" },
    { 0x9E18, "viewmodel_blend" },
    { 0x9E19, "viewmodel_dof_end" },
    { 0x9E1A, "viewmodel_dof_start" },
    { 0x9E1B, "viewmodel_hidden" },
    { 0x9E1C, "viewmodel_swim_animations" },
    { 0x9E1D, "viewmodel_swim_animations_loop" },
    { 0x9E1E, "viewmodel_swim_handle_notetracks" },
    { 0x9E1F, "viewmodelanimupdate" },
    { 0x9E20, "viewtag" },
    { 0x9E21, "vig_ally_injured_cpr" },
    { 0x9E22, "vig_ally_injured_drag" },
    { 0x9E23, "vig_bike_rider_cyclist" },
    { 0x9E24, "vig_bike_rider_init" },
    { 0x9E25, "vig_bike_rider_maintainer" },
    { 0x9E26, "vig_bike_rider_nav" },
    { 0x9E27, "vig_bike_rider_removal" },
    { 0x9E28, "vig_bike_rider_scooter" },
    { 0x9E29, "vig_bike_rider_set_speed" },
    { 0x9E2A, "vig_civ_fail_on_damage" },
    { 0x9E2B, "vig_civ_model_randomizer" },
    { 0x9E2C, "vig_civ_removal" },
    { 0x9E2D, "vig_civ_streetarray" },
    { 0x9E2E, "vig_civ_traffic_balcony_setup" },
    { 0x9E2F, "vig_civ_traffic_init" },
    { 0x9E30, "vig_civ_traffic_spawn_idle_drones" },
    { 0x9E31, "vig_civ_traffic_spawn_walker_drones" },
    { 0x9E32, "vig_civ_traffic_street_setup" },
    { 0x9E33, "vig_civ_traffic_walker_setup" },
    { 0x9E34, "vig_civ_walker_maintainer" },
    { 0x9E35, "vig_civ_walker_removal" },
    { 0x9E36, "vig_intro_civ_populate" },
    { 0x9E37, "vig_mil_balc_setup" },
    { 0x9E38, "vig_tram_setup" },
    { 0x9E39, "vig_tram_setup_car" },
    { 0x9E3A, "vig_tram_setup_car_fx" },
    { 0x9E3B, "vig_tram_setup_car_shaker" },
    { 0x9E3C, "vig_tram_setup_intro" },
    { 0x9E3D, "vig_tram_setup_movement" },
    { 0x9E3E, "vig_vehicle_fail_on_death" },
    { 0x9E3F, "vig_vehicle_removal" },
    { 0x9E40, "vig_vehicle_traffic_init" },
    { 0x9E41, "vig_vehicle_traffic_jammer" },
    { 0x9E42, "vig_vehicle_traffic_removal" },
    { 0x9E43, "vig_vehicle_traffic_scripted_left" },
    { 0x9E44, "vig_vehicle_traffic_scripted_right" },
    { 0x9E45, "vig_vehicle_traffic_straight_mover_movement" },
    { 0x9E46, "vig_vehicle_traffic_turn_mover_movement" },
    { 0x9E47, "vig_walker_streetarray" },
    { 0x9E48, "vign_ai_check_for_death" },
    { 0x9E49, "vignette_actor_delete" },
    { 0x9E4A, "vignette_actor_ignore_everything" },
    { 0x9E4B, "vignette_actor_kill" },
    { 0x9E4C, "vignette_actor_spawn" },
    { 0x9E4D, "vignette_actor_spawn_func" },
    { 0x9E4E, "vignette_drone_spawn" },
    { 0x9E4F, "vignette_register" },
    { 0x9E50, "vignette_register_wait" },
    { 0x9E51, "vignette_vehicle_delete" },
    { 0x9E52, "vignette_vehicle_spawn" },
    { 0x9E53, "vinette_overlay" },
    { 0x9E54, "vip1" },
    { 0x9E55, "virtual_lobby_set_class" },
    { 0x9E56, "virtuallobbyactive" },
    { 0x9E57, "virus1_preset_constructor" },
    { 0x9E58, "visibility_distance" },
    { 0x9E59, "visibility_range_version" },
    { 0x9E5A, "visible" },
    { 0x9E5B, "visibleteam" },
    { 0x9E5C, "vision_cheat_enabled" },
    { 0x9E5D, "vision_default" },
    { 0x9E5E, "vision_enter_canal" },
    { 0x9E5F, "vision_seoul_art_center_atrium" },
    { 0x9E60, "vision_seoul_building_jump" },
    { 0x9E61, "vision_seoul_exterior" },
    { 0x9E62, "vision_seoul_hotel_hallway_cg" },
    { 0x9E63, "vision_seoul_hotel_interior" },
    { 0x9E64, "vision_seoul_hotel_interior_lrg" },
    { 0x9E65, "vision_seoul_shopping" },
    { 0x9E66, "vision_seoul_sinkhole" },
    { 0x9E67, "vision_seoul_streets_02" },
    { 0x9E68, "vision_seoul_streets_02_xx" },
    { 0x9E69, "vision_seoul_subway_interior" },
    { 0x9E6A, "vision_seoul_vista" },
    { 0x9E6B, "vision_set" },
    { 0x9E6C, "vision_set_changes" },
    { 0x9E6D, "vision_set_fog" },
    { 0x9E6E, "vision_set_fog_changes" },
    { 0x9E6F, "vision_set_fog_progress" },
    { 0x9E70, "vision_set_override" },
    { 0x9E71, "vision_set_sanfran" },
    { 0x9E72, "vision_set_transition_ent" },
    { 0x9E73, "vision_set_vision" },
    { 0x9E74, "vision_spidertank_moment_off" },
    { 0x9E75, "vision_spidertank_moment_on" },
    { 0x9E76, "vision_zone_manager" },
    { 0x9E77, "vision_zone_watcher" },
    { 0x9E78, "vision_zone_watcherb" },
    { 0x9E79, "visionset_betrayal_swim_tube" },
    { 0x9E7A, "visionset_default" },
    { 0x9E7B, "visionset_diff" },
    { 0x9E7C, "visionset_underwater" },
    { 0x9E7D, "visionthermaldefault" },
    { 0x9E7E, "visited" },
    { 0x9E7F, "visitfxent" },
    { 0x9E80, "visithideallmarkers" },
    { 0x9E81, "visiting_player_from_node" },
    { 0x9E82, "visitorcentergatebashfx" },
    { 0x9E83, "visitorhideall" },
    { 0x9E84, "visitorrelink" },
    { 0x9E85, "visitorretriggerfx" },
    { 0x9E86, "visitorshowtoplayer" },
    { 0x9E87, "visitorupdatelosmarker" },
    { 0x9E88, "visitorupdatemarkerpos" },
    { 0x9E89, "vista_ambientfx_aa_explosion" },
    { 0x9E8A, "vista_ambientfx_double_layer_missile_hit" },
    { 0x9E8B, "vista_ambientfx_double_layer_missile_hit_loop" },
    { 0x9E8C, "vista_ambientfx_midair_explosion" },
    { 0x9E8D, "vista_ent" },
    { 0x9E8E, "vista_ents" },
    { 0x9E8F, "vista_jet_array" },
    { 0x9E90, "vista_jets_reflection_override" },
    { 0x9E91, "vista_pigeons_alley1_market" },
    { 0x9E92, "vista_police_drones" },
    { 0x9E93, "vista_police_group_drones" },
    { 0x9E94, "vista_rockets" },
    { 0x9E95, "vista_rockets_first_impact" },
    { 0x9E96, "vista_rockets_pod_door_view_01" },
    { 0x9E97, "vista_rockets_pod_door_view_02" },
    { 0x9E98, "vista_warbird_fx" },
    { 0x9E99, "vistime" },
    { 0x9E9A, "visual_origin" },
    { 0x9E9B, "visualgroundoffset" },
    { 0x9E9C, "visuals" },
    { 0x9E9D, "vl_avatar_costume" },
    { 0x9E9E, "vl_avatar_loadout" },
    { 0x9E9F, "vl_cao_focus" },
    { 0x9EA0, "vl_clanprofile_focus" },
    { 0x9EA1, "vl_dof_based_on_focus" },
    { 0x9EA2, "vl_focus" },
    { 0x9EA3, "vl_give_weapons" },
    { 0x9EA4, "vl_ground_setup" },
    { 0x9EA5, "vl_handle_mode_change" },
    { 0x9EA6, "vl_init" },
    { 0x9EA7, "vl_lighting_setup" },
    { 0x9EA8, "vl_local_focus" },
    { 0x9EA9, "vl_main" },
    { 0x9EAA, "vl_onspawnplayer" },
    { 0x9EAB, "vlavatars" },
    { 0x9EAC, "vlcamera" },
    { 0x9EAD, "vlength" },
    { 0x9EAE, "vlobby_dof_based_on_focus" },
    { 0x9EAF, "vlobby_handle_mode_change" },
    { 0x9EB0, "vlobby_lighting_setup" },
    { 0x9EB1, "vlobby_player" },
    { 0x9EB2, "vlobby_vegnette" },
    { 0x9EB3, "vm" },
    { 0x9EB4, "vm_aud_air_vehicle_flyby" },
    { 0x9EB5, "vm_boat_crash_se_fx_start" },
    { 0x9EB6, "vm_boat_crash_se_whiteout" },
    { 0x9EB7, "vm_boat_emerge_fx" },
    { 0x9EB8, "vm_boat_submerge_fx" },
    { 0x9EB9, "vm_boat_wake" },
    { 0x9EBA, "vm_crash_transition" },
    { 0x9EBB, "vm_damaged_model" },
    { 0x9EBC, "vm_disablethrottleupdate" },
    { 0x9EBD, "vm_enablethrottleupdate" },
    { 0x9EBE, "vm_fx_loc" },
    { 0x9EBF, "vm_glass_impact" },
    { 0x9EC0, "vm_ground_vehicle_start" },
    { 0x9EC1, "vm_hand_sparks" },
    { 0x9EC2, "vm_init" },
    { 0x9EC3, "vm_is_proxy" },
    { 0x9EC4, "vm_launch_from" },
    { 0x9EC5, "vm_launch_to" },
    { 0x9EC6, "vm_linkto_new_entity" },
    { 0x9EC7, "vm_normal" },
    { 0x9EC8, "vm_normal_model" },
    { 0x9EC9, "vm_register_custom_callback" },
    { 0x9ECA, "vm_set_range" },
    { 0x9ECB, "vm_set_speed_callback" },
    { 0x9ECC, "vm_set_start_stop_callback" },
    { 0x9ECD, "vm_set_throttle_callback" },
    { 0x9ECE, "vm_soda_model" },
    { 0x9ECF, "vm_soda_start_angle" },
    { 0x9ED0, "vm_soda_start_pos" },
    { 0x9ED1, "vm_soda_stop_angle" },
    { 0x9ED2, "vm_soda_stop_pos" },
    { 0x9ED3, "vm_start_preset" },
    { 0x9ED4, "vm_stop" },
    { 0x9ED5, "vm_stop_preset_instance" },
    { 0x9ED6, "vm_water_impact" },
    { 0x9ED7, "vm2_get_instance_name" },
    { 0x9ED8, "vm2_get_vehicle_instance_count" },
    { 0x9ED9, "vm2_get_vehicle_snd_instance" },
    { 0x9EDA, "vm2x_delete_vehicle_sound_ents" },
    { 0x9EDB, "vm2x_fade_sound_obj" },
    { 0x9EDC, "vm2x_fadeout_vehicle" },
    { 0x9EDD, "vm2x_init_param_io_struct" },
    { 0x9EDE, "vm2x_remove_preset" },
    { 0x9EDF, "vmknifeblockfx" },
    { 0x9EE0, "vmlandingimpact" },
    { 0x9EE1, "vmodelbarrel" },
    { 0x9EE2, "vmodelouter" },
    { 0x9EE3, "vmstabbedfacefx" },
    { 0x9EE4, "vmx_aud_ent_fade_in" },
    { 0x9EE5, "vmx_aud_ent_fade_out" },
    { 0x9EE6, "vmx_callback" },
    { 0x9EE7, "vmx_cleanup_ents" },
    { 0x9EE8, "vmx_do_start_stop_callback" },
    { 0x9EE9, "vmx_get_altitude" },
    { 0x9EEA, "vmx_get_need_to_duck" },
    { 0x9EEB, "vmx_get_roll" },
    { 0x9EEC, "vmx_get_speed" },
    { 0x9EED, "vmx_get_start_sound_playing" },
    { 0x9EEE, "vmx_get_stop_sound_playing" },
    { 0x9EEF, "vmx_get_throttle" },
    { 0x9EF0, "vmx_get_tilt" },
    { 0x9EF1, "vmx_get_yaw" },
    { 0x9EF2, "vmx_ground_speed_watch" },
    { 0x9EF3, "vmx_ground_vehicle_monitor_death" },
    { 0x9EF4, "vmx_init_oneshot_ents" },
    { 0x9EF5, "vmx_monitor_explosion" },
    { 0x9EF6, "vmx_monitor_start_ent" },
    { 0x9EF7, "vmx_monitor_stop_ent" },
    { 0x9EF8, "vmx_play_start_sound" },
    { 0x9EF9, "vmx_play_stop_sound" },
    { 0x9EFA, "vmx_scale_start_sound_pitch" },
    { 0x9EFB, "vmx_scale_start_sound_volume" },
    { 0x9EFC, "vmx_scale_stop_sound_pitch" },
    { 0x9EFD, "vmx_scale_stop_sound_volume" },
    { 0x9EFE, "vmx_stop_start_ent" },
    { 0x9EFF, "vmx_stop_stop_ent" },
    { 0x9F00, "vmx_update_sound" },
    { 0x9F01, "vmx_vehicle_engine" },
    { 0x9F02, "vmx_waittill_deathspin" },
    { 0x9F03, "vmx_waittill_sounddone" },
    { 0x9F04, "vnum" },
    { 0x9F05, "vo" },
    { 0x9F06, "vo_canal" },
    { 0x9F07, "vo_canal_e3" },
    { 0x9F08, "vo_canal_finale" },
    { 0x9F09, "vo_canal_plant_explosives" },
    { 0x9F0A, "vo_canal_razorback" },
    { 0x9F0B, "vo_chatter_death" },
    { 0x9F0C, "vo_cutoff_subway_vo_early_check" },
    { 0x9F0D, "vo_duck_active" },
    { 0x9F0E, "vo_elevator_descent_nag" },
    { 0x9F0F, "vo_fob_meetup" },
    { 0x9F10, "vo_fus_silo_collapse_burke" },
    { 0x9F11, "vo_interior_control_room" },
    { 0x9F12, "vo_interior_control_room_explosion" },
    { 0x9F13, "vo_interior_control_room_nag" },
    { 0x9F14, "vo_interior_lab" },
    { 0x9F15, "vo_interior_reactor" },
    { 0x9F16, "vo_interior_security_room" },
    { 0x9F17, "vo_interior_turbine_elevator" },
    { 0x9F18, "vo_interior_turbine_elevator_nag" },
    { 0x9F19, "vo_interior_turbine_room" },
    { 0x9F1A, "vo_jump_training" },
    { 0x9F1B, "vo_meet_atlas_dialogue" },
    { 0x9F1C, "vo_nag_get_warbirds" },
    { 0x9F1D, "vo_nk_first_contact" },
    { 0x9F1E, "vo_post_building_jump" },
    { 0x9F1F, "vo_priority" },
    { 0x9F20, "vo_push_through_hotel" },
    { 0x9F21, "vo_sd_demo_team_call" },
    { 0x9F22, "vo_sd_drone_swarm_dialogue" },
    { 0x9F23, "vo_shopping_district" },
    { 0x9F24, "vo_sinkhole" },
    { 0x9F25, "vo_subway" },
    { 0x9F26, "vo_subway_car" },
    { 0x9F27, "vo_subway_civ_convo1" },
    { 0x9F28, "vo_subway_civ_convo2" },
    { 0x9F29, "vo_subway_civ_convo3" },
    { 0x9F2A, "vo_subway_civ_convo4" },
    { 0x9F2B, "vo_subway_pa_announcements" },
    { 0x9F2C, "vo_subway_threat_grenade_moment" },
    { 0x9F2D, "vo_test" },
    { 0x9F2E, "vo_tower_debris_radio_chatter" },
    { 0x9F2F, "vo_turbine_room_clear" },
    { 0x9F30, "vo_zipliners_hotel" },
    { 0x9F31, "vodestroyed" },
    { 0x9F32, "voice" },
    { 0x9F33, "voice_count" },
    { 0x9F34, "voice_is_british_based" },
    { 0x9F35, "voicecanburst" },
    { 0x9F36, "void" },
    { 0x9F37, "vol" },
    { 0x9F38, "vol_auto_disable" },
    { 0x9F39, "vol_map_name" },
    { 0x9F3A, "volcanostarteruption" },
    { 0x9F3B, "vols" },
    { 0x9F3C, "volume" },
    { 0x9F3D, "volume_array" },
    { 0x9F3E, "volume_fallingwaterfx" },
    { 0x9F3F, "volume_map_name" },
    { 0x9F40, "volume_wakefx" },
    { 0x9F41, "volumes_targetname" },
    { 0x9F42, "vooffline" },
    { 0x9F43, "vopower" },
    { 0x9F44, "vpoint" },
    { 0x9F45, "vrap_explode" },
    { 0x9F46, "vrap_mute_obj" },
    { 0x9F47, "vrap_mute_trig" },
    { 0x9F48, "vrap_sonic_blast_immunity_toggle" },
    { 0x9F49, "vrap_spawn" },
    { 0x9F4A, "vrap_takedown_lights_off" },
    { 0x9F4B, "vrap_takedown_lights_on" },
    { 0x9F4C, "vrapcount" },
    { 0x9F4D, "vrs1_condition_to_adaptive" },
    { 0x9F4E, "vrs1_condition_to_mix1" },
    { 0x9F4F, "vrs1_condition_to_mix2" },
    { 0x9F50, "vrs1_enter_adaptive" },
    { 0x9F51, "vrs1_enter_mix1" },
    { 0x9F52, "vrs1_enter_mix2" },
    { 0x9F53, "vrs1_instance_init" },
    { 0x9F54, "vtclassname" },
    { 0x9F55, "vteam" },
    { 0x9F56, "vtmodel" },
    { 0x9F57, "vtol" },
    { 0x9F58, "vtol_animnode" },
    { 0x9F59, "vtol_battle_redux" },
    { 0x9F5A, "vtol_damage_monitor" },
    { 0x9F5B, "vtol_death_if_pilot_shot" },
    { 0x9F5C, "vtol_delayed_stinger_ignore" },
    { 0x9F5D, "vtol_exhaust" },
    { 0x9F5E, "vtol_fight" },
    { 0x9F5F, "vtol_fire_late_rpgs" },
    { 0x9F60, "vtol_flyin" },
    { 0x9F61, "vtol_flyover" },
    { 0x9F62, "vtol_fx_land" },
    { 0x9F63, "vtol_lights" },
    { 0x9F64, "vtol_obj_marker_monitor" },
    { 0x9F65, "vtol_player_fired" },
    { 0x9F66, "vtol_reset_player_orientations" },
    { 0x9F67, "vtol_rocket_death" },
    { 0x9F68, "vtol_sequence" },
    { 0x9F69, "vtol_takedown_cargo_and_cables" },
    { 0x9F6A, "vtol_takedown_chopper" },
    { 0x9F6B, "vtol_takedown_cormack" },
    { 0x9F6C, "vtol_takedown_cormack_stinger" },
    { 0x9F6D, "vtol_takedown_dialogue" },
    { 0x9F6E, "vtol_takedown_failure" },
    { 0x9F6F, "vtol_takedown_gideon" },
    { 0x9F70, "vtol_takedown_gideon_slide_fx" },
    { 0x9F71, "vtol_takedown_gun_pickup" },
    { 0x9F72, "vtol_takedown_hide_check" },
    { 0x9F73, "vtol_takedown_ilona" },
    { 0x9F74, "vtol_takedown_player_grabs_cargo" },
    { 0x9F75, "vtol_takedown_shoot_monitor" },
    { 0x9F76, "vtol_takedown_terrain" },
    { 0x9F77, "vtol_takedown_vtol" },
    { 0x9F78, "vtol_takedown_vtol_slide_fx" },
    { 0x9F79, "vtolfx" },
    { 0x9F7A, "vtoverride" },
    { 0x9F7B, "vttype" },
    { 0x9F7C, "vulcanlightset" },
    { 0x9F7D, "vulcanvisionset" },
    { 0x9F7E, "wading_adjust_angles" },
    { 0x9F7F, "wading_footsteps" },
    { 0x9F80, "wading_footsteps_ends" },
    { 0x9F81, "wait_and_delete" },
    { 0x9F82, "wait_and_fire" },
    { 0x9F83, "wait_any_func_array" },
    { 0x9F84, "wait_current_zone_finish" },
    { 0x9F85, "wait_endon" },
    { 0x9F86, "wait_for_all_deck_warbirds_to_unload" },
    { 0x9F87, "wait_for_an_unlocked_trigger" },
    { 0x9F88, "wait_for_anim" },
    { 0x9F89, "wait_for_anim_start" },
    { 0x9F8A, "wait_for_any_trigger_hit" },
    { 0x9F8B, "wait_for_breach_or_deletion" },
    { 0x9F8C, "wait_for_buffer_time_to_pass" },
    { 0x9F8D, "wait_for_cleanup" },
    { 0x9F8E, "wait_for_considerable_left_stick_interact" },
    { 0x9F8F, "wait_for_crash_at_end" },
    { 0x9F90, "wait_for_damage" },
    { 0x9F91, "wait_for_death" },
    { 0x9F92, "wait_for_drone_finished" },
    { 0x9F93, "wait_for_drone_message_or_death" },
    { 0x9F94, "wait_for_either_trigger" },
    { 0x9F95, "wait_for_exit_message" },
    { 0x9F96, "wait_for_exocloak_cancel" },
    { 0x9F97, "wait_for_exocloak_pressed" },
    { 0x9F98, "wait_for_false" },
    { 0x9F99, "wait_for_false2" },
    { 0x9F9A, "wait_for_false3" },
    { 0x9F9B, "wait_for_false4" },
    { 0x9F9C, "wait_for_false5" },
    { 0x9F9D, "wait_for_false6" },
    { 0x9F9E, "wait_for_flag_or_player_command" },
    { 0x9F9F, "wait_for_flag_or_player_command_aux" },
    { 0x9FA0, "wait_for_flag_or_time_elapses" },
    { 0x9FA1, "wait_for_flag_or_timeout" },
    { 0x9FA2, "wait_for_formation" },
    { 0x9FA3, "wait_for_formation_break" },
    { 0x9FA4, "wait_for_game_end" },
    { 0x9FA5, "wait_for_guy_to_die_or_get_in_position" },
    { 0x9FA6, "wait_for_hit_reaction" },
    { 0x9FA7, "wait_for_interrupted" },
    { 0x9FA8, "wait_for_laser_end" },
    { 0x9FA9, "wait_for_level_notify_or_timeout" },
    { 0x9FAA, "wait_for_mech_distance" },
    { 0x9FAB, "wait_for_missile" },
    { 0x9FAC, "wait_for_mission_fail" },
    { 0x9FAD, "wait_for_mob_turret_targets_to_be_destroyed" },
    { 0x9FAE, "wait_for_no_trigger_and_ai_group" },
    { 0x9FAF, "wait_for_no_trigger_and_ai_single" },
    { 0x9FB0, "wait_for_no_trigger_just_ai_group" },
    { 0x9FB1, "wait_for_no_trigger_just_ai_single" },
    { 0x9FB2, "wait_for_not_using_remote" },
    { 0x9FB3, "wait_for_notify_or_timeout" },
    { 0x9FB4, "wait_for_number_enemies_alive" },
    { 0x9FB5, "wait_for_pickup" },
    { 0x9FB6, "wait_for_player_death" },
    { 0x9FB7, "wait_for_player_release" },
    { 0x9FB8, "wait_for_player_switch_to_turret" },
    { 0x9FB9, "wait_for_player_to_complete_reloading" },
    { 0x9FBA, "wait_for_primary_weapon_pickup" },
    { 0x9FBB, "wait_for_script_noteworthy_trigger" },
    { 0x9FBC, "wait_for_sounddone_det_gdn_mitchellonme" },
    { 0x9FBD, "wait_for_sounddone_or_death" },
    { 0x9FBE, "wait_for_stick_press" },
    { 0x9FBF, "wait_for_success_press" },
    { 0x9FC0, "wait_for_targetname_trigger" },
    { 0x9FC1, "wait_for_threat_grenade" },
    { 0x9FC2, "wait_for_thrown_grenade" },
    { 0x9FC3, "wait_for_trigger" },
    { 0x9FC4, "wait_for_trigger_and_ai_group" },
    { 0x9FC5, "wait_for_trigger_and_ai_single" },
    { 0x9FC6, "wait_for_trigger_just_ai_group" },
    { 0x9FC7, "wait_for_trigger_just_ai_single" },
    { 0x9FC8, "wait_for_trigger_or_timeout" },
    { 0x9FC9, "wait_for_trigger_set_flag" },
    { 0x9FCA, "wait_for_trigger_think" },
    { 0x9FCB, "wait_for_trigger_with_group_not_touching" },
    { 0x9FCC, "wait_for_trigger_with_group_touching" },
    { 0x9FCD, "wait_for_true" },
    { 0x9FCE, "wait_for_true2" },
    { 0x9FCF, "wait_for_true3" },
    { 0x9FD0, "wait_for_true4" },
    { 0x9FD1, "wait_for_true5" },
    { 0x9FD2, "wait_for_turn_signal_off" },
    { 0x9FD3, "wait_for_turret_reset" },
    { 0x9FD4, "wait_for_vehicle_dismount" },
    { 0x9FD5, "wait_for_vehicle_mount" },
    { 0x9FD6, "wait_for_walker_to_be_hit_by_smaw" },
    { 0x9FD7, "wait_for_warbird_fire_target_done" },
    { 0x9FD8, "wait_heli_uncloak" },
    { 0x9FD9, "wait_in_current_air_space" },
    { 0x9FDA, "wait_kill_me" },
    { 0x9FDB, "wait_load_costume" },
    { 0x9FDC, "wait_load_costume_show" },
    { 0x9FDD, "wait_load_costume_timeout" },
    { 0x9FDE, "wait_ref_count" },
    { 0x9FDF, "wait_resume_path" },
    { 0x9FE0, "wait_spreader_allotment" },
    { 0x9FE1, "wait_spreaders" },
    { 0x9FE2, "wait_start_firingrange" },
    { 0x9FE3, "wait_then_movetogoalvol" },
    { 0x9FE4, "wait_til_node_wait_triggered" },
    { 0x9FE5, "wait_til_pdrone_launched" },
    { 0x9FE6, "wait_till_agent_funcs_defined" },
    { 0x9FE7, "wait_till_death_try_respawn_death" },
    { 0x9FE8, "wait_till_every_thing_stealth_normal_for" },
    { 0x9FE9, "wait_till_on_ship" },
    { 0x9FEA, "wait_till_should_stop_drawing" },
    { 0x9FEB, "wait_till_snakes_nearby" },
    { 0x9FEC, "wait_time" },
    { 0x9FED, "wait_to_clean_car" },
    { 0x9FEE, "wait_to_decloak_helicopter" },
    { 0x9FEF, "wait_to_destroy_nvg_overlay" },
    { 0x9FF0, "wait_to_fire_rope" },
    { 0x9FF1, "wait_to_give_boost_to_player" },
    { 0x9FF2, "wait_to_go" },
    { 0x9FF3, "wait_to_kill_aim_cursor" },
    { 0x9FF4, "wait_to_kill_path" },
    { 0x9FF5, "wait_to_remove_target" },
    { 0x9FF6, "wait_to_stop_firing" },
    { 0x9FF7, "wait_until_an_enemy_is_in_safe_area" },
    { 0x9FF8, "wait_until_anim_finishes" },
    { 0x9FF9, "wait_until_both_swings_pressed" },
    { 0x9FFA, "wait_until_done_speaking" },
    { 0x9FFB, "wait_until_left_swing_pressed" },
    { 0x9FFC, "wait_until_new_target" },
    { 0x9FFD, "wait_until_next_left_swing" },
    { 0x9FFE, "wait_until_next_right_swing" },
    { 0x9FFF, "wait_until_path_safe" },
    { 0xA000, "wait_until_right_swing_pressed" },
    { 0xA001, "wait_until_unloaded" },
    { 0xA002, "wait_until_vision_check_satisfied_or_disabled" },
    { 0xA003, "waitabit" },
    { 0xA004, "waitaftershot" },
    { 0xA005, "waitanddelete" },
    { 0xA006, "waitanddetonate" },
    { 0xA007, "waitandprocessplayerkilledcallback" },
    { 0xA008, "waitandspawnclient" },
    { 0xA009, "waitattachflag" },
    { 0xA00A, "waitattachmentcooldown" },
    { 0xA00B, "waitcarryobjects" },
    { 0xA00C, "waitcopycatkillcambutton" },
    { 0xA00D, "waitdelay" },
    { 0xA00E, "waitdelayminetime" },
    { 0xA00F, "waitdisableshadows" },
    { 0xA010, "waitforairstrikecancel" },
    { 0xA011, "waitforbadpath" },
    { 0xA012, "waitforbadpathhorde" },
    { 0xA013, "waitforbark" },
    { 0xA014, "waitforblockedwhilestopping" },
    { 0xA015, "waitforbuddyspawntimer" },
    { 0xA016, "waitforc4detonation" },
    { 0xA017, "waitforchangeteam" },
    { 0xA018, "waitforclassselect" },
    { 0xA019, "waitforcleanup" },
    { 0xA01A, "waitfordeath" },
    { 0xA01B, "waitfordrivenchange" },
    { 0xA01C, "waitforfacesound" },
    { 0xA01D, "waitforfacialanim" },
    { 0xA01E, "waitforfollowspeed" },
    { 0xA01F, "waitforgasdamage" },
    { 0xA020, "waitforhoodoodamage" },
    { 0xA021, "waitforhoodooflag" },
    { 0xA022, "waitforkillstreakweaponchange" },
    { 0xA023, "waitforkillstreakweaponswitchinvalid" },
    { 0xA024, "waitforkillstreakweaponswitchstarted" },
    { 0xA025, "waitforlaserdeath" },
    { 0xA026, "waitforpathgoalpos" },
    { 0xA027, "waitforpathset" },
    { 0xA028, "waitforpathsetwhilestopping" },
    { 0xA029, "waitforplayerbulletwhizby" },
    { 0xA02A, "waitforplayerrespawnchoice" },
    { 0xA02B, "waitforplayers" },
    { 0xA02C, "waitforragdoll" },
    { 0xA02D, "waitforratechange" },
    { 0xA02E, "waitforreaderdelete" },
    { 0xA02F, "waitforreinforcementoftype" },
    { 0xA030, "waitforrocketdeath" },
    { 0xA031, "waitforrocketimpact" },
    { 0xA032, "waitforrunwalkchange" },
    { 0xA033, "waitforrunwalkslopechange" },
    { 0xA034, "waitforscramblejump" },
    { 0xA035, "waitforsharpturn" },
    { 0xA036, "waitforsharpturnduringsharpturn" },
    { 0xA037, "waitforsharpturnwhilestopping" },
    { 0xA038, "waitforspawnfinished" },
    { 0xA039, "waitforstancechange" },
    { 0xA03A, "waitforstatechange" },
    { 0xA03B, "waitforstop" },
    { 0xA03C, "waitforstopearly" },
    { 0xA03D, "waitfortimeornotifies" },
    { 0xA03E, "waitfortimeornotify" },
    { 0xA03F, "waitfortimeout" },
    { 0xA040, "waitforwalkerdelete" },
    { 0xA041, "waitillairstrikeoverbombingarea" },
    { 0xA042, "waitillcanspawnclient" },
    { 0xA043, "waiting_for_queue" },
    { 0xA044, "waiting_mechs" },
    { 0xA045, "waiting_on_left_swing" },
    { 0xA046, "waiting_on_right_swing" },
    { 0xA047, "waitingforgate" },
    { 0xA048, "waitingforplayers" },
    { 0xA049, "waitingforspawnduringstreak" },
    { 0xA04A, "waitingtodeactivate" },
    { 0xA04B, "waitingtodie" },
    { 0xA04C, "waitingtoselectclass" },
    { 0xA04D, "waitingtospawn" },
    { 0xA04E, "waitingtospawnamortize" },
    { 0xA04F, "waitingtospawndrone" },
    { 0xA050, "waitloadoutdone" },
    { 0xA051, "waitlongdurationwithgameendtimeupdate" },
    { 0xA052, "waitlongdurationwithhostmigrationpause" },
    { 0xA053, "waitplayerstuckoncarepackagereturn" },
    { 0xA054, "waitrequirevisibility" },
    { 0xA055, "waitrespawnbutton" },
    { 0xA056, "waitrestoreperks" },
    { 0xA057, "waitsetstates" },
    { 0xA058, "waitsetstatic" },
    { 0xA059, "waitsetstop" },
    { 0xA05A, "waitsetthermal" },
    { 0xA05B, "waitskipkillcambutton" },
    { 0xA05C, "waitsmoketime" },
    { 0xA05D, "waitspawnrandombutton" },
    { 0xA05E, "waitspread_code" },
    { 0xA05F, "waitspread_insert" },
    { 0xA060, "waitsuppresstimeout" },
    { 0xA061, "waittakekillstreakweapon" },
    { 0xA062, "waitteamspawnbutton" },
    { 0xA063, "waitthenflashhudtimer" },
    { 0xA064, "waittill_abort_func_ends" },
    { 0xA065, "waittill_aerial_pathnodes_calculated" },
    { 0xA066, "waittill_aigroupcleared" },
    { 0xA067, "waittill_aigroupcount" },
    { 0xA068, "waittill_aigroupcount_or_flag" },
    { 0xA069, "waittill_any" },
    { 0xA06A, "waittill_any_ents" },
    { 0xA06B, "waittill_any_in_array_or_timeout" },
    { 0xA06C, "waittill_any_in_array_or_timeout_no_endon_death" },
    { 0xA06D, "waittill_any_in_array_return" },
    { 0xA06E, "waittill_any_in_array_return_no_endon_death" },
    { 0xA06F, "waittill_any_or_timeout" },
    { 0xA070, "waittill_any_return" },
    { 0xA071, "waittill_any_return_no_endon_death" },
    { 0xA072, "waittill_any_return_parms" },
    { 0xA073, "waittill_any_timeout" },
    { 0xA074, "waittill_any_timeout_no_endon_death" },
    { 0xA075, "waittill_any_timeout_pause_on_death_and_prematch" },
    { 0xA076, "waittill_any_trigger" },
    { 0xA077, "waittill_attack_and_launch_drones" },
    { 0xA078, "waittill_combat" },
    { 0xA079, "waittill_combat_wait" },
    { 0xA07A, "waittill_copier_copies" },
    { 0xA07B, "waittill_crate_activated" },
    { 0xA07C, "waittill_dash_button_pressed" },
    { 0xA07D, "waittill_dash_button_released" },
    { 0xA07E, "waittill_dead" },
    { 0xA07F, "waittill_dead_or_dying" },
    { 0xA080, "waittill_dead_or_dying_thread" },
    { 0xA081, "waittill_dead_thread" },
    { 0xA082, "waittill_dead_timeout" },
    { 0xA083, "waittill_death" },
    { 0xA084, "waittill_dmg_timeout" },
    { 0xA085, "waittill_drones_dead" },
    { 0xA086, "waittill_dropoff_height" },
    { 0xA087, "waittill_either" },
    { 0xA088, "waittill_either_differnt_senders" },
    { 0xA089, "waittill_either_function" },
    { 0xA08A, "waittill_either_function_internal" },
    { 0xA08B, "waittill_enemy_group_size_is" },
    { 0xA08C, "waittill_entity_activate_looking_at" },
    { 0xA08D, "waittill_entity_in_range" },
    { 0xA08E, "waittill_entity_in_range_or_timeout" },
    { 0xA08F, "waittill_entity_out_of_range" },
    { 0xA090, "waittill_finish_moving" },
    { 0xA091, "waittill_func_ends" },
    { 0xA092, "waittill_glass_break" },
    { 0xA093, "waittill_grenade_damage" },
    { 0xA094, "waittill_has_reached_hill_idle" },
    { 0xA095, "waittill_in_range" },
    { 0xA096, "waittill_land_assist_ended" },
    { 0xA097, "waittill_marker_passed" },
    { 0xA098, "waittill_match_or_timeout" },
    { 0xA099, "waittill_msg" },
    { 0xA09A, "waittill_multiple" },
    { 0xA09B, "waittill_multiple_ents" },
    { 0xA09C, "waittill_notetrack_or_damage" },
    { 0xA09D, "waittill_notify_func" },
    { 0xA09E, "waittill_notify_func_ent" },
    { 0xA09F, "waittill_notify_or_flag" },
    { 0xA0A0, "waittill_notify_or_timeout" },
    { 0xA0A1, "waittill_notify_or_timeout_hostmigration_pause" },
    { 0xA0A2, "waittill_notify_or_timeout_return" },
    { 0xA0A3, "waittill_nt" },
    { 0xA0A4, "waittill_objective_event" },
    { 0xA0A5, "waittill_objective_event_notrigger" },
    { 0xA0A6, "waittill_objective_event_proc" },
    { 0xA0A7, "waittill_or_timeout" },
    { 0xA0A8, "waittill_player_exo_climbing" },
    { 0xA0A9, "waittill_player_fall" },
    { 0xA0AA, "waittill_player_hits_a" },
    { 0xA0AB, "waittill_player_in_range" },
    { 0xA0AC, "waittill_player_lookat" },
    { 0xA0AD, "waittill_player_lookat_for_time" },
    { 0xA0AE, "waittill_player_not_exo_climbing" },
    { 0xA0AF, "waittill_player_presses_triggers" },
    { 0xA0B0, "waittill_player_tries_to_advance" },
    { 0xA0B1, "waittill_player_uses_land_assist" },
    { 0xA0B2, "waittill_player_uses_land_assist_or_is_a_jerk" },
    { 0xA0B3, "waittill_player_uses_truck_latch" },
    { 0xA0B4, "waittill_pushed_by" },
    { 0xA0B5, "waittill_s2_drone_ambush_done" },
    { 0xA0B6, "waittill_shot_then_die" },
    { 0xA0B7, "waittill_spawn_waterfall_fight" },
    { 0xA0B8, "waittill_stable" },
    { 0xA0B9, "waittill_string" },
    { 0xA0BA, "waittill_string_no_endon_death" },
    { 0xA0BB, "waittill_string_parms" },
    { 0xA0BC, "waittill_tag_calculated_on_path_grid" },
    { 0xA0BD, "waittill_targetname_volume_dead_then_set_flag" },
    { 0xA0BE, "waittill_till_timeout_or_boost" },
    { 0xA0BF, "waittill_time_or_msg" },
    { 0xA0C0, "waittill_touching_entity" },
    { 0xA0C1, "waittill_trigger_activate_looking_at" },
    { 0xA0C2, "waittill_trigger_with_name" },
    { 0xA0C3, "waittill_triggered_current" },
    { 0xA0C4, "waittill_true_goal" },
    { 0xA0C5, "waittill_turret_is_released" },
    { 0xA0C6, "waittill_vehicles_dead" },
    { 0xA0C7, "waittill_volume_dead" },
    { 0xA0C8, "waittill_volume_dead_or_dying" },
    { 0xA0C9, "waittill_volume_dead_then_set_flag" },
    { 0xA0CA, "waittill_weapon_placed" },
    { 0xA0CB, "waittill_weaponhud_canshow" },
    { 0xA0CC, "waittillaiarraydeadoralerted" },
    { 0xA0CD, "waittillaiarrayneargoal" },
    { 0xA0CE, "waittillaineargoal" },
    { 0xA0CF, "waittillattachmentdone" },
    { 0xA0D0, "waittillbcsdone" },
    { 0xA0D1, "waittillbuddyjoinedairstrike" },
    { 0xA0D2, "waittillbuddyjoinedstreak" },
    { 0xA0D3, "waittilldeadoralertedthread" },
    { 0xA0D4, "waittilldeathorempty" },
    { 0xA0D5, "waittilldeathorleavesquad" },
    { 0xA0D6, "waittilldeathorpaindeath" },
    { 0xA0D7, "waittilldeletedordeath" },
    { 0xA0D8, "waittillenabled" },
    { 0xA0D9, "waittillenemiesreducedto" },
    { 0xA0DA, "waittillfinalkillcamdone" },
    { 0xA0DB, "waittillfiremissile" },
    { 0xA0DC, "waittillgrenadedrops" },
    { 0xA0DD, "waittillhostmigrationdone" },
    { 0xA0DE, "waittillhostmigrationstarts" },
    { 0xA0DF, "waittillkillcamover" },
    { 0xA0E0, "waittillleftplayspace" },
    { 0xA0E1, "waittillneargoal" },
    { 0xA0E2, "waittilloverplayspace" },
    { 0xA0E3, "waittillplayercanbebuddy" },
    { 0xA0E4, "waittillplayerfireortime" },
    { 0xA0E5, "waittillplayerishitagain" },
    { 0xA0E6, "waittillplayeristouchinganytrigger" },
    { 0xA0E7, "waittillplayerlookatescapevehicle" },
    { 0xA0E8, "waittillplayerlookattarget" },
    { 0xA0E9, "waittillplayerlookattargetintrigger" },
    { 0xA0EA, "waittillplayersignalatriumbreach" },
    { 0xA0EB, "waittillpromptactivated" },
    { 0xA0EC, "waittillpromptcomplete" },
    { 0xA0ED, "waittillrecoveredhealth" },
    { 0xA0EE, "waittillreloadfinished" },
    { 0xA0EF, "waittillremoteturretleavereturn" },
    { 0xA0F0, "waittillremoteturretusedreturn" },
    { 0xA0F1, "waittillrestartordistance" },
    { 0xA0F2, "waittillrocketdeath" },
    { 0xA0F3, "waittillrocketsexploded" },
    { 0xA0F4, "waittillslowprocessallowed" },
    { 0xA0F5, "waittillthread" },
    { 0xA0F6, "waittillthread_proc" },
    { 0xA0F7, "waittillturretfired" },
    { 0xA0F8, "waittillturretstuncomplete" },
    { 0xA0F9, "waittillunmarkplayerasrockettarget" },
    { 0xA0FA, "waittimeifplayerishit" },
    { 0xA0FB, "waittimeoruntilturretstatechange" },
    { 0xA0FC, "waittimerforspawn" },
    { 0xA0FD, "waituntil_stop_time_or_posreached" },
    { 0xA0FE, "waituntilmatchstart" },
    { 0xA0FF, "waituntilmovereturnnode" },
    { 0xA100, "waituntilnotetrack" },
    { 0xA101, "waituntilwaverelease" },
    { 0xA102, "wake_me_up_if_still_alive" },
    { 0xA103, "wake_nearby_drones" },
    { 0xA104, "wakeup_physics_sphere_on_ent" },
    { 0xA105, "walk_accuracy" },
    { 0xA106, "walk_node" },
    { 0xA107, "walk_override_weights" },
    { 0xA108, "walk_overrideanim" },
    { 0xA109, "walk_speed" },
    { 0xA10A, "walk_to_school" },
    { 0xA10B, "walkdist_force_walk" },
    { 0xA10C, "walkdist_reset" },
    { 0xA10D, "walkdist_zero" },
    { 0xA10E, "walker" },
    { 0xA10F, "walker_ammo_crate_nag" },
    { 0xA110, "walker_anims" },
    { 0xA111, "walker_badplace" },
    { 0xA112, "walker_damage_fx" },
    { 0xA113, "walker_death_courtyard_kva_cleanup" },
    { 0xA114, "walker_death_courtyard_kva_cleanup_cg" },
    { 0xA115, "walker_drone_fight" },
    { 0xA116, "walker_dying_fx" },
    { 0xA117, "walker_esc_node_locations" },
    { 0xA118, "walker_explode" },
    { 0xA119, "walker_for_swarm" },
    { 0xA11A, "walker_guy_death" },
    { 0xA11B, "walker_jet_flyby" },
    { 0xA11C, "walker_missile_barrage" },
    { 0xA11D, "walker_mobile_turret_dropoff" },
    { 0xA11E, "walker_play_death_anim" },
    { 0xA11F, "walker_step_over" },
    { 0xA120, "walker_tank" },
    { 0xA121, "walker_tank_death_vo" },
    { 0xA122, "walker_tank_dialgue" },
    { 0xA123, "walker_tank_footstep_left" },
    { 0xA124, "walker_tank_footstep_left_rear" },
    { 0xA125, "walker_tank_footstep_right" },
    { 0xA126, "walker_tank_footstep_right_rear" },
    { 0xA127, "walker_tank_fx" },
    { 0xA128, "walker_tank_handle_target" },
    { 0xA129, "walker_tank_missile_fire" },
    { 0xA12A, "walker_tank_reload_ok" },
    { 0xA12B, "walker_tank_success_vo" },
    { 0xA12C, "walker_tank_turret_fire_at_player" },
    { 0xA12D, "walker_tank_turret_fire_at_player_clear" },
    { 0xA12E, "walker_tank_turret_fire_at_player_think" },
    { 0xA12F, "walker_tank_turret_think" },
    { 0xA130, "walker_track_pos" },
    { 0xA131, "walker_trophy_system" },
    { 0xA132, "walker_trophy_system_dialogue" },
    { 0xA133, "walker2" },
    { 0xA134, "walker2_logic" },
    { 0xA135, "walkernode" },
    { 0xA136, "walkers" },
    { 0xA137, "walkertank" },
    { 0xA138, "walking_awareness" },
    { 0xA139, "walking_civilian_react" },
    { 0xA13A, "walkingaimblendtime" },
    { 0xA13B, "walkingaimlimits" },
    { 0xA13C, "walkingmechblendtime" },
    { 0xA13D, "walkingturnrate" },
    { 0xA13E, "walkwayguarddialogue" },
    { 0xA13F, "walkwayguardstoptalking" },
    { 0xA140, "walkwayplayerkilldialogue" },
    { 0xA141, "walkwaystruggleanimations" },
    { 0xA142, "wall_canal_breach" },
    { 0xA143, "wall_climb_cloak_activate" },
    { 0xA144, "wall_climb_dust_fx" },
    { 0xA145, "wall_climb_force_dismount" },
    { 0xA146, "wall_climb_last_jump" },
    { 0xA147, "wall_explosion_01" },
    { 0xA148, "wall_hop_human" },
    { 0xA149, "wall_notetrack_listener" },
    { 0xA14A, "wall_pull_animation" },
    { 0xA14B, "wall_pull_animation_begin" },
    { 0xA14C, "wall_pull_animation_dialogue" },
    { 0xA14D, "wall_pull_slowmo" },
    { 0xA14E, "wall_pullup_burke_anim_start" },
    { 0xA14F, "walla_bridge_runners" },
    { 0xA150, "wallclimb_roots" },
    { 0xA151, "wants_to_fire" },
    { 0xA152, "wantsafespawn" },
    { 0xA153, "wantsbattlebuddy" },
    { 0xA154, "wantshotgun" },
    { 0xA155, "wantstogrowlattarget" },
    { 0xA156, "wanttoattacktargetbutcant" },
    { 0xA157, "warbird" },
    { 0xA158, "warbird_a" },
    { 0xA159, "warbird_anims" },
    { 0xA15A, "warbird_audio" },
    { 0xA15B, "warbird_b_crash_tower" },
    { 0xA15C, "warbird_buddy_exit" },
    { 0xA15D, "warbird_carrying_walker" },
    { 0xA15E, "warbird_circling_perimeter" },
    { 0xA15F, "warbird_crash_site" },
    { 0xA160, "warbird_crush_player" },
    { 0xA161, "warbird_death_function" },
    { 0xA162, "warbird_deathspin" },
    { 0xA163, "warbird_dropoff_01" },
    { 0xA164, "warbird_dropoff_02" },
    { 0xA165, "warbird_dropoff_03" },
    { 0xA166, "warbird_dropoff_04" },
    { 0xA167, "warbird_dropping_mobile_tuerret_camshake" },
    { 0xA168, "warbird_emp_crash_movement" },
    { 0xA169, "warbird_emp_damage_function" },
    { 0xA16A, "warbird_emp_death" },
    { 0xA16B, "warbird_falling_rocks_loop" },
    { 0xA16C, "warbird_fire" },
    { 0xA16D, "warbird_fire_init" },
    { 0xA16E, "warbird_fire_init_monitor" },
    { 0xA16F, "warbird_fire_monitor" },
    { 0xA170, "warbird_flyover_shootdown" },
    { 0xA171, "warbird_get_passengers" },
    { 0xA172, "warbird_ground_fire_init" },
    { 0xA173, "warbird_ground_fire_no_enemy_init" },
    { 0xA174, "warbird_handle_unload" },
    { 0xA175, "warbird_hanger_dropoff" },
    { 0xA176, "warbird_health" },
    { 0xA177, "warbird_heavy_fire" },
    { 0xA178, "warbird_heavy_fire_monitor" },
    { 0xA179, "warbird_heavy_shooting_think" },
    { 0xA17A, "warbird_hide_blury_rotors" },
    { 0xA17B, "warbird_hoverdust" },
    { 0xA17C, "warbird_ignore_until_unloaded" },
    { 0xA17D, "warbird_intro_lighting" },
    { 0xA17E, "warbird_land_fov_change" },
    { 0xA17F, "warbird_mobile_turret_dropoff" },
    { 0xA180, "warbird_recover_fail" },
    { 0xA181, "warbird_shooting_think" },
    { 0xA182, "warbird_start_shooting" },
    { 0xA183, "warbird_strafe_01" },
    { 0xA184, "warbird_strafe_run" },
    { 0xA185, "warbird_toggle_turret_off_after_deploy" },
    { 0xA186, "warbird_turret_off_after_deploy" },
    { 0xA187, "warbird_unload_listener" },
    { 0xA188, "warbird_wait_for_fire_target_done" },
    { 0xA189, "warbird_wait_for_unload" },
    { 0xA18A, "warbird_wait_until_unloaded" },
    { 0xA18B, "warbirdaiattack" },
    { 0xA18C, "warbirdairocketreload" },
    { 0xA18D, "warbirdbuddyturret" },
    { 0xA18E, "warbirdcleanup" },
    { 0xA18F, "warbirdfire" },
    { 0xA190, "warbirdflightpathnodes" },
    { 0xA191, "warbirdinit" },
    { 0xA192, "warbirdinuse" },
    { 0xA193, "warbirdkilled" },
    { 0xA194, "warbirdlightfx" },
    { 0xA195, "warbirdlightset" },
    { 0xA196, "warbirdlookatenemy" },
    { 0xA197, "warbirdmakevehiclesolidcapsule" },
    { 0xA198, "warbirdmovetoattackpoint" },
    { 0xA199, "warbirdondeath" },
    { 0xA19A, "warbirdoverheatbarcolormonitor" },
    { 0xA19B, "warbirdrocketdamageindicator" },
    { 0xA19C, "warbirdrockethudupdate" },
    { 0xA19D, "warbirdrocketreloadsound" },
    { 0xA19E, "warbirdsetting" },
    { 0xA19F, "warbirdturret" },
    { 0xA1A0, "warbirdvisionset" },
    { 0xA1A1, "warehouse_car_shots" },
    { 0xA1A2, "warehouse_chase_vehicle_02" },
    { 0xA1A3, "warehouse_chase_vehicle_03" },
    { 0xA1A4, "warehouse_chase_vehicle_04" },
    { 0xA1A5, "warehouse_one_shots_glass" },
    { 0xA1A6, "warehouse_one_shots_rock" },
    { 0xA1A7, "waribird_intro_vfx" },
    { 0xA1A8, "warn_facial_dialogue_too_many" },
    { 0xA1A9, "warn_facial_dialogue_unspoken" },
    { 0xA1AA, "warning" },
    { 0xA1AB, "warning_box_functions" },
    { 0xA1AC, "warning_fade" },
    { 0xA1AD, "warning_lines" },
    { 0xA1AE, "warning_pulse" },
    { 0xA1AF, "warning_sign_hide_fx" },
    { 0xA1B0, "warning_sign_show_fx" },
    { 0xA1B1, "warning_time" },
    { 0xA1B2, "warning_update_text" },
    { 0xA1B3, "warningelement" },
    { 0xA1B4, "warningradiussq" },
    { 0xA1B5, "warningzheight" },
    { 0xA1B6, "warp_allies" },
    { 0xA1B7, "warp_allies_forward_sinkhole" },
    { 0xA1B8, "warp_to_start" },
    { 0xA1B9, "was_ever_visible" },
    { 0xA1BA, "was_headshot" },
    { 0xA1BB, "was_in_exposed_group" },
    { 0xA1BC, "was_on" },
    { 0xA1BD, "was_walking" },
    { 0xA1BE, "wasaliveatmatchstart" },
    { 0xA1BF, "wasallowingpain" },
    { 0xA1C0, "waschained" },
    { 0xA1C1, "wascontested" },
    { 0xA1C2, "wascooked" },
    { 0xA1C3, "wasdamaged" },
    { 0xA1C4, "wasdamagedbyexplosive" },
    { 0xA1C5, "wasdamagedfrombulletpenetration" },
    { 0xA1C6, "waselminatedbyenemy" },
    { 0xA1C7, "wasemp" },
    { 0xA1C8, "wasfacingmotion" },
    { 0xA1C9, "wasflashbangimmune" },
    { 0xA1CA, "waslastround" },
    { 0xA1CB, "wasleftunoccupied" },
    { 0xA1CC, "wasonlyround" },
    { 0xA1CD, "wasp_cloak_off" },
    { 0xA1CE, "wasp_cloak_on" },
    { 0xA1CF, "waspreviouslyincover" },
    { 0xA1D0, "wasrecall" },
    { 0xA1D1, "wasswitchingteamsforonplayerkilled" },
    { 0xA1D2, "wasti" },
    { 0xA1D3, "wasunderwater" },
    { 0xA1D4, "waswinning" },
    { 0xA1D5, "watch_ally_alert" },
    { 0xA1D6, "watch_ball_pickup_and_loss" },
    { 0xA1D7, "watch_bloodplosion" },
    { 0xA1D8, "watch_bot_died_during_crate" },
    { 0xA1D9, "watch_bot_died_during_revive" },
    { 0xA1DA, "watch_death_endon" },
    { 0xA1DB, "watch_distance_on_tutorial_spawner" },
    { 0xA1DC, "watch_follow_objective" },
    { 0xA1DD, "watch_for_alert" },
    { 0xA1DE, "watch_for_death" },
    { 0xA1DF, "watch_for_deaths" },
    { 0xA1E0, "watch_for_joined_team" },
    { 0xA1E1, "watch_for_player_to_reach_overlook" },
    { 0xA1E2, "watch_for_tutorial_enemy_death" },
    { 0xA1E3, "watch_for_underwater" },
    { 0xA1E4, "watch_goal_aborted" },
    { 0xA1E5, "watch_hide_pack_notetracks" },
    { 0xA1E6, "watch_jump_flag" },
    { 0xA1E7, "watch_jumper" },
    { 0xA1E8, "watch_mech_firing" },
    { 0xA1E9, "watch_node_chance" },
    { 0xA1EA, "watch_nodes" },
    { 0xA1EB, "watch_nodes_aborted" },
    { 0xA1EC, "watch_nodes_stop" },
    { 0xA1ED, "watch_out_of_ammo" },
    { 0xA1EE, "watch_player_braking" },
    { 0xA1EF, "watch_player_grapple" },
    { 0xA1F0, "watch_player_shot_me" },
    { 0xA1F1, "watch_players_connecting" },
    { 0xA1F2, "watch_rider_death" },
    { 0xA1F3, "watch_show_pack_notetracks" },
    { 0xA1F4, "watch_stinger_nags" },
    { 0xA1F5, "watch_tag_destination" },
    { 0xA1F6, "watch_tappy_progress" },
    { 0xA1F7, "watch_to_delete" },
    { 0xA1F8, "watch_tower_nags" },
    { 0xA1F9, "watch_turn_off_mbs" },
    { 0xA1FA, "watch_turret_hit_heli" },
    { 0xA1FB, "watchadrenalineusage" },
    { 0xA1FC, "watchagentspawn" },
    { 0xA1FD, "watchaienterwater" },
    { 0xA1FE, "watchallplayerdeath" },
    { 0xA1FF, "watchattackstate" },
    { 0xA200, "watchattackstatefunc" },
    { 0xA201, "watchbackbuttonpress" },
    { 0xA202, "watchbarking" },
    { 0xA203, "watchc4" },
    { 0xA204, "watchc4altdetonate" },
    { 0xA205, "watchc4altdetonation" },
    { 0xA206, "watchc4detonation" },
    { 0xA207, "watchc4stuck" },
    { 0xA208, "watchc4usage" },
    { 0xA209, "watchcarryobjects" },
    { 0xA20A, "watchclaymores" },
    { 0xA20B, "watchconnectedplayfx" },
    { 0xA20C, "watchconnectedplayfxexplosive" },
    { 0xA20D, "watchcranenotetrack" },
    { 0xA20E, "watchdamagechemical" },
    { 0xA20F, "watchdeath" },
    { 0xA210, "watchdeployedriotshielddamage" },
    { 0xA211, "watchdeployedriotshieldents" },
    { 0xA212, "watchdistortdisconnectdeath" },
    { 0xA213, "watchdrop" },
    { 0xA214, "watchdvars" },
    { 0xA215, "watchenemyvelocity" },
    { 0xA216, "watchenterandexit" },
    { 0xA217, "watchenterandexitinput" },
    { 0xA218, "watchexplosivedroneusage" },
    { 0xA219, "watchexplosivegelaltdetonate" },
    { 0xA21A, "watchexplosivegelusage" },
    { 0xA21B, "watchextrahealthusage" },
    { 0xA21C, "watchfasthealusage" },
    { 0xA21D, "watchfavoriteenemydeath" },
    { 0xA21E, "watchforclasschange" },
    { 0xA21F, "watchforclustersplit" },
    { 0xA220, "watchfordeath" },
    { 0xA221, "watchforextramissilefire" },
    { 0xA222, "watchforhostmigrationsetround" },
    { 0xA223, "watchforincomingfire" },
    { 0xA224, "watchforjoin" },
    { 0xA225, "watchforlasermovement" },
    { 0xA226, "watchforleavegame" },
    { 0xA227, "watchforneedtoturnortimeout" },
    { 0xA228, "watchforpickup" },
    { 0xA229, "watchforrandomspawnbutton" },
    { 0xA22A, "watchforstick" },
    { 0xA22B, "watchforteamchange" },
    { 0xA22C, "watchforthrowbacks" },
    { 0xA22D, "watchgoalchanged" },
    { 0xA22E, "watchgrenadegraceperiod" },
    { 0xA22F, "watchgrenadetowardsplayer" },
    { 0xA230, "watchgrenadetowardsplayerinternal" },
    { 0xA231, "watchgrenadetowardsplayertimeout" },
    { 0xA232, "watchgrenadeusage" },
    { 0xA233, "watchhasdonecombat" },
    { 0xA234, "watchhitbymissile" },
    { 0xA235, "watchhostmigration" },
    { 0xA236, "watchjoinedteamplayfx" },
    { 0xA237, "watchjoinedteamplayfxexplosive" },
    { 0xA238, "watchmanualdetonationbydoubletap" },
    { 0xA239, "watchmanualdetonationbyemptythrow" },
    { 0xA23A, "watchmanuallydetonatedfordoubletap" },
    { 0xA23B, "watchmanuallydetonatedusage" },
    { 0xA23C, "watchmgfireuncloak" },
    { 0xA23D, "watchmineusage" },
    { 0xA23E, "watchminimap" },
    { 0xA23F, "watchmissileproximity" },
    { 0xA240, "watchmissileusage" },
    { 0xA241, "watchmutebombusage" },
    { 0xA242, "watchoffhandcancel" },
    { 0xA243, "watchownerdamage" },
    { 0xA244, "watchownerdeath" },
    { 0xA245, "watchownermessageondeath" },
    { 0xA246, "watchownerteamchange" },
    { 0xA247, "watchpainteddeath" },
    { 0xA248, "watchpaintgrenade" },
    { 0xA249, "watchpickup" },
    { 0xA24A, "watchplayerconnected" },
    { 0xA24B, "watchplayerdeathdisconnect" },
    { 0xA24C, "watchplayerdeathdisconnectexplosive" },
    { 0xA24D, "watchplayerenterlasercore" },
    { 0xA24E, "watchplayerenterwater" },
    { 0xA24F, "watchrangerusage" },
    { 0xA250, "watchreloading" },
    { 0xA251, "watchriotshielddeploy" },
    { 0xA252, "watchriotshieldpickup" },
    { 0xA253, "watchriotshieldstuckentitydeath" },
    { 0xA254, "watchriotshielduse" },
    { 0xA255, "watchrobotarmnotetrack" },
    { 0xA256, "watchselectbuttonpress" },
    { 0xA257, "watchsentryusage" },
    { 0xA258, "watchshootentvelocity" },
    { 0xA259, "watchshotgunswitchnotetracks" },
    { 0xA25A, "watchslide" },
    { 0xA25B, "watchsmokeexplode" },
    { 0xA25C, "watchstartweaponchange" },
    { 0xA25D, "watchstingerusage" },
    { 0xA25E, "watchstoppingpowerkill" },
    { 0xA25F, "watchsuppression" },
    { 0xA260, "watchtrackingdroneusage" },
    { 0xA261, "watchtridroneusage" },
    { 0xA262, "watchtrophyusage" },
    { 0xA263, "watchweaponchange" },
    { 0xA264, "watchweaponreload" },
    { 0xA265, "watchweaponusage" },
    { 0xA266, "water" },
    { 0xA267, "water_allow_jump" },
    { 0xA268, "water_allow_prone" },
    { 0xA269, "water_allow_sprint" },
    { 0xA26A, "water_barrell_splash_screen_fx" },
    { 0xA26B, "water_bubbles_transition_player_view" },
    { 0xA26C, "water_bubbles_truck_door" },
    { 0xA26D, "water_crash_jeep_1" },
    { 0xA26E, "water_crash_jeep_2" },
    { 0xA26F, "water_current" },
    { 0xA270, "water_default_vision_set_enabled" },
    { 0xA271, "water_depth" },
    { 0xA272, "water_depth_below" },
    { 0xA273, "water_depth_state" },
    { 0xA274, "water_exp_audio" },
    { 0xA275, "water_explosions" },
    { 0xA276, "water_explosions_far" },
    { 0xA277, "water_explosions_near" },
    { 0xA278, "water_foley_type" },
    { 0xA279, "water_ground_ref_ent" },
    { 0xA27A, "water_impacts" },
    { 0xA27B, "water_last_weapon" },
    { 0xA27C, "water_lastemerge" },
    { 0xA27D, "water_level_z" },
    { 0xA27E, "water_rising_01" },
    { 0xA27F, "water_rising_02" },
    { 0xA280, "water_rising_03" },
    { 0xA281, "water_set_control_options" },
    { 0xA282, "water_set_depth" },
    { 0xA283, "water_sheeting" },
    { 0xA284, "water_sheeting_think" },
    { 0xA285, "water_splash" },
    { 0xA286, "water_splash_function" },
    { 0xA287, "water_splash_info" },
    { 0xA288, "water_splash_reset_function" },
    { 0xA289, "water_step" },
    { 0xA28A, "water_touching" },
    { 0xA28B, "water_trigger_current" },
    { 0xA28C, "water_trigger_register" },
    { 0xA28D, "water_triggers" },
    { 0xA28E, "water_vision_set_enabled" },
    { 0xA28F, "water_wading_move_speed" },
    { 0xA290, "water_wading_move_speed_target" },
    { 0xA291, "water_wading_waterdepthtype" },
    { 0xA292, "water_wading_wobble" },
    { 0xA293, "water_wading_wobble_target" },
    { 0xA294, "water_wake_speed" },
    { 0xA295, "water_warning" },
    { 0xA296, "waterbadtrigger" },
/* gap here
    "waterdeletez",
    "waterfall_save",
    "waterfx",
    "waterline_ents",
    "waterline_offset",
    "waterthink",
    "waterthink_rampspeed",
    "wave_1_5_ally_move",
    "wave_1_5_retreat",
    "wave_1_ally_move",
    "wave_1_enemy_logic",
    "wave_1_logic",
    "wave_1_zippers",
    "wave_2_special_start",
    "wave_3_ally_move_left",
    "wave_3_ally_move_right",
    "wave_3_retreat",
    "wave_3_retreat_vol",
    "wave_3_zippers",
    "wave1",
    "wavedelay",
    "wavefirstspawn",
    "waveplayerspawnindex",
    "waves",
    "wavespawnindex",
    "wavespawntimer",
    "waypoint",
    "weap_has_thermal",
    "weap_is_em1",
    "weap_is_hbra3",
    "weap_is_himar",
    "weapon_ammo",
    "weapon_ammo_bar",
    "weapon_ammo_bar_color",
    "weapon_ammo_bar_reload",
    "weapon_ammo_bar_value",
    "weapon_ammo_count",
    "weapon_ammo_max",
    "weapon_col",
    "weapon_cooldown_active",
    "weapon_cooldown_time",
    "weapon_drop_cleanup",
    "weapon_fire",
    "weapon_fire_notify",
    "weapon_fire_sound",
    "weapon_input_cooldown_active",
    "weapon_list_debug",
    "weapon_name",
    "weapon_names",
    "weapon_notify_loop",
    "weapon_out",
    "weapon_pickups_disable",
    "weapon_platform_fire_1",
    "weapon_platform_fire_2",
    "weapon_platform_fire_3",
    "weapon_platform_rigged",
    "weapon_pump_action_shotgun",
    "weapon_ready_to_fire",
    "weapon_reload",
    "weapon_reload_time",
    "weaponattachments",
    "weaponcamoorder",
    "weapondamagetracepassed",
    "weapondmgmod",
    "weapondropfunction",
    "weaponfire",
    "weaponisriotshield",
    "weaponisshockplantriotshield",
    "weaponlinker",
    "weaponlist",
    "weaponlistenforstopfire",
    "weaponname",
    "weaponnamefull",
    "weaponplf_flyby_dustfx_sinkhole",
    "weaponpos",
    "weaponposdropping",
    "weaponproficiency",
    "weaponrefs",
    "weapons",
    "weapons_with_ir",
    "weaponsetup",
    "weaponslot",
    "weaponsound",
    "weaponspeed",
    "weaponstate",
    "weaponstorestore",
    "weapontag01",
    "weapontag02",
    "weapontag03",
    "weapontag04",
    "weapontweaks",
    "weaponusagename",
    "weaponusagestarttime",
    "weather_report",
*/
    { 0xA2F7, "weave" },
    { 0xA2F8, "welder" },
    { 0xA2F9, "went_thither" },
    { 0xA2FA, "went_thither_time" },
    { 0xA2FB, "wetlevel" },
    { 0xA2FC, "wheel_for_hostage_car" },
    { 0xA2FD, "wheel_speed_modifier" },
    { 0xA2FE, "wheeldir" },
    { 0xA2FF, "wheeldirectionchange" },
    { 0xA300, "wheelman_success" },
    { 0xA301, "wheels_bump_impact" },
    { 0xA302, "when_am_i_near_player" },
    { 0xA303, "whisper" },
    { 0xA304, "whistle" },
    { 0xA305, "whistle_count" },
    { 0xA306, "whistle_hint_used" },
    { 0xA307, "whistle_no_relay" },
    { 0xA308, "whistle_tutorial_enemy" },
    { 0xA309, "white_hoodoo_fx" },
    { 0xA30A, "white_hoodoos" },
    { 0xA30B, "white_out" },
    { 0xA30C, "white_overlay" },
    { 0xA30D, "whiz" },
    { 0xA30E, "whiz_init" },
    { 0xA30F, "whiz_set_offset" },
    { 0xA310, "whiz_set_preset" },
    { 0xA311, "whiz_set_probabilities" },
    { 0xA312, "whiz_set_radii" },
    { 0xA313, "whiz_set_spreads" },
    { 0xA314, "whiz_use_string_table" },
    { 0xA315, "whizby_settings" },
    { 0xA316, "whizbyenemy" },
    { 0xA317, "whizx_get_mix_preset_from_stringtable_internal" },
    { 0xA318, "whizx_get_stringtable_preset" },
    { 0xA319, "widebeam" },
    { 0xA31A, "widen_player_view" },
    { 0xA31B, "wildcards" },
    { 0xA31C, "wildcardsowned" },
    { 0xA31D, "will_be_manhandled" },
    { 0xA31E, "will_boid_clip_camera" },
    { 0xA31F, "will_doorshield_debris" },
    { 0xA320, "will_doorshield_foley" },
    { 0xA321, "will_doorshield_grabs" },
    { 0xA322, "will_doorshield_rip" },
    { 0xA323, "will_doorshield_tension" },
    { 0xA324, "will_irons" },
    { 0xA325, "will_irons_intro" },
    { 0xA326, "will_perarts_jump_explosions" },
    { 0xA327, "will_reveal_fov_default" },
    { 0xA328, "will_room_door_exit" },
    { 0xA329, "will_room_logic" },
    { 0xA32A, "will_room_speech_end" },
    { 0xA32B, "winbycaptures" },
    { 0xA32C, "wind" },
    { 0xA32D, "wind_dir" },
    { 0xA32E, "wind_gate_open" },
    { 0xA32F, "wind_gust" },
    { 0xA330, "wind_lp" },
    { 0xA331, "wind_over_trees" },
    { 0xA332, "wind_warning" },
    { 0xA333, "windcontroller" },
    { 0xA334, "windmill_sniper_shot" },
    { 0xA335, "windmill_sniper_shot_multi" },
    { 0xA336, "windmill_sniper_shot_whizby" },
    { 0xA337, "window_destroy" },
    { 0xA338, "window_down_height" },
    { 0xA339, "window_explosion_wait_think" },
    { 0xA33A, "window_guy" },
    { 0xA33B, "window_hint" },
    { 0xA33C, "window_position" },
    { 0xA33D, "windowgapjumpglassshatter" },
    { 0xA33E, "windowhoteljumpglassshatter" },
    { 0xA33F, "wingman" },
    { 0xA340, "wingman_getgoalpos" },
    { 0xA341, "wingman_think" },
    { 0xA342, "winner" },
    { 0xA343, "wipeout" },
    { 0xA344, "wirewander" },
    { 0xA345, "within_angle" },
    { 0xA346, "within_attack_range" },
    { 0xA347, "within_fov" },
    { 0xA348, "within_fov_2d" },
    { 0xA349, "within_fov_of_players" },
    { 0xA34A, "within_player_fov" },
    { 0xA34B, "witness_kill_valid" },
    { 0xA34C, "wood_debris" },
    { 0xA34D, "worker_spawn_func" },
    { 0xA34E, "world_body" },
    { 0xA34F, "world_x" },
    { 0xA350, "worldicons" },
    { 0xA351, "worldtolocalcoords" },
    { 0xA352, "worlduseicons" },
    { 0xA353, "worthydamageratio" },
    { 0xA354, "woundedsoldierdeath" },
    { 0xA355, "wpn_deam160_aud_charges" },
    { 0xA356, "wpn_deam160_charge" },
    { 0xA357, "wpn_deam160_charge_dots_increase" },
    { 0xA358, "wpn_deam160_full_charge" },
    { 0xA359, "wpn_deam160_init" },
    { 0xA35A, "wpn_deam160_is_chargeable" },
    { 0xA35B, "wpn_deam160_play_charge_loop_sfx" },
    { 0xA35C, "wpn_deam160_shot" },
    { 0xA35D, "wpn_deam160_watch_weapon_change" },
    { 0xA35E, "write_entity" },
    { 0xA35F, "write_log" },
    { 0xA360, "writebufferedstats" },
    { 0xA361, "writesegmentdata" },
    { 0xA362, "x_on_closest_cardoor" },
    { 0xA363, "x4_walker_controls_hints_shown" },
    { 0xA364, "x4_walker_fire_missile" },
    { 0xA365, "x4_walker_hud_missile_launched" },
    { 0xA366, "x4_walker_hud_target_aquired" },
    { 0xA367, "x4walker_player_invulnerability" },
    { 0xA368, "x4walker_spawn_player_rig" },
    { 0xA369, "x4walker_wheels_fusion_turret" },
    { 0xA36A, "x4walker_wheels_seoul_turret" },
    { 0xA36B, "x4ww_condition_callback_to_state_breaking" },
    { 0xA36C, "x4ww_condition_callback_to_state_destruct" },
    { 0xA36D, "x4ww_condition_callback_to_state_enter_vehicle" },
    { 0xA36E, "x4ww_condition_callback_to_state_exit_vehicle" },
    { 0xA36F, "x4ww_condition_callback_to_state_idle" },
    { 0xA370, "x4ww_condition_callback_to_state_moving" },
    { 0xA371, "x4ww_condition_callback_to_state_off" },
    { 0xA372, "x4ww_condition_callback_to_state_shutoff" },
    { 0xA373, "x4ww_condition_callback_to_state_start_move" },
    { 0xA374, "x4ww_condition_callback_to_state_startup" },
    { 0xA375, "x4ww_condition_callback_to_state_stopped" },
    { 0xA376, "x4ww_condition_callback_to_state_turret_elevate" },
    { 0xA377, "x4ww_condition_callback_to_state_turret_rotate" },
    { 0xA378, "x4ww_condition_callback_to_state_turret_rotate_accel" },
    { 0xA379, "x4ww_condition_callback_to_state_turret_rotate_decel" },
    { 0xA37A, "x4ww_condition_callback_to_state_turret_stopped" },
    { 0xA37B, "x4ww_condition_callback_to_state_wheels_bump_impact" },
    { 0xA37C, "x4ww_condition_callback_to_state_wheels_neutral" },
    { 0xA37D, "x4ww_input_callback_gun_pitch_rate" },
    { 0xA37E, "x4ww_input_callback_gun_yaw_rate" },
    { 0xA37F, "x4ww_input_callback_player_driver" },
    { 0xA380, "x4ww_input_callback_wheel_zvelocity" },
    { 0xA381, "x4ww_input_callback_wheel_zvelocity_front_left" },
    { 0xA382, "x4ww_input_callback_wheel_zvelocity_front_right" },
    { 0xA383, "x4ww_input_callback_wheel_zvelocity_rear_left" },
    { 0xA384, "x4ww_input_callback_wheel_zvelocity_rear_right" },
    { 0xA385, "x4wwt_condition_callback_to_state_breaking" },
    { 0xA386, "x4wwt_condition_callback_to_state_destruct" },
    { 0xA387, "x4wwt_condition_callback_to_state_enter_vehicle" },
    { 0xA388, "x4wwt_condition_callback_to_state_exit_vehicle" },
    { 0xA389, "x4wwt_condition_callback_to_state_idle" },
    { 0xA38A, "x4wwt_condition_callback_to_state_moving" },
    { 0xA38B, "x4wwt_condition_callback_to_state_off" },
    { 0xA38C, "x4wwt_condition_callback_to_state_shutoff" },
    { 0xA38D, "x4wwt_condition_callback_to_state_start_move" },
    { 0xA38E, "x4wwt_condition_callback_to_state_startup" },
    { 0xA38F, "x4wwt_condition_callback_to_state_stopped" },
    { 0xA390, "x4wwt_condition_callback_to_state_turret_elevate" },
    { 0xA391, "x4wwt_condition_callback_to_state_turret_rotate" },
    { 0xA392, "x4wwt_condition_callback_to_state_turret_rotate_accel" },
    { 0xA393, "x4wwt_condition_callback_to_state_turret_rotate_decel" },
    { 0xA394, "x4wwt_condition_callback_to_state_turret_stopped" },
    { 0xA395, "x4wwt_condition_callback_to_state_wheels_bump_impact" },
    { 0xA396, "x4wwt_condition_callback_to_state_wheels_neutral" },
    { 0xA397, "x4wwt_input_callback_gun_pitch_rate" },
    { 0xA398, "x4wwt_input_callback_gun_yaw_rate" },
    { 0xA399, "x4wwt_input_callback_player_driver" },
    { 0xA39A, "x4wwt_input_callback_wheel_zvelocity" },
    { 0xA39B, "x4wwt_input_callback_wheel_zvelocity_front_left" },
    { 0xA39C, "x4wwt_input_callback_wheel_zvelocity_front_right" },
    { 0xA39D, "x4wwt_input_callback_wheel_zvelocity_rear_left" },
    { 0xA39E, "x4wwt_input_callback_wheel_zvelocity_rear_right" },
    { 0xA39F, "xoffset" },
    { 0xA3A0, "xp_ai_func" },
    { 0xA3A1, "xp_enable" },
    { 0xA3A2, "xp_give_func" },
    { 0xA3A3, "xpadding" },
    { 0xA3A4, "xpatlifestart" },
    { 0xA3A5, "xpeventinfo" },
    { 0xA3A6, "xppointspopup" },
    { 0xA3A7, "xppopup" },
    { 0xA3A8, "xprompt_on_brick" },
    { 0xA3A9, "xpscalar" },
    { 0xA3AA, "xpscale" },
    { 0xA3AB, "xpupdatetotal" },
    { 0xA3AC, "xraywall_on" },
    { 0xA3AD, "xraywall_static" },
    { 0xA3AE, "xslicefade" },
    { 0xA3AF, "xslicestartdialogue" },
    { 0xA3B0, "xuid2ownerid" },
    { 0xA3B1, "xy" },
    { 0xA3B2, "yards2dist" },
    { 0xA3B3, "yards2units" },
    { 0xA3B4, "yaw" },
    { 0xA3B5, "yaw_per_sec_calc" },
    { 0xA3B6, "yaw_rate" },
    { 0xA3B7, "yaw_scale" },
    { 0xA3B8, "yaw_tilt_to_direction_vector" },
    { 0xA3B9, "yawdiff" },
    { 0xA3BA, "yoffset" },
    { 0xA3BB, "youre_dead_functon" },
    { 0xA3BC, "youre_spoted_functon" },
    { 0xA3BD, "ypadding" },
    { 0xA3BE, "zap_local_drones" },
    { 0xA3BF, "zip" },
    { 0xA3C0, "zip_debris_anim" },
    { 0xA3C1, "zip_rooftop_dialogue" },
    { 0xA3C2, "zip_team_two_deployed_dialogue" },
    { 0xA3C3, "zipline_animname" },
    { 0xA3C4, "zipline_end_org" },
    { 0xA3C5, "zipline_gun_model" },
    { 0xA3C6, "zipline_gunner_tag" },
    { 0xA3C7, "zipline_guy_laser_think" },
    { 0xA3C8, "zipline_guy_shoot_think" },
    { 0xA3C9, "zipline_land_anims" },
    { 0xA3CA, "zippers_spawner" },
    { 0xA3CB, "zoffset" },
    { 0xA3CC, "zombiedialog" },
    { 0xA3CD, "zombieextractiongates" },
    { 0xA3CE, "zombiegivemaxammo" },
    { 0xA3CF, "zombieincreasewavecount" },
    { 0xA3D0, "zombiemovinggates" },
    { 0xA3D1, "zombiepreloadweapons" },
    { 0xA3D2, "zombierotatinggates" },
    { 0xA3D3, "zombiescompleted" },
    { 0xA3D4, "zombiesdead" },
    { 0xA3D5, "zombiesdestroykillstreaks" },
    { 0xA3D6, "zombiesdisablearmories" },
    { 0xA3D7, "zombiesetspeedscale" },
    { 0xA3D8, "zombiesmusic" },
    { 0xA3D9, "zombiesstarted" },
    { 0xA3DA, "zombiewavesequence" },
    { 0xA3DB, "zombieweaponpickup" },
    { 0xA3DC, "zombieweapons" },
    { 0xA3DD, "zone" },
    { 0xA3DE, "zone_boarder_effect" },
    { 0xA3DF, "zone_boarder_effect_stop" },
    { 0xA3E0, "zone_bounds" },
    { 0xA3E1, "zone_filters_enabled" },
    { 0xA3E2, "zone_flag_effect" },
    { 0xA3E3, "zone_flag_effect_stop" },
    { 0xA3E4, "zone_from_name", },
    { 0xA3E5, "zone_get_node_nearest_2d_bounds" },
    { 0xA3E6, "zone_handler" },
    { 0xA3E7, "zone_handler_snipers" },
    { 0xA3E8, "zone_height" },
    { 0xA3E9, "zone_mgr" },
    { 0xA3EA, "zone_radius" },
    { 0xA3EB, "zone_set_neutral" },
    { 0xA3EC, "zone_set_team" },
    { 0xA3ED, "zone_set_waiting" },
    { 0xA3EE, "zone_to_name" },
    { 0xA3EF, "zonecount" },
    { 0xA3F0, "zonedestroyedbytimer" },
    { 0xA3F1, "zonedestroyedinenemystr" },
    { 0xA3F2, "zoneduration" },
    { 0xA3F3, "zonemix" },
    { 0xA3F4, "zonemovetime" },
    { 0xA3F5, "zonerevealtime" },
    { 0xA3F6, "zones" },
    { 0xA3F7, "zonespawninginstr" },
    { 0xA3F8, "zonespawnqueue" },

// S1 stuff
    { 0xA4D6, "character/character_sp_usmc_at4" },
    { 0xA4D7, "character/character_sp_usmc_james" },
    { 0xA4D8, "character/character_sp_usmc_ryan" },
    { 0xA4D9, "character/character_sp_usmc_sami" },
    { 0xA4DA, "character/character_sp_usmc_sami_goggles" },
    { 0xA4DB, "character/character_sp_usmc_zach" },
    { 0xA4DC, "character/character_sp_usmc_zach_goggles" },
    { 0xA4DD, "character/character_us_marine_ar" },
    { 0xA4DE, "character/character_us_marine_ar_lowlod" },
    { 0xA4DF, "character/character_us_marine_dress" },
    { 0xA4E0, "character/character_us_marine_dress_a" },
    { 0xA4E1, "character/character_us_marine_dress_b" },
    { 0xA4E2, "character/character_us_marine_dress_c" },
    { 0xA4E3, "character/character_us_marine_dress_d" },
    { 0xA4E4, "character/character_us_marine_dress_e" },
    { 0xA4E5, "character/character_us_marine_dress_f" },
    { 0xA4E6, "character/character_us_marine_dress_lowlod" },
    { 0xA4E7, "character/character_us_marine_seofob_ar" },
    { 0xA4E8, "character/character_us_marine_shotgun_lowlod" },
    { 0xA4E9, "character/character_us_marine_smg" },
    { 0xA4EA, "character/character_us_marine_smg_lowlod" },
    { 0xA4EB, "character/character_us_marine_smg_seo" },
    { 0xA4EC, "character/character_us_marine_smg_seointro" },
    { 0xA4ED, "character/mp_character_cloak_test" },
    { 0xA4EE, "character/mp_character_sentinel" },
    { 0xA4EF, "codescripts/character" },
    { 0xA4F0, "common_scripts/_artcommon" },
    { 0xA4F1, "common_scripts/_bcs_location_trigs" },
    { 0xA4F2, "common_scripts/_createfx" },
    { 0xA4F3, "common_scripts/_createfxmenu" },
    { 0xA4F4, "common_scripts/_destructible" },
    { 0xA4F5, "common_scripts/_dynamic_world" },
    { 0xA4F6, "common_scripts/_elevator" },
    { 0xA4F7, "common_scripts/_exploder" },
    { 0xA4F8, "common_scripts/_fx" },
    { 0xA4F9, "common_scripts/_pipes" },
    { 0xA4FA, "common_scripts/utility" },
    { 0xA4FB, "destructible_scripts/computer_01_destp" },
    { 0xA4FC, "destructible_scripts/container_plastic_72x56x48_01_destp" },
    { 0xA4FD, "destructible_scripts/container_plastic_beige_med_01_destp" },
    { 0xA4FE, "destructible_scripts/greece_spinning_displays" },
    { 0xA4FF, "destructible_scripts/powerbox_112x64_01_green_destp" },
    { 0xA500, "destructible_scripts/security_camera_scanner_destp" },
    { 0xA501, "destructible_scripts/toy_chicken" },
    { 0xA502, "destructible_scripts/toy_chicken_common" },
    { 0xA503, "destructible_scripts/toy_electricbox4" },
    { 0xA504, "destructible_scripts/toy_generator" },
    { 0xA505, "destructible_scripts/toy_generator_on" },
    { 0xA506, "destructible_scripts/toy_locker_double" },
    { 0xA507, "destructible_scripts/vehicle_civ_domestic_sedan_01_glass" },
    { 0xA508, "destructible_scripts/vehicle_civ_domestic_sedan_police_destpv" },
    { 0xA509, "destructible_scripts/vehicle_civ_domestic_sedan_taxi_glass" },
    { 0xA50A, "destructible_scripts/vehicle_civ_smartcar_destpv" },
    { 0xA50B, "destructible_scripts/vehicle_luxurysedan" },
    { 0xA50C, "destructible_scripts/vehicle_luxurysedan_2008" },
    { 0xA50D, "destructible_scripts/vehicle_pickup" },
    { 0xA50E, "destructible_scripts/vehicle_suv_atlas_destpv" },
    { 0xA50F, "destructible_scripts/wall_firebox_destp" },
    { 0xA510, "maps/_anim" },
    { 0xA511, "maps/_animatedmodels" },
    { 0xA512, "maps/_ar_view" },
    { 0xA513, "maps/_art" },
    { 0xA514, "maps/_autosave" },
    { 0xA515, "maps/_bobbing_boats" },
    { 0xA516, "maps/_breach" },
    { 0xA517, "maps/_car_door_shield" },
    { 0xA518, "maps/_cg_encounter_perf_monitor" },
    { 0xA519, "maps/_chargeable_weapon" },
    { 0xA51A, "maps/_cloak" },
    { 0xA51B, "maps/_cloak_enemy_behavior" },
    { 0xA51C, "maps/_colors" },
    { 0xA51D, "maps/_compass" },
    { 0xA51E, "maps/_controlled_orbiting_drone" },
    { 0xA51F, "maps/_controlled_sniperdrone" },
    { 0xA520, "maps/_coop" },
    { 0xA521, "maps/_createfx" },
    { 0xA522, "maps/_credits" },
    { 0xA523, "maps/_credits_autogen" },
    { 0xA524, "maps/_damagefeedback" },
    { 0xA525, "maps/_dds" },
    { 0xA526, "maps/_debug" },
    { 0xA527, "maps/_deployablecoverai" },
    { 0xA528, "maps/_detonategrenades" },
    { 0xA529, "maps/_dog_control" },
    { 0xA52A, "maps/_dog_kinect" },
    { 0xA52B, "maps/_drone" },
    { 0xA52C, "maps/_drone_ai" },
    { 0xA52D, "maps/_drone_base" },
    { 0xA52E, "maps/_drone_civilian" },
    { 0xA52F, "maps/_dshk_player" },
    { 0xA530, "maps/_endmission" },
    { 0xA531, "maps/_exo_climb" },
    { 0xA532, "maps/_exo_punch_door" },
    { 0xA533, "maps/_exo_shield_sp" },
    { 0xA534, "maps/_flashlight_cheap" },
    { 0xA535, "maps/_foam_bomb" },
    { 0xA536, "maps/_friendlyfire" },
    { 0xA537, "maps/_gameskill" },
    { 0xA538, "maps/_global_fx" },
    { 0xA539, "maps/_global_fx_code" },
    { 0xA53A, "maps/_grapple" },
    { 0xA53B, "maps/_grapple_anim" },
    { 0xA53C, "maps/_grapple_traverse" },
    { 0xA53D, "maps/_hand_signals" },
    { 0xA53E, "maps/_helicopter_ai" },
    { 0xA53F, "maps/_helicopter_globals" },
    { 0xA540, "maps/_high_speed_clouds" },
    { 0xA541, "maps/_hms_ai_utility" },
    { 0xA542, "maps/_hms_door_interact" },
    { 0xA543, "maps/_hms_greece_civilian" },
    { 0xA544, "maps/_hms_utility" },
    { 0xA545, "maps/_hud" },
    { 0xA546, "maps/_hud_util" },
    { 0xA547, "maps/_idle" },
    { 0xA548, "maps/_idle_phone" },
    { 0xA549, "maps/_idle_smoke" },
    { 0xA54A, "maps/_intelligence" },
    { 0xA54B, "maps/_introscreen" },
    { 0xA54C, "maps/_inventory" },
    { 0xA54D, "maps/_juggernaut" },
    { 0xA54E, "maps/_lighting" },
    { 0xA54F, "maps/_lights" },
    { 0xA550, "maps/_load" },
    { 0xA551, "maps/_loadout" },
    { 0xA552, "maps/_loadout_code" },
    { 0xA553, "maps/_mark_and_execute" },
    { 0xA554, "maps/_mech" },
    { 0xA555, "maps/_mech_aud" },
    { 0xA556, "maps/_mech_grapple" },
    { 0xA557, "maps/_mg_penetration" },
    { 0xA558, "maps/_mgturret" },
    { 0xA559, "maps/_mgturret_auto_nonai" },
    { 0xA55A, "maps/_microdronelauncher" },
    { 0xA55B, "maps/_microwave_grenade" },
    { 0xA55C, "maps/_mocap_ar" },
    { 0xA55D, "maps/_names" },
    { 0xA55E, "maps/_nightvision" },
    { 0xA55F, "maps/_patrol" },
    { 0xA560, "maps/_patrol_anims" },
    { 0xA561, "maps/_patrol_anims_active" },
    { 0xA562, "maps/_patrol_anims_casualkiller" },
    { 0xA563, "maps/_patrol_anims_creepwalk" },
    { 0xA564, "maps/_patrol_anims_patroljog" },
    { 0xA565, "maps/_patrol_cold_anims" },
    { 0xA566, "maps/_patrol_extended" },
    { 0xA567, "maps/_player_boost_dash" },
    { 0xA568, "maps/_player_boost_jump_anims" },
    { 0xA569, "maps/_player_boost_jump_aud" },
    { 0xA56A, "maps/_player_death" },
    { 0xA56B, "maps/_player_exo" },
    { 0xA56C, "maps/_player_fastzip" },
    { 0xA56D, "maps/_player_high_jump" },
    { 0xA56E, "maps/_player_land_assist" },
    { 0xA56F, "maps/_player_stats" },
    { 0xA570, "maps/_playermech_code" },
    { 0xA571, "maps/_pmove" },
    { 0xA572, "maps/_president" },
    { 0xA573, "maps/_props" },
    { 0xA574, "maps/_rambo" },
    { 0xA575, "maps/_riotshield" },
    { 0xA576, "maps/_sarray" },
    { 0xA577, "maps/_shg_anim" },
    { 0xA578, "maps/_shg_debug" },
    { 0xA579, "maps/_shg_design_tools" },
    { 0xA57A, "maps/_shg_fx" },
    { 0xA57B, "maps/_shg_utility" },
    { 0xA57C, "maps/_slowmo_breach" },
    { 0xA57D, "maps/_sniper_glint" },
    { 0xA57E, "maps/_sniper_setup_ai" },
    { 0xA57F, "maps/_sonicaoe" },
    { 0xA580, "maps/_sp_matchdata" },
    { 0xA581, "maps/_spawner" },
    { 0xA582, "maps/_stealth" },
    { 0xA583, "maps/_stealth_accuracy_friendly" },
    { 0xA584, "maps/_stealth_animation_funcs" },
    { 0xA585, "maps/_stealth_anims" },
    { 0xA586, "maps/_stealth_behavior_enemy" },
    { 0xA587, "maps/_stealth_behavior_friendly" },
    { 0xA588, "maps/_stealth_behavior_system" },
    { 0xA589, "maps/_stealth_color_friendly" },
    { 0xA58A, "maps/_stealth_corpse_enemy" },
    { 0xA58B, "maps/_stealth_corpse_system" },
    { 0xA58C, "maps/_stealth_debug" },
    { 0xA58D, "maps/_stealth_display" },
    { 0xA58E, "maps/_stealth_event_enemy" },
    { 0xA58F, "maps/_stealth_shared_utilities" },
    { 0xA590, "maps/_stealth_smartstance_friendly" },
    { 0xA591, "maps/_stealth_threat_enemy" },
    { 0xA592, "maps/_stealth_utility" },
    { 0xA593, "maps/_stealth_visibility_enemy" },
    { 0xA594, "maps/_stealth_visibility_friendly" },
    { 0xA595, "maps/_stealth_visibility_system" },
    { 0xA596, "maps/_stingerm7" },
    { 0xA597, "maps/_stingerm7_greece" },
    { 0xA598, "maps/_swim_ai" },
    { 0xA599, "maps/_swim_ai_common" },
    { 0xA59A, "maps/_swim_player" },
    { 0xA59B, "maps/_tagging" },
    { 0xA59C, "maps/_target_lock" },
    { 0xA59D, "maps/_treadfx" },
    { 0xA59E, "maps/_trigger" },
    { 0xA59F, "maps/_underwater" },
    { 0xA5A0, "maps/_upgrade_challenge" },
    { 0xA5A1, "maps/_upgrade_perks" },
    { 0xA5A2, "maps/_upgrade_system" },
    { 0xA5A3, "maps/_urgent_walk" },
    { 0xA5A4, "maps/_utility" },
    { 0xA5A5, "maps/_utility_code" },
    { 0xA5A6, "maps/_utility_dogs" },
    { 0xA5A7, "maps/_variable_grenade" },
    { 0xA5A8, "maps/_vehicle" },
    { 0xA5A9, "maps/_vehicle_aianim" },
    { 0xA5AA, "maps/_vehicle_code" },
    { 0xA5AB, "maps/_vehicle_free_drive" },
    { 0xA5AC, "maps/_vehicle_missile" },
    { 0xA5AD, "maps/_vehicle_shg" },
    { 0xA5AE, "maps/_vehicle_traffic" },
    { 0xA5AF, "maps/_vignette_util" },
    { 0xA5B0, "maps/_warzone_tactics" },
    { 0xA5B1, "maps/_water" },
    { 0xA5B2, "maps/_weapon_pdrone" },
    { 0xA5B3, "maps/_weather" },
    { 0xA5B4, "maps/betrayal_fx" },
    { 0xA5B5, "maps/betrayal_precache" },
    { 0xA5B6, "maps/captured_fx" },
    { 0xA5B7, "maps/captured_precache" },
    { 0xA5B8, "maps/crash_fx" },
    { 0xA5B9, "maps/crash_precache" },
    { 0xA5BA, "maps/credits_s1_fx" },
    { 0xA5BB, "maps/credits_s1_precache" },
    { 0xA5BC, "maps/detroit_fx" },
    { 0xA5BD, "maps/detroit_precache" },
    { 0xA5BE, "maps/df_baghdad_fx" },
    { 0xA5BF, "maps/df_baghdad_precache" },
    { 0xA5C0, "maps/df_fly_fx" },
    { 0xA5C1, "maps/df_fly_precache" },
    { 0xA5C2, "maps/finale_fx" },
    { 0xA5C3, "maps/finale_precache" },
    { 0xA5C4, "maps/fusion_fx" },
    { 0xA5C5, "maps/fusion_precache" },
    { 0xA5C6, "maps/greece_conf_center_fx" },
    { 0xA5C7, "maps/greece_ending_fx" },
    { 0xA5C8, "maps/greece_fx" },
    { 0xA5C9, "maps/greece_precache" },
    { 0xA5CA, "maps/greece_safehouse_fx" },
    { 0xA5CB, "maps/greece_sniper_scramble_fx" },
    { 0xA5CC, "maps/irons_estate_fx" },
    { 0xA5CD, "maps/irons_estate_precache" },
    { 0xA5CE, "maps/lab_fx" },
    { 0xA5CF, "maps/lab_precache" },
    { 0xA5D0, "maps/lagos_fx" },
    { 0xA5D1, "maps/lagos_precache" },
    { 0xA5D2, "maps/recovery_fx" },
    { 0xA5D3, "maps/recovery_precache" },
    { 0xA5D4, "maps/sanfran_b_fx" },
    { 0xA5D5, "maps/sanfran_b_precache" },
    { 0xA5D6, "maps/sanfran_fx" },
    { 0xA5D7, "maps/sanfran_precache" },
    { 0xA5D8, "maps/seoul_fx" },
    { 0xA5D9, "maps/seoul_precache" },
    { 0xA5DA, "mptype/mptype_cloak_test" },
    { 0xA5DB, "soundscripts/_ambient" },
    { 0xA5DC, "soundscripts/_audio" },
    { 0xA5DD, "soundscripts/_audio_dynamic_ambi" },
    { 0xA5DE, "soundscripts/_audio_mix_manager" },
    { 0xA5DF, "soundscripts/_audio_music" },
    { 0xA5E0, "soundscripts/_audio_presets_music" },
    { 0xA5E1, "soundscripts/_audio_presets_vehicles" },
    { 0xA5E2, "soundscripts/_audio_reverb" },
    { 0xA5E3, "soundscripts/_audio_stream_manager" },
    { 0xA5E4, "soundscripts/_audio_vehicle_manager" },
    { 0xA5E5, "soundscripts/_audio_vehicles" },
    { 0xA5E6, "soundscripts/_audio_whizby" },
    { 0xA5E7, "soundscripts/_audio_zone_manager" },
    { 0xA5E8, "soundscripts/_snd" },
    { 0xA5E9, "soundscripts/_snd_common" },
    { 0xA5EA, "soundscripts/_snd_debug_bayless" },
    { 0xA5EB, "soundscripts/_snd_debug_bina" },
    { 0xA5EC, "soundscripts/_snd_debug_blondin" },
    { 0xA5ED, "soundscripts/_snd_debug_caisley" },
    { 0xA5EE, "soundscripts/_snd_debug_gavazza" },
    { 0xA5EF, "soundscripts/_snd_debug_kilborn" },
    { 0xA5F0, "soundscripts/_snd_debug_loperfido" },
    { 0xA5F1, "soundscripts/_snd_debug_mcsweeney" },
    { 0xA5F2, "soundscripts/_snd_debug_mika" },
    { 0xA5F3, "soundscripts/_snd_debug_naas" },
    { 0xA5F4, "soundscripts/_snd_debug_nuniyants" },
    { 0xA5F5, "soundscripts/_snd_debug_swenson" },
    { 0xA5F6, "soundscripts/_snd_debug_veca" },
    { 0xA5F7, "soundscripts/_snd_filters" },
    { 0xA5F8, "soundscripts/_snd_foley" },
    { 0xA5F9, "soundscripts/_snd_hud" },
    { 0xA5FA, "soundscripts/_snd_pcap" },
    { 0xA5FB, "soundscripts/_snd_playsound" },
    { 0xA5FC, "soundscripts/_snd_timescale" },
    { 0xA5FD, "soundscripts/so_aud" },
    { 0xA5FE, "vehicle_scripts/_atlas_jet" },
    { 0xA5FF, "vehicle_scripts/_atlas_piranha" },
    { 0xA600, "vehicle_scripts/_atlas_suv" },
    { 0xA601, "vehicle_scripts/_atlas_van" },
    { 0xA602, "vehicle_scripts/_attack_drone" },
    { 0xA603, "vehicle_scripts/_attack_drone_aud" },
    { 0xA604, "vehicle_scripts/_attack_drone_common" },
    { 0xA605, "vehicle_scripts/_attack_drone_controllable" },
    { 0xA606, "vehicle_scripts/_attack_drone_individual" },
    { 0xA607, "vehicle_scripts/_attack_drone_kamikaze" },
    { 0xA608, "vehicle_scripts/_attack_drone_queen" },
    { 0xA609, "vehicle_scripts/_attack_heli" },
    { 0xA60A, "vehicle_scripts/_chinese_brave_warrior" },
    { 0xA60B, "vehicle_scripts/_civ_boat" },
    { 0xA60C, "vehicle_scripts/_civ_boxtruck_ai" },
    { 0xA60D, "vehicle_scripts/_civ_domestic_bus" },
    { 0xA60E, "vehicle_scripts/_civ_domestic_economy_ai" },
    { 0xA60F, "vehicle_scripts/_civ_domestic_minivan" },
    { 0xA610, "vehicle_scripts/_civ_domestic_sedan_01" },
    { 0xA611, "vehicle_scripts/_civ_domestic_sedan_police" },
    { 0xA612, "vehicle_scripts/_civ_domestic_sedan_taxi_01" },
    { 0xA613, "vehicle_scripts/_civ_domestic_sportscar_01" },
    { 0xA614, "vehicle_scripts/_civ_domestic_suv" },
    { 0xA615, "vehicle_scripts/_civ_domestic_truck" },
    { 0xA616, "vehicle_scripts/_civ_full_size_pickup_01_ai" },
    { 0xA617, "vehicle_scripts/_civ_full_size_technical" },
    { 0xA618, "vehicle_scripts/_civ_pickup_truck_01" },
    { 0xA619, "vehicle_scripts/_civ_smartcar" },
    { 0xA61A, "vehicle_scripts/_civ_workvan" },
    { 0xA61B, "vehicle_scripts/_cover_drone" },
    { 0xA61C, "vehicle_scripts/_cover_drone_aud" },
    { 0xA61D, "vehicle_scripts/_diveboat" },
    { 0xA61E, "vehicle_scripts/_diveboat_aud" },
    { 0xA61F, "vehicle_scripts/_empty" },
    { 0xA620, "vehicle_scripts/_ft101_tank" },
    { 0xA621, "vehicle_scripts/_gaz" },
    { 0xA622, "vehicle_scripts/_gaz_dshk" },
    { 0xA623, "vehicle_scripts/_gaz_dshk_aud" },
    { 0xA624, "vehicle_scripts/_generic_script_model_lagos" },
    { 0xA625, "vehicle_scripts/_havoc_missile_scripted" },
    { 0xA626, "vehicle_scripts/_hovertank" },
    { 0xA627, "vehicle_scripts/_hovertank_aud" },
    { 0xA628, "vehicle_scripts/_ind_semi_truck_fuel_tanker" },
    { 0xA629, "vehicle_scripts/_jetbike" },
    { 0xA62A, "vehicle_scripts/_jetbike_aud" },
    { 0xA62B, "vehicle_scripts/_littlebird" },
    { 0xA62C, "vehicle_scripts/_littlebird_aud" },
    { 0xA62D, "vehicle_scripts/_littlebird_landing" },
    { 0xA62E, "vehicle_scripts/_littlebird_player" },
    { 0xA62F, "vehicle_scripts/_mi17" },
    { 0xA630, "vehicle_scripts/_mi17_aud" },
    { 0xA631, "vehicle_scripts/_mi17_noai" },
    { 0xA632, "vehicle_scripts/_mig29" },
    { 0xA633, "vehicle_scripts/_mig29_controllable" },
    { 0xA634, "vehicle_scripts/_mil_cargo_truck" },
    { 0xA635, "vehicle_scripts/_pdrone" },
    { 0xA636, "vehicle_scripts/_pdrone_aud" },
    { 0xA637, "vehicle_scripts/_pdrone_player" },
    { 0xA638, "vehicle_scripts/_pdrone_player_aud" },
    { 0xA639, "vehicle_scripts/_pdrone_security" },
    { 0xA63A, "vehicle_scripts/_pdrone_security_aud" },
    { 0xA63B, "vehicle_scripts/_pdrone_tactical_picker" },
    { 0xA63C, "vehicle_scripts/_pdrone_threat_sensor" },
    { 0xA63D, "vehicle_scripts/_pitbull" },
    { 0xA63E, "vehicle_scripts/_pitbull_aud" },
    { 0xA63F, "vehicle_scripts/_razorback" },
    { 0xA640, "vehicle_scripts/_razorback_fx" },
    { 0xA641, "vehicle_scripts/_s19" },
    { 0xA642, "vehicle_scripts/_sentinel_survey_drone_hud" },
    { 0xA643, "vehicle_scripts/_shrike" },
    { 0xA644, "vehicle_scripts/_sidewinder_scripted" },
    { 0xA645, "vehicle_scripts/_slamraam" },
    { 0xA646, "vehicle_scripts/_sniper_drone" },
    { 0xA647, "vehicle_scripts/_sniper_drone_aud" },
    { 0xA648, "vehicle_scripts/_uk_delivery_truck" },
    { 0xA649, "vehicle_scripts/_vehicle_missile_launcher_ai" },
    { 0xA64A, "vehicle_scripts/_vehicle_multiweapon_util" },
    { 0xA64B, "vehicle_scripts/_vehicle_turret_ai" },
    { 0xA64C, "vehicle_scripts/_vrap" },
    { 0xA64D, "vehicle_scripts/_walker_tank" },
    { 0xA64E, "vehicle_scripts/_x4walker_wheels" },
    { 0xA64F, "vehicle_scripts/_x4walker_wheels_aud" },
    { 0xA650, "vehicle_scripts/_x4walker_wheels_turret" },
    { 0xA651, "vehicle_scripts/_x4walker_wheels_turret_aud" },
    { 0xA652, "vehicle_scripts/_x4walker_wheels_turret_closed" },
    { 0xA653, "vehicle_scripts/_x4walker_wheels_turret_closed_aud" },
    { 0xA654, "vehicle_scripts/_xh9_warbird" },
/*
    { 0x0000, "xmodelalias/alias_africa_civilian_male_heads" },
    { 0x0000, "xmodelalias/alias_atlas_bodyguard_heads" },
    { 0x0000, "xmodelalias/alias_civ_afr_dark_male_bodies_casual" },
    { 0x0000, "xmodelalias/alias_civ_afr_dark_male_bodies_dress" },
    { 0x0000, "xmodelalias/alias_civ_afr_dark_male_heads" },
    { 0x0000, "xmodelalias/alias_civ_afr_drk_female_bodies_cas" },
    { 0x0000, "xmodelalias/alias_civ_afr_drk_female_bodies_drs" },
    { 0x0000, "xmodelalias/alias_civ_afr_drk_female_heads" },
    { 0x0000, "xmodelalias/alias_civ_afr_lgt_fem_bod_drs_sml" },
    { 0x0000, "xmodelalias/alias_civ_afr_lgt_female_bodies_cas" },
    { 0x0000, "xmodelalias/alias_civ_afr_lgt_female_bodies_drs" },
    { 0x0000, "xmodelalias/alias_civ_afr_lgt_female_heads" },
    { 0x0000, "xmodelalias/alias_civ_afr_light_male_bodies_casual" },
    { 0x0000, "xmodelalias/alias_civ_afr_light_male_bodies_dress" },
    { 0x0000, "xmodelalias/alias_civ_afr_light_male_heads" },
    { 0x0000, "xmodelalias/alias_civ_asi_male_bodies_casual" },
    { 0x0000, "xmodelalias/alias_civ_asi_male_bodies_dress" },
    { 0x0000, "xmodelalias/alias_civ_asi_male_heads" },
    { 0x0000, "xmodelalias/alias_civ_asi_male_heads_cpt" },
    { 0x0000, "xmodelalias/alias_civ_cau_fem_bod_drs_sml" },
    { 0x0000, "xmodelalias/alias_civ_cau_fem_heads_sml" },
    { 0x0000, "xmodelalias/alias_civ_cau_female_bodies_cas" },
    { 0x0000, "xmodelalias/alias_civ_cau_female_bodies_drs" },
    { 0x0000, "xmodelalias/alias_civ_cau_female_heads" },
    { 0x0000, "xmodelalias/alias_civ_cau_male_bodies_casual" },
    { 0x0000, "xmodelalias/alias_civ_cau_male_bodies_dress" },
    { 0x0000, "xmodelalias/alias_civ_cau_male_heads" },
    { 0x0000, "xmodelalias/alias_civ_cau_male_heads_hazmat_nohat" },
    { 0x0000, "xmodelalias/alias_civ_mde_female_bodies_cas" },
    { 0x0000, "xmodelalias/alias_civ_mde_female_bodies_drs" },
    { 0x0000, "xmodelalias/alias_civ_mde_female_heads" },
    { 0x0000, "xmodelalias/alias_civ_mde_male_bodies_casual" },
    { 0x0000, "xmodelalias/alias_civ_mde_male_bodies_dress" },
    { 0x0000, "xmodelalias/alias_civ_mde_male_heads" },
    { 0x0000, "xmodelalias/alias_civ_pris_afr_dark_male_bodies" },
    { 0x0000, "xmodelalias/alias_civ_pris_cau_male_bodies" },
    { 0x0000, "xmodelalias/alias_civ_pris_mde_male_bodies" },
    { 0x0000, "xmodelalias/alias_civ_rec_funeral_male_body" },
    { 0x0000, "xmodelalias/alias_civ_rec_funeral_male_body_afr" },
    { 0x0000, "xmodelalias/alias_civ_rec_funeral_male_heads" },
    { 0x0000, "xmodelalias/alias_civ_rec_funeral_male_heads_afr" },
    { 0x0000, "xmodelalias/alias_civ_urban_dead_body_a" },
    { 0x0000, "xmodelalias/alias_civ_urban_dead_body_b" },
    { 0x0000, "xmodelalias/alias_civ_urban_dead_body_c" },
    { 0x0000, "xmodelalias/alias_civ_urban_male_heads_afr_light" },
    { 0x0000, "xmodelalias/alias_civ_worker_hardhat_s1_heads" },
    { 0x0000, "xmodelalias/alias_civilian_heads_prisoner_female" },
    { 0x0000, "xmodelalias/alias_civilian_slum_heads" },
    { 0x0000, "xmodelalias/alias_civilian_slum_heads_wht" },
    { 0x0000, "xmodelalias/alias_civilian_worker_heads" },
    { 0x0000, "xmodelalias/alias_cloak_test" },
    { 0x0000, "xmodelalias/alias_coop_cloaked_static_heads" },
    { 0x0000, "xmodelalias/alias_enemy_atlas_arctic_heads" },
    { 0x0000, "xmodelalias/alias_enemy_atlas_elite_heads" },
    { 0x0000, "xmodelalias/alias_enemy_atlas_heads" },
    { 0x0000, "xmodelalias/alias_greece_civilian_heads_males_a" },
    { 0x0000, "xmodelalias/alias_greece_civilian_heads_males_b" },
    { 0x0000, "xmodelalias/alias_kva_heads" },
    { 0x0000, "xmodelalias/alias_mp_sentinel_heads" },
    { 0x0000, "xmodelalias/alias_nigerian_army_bodies" },
    { 0x0000, "xmodelalias/alias_nigerian_army_heads" },
    { 0x0000, "xmodelalias/alias_pmc_casual_heads" },
    { 0x0000, "xmodelalias/alias_pmc_casual_heads_asi" },
    { 0x0000, "xmodelalias/alias_pmc_helmet_heads" },
    { 0x0000, "xmodelalias/alias_sentinel_arctic_bodies" },
    { 0x0000, "xmodelalias/alias_sentinel_arctic_heads" },
    { 0x0000, "xmodelalias/alias_sentinel_bodies" },
    { 0x0000, "xmodelalias/alias_sentinel_heads" },
    { 0x0000, "xmodelalias/alias_sentinel_udt_heads" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_body_females" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_body_males_a" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_body_males_b" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_body_males_d" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_body_males_f" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_head_females" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_head_males_a" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_head_males_b" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_head_males_c" },
    { 0x0000, "xmodelalias/alias_seoul_civilian_head_males_d" },
    { 0x0000, "xmodelalias/alias_us_marine_dress_bodies" },
    { 0x0000, "xmodelalias/alias_us_marine_dress_heads" },
    { 0x0000, "xmodelalias/alias_us_marine_heads" },
    { 0x0000, "maps/animated_models/foliage_tree_grey_oak_lg_a" },
    { 0x0000, "maps/createart/betrayal_art" },
    { 0x0000, "maps/createart/betrayal_fog" },
    { 0x0000, "maps/createart/betrayal_fog_hdr" },
    { 0x0000, "maps/createart/captured_art" },
    { 0x0000, "maps/createart/captured_fog" },
    { 0x0000, "maps/createart/captured_fog_hdr" },
    { 0x0000, "maps/createart/crash_art" },
    { 0x0000, "maps/createart/crash_fog" },
    { 0x0000, "maps/createart/crash_fog_hdr" },
    { 0x0000, "maps/createart/credits_s1_art" },
    { 0x0000, "maps/createart/credits_s1_fog" },
    { 0x0000, "maps/createart/credits_s1_fog_hdr" },
    { 0x0000, "maps/createart/detroit_art" },
    { 0x0000, "maps/createart/detroit_fog" },
    { 0x0000, "maps/createart/detroit_fog_hdr" },
    { 0x0000, "maps/createart/df_baghdad_art" },
    { 0x0000, "maps/createart/df_baghdad_fog" },
    { 0x0000, "maps/createart/df_baghdad_fog_hdr" },
    { 0x0000, "maps/createart/df_fly_art" },
    { 0x0000, "maps/createart/df_fly_fog" },
    { 0x0000, "maps/createart/df_fly_fog_hdr" },
    { 0x0000, "maps/createart/finale_art" },
    { 0x0000, "maps/createart/finale_fog" },
    { 0x0000, "maps/createart/finale_fog_hdr" },
    { 0x0000, "maps/createart/fusion_art" },
    { 0x0000, "maps/createart/fusion_fog" },
    { 0x0000, "maps/createart/fusion_fog_hdr" },
    { 0x0000, "maps/createart/greece_art" },
    { 0x0000, "maps/createart/greece_fog" },
    { 0x0000, "maps/createart/greece_fog_hdr" },
    { 0x0000, "maps/createart/irons_estate_art" },
    { 0x0000, "maps/createart/irons_estate_fog" },
    { 0x0000, "maps/createart/irons_estate_fog_hdr" },
    { 0x0000, "maps/createart/lab_art" },
    { 0x0000, "maps/createart/lab_fog" },
    { 0x0000, "maps/createart/lab_fog_hdr" },
    { 0x0000, "maps/createart/lagos_art" },
    { 0x0000, "maps/createart/lagos_fog" },
    { 0x0000, "maps/createart/lagos_fog_hdr" },
    { 0x0000, "maps/createart/mp_comeback_art" },
    { 0x0000, "maps/createart/mp_comeback_fog" },
    { 0x0000, "maps/createart/mp_comeback_fog_hdr" },
    { 0x0000, "maps/createart/mp_detroit_art" },
    { 0x0000, "maps/createart/mp_detroit_fog" },
    { 0x0000, "maps/createart/mp_detroit_fog_hdr" },
    { 0x0000, "maps/createart/mp_greenband_art" },
    { 0x0000, "maps/createart/mp_greenband_fog" },
    { 0x0000, "maps/createart/mp_greenband_fog_hdr" },
    { 0x0000, "maps/createart/mp_instinct_art" },
    { 0x0000, "maps/createart/mp_instinct_fog" },
    { 0x0000, "maps/createart/mp_instinct_fog_hdr" },
    { 0x0000, "maps/createart/mp_lab2_art" },
    { 0x0000, "maps/createart/mp_lab2_fog" },
    { 0x0000, "maps/createart/mp_lab2_fog_hdr" },
    { 0x0000, "maps/createart/mp_laser2_art" },
    { 0x0000, "maps/createart/mp_laser2_fog" },
    { 0x0000, "maps/createart/mp_laser2_fog_hdr" },
    { 0x0000, "maps/createart/mp_levity_art" },
    { 0x0000, "maps/createart/mp_levity_fog" },
    { 0x0000, "maps/createart/mp_levity_fog_hdr" },
    { 0x0000, "maps/createart/mp_prison_art" },
    { 0x0000, "maps/createart/mp_prison_fog" },
    { 0x0000, "maps/createart/mp_prison_fog_hdr" },
    { 0x0000, "maps/createart/mp_prison_z_art" },
    { 0x0000, "maps/createart/mp_prison_z_fog" },
    { 0x0000, "maps/createart/mp_prison_z_fog_hdr" },
    { 0x0000, "maps/createart/mp_recovery_art" },
    { 0x0000, "maps/createart/mp_recovery_fog" },
    { 0x0000, "maps/createart/mp_recovery_fog_hdr" },
    { 0x0000, "maps/createart/mp_refraction_art" },
    { 0x0000, "maps/createart/mp_refraction_fog" },
    { 0x0000, "maps/createart/mp_refraction_fog_hdr" },
    { 0x0000, "maps/createart/mp_solar_art" },
    { 0x0000, "maps/createart/mp_solar_fog" },
    { 0x0000, "maps/createart/mp_solar_fog_hdr" },
    { 0x0000, "maps/createart/mp_terrace_art" },
    { 0x0000, "maps/createart/mp_terrace_fog" },
    { 0x0000, "maps/createart/mp_terrace_fog_hdr" },
    { 0x0000, "maps/createart/mp_venus_art" },
    { 0x0000, "maps/createart/mp_venus_fog" },
    { 0x0000, "maps/createart/mp_venus_fog_hdr" },
*/
    { 0xA6F9, "maps/createart/mp_vlobby_room_art" },
    { 0xA6FA, "maps/createart/mp_vlobby_room_fog" },
    { 0xA6FB, "maps/createart/mp_vlobby_room_fog_hdr" },
//  { 0xA6FX-0xA71F } S1 stuff
    { 0xA720, "maps/mp/_adrenaline" },
    { 0xA72A, "maps/mp/_aerial_pathnodes" },
    { 0xA72B, "maps/mp/_animatedmodels" },
    { 0xA72C, "maps/mp/_areas" },
    { 0xA72D, "maps/mp/_art" },
    { 0xA72E, "maps/mp/_audio" },
    { 0xA72F, "maps/mp/_awards" },
    { 0xA730, "maps/mp/_braggingrights" },
    { 0xA731, "maps/mp/_compass" },
    { 0xA732, "maps/mp/_createfx" },
    { 0xA733, "maps/mp/_crib" },
    { 0xA734, "maps/mp/_destructables" },
    { 0xA735, "maps/mp/_dynamic_events" },
    { 0xA736, "maps/mp/_empgrenade" },
    { 0xA737, "maps/mp/_entityheadicons" },
    { 0xA738, "maps/mp/_events" },
    { 0xA739, "maps/mp/_exo_battery" },
    { 0xA73A, "maps/mp/_exo_cloak" },
    { 0xA73B, "maps/mp/_exo_hover" },
    { 0xA73C, "maps/mp/_exo_mute" },
    { 0xA73D, "maps/mp/_exo_ping" },
    { 0xA73E, "maps/mp/_exo_repulsor" },
    { 0xA73F, "maps/mp/_exo_shield" },
    { 0xA740, "maps/mp/_exo_suit" },
    { 0xA741, "maps/mp/_exocrossbow" },
    { 0xA742, "maps/mp/_exoknife" },
    { 0xA743, "maps/mp/_explosive_drone" },
    { 0xA744, "maps/mp/_explosive_gel" },
    { 0xA745, "maps/mp/_extrahealth" },
    { 0xA746, "maps/mp/_fastheal" },
    { 0xA747, "maps/mp/_flashgrenades" },
    { 0xA748, "maps/mp/_fx" },
    { 0xA749, "maps/mp/_global_fx" },
    { 0xA74A, "maps/mp/_global_fx_code" },
    { 0xA74B, "maps/mp/_lasersight" },
    { 0xA74C, "maps/mp/_load" },
    { 0xA74D, "maps/mp/_lsrmissileguidance" },
    { 0xA74E, "maps/mp/_matchdata" },
    { 0xA74F, "maps/mp/_menus" },
    { 0xA750, "maps/mp/_microdronelauncher" },
    { 0xA751, "maps/mp/_movers" },
    { 0xA752, "maps/mp/_mp_lights" },
    { 0xA753, "maps/mp/_mutebomb" },
    { 0xA754, "maps/mp/_na45" },
    { 0xA755, "maps/mp/_opticsthermal" },
    { 0xA756, "maps/mp/_reinforcements" },
    { 0xA757, "maps/mp/_riotshield" },
    { 0xA758, "maps/mp/_scoreboard" },
    { 0xA759, "maps/mp/_shutter" },
    { 0xA75A, "maps/mp/_snd_common_mp" },
    { 0xA75B, "maps/mp/_stinger" },
    { 0xA75C, "maps/mp/_stingerm7" },
    { 0xA75D, "maps/mp/_stock" },
    { 0xA75E, "maps/mp/_target_enhancer" },
    { 0xA75F, "maps/mp/_teleport" },
    { 0xA760, "maps/mp/_threatdetection" },
    { 0xA761, "maps/mp/_tracking_drone" },
    { 0xA762, "maps/mp/_trackrounds" },
    { 0xA763, "maps/mp/_tridrone" },
    { 0xA764, "maps/mp/_utility" },
    { 0xA765, "maps/mp/_vl_base" },
    { 0xA766, "maps/mp/_vl_camera" },
    { 0xA767, "maps/mp/_vl_firingrange" },
    { 0xA768, "maps/mp/_vl_selfiebooth" },
    { 0xA769, "maps/mp/_water" },
    { 0xA76A, "maps/mp/_zipline" },
    { 0xA76B, "maps/mp/mp_comeback_fx" },
    { 0xA76C, "maps/mp/mp_comeback_precache" },
    { 0xA76D, "maps/mp/mp_detroit_fx" },
    { 0xA76E, "maps/mp/mp_detroit_precache" },
    { 0xA76D, "maps/mp/mp_greenband_fx" },
    { 0xA770, "maps/mp/mp_greenband_precache" },
    { 0xA771, "maps/mp/mp_instinct_fx" },
    { 0xA772, "maps/mp/mp_instinct_precache" },
    { 0xA773, "maps/mp/mp_lab2_fx" },
    { 0xA774, "maps/mp/mp_lab2_precache" },
    { 0xA775, "maps/mp/mp_laser2_fx" },
    { 0xA776, "maps/mp/mp_laser2_precache" },
    { 0xA777, "maps/mp/mp_levity_fx" },
    { 0xA778, "maps/mp/mp_levity_precache" },
    { 0xA779, "maps/mp/mp_prison_fx" },
    { 0xA77A, "maps/mp/mp_prison_precache" },
    { 0xA77B, "maps/mp/mp_prison_z_fx" },
    { 0xA77C, "maps/mp/mp_prison_z_precache" },
    { 0xA77D, "maps/mp/mp_recovery_fx" },
    { 0xA77E, "maps/mp/mp_recovery_precache" },
    { 0xA77F, "maps/mp/mp_refraction_fx" },
    { 0xA780, "maps/mp/mp_refraction_precache" },
    { 0xA781, "maps/mp/mp_solar_fx" },
    { 0xA782, "maps/mp/mp_solar_precache" },
    { 0xA783, "maps/mp/mp_terrace_fx" },
    { 0xA784, "maps/mp/mp_terrace_precache" },
    { 0xA785, "maps/mp/mp_venus_fx" },
    { 0xA786, "maps/mp/mp_venus_precache" },
    { 0xA787, "maps/mp/mp_vlobby_room_fx" },
    { 0xA788, "maps/mp/mp_vlobby_room_precache" },
    { 0xA789, "maps/mp/gametypes/_battlebuddy" },
    { 0xA78A, "maps/mp/gametypes/_battlechatter_mp" },
    { 0xA78B, "maps/mp/gametypes/_class" },
    { 0xA78C, "maps/mp/gametypes/_clientids" },
    { 0xA78D, "maps/mp/gametypes/_damage" },
    { 0xA78E, "maps/mp/gametypes/_damagefeedback" },
    { 0xA78F, "maps/mp/gametypes/_deathicons" },
    { 0xA790, "maps/mp/gametypes/_dev" },
    { 0xA791, "maps/mp/gametypes/_equipment" },
    { 0xA792, "maps/mp/gametypes/_friendicons" },
    { 0xA793, "maps/mp/gametypes/_gamelogic" },
    { 0xA794, "maps/mp/gametypes/_gameobjects" },
    { 0xA795, "maps/mp/gametypes/_gamescores" },
    { 0xA796, "maps/mp/gametypes/_globalentities" },
    { 0xA797, "maps/mp/gametypes/_globallogic" },
    { 0xA798, "maps/mp/gametypes/_hardpoints" },
    { 0xA799, "maps/mp/gametypes/_healthoverlay" },
    { 0xA79A, "maps/mp/gametypes/_high_jump_mp" },
    { 0xA79B, "maps/mp/gametypes/_horde_armory" },
    { 0xA79C, "maps/mp/gametypes/_horde_crates" },
    { 0xA79D, "maps/mp/gametypes/_horde_dialog" },
    { 0xA79E, "maps/mp/gametypes/_horde_drones" },
    { 0xA79F, "maps/mp/gametypes/_horde_laststand" },
    { 0xA7A0, "maps/mp/gametypes/_horde_sentry" },
    { 0xA7A1, "maps/mp/gametypes/_horde_smart_grenade" },
    { 0xA7A2, "maps/mp/gametypes/_horde_util" },
    { 0xA7A3, "maps/mp/gametypes/_horde_zombies" },
    { 0xA7A4, "maps/mp/gametypes/_hostmigration" },
    { 0xA7A5, "maps/mp/gametypes/_hud" },
    { 0xA7A6, "maps/mp/gametypes/_hud_message" },
    { 0xA7A7, "maps/mp/gametypes/_hud_util" },
    { 0xA7A8, "maps/mp/gametypes/_killcam" },
    { 0xA7A9, "maps/mp/gametypes/_menus" },
    { 0xA7AA, "maps/mp/gametypes/_misions" },
    { 0xA7AB, "maps/mp/gametypes/_music_and_dialog" },
    { 0xA7AC, "maps/mp/gametypes/_objpoints" },
    { 0xA7AD, "maps/mp/gametypes/_orbital" },
    { 0xA7AE, "maps/mp/gametypes/_persistence" },
    { 0xA7AF, "maps/mp/gametypes/_player_boost_jump_mp" },
    { 0xA7B0, "maps/mp/gametypes/_playercards" },
    { 0xA7B1, "maps/mp/gametypes/_playerlogic" },
    { 0xA7B2, "maps/mp/gametypes/_portable_radar" },
    { 0xA7B3, "maps/mp/gametypes/_quickmessages" },
    { 0xA7B4, "maps/mp/gametypes/_rank" },
    { 0xA7B5, "maps/mp/gametypes/_scrambler" },
    { 0xA7B6, "maps/mp/gametypes/_serversettings" },
    { 0xA7B7, "maps/mp/gametypes/_shellshock" },
    { 0xA7B8, "maps/mp/gametypes/_spawnfactor" },
    { 0xA7B9, "maps/mp/gametypes/_spawnlogic" },
    { 0xA7BA, "maps/mp/gametypes/_spawnscoring" },
    { 0xA7BB, "maps/mp/gametypes/_spectating" },
    { 0xA7BC, "maps/mp/gametypes/_teams" },
    { 0xA7BD, "maps/mp/gametypes/_tweakables" },
    { 0xA7BE, "maps/mp/gametypes/_weapons" },
    { 0xA7BF, "maps/mp/killstreaks/_aerial_utility" },
    { 0xA7C0, "maps/mp/killstreaks/_agent_killstreak" },
    { 0xA7C1, "maps/mp/killstreaks/_airdrop" },
    { 0xA7C2, "maps/mp/killstreaks/_airstrike" },
    { 0xA7C3, "maps/mp/killstreaks/_assaultdrone_ai" },
    { 0xA7C4, "maps/mp/killstreaks/_autosentry" },
    { 0xA7C5, "maps/mp/killstreaks/_coop_util" },
    { 0xA7C6, "maps/mp/killstreaks/_dog_killstreak" },
    { 0xA7C7, "maps/mp/killstreaks/_drone_assault" },
    { 0xA7C8, "maps/mp/killstreaks/_drone_carepackage" },
    { 0xA7C9, "maps/mp/killstreaks/_drone_common" },
    { 0xA7CA, "maps/mp/killstreaks/_drone_recon" },
    { 0xA7CB, "maps/mp/killstreaks/_emp" },
    { 0xA7CC, "maps/mp/killstreaks/_juggernaut" },
    { 0xA7CD, "maps/mp/killstreaks/_killstreaks" },
    { 0xA7CE, "maps/mp/killstreaks/_killstreaks_init" },
    { 0xA7CF, "maps/mp/killstreaks/_marking_util" },
    { 0xA7D0, "maps/mp/killstreaks/_missile_strike" },
    { 0xA7D1, "maps/mp/killstreaks/_nuke" },
    { 0xA7D2, "maps/mp/killstreaks/_orbital_carepackage" },
    { 0xA7D3, "maps/mp/killstreaks/_orbital_strike" },
    { 0xA7D4, "maps/mp/killstreaks/_orbital_util" },
    { 0xA7D5, "maps/mp/killstreaks/_orbitalsupport" },
    { 0xA7D6, "maps/mp/killstreaks/_placeable" },
    { 0xA7D7, "maps/mp/killstreaks/_remoteturret" },
    { 0xA7D8, "maps/mp/killstreaks/_rippedturret" },
    { 0xA7D9, "maps/mp/killstreaks/_teamammorefill" },
    { 0xA7DA, "maps/mp/killstreaks/_uav" },
    { 0xA7DB, "maps/mp/killstreaks/_warbird" },
    { 0xA7DC, "maps/mp/killstreaks/streak_mp_comeback" },
    { 0xA7DD, "maps/mp/killstreaks/streak_mp_detroit" },
    { 0xA7DE, "maps/mp/killstreaks/streak_mp_instinct" },
    { 0xA7DF, "maps/mp/killstreaks/streak_mp_laser2" },
    { 0xA7E0, "maps/mp/killstreaks/streak_mp_prison" },
    { 0xA7E1, "maps/mp/killstreaks/streak_mp_recovery" },
    { 0xA7E2, "maps/mp/killstreaks/streak_mp_refraction" },
    { 0xA7E3, "maps/mp/killstreaks/streak_mp_solar" },
    { 0xA7E4, "maps/mp/killstreaks/streak_mp_terrace" },
    { 0xA7E5, "maps/mp/perks/_perkfunctions" },
    { 0xA7E6, "maps/mp/perks/_perks" },
}};

struct __init__
{
    __init__()
    {
        static bool init = false;
        if (init) return;
        init = true;

        opcode_map.reserve(opcode_list.size());
        opcode_map_rev.reserve(opcode_list.size());
        function_map.reserve(function_list.size());
        function_map_rev.reserve(function_list.size());
        method_map.reserve(method_list.size());
        method_map_rev.reserve(method_list.size());
        token_map.reserve(token_list.size());
        token_map_rev.reserve(token_list.size());

        for (const auto& entry : opcode_list)
        {
            opcode_map.insert({ entry.first, entry.second });
            opcode_map_rev.insert({ entry.second, entry.first });
        }

        for (const auto& entry : function_list)
        {
            function_map.insert({ entry.first, entry.second });
            function_map_rev.insert({ entry.second, entry.first });
        }

        for (const auto& entry : method_list)
        {
            method_map.insert({ entry.first, entry.second });
            method_map_rev.insert({ entry.second, entry.first });
        }

        for (const auto& entry : token_list)
        {
            token_map.insert({ entry.first, entry.second });
            token_map_rev.insert({ entry.second, entry.first });
        }
    }
};

__init__ _;

} // namespace xsk::gsc::h1

#ifdef _MSC_VER
#pragma warning(pop)
#endif

// ps4 method_list

/*
"attach"
"detach"
"detachall"
"getattachsize"
"getattachmodelname"
"getattachtagname"
"getattachignorecollision"
"hidepart"
"hidepart_allinstances"
"hideallparts"
"showpart"
"showallparts"
"linkto"
"linktoblendtotag"
"unlink"
"islinked"
"enablelinkto"
"playerlinkto"
"playerlinktodelta"
"playerlinkweaponviewtodelta"
"playerlinktoabsolute"
"playerlinktoblend"
"playerlinkedoffsetenable"
"playerlinkedoffsetdisable"
"playerlinkedsetviewznear"
"playerlinkedsetusebaseangleforviewclamp"
"lerpviewangleclamp"
"setviewangleresistance"
"springcamenabled"
"springcamdisabled"
"linktoplayerview"
"unlinkfromplayerview"
"geteye"
"istouching"
"getistouchingentities"
"stoploopsound"
"stopsounds"
"playrumbleonentity"
"playrumblelooponentity"
"stoprumble"
"delete"
"setmodel"
"laseron"
"laseroff"
"laseraltviewon"
"laseraltviewoff"
"thermalvisionon"
"thermalvisionoff"
"thermalvisionfofoverlayon"
"thermalvisionfofoverlayoff"
"autospotoverlayon"
"autospotoverlayoff"
"seteyesonuplinkenabled"
"setdamagefeedback"
"setcontents"
"makeusable"
"makeunusable"
"makeglobalusable"
"makeglobalunusable"
"setcursorhint"
"sethintstring"
"setsecondaryhintstring"
"forceusehinton"
"forceusehintoff"
"makesoft"
"makehard"
"willneverchange"
"startfiring"
"stopfiring"
"isfiringturret"
"startbarrelspin"
"stopbarrelspin"
"getbarrelspinrate"
"remotecontrolturret"
"remotecontrolturretoff"
"shootturret"
"getturretowner"
"setsentryowner"
"setsentrycarrier"
"setturretminimapvisible"
"settargetentity"
"snaptotargetentity"
"cleartargetentity"
"getturrettarget"
"setplayerspread"
"setaispread"
"setsuppressiontime"
"setconvergencetime"
"setconvergenceheightpercent"
"setturretteam"
"maketurretsolid"
"maketurretoperable"
"maketurretinoperable"
"setturretaccuracy"
"setrightarc"
"setleftarc"
"settoparc"
"setbottomarc"
"setautorotationdelay"
"setdefaultdroppitch"
"restoredefaultdroppitch"
"turretfiredisable"
"turretfireenable"
"setturretmodechangewait"
"usetriggerrequirelookat"
"getstance"
"setstance"
"itemweaponsetammo"
"getammocount"
"gettagorigin"
"gettagangles"
"shellshock"
"stunplayer"
"stopshellshock"
"fadeoutshellshock"
"setdepthoffield"
"setviewmodeldepthoffield"
"setmotionblurmovescale"
"setmotionblurturnscale"
"setmotionblurzoomscale"
"viewkick"
"localtoworldcoords"
"getentitynumber"
"getentityvelocity"
"enablegrenadetouchdamage"
"disablegrenadetouchdamage"
"enableaimassist"
"disableaimassist"
"radiusdamage"
"detonate"
"damageconetrace"
"sightconetrace"
"missile_settargetent"
"missile_settargetpos"
"missile_cleartarget"
"missile_setflightmodedirect"
"missile_setflightmodetop"
"getlightintensity"
"setlightintensity"
"isragdoll"
"setmovespeedscale"
"cameralinkto"
"cameraunlink"
"controlslinkto"
"controlsunlink"
"makevehiclesolidcapsule"
"teleportentityrelative"
"makevehiclesolidsphere"
"makevehiclesolid"
"remotecontrolvehicle"
"remotecontrolvehicleoff"
"isfiringvehicleturret"
"remotecontrolvehicletarget"
"remotecontrolvehicletargetoff"
"drivevehicleandcontrolturret"
"drivevehicleandcontrolturretoff"
"getplayersetting"
"getlocalplayerprofiledata"
"setlocalplayerprofiledata"
"remotecamerasoundscapeon"
"remotecamerasoundscapeoff"
"setmotiontrackervisible"
"getmotiontrackervisible"
"worldpointinreticle_circle"
"worldpointinreticle_rect"
"getpointinbounds"
"transfermarkstonewscriptmodel"
"setwatersheeting"
"addontoviewmodel"
"clearviewmodeladdons"
"setweaponhudiconoverride"
"getweaponhudiconoverride"
"setempjammed"
"playersetexpfog"
"playersetexpfogext"
"playersetatmosfog"
"isitemunlocked"
"getplayerdata"
"setplayerdata"
"getcacplayerdata"
"setcacplayerdata"
"trackerupdate"
"pingplayer"
"buttonpressed"
"sayall"
"sayteam"
"setspawnweapon"
"dropitem"
"dropscavengerbag"
"finishplayerdamage"
"suicide"
"closeingamemenu"
"iprintln"
"iprintlnbold"
"spawn"
"setentertime"
"cloneplayer"
"istalking"
"allowspectateteam"
"forcespectatepov"
"getguid"
"getxuid"
"getucdidhigh"
"getucdidlow"
"getclanidhigh"
"getclanidlow"
"ishost"
"getspectatingplayer"
"predictstreampos"
"updatescores"
"updatedmscores"
"setrank"
"setcardtitle"
"setcardicon"
"setcardnameplate"
"setcarddisplayslot"
"kc_regweaponforfxremoval"
"laststandrevive"
"startlaststand"
"setspectatedefaults"
"getthirdpersoncrosshairoffset"
"disableweaponpickup"
"enableweaponpickup"
"issplitscreenplayer"
"issplitscreenplayerprimary"
"markforeyeson"
"issighted"
"getsightedplayers"
"getplayerssightingme"
"getviewmodel"
"fragbuttonpressed"
"secondaryoffhandbuttonpressed"
"getcurrentweaponclipammo"
"setvelocity"
"getplayerviewheight"
"getnormalizedmovement"
"getnormalizedcameramovement"
"giveweapon"
"takeweapon"
"takeallweapons"
"getcurrentweapon"
"getcurrentprimaryweapon"
"getcurrentoffhand"
"hasweapon"
"switchtoweapon"
"switchtoweaponimmediate"
"gethybridsightenabled"
"switchtooffhand"
"givestartammo"
"givemaxammo"
"getfractionstartammo"
"getfractionmaxammo"
"isdualwielding"
"isreloading"
"isswitchingweapon"
"setorigin"
"getvelocity"
"setplayerangles"
"getplayerangles"
"usebuttonpressed"
"attackbuttonpressed"
"adsbuttonpressed"
"meleebuttonpressed"
"playerads"
"isonground"
"isusingturret"
"setviewmodel"
"setlethalweapon"
"getlethalweapon"
"settacticalweapon"
"gettacticalweapon"
"beginlocationselection"
"endlocationselection"
"disableweapons"
"enableweapons"
"disableoffhandweapons"
"enableoffhandweapons"
"disableweaponswitch"
"enableweaponswitch"
"openpopupmenu"
"openpopupmenunomouse"
"closepopupmenu"
"openmenu"
"closemenu"
"savematchrulestohistory"
"freezecontrols"
"disableusability"
"enableusability"
"setwhizbyspreads"
"setwhizbyradii"
"setreverb"
"deactivatereverb"
"setvolmod"
"playlocalsound"
"stoplocalsound"
"setweaponammoclip"
"setweaponammostock"
"getweaponammoclip"
"getweaponammostock"
"anyammoforweaponmodes"
"setclientomnvar"
"setclientdvar"
"setclientdvars"
"setclientspawnsighttraces"
"clientspawnsighttracepassed"
"allowads"
"allowjump"
"allowladder"
"allowmantle"
"allowsprint"
"setspreadoverride"
"resetspreadoverride"
"setaimspreadmovementscale"
"setactionslot"
"setviewkickscale"
"getviewkickscale"
"getweaponslistall"
"getweaponslistprimaries"
"getweaponslistoffhands"
"getweaponslistitems"
"getweaponslistexclusives"
"getweaponslist"
"canplayerplacesentry"
"canplayerplacetank"
"visionsetnakedforplayer"
"visionsetnightforplayer"
"visionsetmissilecamforplayer"
"visionsetthermalforplayer"
"visionsetpainforplayer"
"setblurforplayer"
"getplayerweaponmodel"
"getplayerknifemodel"
"updateentitywithweapons"
"notifyonplayercommand"
"canmantle"
"forcemantle"
"ismantling"
"playfx"
"player_recoilscaleon"
"player_recoilscaleoff"
"weaponlockstart"
"weaponlockfinalize"
"weaponlockfree"
"weaponlocktargettooclose"
"weaponlocknoclearance"
"visionsyncwithplayer"
"showhudsplash"
"setperk"
"hasperk"
"clearperks"
"unsetperk"
"registerparty"
"getfireteammembers"
"noclip"
"ufo"
"moveto"
"movex"
"movey"
"movez"
"movegravity"
"moveslide"
"stopmoveslide"
"rotateto"
"rotatepitch"
"rotateyaw"
"rotateroll"
"addpitch"
"addyaw"
"addroll"
"vibrate"
"rotatevelocity"
"solid"
"notsolid"
"setcandamage"
"setcanradiusdamage"
"physicslaunchclient"
"physicslaunchserver"
"physicslaunchserveritem"
"clonebrushmodeltoscriptmodel"
"scriptmodelplayanim"
"scriptmodelclearanim"
"scriptmodelplayanimdeltamotion"
"vehicle_teleport"
"attachpath"
"getattachpos"
"startpath"
"setswitchnode"
"setwaitspeed"
"vehicle_finishdamage"
"vehicle_setspeed"
"vehicle_setspeedimmediate"
"vehicle_rotateyaw"
"vehicle_getspeed"
"vehicle_getvelocity"
"vehicle_getbodyvelocity"
"vehicle_getsteering"
"vehicle_getthrottle"
"vehicle_turnengineoff"
"vehicle_turnengineon"
"vehicle_orientto"
"getgoalspeedmph"
"setacceleration"
"setdeceleration"
"resumespeed"
"setyawspeed"
"setyawspeedbyname"
"setmaxpitchroll"
"setairresistance"
"setturningability"
"setjitterparams"
"sethoverparams"
"joltbody"
"freevehicle"
"getwheelsurface"
"getvehicleowner"
"setvehiclelookattext"
"setvehicleteam"
"setneargoalnotifydist"
"setvehgoalpos"
"setgoalyaw"
"cleargoalyaw"
"settargetyaw"
"cleartargetyaw"
"vehicle_helisetai"
"setturrettargetvec"
"setturrettargetent"
"clearturrettarget"
"vehicle_canturrettargetpoint"
"setlookatent"
"clearlookatent"
"setvehweapon"
"fireweapon"
"vehicleturretcontrolon"
"vehicleturretcontroloff"
"isturretready"
"vehicledriveto"
"vehicle_dospawn"
"vehicle_isphysveh"
"vehphys_crash"
"vehphys_launch"
"vehphys_disablecrashing"
"vehphys_enablecrashing"
"vehphys_setspeed"
"vehphys_setconveyorbelt"
"freehelicopter"
"playerlinkedturretanglesenable"
"playerlinkedturretanglesdisable"
"playerlinkedvehicleanglesenable"
"playerlinkedvehicleanglesdisable"
"playersetstreamorigin"
"playerclearstreamorigin"
"nightvisionviewon"
"nightvisionviewoff"
"painvisionon"
"painvisionoff"
"getplayerintelisfound"
"setplayerintelfound"
"newpip"
"sethuddynlight"
"startscriptedanim"
"startcoverbehavior"
"startcoverarrival"
"starttraversearrival"
"checkcoverexitposwithpath"
"shoot"
"shootblank"
"melee"
"updateplayersightaccuracy"
"findshufflecovernode"
"findnearbycovernode"
"findcovernode"
"findbestcovernode"
"getcovernode"
"usecovernode"
"iscovervalidagainstenemy"
"reacquirestep"
"findreacquiredirectpath"
"trimpathtoattack"
"reacquiremove"
"findreacquireproximatepath"
"flagenemyunattackable"
"enterprone"
"exitprone"
"setproneanimnodes"
"updateprone"
"clearpitchorient"
"setlookatanimnodes"
"setlookat"
"setlookatentity"
"setlookatyawlimits"
"stoplookat"
"getmuzzlepos"
"getmuzzleangle"
"getmuzzlesideoffsetpos"
"getaimangle"
"canshoot"
"canshootenemy"
"cansee"
"seerecently"
"lastknowntime"
"lastknownpos"
"dropweapon"
"maymovetopoint"
"maymovefrompointtopoint"
"teleport"
"forceteleport"
"safeteleport"
"withinapproxpathdist"
"ispathdirect"
"allowedstances"
"isstanceallowed"
"issuppressionwaiting"
"issuppressed"
"ismovesuppressed"
"checkgrenadethrow"
"checkgrenadelaunch"
"checkgrenadelaunchpos"
"throwgrenade"
"pickupgrenade"
"useturret"
"stopuseturret"
"canuseturret"
"traversemode"
"animmode"
"orientmode"
"getmotionangle"
"shouldfacemotion"
"getanglestolikelyenemypath"
"setturretanim"
"getturret"
"getgroundenttype"
"forcestartnegotiation"
"setalienjumpcostscale"
"setalienruncostscale"
"setalientraversecostscale"
"animcustom"
"isinscriptedstate"
"canattackenemynode"
"getnegotiationstartnode"
"getnegotiationendnode"
"getnegotiationnextnode"
"getdoorpathnode"
"comparenodedirtopathdir"
"checkprone"
"pushplayer"
"checkgrenadethrowpos"
"setgoalnode"
"setgoalpos"
"setgoalentity"
"setgoalvolume"
"setgoalvolumeauto"
"getgoalvolume"
"cleargoalvolume"
"setfixednodesafevolume"
"getfixednodesafevolume"
"clearfixednodesafevolume"
"isingoal"
"setruntopos"
"nearnode"
"nearclaimnode"
"nearclaimnodeandangle"
"atdangerousnode"
"getisforcedincombat"
"setisforcedincombat"
"getenemyinfo"
"clearenemy"
"setentitytarget"
"clearentitytarget"
"setpotentialthreat"
"clearpotentialthreat"
"setflashbanged"
"setengagementmindist"
"setengagementmaxdist"
"isknownenemyinradius"
"isknownenemyinvolume"
"settalktospecies"
"invisiblenotsolid"
"visiblesolid"
"setdefaultaimlimits"
"initriotshieldhealth"
"getenemysqdist"
"getclosestenemysqdist"
"setthreatbiasgroup"
"getthreatbiasgroup"
"makeentitysentient"
"freeentitysentient"
"isindoor"
"getdroptofloorposition"
"isbadguy"
"animscripted"
"animscriptedthirdperson"
"animrelative"
"stopanimscripted"
"clearanim"
"setanimknob"
"setanimknoblimited"
"setanimknobrestart"
"setanimknoblimitedrestart"
"setanimknoball"
"setanimknoballlimited"
"setanimknoballrestart"
"setanimknoballlimitedrestart"
"setanim"
"setanimlimited"
"setanimrestart"
"setanimlimitedrestart"
"getanimtime"
"getanimweight"
"getanimassettype"
"setflaggedanimknob"
"setflaggedanimknoblimited"
"setflaggedanimknobrestart"
"setflaggedanimknoblimitedrestart"
"setflaggedanimknoball"
"setflaggedanimknoballrestart"
"setflaggedanim"
"setflaggedanimlimited"
"setflaggedanimrestart"
"setflaggedanimlimitedrestart"
"useanimtree"
"stopuseanimtree"
"setanimtime"
"allowstand"
"allowcrouch"
"allowprone"
"allowlean"
"allowswim"
"setocclusion"
"deactivateocclusion"
"deactivateallocclusion"
"isocclusionenabled"
"iseqenabled"
"seteq"
"seteqbands"
"deactivateeq"
"seteqlerp"
"islookingat"
"isthrowinggrenade"
"isfiring"
"ismeleeing"
"setautopickup"
"allowmelee"
"allowfire"
"enablehealthshield"
"enabledeathshield"
"nightvisiongogglesforceon"
"nightvisiongogglesforceoff"
"enableinvulnerability"
"disableinvulnerability"
"enablebreaching"
"disablebreaching"
"forceviewmodelanimation"
"disableturretdismount"
"enableturretdismount"
"uploadscore"
"uploadtime"
"uploadleaderboards"
"giveachievement"
"hidehud"
"showhud"
"mountvehicle"
"dismountvehicle"
"enableslowaim"
"disableslowaim"
"usehintsinvehicle"
"vehicleattackbuttonpressed"
"setwhizbyoffset"
"setwhizbyprobabilities"
"visionsetnakedforplayer_lerp"
"setwaitnode"
"returnplayercontrol"
"vehphys_starttrack"
"vehphys_clearautodisable"
"vehicleusealtblendedaudio"
"settext"
"clearalltextafterhudelem"
"setshader"
"settargetent"
"cleartargetent"
"settimer"
"settimerup"
"settimerstatic"
"settenthstimer"
"settenthstimerup"
"settenthstimerstatic"
"setclock"
"setclockup"
"setvalue"
"setwaypoint"
"setwaypointedgestyle_rotatingicon"
"setwaypointedgestyle_secondaryarrow"
"setwaypointiconoffscreenonly"
"fadeovertime"
"scaleovertime"
"moveovertime"
"reset"
"destroy"
"setpulsefx"
"setplayernamestring"
"changefontscaleovertime"
"startignoringspotlight"
"stopignoringspotlight"
"dontcastshadows"
"castshadows"
"setstablemissile"
"playersetgroundreferenceent"
"dontinterpolate"
"dospawn"
"stalingradspawn"
"getorigin"
"getcentroid"
"getshootatpos"
"getdebugeye"
"useby"
"playsound"
"playsoundevent"
"getsoundeventplayingonentity"
"setsoundeventparameter"
"stopsoundevent"
"playsoundatviewheight"
"prefetchsound"
"setpitch"
"scalepitch"
"setvolume"
"scalevolume"
"enableportalgroup"
"setspeakermapmonotostereo"
"setspeakermapmonoto51"
"setdistributed2dsound"
"playsoundasmaster"
"playloopsound"
"eqon"
"eqoff"
"haseq"
"iswaitingonsound"
"playfoley"
"getnormalhealth"
"setnormalhealth"
"dodamage"
"kill"
"show"
"hide"
"showonclient"
"hideonclient"
"disconnectpaths"
"connectpaths"
"disconnectnode"
"connectnode"
"startusingheroonlylighting"
"stopusingheroonlylighting"
"startusinglessfrequentlighting"
"stopusinglessfrequentlighting"
"setmovingplatformplayerturnrate"
"setthermalfog"
"setnightvisionfog"
"clearthermalfog"
"clearnightvisionfog"
"digitaldistortsetparams"
"setmode"
"getmode"
"setturretignoregoals"
"setturretcanaidetach"
"setturretfov"
"setplayerturretfov"
"lerpfov"
"lerpfovscale"
"getvalidcoverpeekouts"
"gethighestnodestance"
"doesnodeallowstance"
"doesnodeforcecombat"
"getgunangles"
"magicgrenade"
"magicgrenademanual"
"getentnum"
"launch"
"setsoundblend"
"makefakeai"
"spawndrone"
"setcorpseremovetimer"
"setlookattext"
"setspawnerteam"
"addaieventlistener"
"removeaieventlistener"
"getlightcolor"
"setlightcolor"
"getlightradius"
"setlightradius"
"getlightfovinner"
"getlightfovouter"
"setlightfovrange"
"getlightexponent"
"setlightexponent"
"startragdoll"
"startragdollfromimpact"
"queryshouldearlyragdoll"
"shouldearlyragdoll"
"logstring"
"laserhidefromclient"
"stopsounddspbus"
"thermaldrawenable"
"thermaldrawdisable"
"setturretdismountorg"
"setdamagestage"
"playsoundtoteam"
"playsoundtoplayer"
"playerhide"
"playershow"
"showtoplayer"
"threatdetectedtoplayer"
"clearthreatdetected"
"enableplayeruse"
"disableplayeruse"
"enableammogeneration"
"disableammogeneration"
"makescrambler"
"makeportableradar"
"clearscrambler"
"clearportableradar"
"placespawnpoint"
"setteamfortrigger"
"clientclaimtrigger"
"clientreleasetrigger"
"releaseclaimedtrigger"
"isusingonlinedataoffline"
"getrestedtime"
"sendleaderboards"
"isonladder"
"getcorpseanim"
"playerforcedeathanim"
"enablefocus"
"disablefocus"
"enableaudiozoom"
"disableaudiozoom"
"startac130"
"stopac130"
"enablemousesteer"
"setscriptmoverkillcam"
"usinggamepad"
"forcethirdpersonwhenfollowing"
"disableforcethirdpersonwhenfollowing"
"botsetflag"
"botsetstance"
"botsetscriptmove"
"botsetscriptgoal"
"botsetscriptgoalnode"
"botclearscriptgoal"
"botsetscriptenemy"
"botclearscriptenemy"
"botsetattacker"
"botgetscriptgoal"
"botgetscriptgoalradius"
"botgetscriptgoalyaw"
"botgetscriptgoaltype"
"botgetentrancepoint"
"botgetworldsize"
"botnodeavailable"
"botfindnoderandom"
"botmemoryevent"
"botmemoryselectpos"
"botnodepick"
"bothasscriptgoal"
"botgetpersonality"
"botthrowgrenade"
"botgetmemoryevents"
"botsetpersonality"
"botsetdifficulty"
"botgetdifficulty"
"botgetworldclosestedge"
"botlookatpoint"
"botpredictseepoint"
"botcanseeentity"
"botgetnodesonpath"
"botnodepickmultiple"
"botgetnearestnode"
"botgetfovdot"
"botsetawareness"
"botpursuingscriptgoal"
"botgetscriptgoalnode"
"botgetimperfectenemyinfo"
"botflagmemoryevents"
"botsetpathingstyle"
"botsetdifficultysetting"
"botgetdifficultysetting"
"botgetpathdist"
"botisrandomized"
"botpressbutton"
"botclearbutton"
"botnodescoremultiple"
"getnodenumber"
"setclientowner"
"setotherent"
"setaisightlinevisible"
"setentityowner"
"nodeisdisconnected"
"getnearestnode"
"makeentitynomeleetarget"
"isagent"
"spawnagent"
"finishagentdamage"
"setagentattacker"
"cloneagent"
"agentcanseesentient"
"scragentsetwaypoint"
"scragentsetgoalpos"
"scragentgetgoalpos"
"scragentsetgoalnode"
"scragentsetgoalentity"
"scragentsetgoalradius"
"scragentsetanimscale"
"scragentsetorientmode"
"scragentsetanimmode"
"scragentsetphysicsmode"
"scragentsetclipmode"
"scragentsetmaxturnspeed"
"scragentgetmaxturnspeed"
"scragentbeginmelee"
"scragentsetscripted"
"scragentdotrajectory"
"scragentdoanimlerp"
"scragentsetviewheight"
"scragentclaimnode"
"scragentrelinquishclaimednode"
"setradarping"
"setradarhighlight"
"setsonarvision"
"setharmonicbreach"
"setmaterialscriptparam"
"getaimassistdeltas"
"getaimassisttargetangles"
"getchargetime"
"overridereflectionprobe"
"defaultreflectionprobe"
"isholdinggrenade"
"isswitchinggrenade"
"ispreparinggrenade"
"setstencilstateoverride"
"clearstencilstateoverride"
"allowhighjump"
"isjumping"
"ishighjumping"
"vehicle_setvelocity"
"vehicle_addvelocity"
"getbraggingright"
"getmodelfromentity"
"getweaponheatlevel"
"isweaponoverheated"
"sprintbuttonpressed"
"vehicle_planethrottleoverride"
"vehicle_planethrottlereturncontrol"
"vehicle_planecrash"
"copyanimtreestate"
"lightsetforplayer"
"lightsetoverrideenableforplayer"
"lightsetoverridedisableforplayer"
"physicslaunchclientwithimpulse"
"setorcaavoidance"
"iswheelslipping"
"killnotification"
"setanimrate"
"setdoghandler"
"setdogcommand"
"setdogattackradius"
"isdogfollowinghandler"
"setdogmaxdrivespeed"
"isdogbeingdriven"
"setdogautoattackwhendriven"
"getdogattackbeginnode"
"setanimclass"
"enableanimstate"
"setanimstate"
"getanimentry"
"getanimentryname"
"getanimentryalias"
"getanimentrycount"
"pushplayervector"
"issprinting"
"playerlinkeduselinkedvelocity"
"shootstopsound"
"setclothtype"
"getclothmovesound"
"getequipmovesound"
"jumpbuttonpressed"
"rotateby"
"getlookaheaddir"
"getpathgoalpos"
"setrocketcorpse"
"setcorpsefalling"
"setsurfacetype"
"aiphysicstrace"
"aiphysicstracepassed"
"setdevtext"
"forcemovingplatformentity"
"setmovingplatformtrigger"
"visionsetstage"
"linkwaypointtotargetwithoffset"
"getlinkedparent"
"getmovingplatformparent"
"setnameplatematerial"
"retargetscriptmodellighting"
"setmantlesoundflavor"
"clearclienttriggeraudiozone"
"setclienttriggeraudiozone"
"makevehiclenotcollidewithplayers"
"getbobrate"
"setbobrate"
"setscriptablepartstate"
"stopsliding"
"cancelrocketcorpse"
"setdronegoalpos"
"hudoutlineenable"
"hudoutlinedisable"
"motionblurhqenable"
"motionblurhqdisable"
"screenshakeonentity"
"setpitchorient"
"worldpointtoscreenpos"
"linktoplayerviewignoreparentrot"
"shouldplaymeleedeathanim"
"botfirstavailablegrenade"
"visionsetwaterforplayer"
"setwatersurfacetransitionfx"
"linktoplayerviewfollowwatersurface"
"linktoplayerviewattachwatersurfacetransitioneffects"
"playersetwaterfog"
"emissiveblend"
"enableforceviewmodeldof"
"disableforceviewmodeldof"
"getcustomizationbody"
"getcustomizationhead"
"getcustomizationviewmodel"
"setviewmodeldepth"
"isenemyaware"
"hasenemybeenseen"
"physicssetmaxlinvel"
"physicssetmaxangvel"
"physicsgetlinvel"
"physicsgetlinspeed"
"physicsgetangvel"
"physicsgetangspeed"
"disablemissileboosting"
"enablemissileboosting"
"canspawntestclient"
"spawntestclient"
"loadcustomizationplayerview"
"setgrenadethrowscale"
"setgrenadecookscale"
"setplanesplineid"
"hudoutlineenableforclient"
"hudoutlinedisableforclient"
"hudoutlineenableforclients"
"hudoutlinedisableforclients"
"turretsetbarrelspinenabled"
"hasloadedcustomizationplayerview"
"setclienttriggeraudiozonelerp"
"setclienttriggeraudiozonepartial"
"scragentdoanimrelative"
"rotatetolinked"
"rotatebylinked"
"setlinkedangles"
"getcorpseentity"
"removefrommovingplatformsystem"
"logmatchdatalife"
"logmatchdatadeath"
"queuedialogforplayer"
"setmlgcameradefaults"
"ismlgspectator"
"disableautoreload"
"enableautoreload"
"issprintsliding"
"getlinkedchildren"
"botpredictenemycampspots"
"playsoundonmovingent"
"cancelmantle"
"hasfemalecustomizationmodel"
"loadviewweapons"
"setscriptabledamageowner"
"getscriptabletypeforentity"
"setfxkilldefondelete"
"getdogavoident"
"enabledogavoidance"
"enablehybridsight"
"lastknownreason"
"gettagindex"
"challengenotification"
"cancelaimove"
"vehicle_jetbikesethoverforcescale"
"linktosynchronizedparent"
"getclientomnvar"
"drawpostresolve"
"drawpostresolveoff"
"getcacplayerdataforgroup"
"cloakingenable"
"cloakingdisable"
"getunnormalizedcameramovement"
"getturretheat"
"isturretoverheated"
"vehicle_jetbikegetthrustfraction"
"vehicle_jetbikegetdragfraction"
"vehicle_jetbikegetantislipfraction"
"vehicle_jetbikegettotalrepulsorfraction"
"vehicle_assignbrushmodelcollision"
"vehicle_removebrushmodelcollision"
"vehicle_hovertanksethoverforcescale"
"forcesprint"
"forceads"
"forcedeathfall"
"gethybridscopestate"
"sethybridscopestate"
"getvieworigin"
"setweaponmodelvariant"
"ridevehicle"
"stopridingvehicle"
"getmantlesound"
"autoboltmissileeffects"
"disablemissilestick"
"enablemissilestick"
"setmissileminimapvisible"
"isoffhandweaponreadytothrow"
"isleaning"
"makecollidewithitemclip"
"ismovementfromgamepad"
"visionsetpostapplyforplayer"
"setlookattarget"
"clearlookattarget"
"overridematerial"
"overridematerialreset"
"overridetexture"
"overrideviewmodelmaterial"
"overrideviewmodelmaterialreset"
"enemyincrosshairs"
"setviewmodelmaterialscriptparam"
"vehicle_hovertankgetthrottleforce"
"vehicle_hovertankgetrepulsorforces"
"vehicle_hovertankgetantislipforce"
"vehicle_hovertankgetuprightingforce"
"vehicle_hovertankgetautoyawforce"
"getturretyawrate"
"getturretpitchrate"
"setclienttriggervisionset"
"overridelightingorigin"
"defaultlightingorigin"
"playdynamicambience"
"stopdynamicambience"
"isusinghandbrake"
"isusingboost"
"showviewmodel"
"hideviewmodel"
"setpickupweapon"
"playerlinkedmantleenable"
"allowpowerslide"
"allowhighjumpdrop"
"despawnagent"
"vehicle_setfakespeed"
"vehicle_jetbikesetthrustscale"
"agentclearscriptvars"
"scriptmodelplayanimdeltamotionfrompos"
"drawfacingentity"
"allowdodge"
"setcanspawnvehicleson"
"vehicle_setminimapvisible"
"setclutforplayer"
"setclutoverrideenableforplayer"
"setclutoverridedisableforplayer"
"setpainvisioneq"
"setplayermech"
"setdamagecallbackon"
"finishentitydamage"
"getlightshadowstate"
"setlightshadowstate"
"forceviewmodelanimationclear"
"designatefoftarget"
"sethintstringvisibleonlytoowner"
"notifyonplayercommandremove"
"canmantleex"
"allowboostjump"
"batterydischargebegin"
"batterydischargeend"
"batterydischargeonce"
"batterygetcharge"
"batterysetcharge"
"batteryfullrecharge"
"batterygetsize"
"batterysetdischargescale"
"batterygetdischargerate"
"batteryisinuse"
"enablephysicaldepthoffieldscripting"
"disablephysicaldepthoffieldscripting"
"setphysicaldepthoffield"
"setadsphysicaldepthoffield"
"vehicle_gettopspeed"
"gettoparc"
"getbottomarc"
"forcejump"
"vehicle_helicoptersetmaxangularvelocity"
"vehicle_helicoptersetmaxangularacceleration"
"setdemigod"
"attachnobuilddobj"
"setviewmodelanim"
"setviewmodelanimtime"
"pauseviewmodelanim"
"setadditiveviewmodelanim"
"activityfeedwriteingamepost"
"setcostumemodels"
"vehicle_getcurrentnode"
"setphysicalviewmodeldepthoffield"
"scriptmodelpauseanim"
"digitaldistortsetmaterial"
"disableoffhandsecondaryweapons"
"enableoffhandsecondaryweapons"
"canplaceriotshield"
"setriotshieldfailhint"
"enabledetonate"
"getdetonateenabled"
"playergetuseent"
"refreshshieldmodels"
"vehicle_diveboatissubmerged"
"scragentusemodelcollisionbounds"
"scragentsetwallruncost"
"getgravity"
"setgravityoverride"
"resetgravityoverride"
"vehphys_getvelocity"
"vehphys_isoffground"
"getjointype"
"vehicle_diveboatdive"
"addsoundmutedevice"
"removesoundmutedevice"
"clientaddsoundsubmix"
"clientclearsoundsubmix"
"clientclearallsubmixes"
"clientblendsoundsubmix"
"clientmakesoundsubmixsticky"
"clientmakesoundsubmixunsticky"
"clientenablesoundcontextoverride"
"clientdisablesoundcontextoverride"
"getthreatsightdelay"
"isusingoffhand"
"physicsstop"
"setremotehelicopterthrottlescale"
"actorusemodelcollisionbounds"
"setaxialmove"
"pathabilityadd"
"pathabilityremove"
"evaluatetrajectorydelta"
"rotateovertime"
"vehicle_diveboatenabledive"
"initwaterclienttrigger"
"getplayerweaponviewmodel"
"setturretheatwhenoverheating"
"setthreatdetection"
"setignorefoliagesightingme"
"loadcostumemodels"
"crouchbuttonpressed"
"disablealternatemelee"
"enablealternatemelee"
"hasblendshapes"
"getactiveanimations"
"hidepartviewmodel"
"luiopenmenu"
"screenpostoworldpoint"
"iscloaked"
"vehicleget3pcameraoffset"
"vehicleget3ppitchclamp"
"setstompbreakthrough"
"getstompbreakthrough"
"selfieaccessselfievalidflaginplayerdef"
"selfieaccessselfiecustomassetsarestreamed"
"selfieupdateselfieviewparameters"
"selfieinitializeselfieupdate"
"selfiescreenshottaken"
"selfieuploadcompleted"
"selfierestorebufferswaps"
"getsystemtimesp"
"setmissilecoasting"
"setmlgspectator"
"gettotalmpxp"
"turretsetgroundaimentity"
"hideweapontags"
"getweapondamagelocationmultiplier"
"setorbiterents"
"enablereload"
"isgroundentoverwater"
"setballpassallowed"
"consumereinforcement"
"ghost"
"loadweapons"
"playscheduledcinematicsound"
"setopaqueunlitforplayer"
"setwaypointiconfadeatcenter"
"setreinforcementhintstrings"
"enablecustomweaponcontext"
"disablecustomweaponcontext"
"setshadowrendering"
"playlocalannouncersound"
"setmissilespecialclipmask"
"vehicle_diveboatgetthrottleforce"
"vehicle_diveboatgetdragforce"
"isdodging"
"ispowersliding"
"getusableentity"
"getcurrentping"
"sethidetrigger"
"detonatebydoubletap"
"getnormalizedflick"
"getdwid"
"setplayerinfospmatchdata"
"physicsisactive"
"hasanimtree"
"isgod"
"setagentcostumeindex"
"visionsetoverdriveforplayer"
"issplitscreenotherplayerenemy"
"setowneroriginal"
"getlinkedtagname"
"forcefirstpersonwhenfollowed"
"disableforcefirstpersonwhenfollowed"
"setwaypointaerialtargeting"
"worldweaponsloaded"
"enablegrenadethrowback"
"usetriggertouchcheckstance"
"onlystreamactiveweapon"
"precachekillcamiconforweapon"
"selfierequestupdate"
"getclanwarsbonus"
"scragentsetspecies"
"scragentallowboost"
"scragentsetnopenetrate"
"finishplayerdamage_impactfx"
"finishagentdamage_impactfx"
"scragentsetorienttoground"
"scragentsetallowragdoll"
"scragentsetobstacleavoid"
"scragentsetlateralcodemove"
"scragentsetpathteamspread"
"isnotarget"
"setmovingplatformjitter"
"agentusescragentclipmask"
"setmeleechargevalid"
"ishighjumpallowed"
"setprestigemastery"
"agentsetfavoriteenemy"
"getpointinmodelbounds"
"setexomeleechargevalid"
"setdivision"
"setgrapplinghooktarget"
"scragentgetnodesonpath"
"addzmexploderbloodfx"
"sethighjumpresetallowed"
"scragentsetzombietype"
"getgroundentity"
"isnoclip"
"deleteonhostmigration"
"scragentgetphysicsmode"
"deathdropgrenade"
"stopsound"
"scragentsettraversenoderadius"
"scragentgettraversenoderadius"
"allowriotshieldplant"
"setstatic"
"scragentsynchronizeanims"
"settertiaryhintstring"
"scragentclearpath"
"scragenttrimpath"
"getsnapshotindexforclient"
"getsnapshotacknowledgedindexforclient"
"hasanimstate"
"movecomparison_enable"
"movecomparison_setbuttonpressed"
"movecomparison_setstickvalue"
"cloneclientasscriptmodel"
"disablerootmotion"
"playerlinktodeltablendviewangle"
"startweaponinspection"
"isinspectingweapon"
"luinotifyevent"
"luinotifyeventtospectators"
"enablequatinterpolationrotation"
"doesnodeforceidle"
"setisignoringgrenades"
*/


/*
{ 0x0000, "character/character_atlas_ar" },
{ 0x0000, "character/character_atlas_arctic_ar" },
{ 0x0000, "character/character_atlas_arctic_smg" },
{ 0x0000, "character/character_atlas_bodyguard_smg" },
{ 0x0000, "character/character_atlas_elete" },
{ 0x0000, "character/character_atlas_mech_pilot" },
{ 0x0000, "character/character_atlas_noexo" },
{ 0x0000, "character/character_atlas_pmc_estate_smg" },
{ 0x0000, "character/character_atlas_security_ar" },
{ 0x0000, "character/character_atlas_smg" },
{ 0x0000, "character/character_atlas_smg_lowlod" },
{ 0x0000, "character/character_casual_irons" },
{ 0x0000, "character/character_casual_irons_bet_holo" },
{ 0x0000, "character/character_civ_afr_dark_female_casual" },
{ 0x0000, "character/character_civ_afr_dark_female_dress" },
{ 0x0000, "character/character_civ_afr_dark_male_casual" },
{ 0x0000, "character/character_civ_afr_dark_male_dress" },
{ 0x0000, "character/character_civ_afr_drk_female_cas" },
{ 0x0000, "character/character_civ_afr_lgt_female_cas" },
{ 0x0000, "character/character_civ_afr_light_fem_drs_sml" },
{ 0x0000, "character/character_civ_afr_light_female_casual" },
{ 0x0000, "character/character_civ_afr_light_female_dress" },
{ 0x0000, "character/character_civ_afr_light_male_casual" },
{ 0x0000, "character/character_civ_afr_light_male_dress" },
{ 0x0000, "character/character_civ_afr_male_cas_grk" },
{ 0x0000, "character/character_civ_afr_male_drs_grk" },
{ 0x0000, "character/character_civ_african_male_b" },
{ 0x0000, "character/character_civ_african_male_c" },
{ 0x0000, "character/character_civ_african_male_d" },
{ 0x0000, "character/character_civ_asi_male_casual" },
{ 0x0000, "character/character_civ_asi_male_dress" },
{ 0x0000, "character/character_civ_cau_fem_drs_sml" },
{ 0x0000, "character/character_civ_cau_female_casual" },
{ 0x0000, "character/character_civ_cau_female_dress" },
{ 0x0000, "character/character_civ_cau_male_casual" },
{ 0x0000, "character/character_civ_cau_male_casual_ball1" },
{ 0x0000, "character/character_civ_cau_male_casual_ball2" },
{ 0x0000, "character/character_civ_cau_male_casual_grk" },
{ 0x0000, "character/character_civ_cau_male_dress" },
{ 0x0000, "character/character_civ_cau_male_dress_grk" },
{ 0x0000, "character/character_civ_mde_female_casual" },
{ 0x0000, "character/character_civ_mde_female_dress" },
{ 0x0000, "character/character_civ_mde_male_casual" },
{ 0x0000, "character/character_civ_mde_male_dress" },
{ 0x0000, "character/character_civ_pris_afr_dark_male_lite" },
{ 0x0000, "character/character_civ_pris_cau_male_lite" },
{ 0x0000, "character/character_civ_pris_mde_male_lite" },
{ 0x0000, "character/character_civ_rec_funeral_female_a" },
{ 0x0000, "character/character_civ_rec_funeral_female_b" },
{ 0x0000, "character/character_civ_rec_funeral_female_c" },
{ 0x0000, "character/character_civ_rec_funeral_female_d" },
{ 0x0000, "character/character_civ_rec_funeral_female_wife" },
{ 0x0000, "character/character_civ_rec_funeral_male" },
{ 0x0000, "character/character_civ_rec_funeral_male_afr" },
{ 0x0000, "character/character_civ_rec_funeral_male_afr_a" },
{ 0x0000, "character/character_civ_rec_funeral_male_afr_b" },
{ 0x0000, "character/character_civ_rec_funeral_male_afr_c" },
{ 0x0000, "character/character_civ_rec_funeral_male_afr_d" },
{ 0x0000, "character/character_civ_rec_funeral_male_asi_a" },
{ 0x0000, "character/character_civ_rec_funeral_male_cau_a" },
{ 0x0000, "character/character_civ_rec_funeral_male_cau_b" },
{ 0x0000, "character/character_civ_rec_funeral_male_cau_c" },
{ 0x0000, "character/character_civ_rec_funeral_male_cau_d" },
{ 0x0000, "character/character_civ_rec_funeral_male_cau_e" },
{ 0x0000, "character/character_civ_rec_funeral_male_cau_f" },
{ 0x0000, "character/character_civ_s1_female_a" },
{ 0x0000, "character/character_civ_s1_female_b" },
{ 0x0000, "character/character_civ_s1_female_c" },
{ 0x0000, "character/character_civ_s1_female_d" },
{ 0x0000, "character/character_civ_s1_female_dead_a" },
{ 0x0000, "character/character_civ_s1_female_dead_b" },
{ 0x0000, "character/character_civ_s1_female_e" },
{ 0x0000, "character/character_civ_s1_female_f" },
{ 0x0000, "character/character_civ_s1_female_g" },
{ 0x0000, "character/character_civ_s1_male_a" },
{ 0x0000, "character/character_civ_s1_male_b" },
{ 0x0000, "character/character_civ_s1_male_c" },
{ 0x0000, "character/character_civ_s1_male_d" },
{ 0x0000, "character/character_civ_s1_male_dead_a" },
{ 0x0000, "character/character_civ_s1_male_dead_b" },
{ 0x0000, "character/character_civ_s1_male_dead_c" },
{ 0x0000, "character/character_civ_s1_male_e" },
{ 0x0000, "character/character_civ_s1_male_hostage_lag" },
{ 0x0000, "character/character_civ_s1_worker_a" },
{ 0x0000, "character/character_civ_s1_worker_b" },
{ 0x0000, "character/character_civ_s1_worker_hardhat" },
{ 0x0000, "character/character_civ_scientist_s1_a" },
{ 0x0000, "character/character_civ_scientist_s1_b" },
{ 0x0000, "character/character_civ_scientist_s1_c" },
{ 0x0000, "character/character_civ_scientist_s1_d" },
{ 0x0000, "character/character_civ_scientist_s1_e" },
{ 0x0000, "character/character_civ_scientist_s1_f" },
{ 0x0000, "character/character_civ_seoul_female" },
{ 0x0000, "character/character_civ_seoul_male_a" },
{ 0x0000, "character/character_civ_seoul_male_b" },
{ 0x0000, "character/character_civ_seoul_male_d" },
{ 0x0000, "character/character_civ_seoul_male_e" },
{ 0x0000, "character/character_civ_seoul_male_f" },
{ 0x0000, "character/character_civ_seoul_male_principle" },
{ 0x0000, "character/character_civilian_africa_male_a" },
{ 0x0000, "character/character_civilian_africa_male_b" },
{ 0x0000, "character/character_civilian_africa_male_c" },
{ 0x0000, "character/character_civilian_india_female_a" },
{ 0x0000, "character/character_civilian_india_female_b" },
{ 0x0000, "character/character_civilian_india_male_a" },
{ 0x0000, "character/character_civilian_india_male_b" },
{ 0x0000, "character/character_civilian_india_male_c" },
{ 0x0000, "character/character_civilian_india_male_d" },
{ 0x0000, "character/character_civilian_prisoner_female_a" },
{ 0x0000, "character/character_civilian_prisoner_female_b" },
{ 0x0000, "character/character_civilian_slum_male_aa" },
{ 0x0000, "character/character_civilian_slum_male_aa_wht" },
{ 0x0000, "character/character_civilian_slum_male_ab" },
{ 0x0000, "character/character_civilian_slum_male_ab_wht" },
{ 0x0000, "character/character_civilian_slum_male_ba" },
{ 0x0000, "character/character_civilian_slum_male_ba_wht" },
{ 0x0000, "character/character_civilian_slum_male_bb" },
{ 0x0000, "character/character_civilian_slum_male_bb_wht" },
{ 0x0000, "character/character_civilian_worker_a" },
{ 0x0000, "character/character_civilian_worker_b" },
{ 0x0000, "character/character_civilian_worker_c" },
{ 0x0000, "character/character_coop_cloaked_static" },
{ 0x0000, "character/character_doctor" },
{ 0x0000, "character/character_doctor_cpt" },
{ 0x0000, "character/character_doctor_mwi" },
{ 0x0000, "character/character_doctor_mwi_holo" },
{ 0x0000, "character/character_doctor_pas" },
{ 0x0000, "character/character_dprk_ar" },
{ 0x0000, "character/character_dprk_shotgun" },
{ 0x0000, "character/character_dprk_smg" },
{ 0x0000, "character/character_hero_burke_b_atlas" },
{ 0x0000, "character/character_hero_burke_b_pmc" },
{ 0x0000, "character/character_hero_burke_sentinel" },
{ 0x0000, "character/character_hero_burke_sentinel_cloak" },
{ 0x0000, "character/character_hero_carter_pmc" },
{ 0x0000, "character/character_hero_cormack_captured" },
{ 0x0000, "character/character_hero_cormack_cloak" },
{ 0x0000, "character/character_hero_cormack_marine" },
{ 0x0000, "character/character_hero_cormack_marine_damaged" },
{ 0x0000, "character/character_hero_cormack_marine_dress" },
{ 0x0000, "character/character_hero_cormack_marine_seointro" },
{ 0x0000, "character/character_hero_cormack_sentinel" },
{ 0x0000, "character/character_hero_cormack_sentinel_arctic" },
{ 0x0000, "character/character_hero_cormack_sentinel_udt_b" },
{ 0x0000, "character/character_hero_cormack_sentinel_udtgr" },
{ 0x0000, "character/character_hero_gideon_atlas" },
{ 0x0000, "character/character_hero_gideon_atlas_arctic" },
{ 0x0000, "character/character_hero_gideon_atlas_pmc" },
{ 0x0000, "character/character_hero_gideon_atlas_pmc_mask" },
{ 0x0000, "character/character_hero_gideon_captured" },
{ 0x0000, "character/character_hero_gideon_pmc" },
{ 0x0000, "character/character_hero_gideon_sentinel_cloak" },
{ 0x0000, "character/character_hero_gideon_sentinel_finale" },
{ 0x0000, "character/character_hero_gideon_sentinel_jetpack" },
{ 0x0000, "character/character_hero_gideon_sentinel_pilot" },
{ 0x0000, "character/character_hero_ilana_atlas_pmc" },
{ 0x0000, "character/character_hero_ilana_captured" },
{ 0x0000, "character/character_hero_ilana_sentinel_arctic" },
{ 0x0000, "character/character_hero_ilana_sentinel_pilot" },
{ 0x0000, "character/character_hero_ilana_sentinel_udt_b" },
{ 0x0000, "character/character_hero_ilana_sentinel_udtgr" },
{ 0x0000, "character/character_hero_ilana_tourist" },
{ 0x0000, "character/character_hero_irons" },
{ 0x0000, "character/character_hero_joker_atlas" },
{ 0x0000, "character/character_hero_joker_atlas_pmc" },
{ 0x0000, "character/character_hero_knox_sentinel" },
{ 0x0000, "character/character_hero_knox_sentinel_cloak" },
{ 0x0000, "character/character_hero_knox_sentinel_det_cloak" },
{ 0x0000, "character/character_hero_knox_sentinel_jetpack" },
{ 0x0000, "character/character_hero_knox_sentinel_pilot" },
{ 0x0000, "character/character_hero_knox_sentinel_udt" },
{ 0x0000, "character/character_hero_knox_sentinel_udtgr" },
{ 0x0000, "character/character_hero_parker_atlas" },
{ 0x0000, "character/character_hero_will_marine" },
{ 0x0000, "character/character_hero_will_marine_seointro" },
{ 0x0000, "character/character_ie_doctor" },
{ 0x0000, "character/character_kva_ar" },
{ 0x0000, "character/character_kva_civ_a" },
{ 0x0000, "character/character_kva_civ_b" },
{ 0x0000, "character/character_kva_civ_c" },
{ 0x0000, "character/character_kva_hazmat" },
{ 0x0000, "character/character_kva_hazmat_nohat" },
{ 0x0000, "character/character_kva_leader_hades" },
{ 0x0000, "character/character_kva_lmg" },
{ 0x0000, "character/character_kva_shotgun" },
{ 0x0000, "character/character_kva_smg" },
{ 0x0000, "character/character_mech" },
{ 0x0000, "character/character_mech_long_lod" },
{ 0x0000, "character/character_mech_long_lod_baghdad" },
{ 0x0000, "character/character_mech_scaled" },
{ 0x0000, "character/character_navy_sf_assault_a" },
{ 0x0000, "character/character_navy_sf_assault_b" },
{ 0x0000, "character/character_navy_sf_assault_c" },
{ 0x0000, "character/character_nigerian_army" },
{ 0x0000, "character/character_nigerian_general" },
{ 0x0000, "character/character_nigerian_prime_minister" },
{ 0x0000, "character/character_pmc_ar" },
{ 0x0000, "character/character_pmc_ar_lowlod" },
{ 0x0000, "character/character_pmc_cap_ar" },
{ 0x0000, "character/character_pmc_noexo" },
{ 0x0000, "character/character_pmc_noexo_rec_driver" },
{ 0x0000, "character/character_pmc_smg" },
{ 0x0000, "character/character_pmc_smg_asi" },
{ 0x0000, "character/character_potus" },
{ 0x0000, "character/character_sentinel" },
{ 0x0000, "character/character_sentinel_arctic_ar" },
{ 0x0000, "character/character_sentinel_cloak" },
{ 0x0000, "character/character_sentinel_ie" },
{ 0x0000, "character/character_sentinel_ie_land" },
{ 0x0000, "character/character_sentinel_soldier_cloaked" },
{ 0x0000, "character/character_sf_police_a" },
{ 0x0000, "character/character_sf_police_b" },
{ 0x0000, "character/character_sf_police_c" },
{ 0x0000, "character/character_sp_doberman_dog" },
{ 0x0000, "character/character_sp_usmc_at4" },
{ 0x0000, "character/character_sp_usmc_james" },
{ 0x0000, "character/character_sp_usmc_ryan" },
{ 0x0000, "character/character_sp_usmc_sami" },
{ 0x0000, "character/character_sp_usmc_sami_goggles" },
{ 0x0000, "character/character_sp_usmc_zach" },
{ 0x0000, "character/character_sp_usmc_zach_goggles" },
{ 0x0000, "character/character_us_marine_ar" },
{ 0x0000, "character/character_us_marine_ar_lowlod" },
{ 0x0000, "character/character_us_marine_dress" },
{ 0x0000, "character/character_us_marine_dress_a" },
{ 0x0000, "character/character_us_marine_dress_b" },
{ 0x0000, "character/character_us_marine_dress_c" },
{ 0x0000, "character/character_us_marine_dress_d" },
{ 0x0000, "character/character_us_marine_dress_e" },
{ 0x0000, "character/character_us_marine_dress_f" },
{ 0x0000, "character/character_us_marine_dress_lowlod" },
{ 0x0000, "character/character_us_marine_seofob_ar" },
{ 0x0000, "character/character_us_marine_shotgun_lowlod" },
{ 0x0000, "character/character_us_marine_smg" },
{ 0x0000, "character/character_us_marine_smg_lowlod" },
{ 0x0000, "character/character_us_marine_smg_seo" },
{ 0x0000, "character/character_us_marine_smg_seointro" },
{ 0x0000, "character/mp_character_cloak_test" },
{ 0x0000, "character/mp_character_sentinel" },

{ 0xA4EF, "codescripts/character" },
{ 0xA4F0, "common_scripts/_artcommon" },
{ 0xA4F1, "common_scripts/_bcs_location_trigs" },
{ 0xA4F2, "common_scripts/_createfx" },
{ 0xA4F3, "common_scripts/_createfxmenu" },
{ 0xA4F4, "common_scripts/_destructible" },
{ 0xA4F5, "common_scripts/_dynamic_world" },
{ 0xA4F6, "common_scripts/_elevator" },
{ 0xA4F7, "common_scripts/_exploder" },
{ 0xA4F8, "common_scripts/_fx" },
{ 0xA4F9, "common_scripts/_pipes" },
{ 0xA4FA, "common_scripts/utility" },

{ 0x0000, "destructible_scripts/computer_01_destp" },
{ 0x0000, "destructible_scripts/container_plastic_72x56x48_01_destp" },
{ 0x0000, "destructible_scripts/container_plastic_beige_med_01_destp" },
{ 0x0000, "destructible_scripts/greece_spinning_displays" },
{ 0x0000, "destructible_scripts/powerbox_112x64_01_green_destp" },
{ 0x0000, "destructible_scripts/security_camera_scanner_destp" },
{ 0x0000, "destructible_scripts/toy_chicken" },
{ 0x0000, "destructible_scripts/toy_chicken_common" },
{ 0x0000, "destructible_scripts/toy_electricbox4" },
{ 0x0000, "destructible_scripts/toy_generator" },
{ 0x0000, "destructible_scripts/toy_generator_on" },
{ 0x0000, "destructible_scripts/toy_locker_double" },
{ 0x0000, "destructible_scripts/vehicle_civ_domestic_sedan_01_glass" },
{ 0x0000, "destructible_scripts/vehicle_civ_domestic_sedan_police_destpv" },
{ 0x0000, "destructible_scripts/vehicle_civ_domestic_sedan_taxi_glass" },
{ 0x0000, "destructible_scripts/vehicle_civ_smartcar_destpv" },
{ 0x0000, "destructible_scripts/vehicle_luxurysedan" },
{ 0x0000, "destructible_scripts/vehicle_luxurysedan_2008" },
{ 0x0000, "destructible_scripts/vehicle_pickup" },
{ 0x0000, "destructible_scripts/vehicle_suv_atlas_destpv" },
{ 0x0000, "destructible_scripts/wall_firebox_destp" },
{ 0x0000, "maps/_anim" },
{ 0x0000, "maps/_animatedmodels" },
{ 0x0000, "maps/_ar_view" },
{ 0x0000, "maps/_art" },
{ 0x0000, "maps/_autosave" },
{ 0x0000, "maps/_bobbing_boats" },
{ 0x0000, "maps/_breach" },
{ 0x0000, "maps/_car_door_shield" },
{ 0x0000, "maps/_cg_encounter_perf_monitor" },
{ 0x0000, "maps/_chargeable_weapon" },
{ 0x0000, "maps/_cloak" },
{ 0x0000, "maps/_cloak_enemy_behavior" },
{ 0x0000, "maps/_colors" },
{ 0x0000, "maps/_compass" },
{ 0x0000, "maps/_controlled_orbiting_drone" },
{ 0x0000, "maps/_controlled_sniperdrone" },
{ 0x0000, "maps/_coop" },
{ 0x0000, "maps/_createfx" },
{ 0x0000, "maps/_credits" },
{ 0x0000, "maps/_credits_autogen" },
{ 0x0000, "maps/_damagefeedback" },
{ 0x0000, "maps/_dds" },
{ 0x0000, "maps/_debug" },
{ 0x0000, "maps/_deployablecoverai" },
{ 0x0000, "maps/_detonategrenades" },
{ 0x0000, "maps/_dog_control" },
{ 0x0000, "maps/_dog_kinect" },
{ 0x0000, "maps/_drone" },
{ 0x0000, "maps/_drone_ai" },
{ 0x0000, "maps/_drone_base" },
{ 0x0000, "maps/_drone_civilian" },
{ 0x0000, "maps/_dshk_player" },
{ 0x0000, "maps/_endmission" },
{ 0x0000, "maps/_exo_climb" },
{ 0x0000, "maps/_exo_punch_door" },
{ 0x0000, "maps/_exo_shield_sp" },
{ 0x0000, "maps/_flashlight_cheap" },
{ 0x0000, "maps/_foam_bomb" },
{ 0x0000, "maps/_friendlyfire" },
{ 0x0000, "maps/_gameskill" },
{ 0x0000, "maps/_global_fx" },
{ 0x0000, "maps/_global_fx_code" },
{ 0x0000, "maps/_grapple" },
{ 0x0000, "maps/_grapple_anim" },
{ 0x0000, "maps/_grapple_traverse" },
{ 0x0000, "maps/_hand_signals" },
{ 0x0000, "maps/_helicopter_ai" },
{ 0x0000, "maps/_helicopter_globals" },
{ 0x0000, "maps/_high_speed_clouds" },
{ 0x0000, "maps/_hms_ai_utility" },
{ 0x0000, "maps/_hms_door_interact" },
{ 0x0000, "maps/_hms_greece_civilian" },
{ 0x0000, "maps/_hms_utility" },
{ 0x0000, "maps/_hud" },
{ 0x0000, "maps/_hud_util" },
{ 0x0000, "maps/_idle" },
{ 0x0000, "maps/_idle_phone" },
{ 0x0000, "maps/_idle_smoke" },
{ 0x0000, "maps/_intelligence" },
{ 0x0000, "maps/_introscreen" },
{ 0x0000, "maps/_inventory" },
{ 0x0000, "maps/_juggernaut" },
{ 0x0000, "maps/_lighting" },
{ 0x0000, "maps/_lights" },
{ 0x0000, "maps/_load" },
{ 0x0000, "maps/_loadout" },
{ 0x0000, "maps/_loadout_code" },
{ 0x0000, "maps/_mark_and_execute" },
{ 0x0000, "maps/_mech" },
{ 0x0000, "maps/_mech_aud" },
{ 0x0000, "maps/_mech_grapple" },
{ 0x0000, "maps/_mg_penetration" },
{ 0x0000, "maps/_mgturret" },
{ 0x0000, "maps/_mgturret_auto_nonai" },
{ 0x0000, "maps/_microdronelauncher" },
{ 0x0000, "maps/_microwave_grenade" },
{ 0x0000, "maps/_mocap_ar" },
{ 0x0000, "maps/_names" },
{ 0x0000, "maps/_nightvision" },
{ 0x0000, "maps/_patrol" },
{ 0x0000, "maps/_patrol_anims" },
{ 0x0000, "maps/_patrol_anims_active" },
{ 0x0000, "maps/_patrol_anims_casualkiller" },
{ 0x0000, "maps/_patrol_anims_creepwalk" },
{ 0x0000, "maps/_patrol_anims_patroljog" },
{ 0x0000, "maps/_patrol_cold_anims" },
{ 0x0000, "maps/_patrol_extended" },
{ 0x0000, "maps/_player_boost_dash" },
{ 0x0000, "maps/_player_boost_jump_anims" },
{ 0x0000, "maps/_player_boost_jump_aud" },
{ 0x0000, "maps/_player_death" },
{ 0x0000, "maps/_player_exo" },
{ 0x0000, "maps/_player_fastzip" },
{ 0x0000, "maps/_player_high_jump" },
{ 0x0000, "maps/_player_land_assist" },
{ 0x0000, "maps/_player_stats" },
{ 0x0000, "maps/_playermech_code" },
{ 0x0000, "maps/_pmove" },
{ 0x0000, "maps/_president" },
{ 0x0000, "maps/_props" },
{ 0x0000, "maps/_rambo" },
{ 0x0000, "maps/_riotshield" },
{ 0x0000, "maps/_sarray" },
{ 0x0000, "maps/_shg_anim" },
{ 0x0000, "maps/_shg_debug" },
{ 0x0000, "maps/_shg_design_tools" },
{ 0x0000, "maps/_shg_fx" },
{ 0x0000, "maps/_shg_utility" },
{ 0x0000, "maps/_slowmo_breach" },
{ 0x0000, "maps/_sniper_glint" },
{ 0x0000, "maps/_sniper_setup_ai" },
{ 0x0000, "maps/_sonicaoe" },
{ 0x0000, "maps/_sp_matchdata" },
{ 0x0000, "maps/_spawner" },
{ 0x0000, "maps/_stealth" },
{ 0x0000, "maps/_stealth_accuracy_friendly" },
{ 0x0000, "maps/_stealth_animation_funcs" },
{ 0x0000, "maps/_stealth_anims" },
{ 0x0000, "maps/_stealth_behavior_enemy" },
{ 0x0000, "maps/_stealth_behavior_friendly" },
{ 0x0000, "maps/_stealth_behavior_system" },
{ 0x0000, "maps/_stealth_color_friendly" },
{ 0x0000, "maps/_stealth_corpse_enemy" },
{ 0x0000, "maps/_stealth_corpse_system" },
{ 0x0000, "maps/_stealth_debug" },
{ 0x0000, "maps/_stealth_display" },
{ 0x0000, "maps/_stealth_event_enemy" },
{ 0x0000, "maps/_stealth_shared_utilities" },
{ 0x0000, "maps/_stealth_smartstance_friendly" },
{ 0x0000, "maps/_stealth_threat_enemy" },
{ 0x0000, "maps/_stealth_utility" },
{ 0x0000, "maps/_stealth_visibility_enemy" },
{ 0x0000, "maps/_stealth_visibility_friendly" },
{ 0x0000, "maps/_stealth_visibility_system" },
{ 0x0000, "maps/_stingerm7" },
{ 0x0000, "maps/_stingerm7_greece" },
{ 0x0000, "maps/_swim_ai" },
{ 0x0000, "maps/_swim_ai_common" },
{ 0x0000, "maps/_swim_player" },
{ 0x0000, "maps/_tagging" },
{ 0x0000, "maps/_target_lock" },
{ 0x0000, "maps/_treadfx" },
{ 0x0000, "maps/_trigger" },
{ 0x0000, "maps/_underwater" },
{ 0x0000, "maps/_upgrade_challenge" },
{ 0x0000, "maps/_upgrade_perks" },
{ 0x0000, "maps/_upgrade_system" },
{ 0x0000, "maps/_urgent_walk" },
{ 0x0000, "maps/_utility" },
{ 0x0000, "maps/_utility_code" },
{ 0x0000, "maps/_utility_dogs" },
{ 0x0000, "maps/_variable_grenade" },
{ 0x0000, "maps/_vehicle" },
{ 0x0000, "maps/_vehicle_aianim" },
{ 0x0000, "maps/_vehicle_code" },
{ 0x0000, "maps/_vehicle_free_drive" },
{ 0x0000, "maps/_vehicle_missile" },
{ 0x0000, "maps/_vehicle_shg" },
{ 0x0000, "maps/_vehicle_traffic" },
{ 0x0000, "maps/_vignette_util" },
{ 0x0000, "maps/_warzone_tactics" },
{ 0x0000, "maps/_water" },
{ 0x0000, "maps/_weapon_pdrone" },
{ 0x0000, "maps/_weather" },
{ 0x0000, "maps/betrayal_fx" },
{ 0x0000, "maps/betrayal_precache" },
{ 0x0000, "maps/captured_fx" },
{ 0x0000, "maps/captured_precache" },
{ 0x0000, "maps/crash_fx" },
{ 0x0000, "maps/crash_precache" },
{ 0x0000, "maps/credits_s1_fx" },
{ 0x0000, "maps/credits_s1_precache" },
{ 0x0000, "maps/detroit_fx" },
{ 0x0000, "maps/detroit_precache" },
{ 0x0000, "maps/df_baghdad_fx" },
{ 0x0000, "maps/df_baghdad_precache" },
{ 0x0000, "maps/df_fly_fx" },
{ 0x0000, "maps/df_fly_precache" },
{ 0x0000, "maps/finale_fx" },
{ 0x0000, "maps/finale_precache" },
{ 0x0000, "maps/fusion_fx" },
{ 0x0000, "maps/fusion_precache" },
{ 0x0000, "maps/greece_conf_center_fx" },
{ 0x0000, "maps/greece_ending_fx" },
{ 0x0000, "maps/greece_fx" },
{ 0x0000, "maps/greece_precache" },
{ 0x0000, "maps/greece_safehouse_fx" },
{ 0x0000, "maps/greece_sniper_scramble_fx" },
{ 0x0000, "maps/irons_estate_fx" },
{ 0x0000, "maps/irons_estate_precache" },
{ 0x0000, "maps/lab_fx" },
{ 0x0000, "maps/lab_precache" },
{ 0x0000, "maps/lagos_fx" },
{ 0x0000, "maps/lagos_precache" },
{ 0x0000, "maps/recovery_fx" },
{ 0x0000, "maps/recovery_precache" },
{ 0x0000, "maps/sanfran_b_fx" },
{ 0x0000, "maps/sanfran_b_precache" },
{ 0x0000, "maps/sanfran_fx" },
{ 0x0000, "maps/sanfran_precache" },
{ 0x0000, "maps/seoul_fx" },
{ 0x0000, "maps/seoul_precache" },
{ 0x0000, "mptype/mptype_cloak_test" },
{ 0x0000, "soundscripts/_ambient" },
{ 0x0000, "soundscripts/_audio" },
{ 0x0000, "soundscripts/_audio_dynamic_ambi" },
{ 0x0000, "soundscripts/_audio_mix_manager" },
{ 0x0000, "soundscripts/_audio_music" },
{ 0x0000, "soundscripts/_audio_presets_music" },
{ 0x0000, "soundscripts/_audio_presets_vehicles" },
{ 0x0000, "soundscripts/_audio_reverb" },
{ 0x0000, "soundscripts/_audio_stream_manager" },
{ 0x0000, "soundscripts/_audio_vehicle_manager" },
{ 0x0000, "soundscripts/_audio_vehicles" },
{ 0x0000, "soundscripts/_audio_whizby" },
{ 0x0000, "soundscripts/_audio_zone_manager" },
{ 0x0000, "soundscripts/_snd" },
{ 0x0000, "soundscripts/_snd_common" },
{ 0x0000, "soundscripts/_snd_debug_bayless" },
{ 0x0000, "soundscripts/_snd_debug_bina" },
{ 0x0000, "soundscripts/_snd_debug_blondin" },
{ 0x0000, "soundscripts/_snd_debug_caisley" },
{ 0x0000, "soundscripts/_snd_debug_gavazza" },
{ 0x0000, "soundscripts/_snd_debug_kilborn" },
{ 0x0000, "soundscripts/_snd_debug_loperfido" },
{ 0x0000, "soundscripts/_snd_debug_mcsweeney" },
{ 0x0000, "soundscripts/_snd_debug_mika" },
{ 0x0000, "soundscripts/_snd_debug_naas" },
{ 0x0000, "soundscripts/_snd_debug_nuniyants" },
{ 0x0000, "soundscripts/_snd_debug_swenson" },
{ 0x0000, "soundscripts/_snd_debug_veca" },
{ 0x0000, "soundscripts/_snd_filters" },
{ 0x0000, "soundscripts/_snd_foley" },
{ 0x0000, "soundscripts/_snd_hud" },
{ 0x0000, "soundscripts/_snd_pcap" },
{ 0x0000, "soundscripts/_snd_playsound" },
{ 0x0000, "soundscripts/_snd_timescale" },
{ 0x0000, "soundscripts/so_aud" },
{ 0x0000, "vehicle_scripts/_atlas_jet" },
{ 0x0000, "vehicle_scripts/_atlas_piranha" },
{ 0x0000, "vehicle_scripts/_atlas_suv" },
{ 0x0000, "vehicle_scripts/_atlas_van" },
{ 0x0000, "vehicle_scripts/_attack_drone" },
{ 0x0000, "vehicle_scripts/_attack_drone_aud" },
{ 0x0000, "vehicle_scripts/_attack_drone_common" },
{ 0x0000, "vehicle_scripts/_attack_drone_controllable" },
{ 0x0000, "vehicle_scripts/_attack_drone_individual" },
{ 0x0000, "vehicle_scripts/_attack_drone_kamikaze" },
{ 0x0000, "vehicle_scripts/_attack_drone_queen" },
{ 0x0000, "vehicle_scripts/_attack_heli" },
{ 0x0000, "vehicle_scripts/_chinese_brave_warrior" },
{ 0x0000, "vehicle_scripts/_civ_boat" },
{ 0x0000, "vehicle_scripts/_civ_boxtruck_ai" },
{ 0x0000, "vehicle_scripts/_civ_domestic_bus" },
{ 0x0000, "vehicle_scripts/_civ_domestic_economy_ai" },
{ 0x0000, "vehicle_scripts/_civ_domestic_minivan" },
{ 0x0000, "vehicle_scripts/_civ_domestic_sedan_01" },
{ 0x0000, "vehicle_scripts/_civ_domestic_sedan_police" },
{ 0x0000, "vehicle_scripts/_civ_domestic_sedan_taxi_01" },
{ 0x0000, "vehicle_scripts/_civ_domestic_sportscar_01" },
{ 0x0000, "vehicle_scripts/_civ_domestic_suv" },
{ 0x0000, "vehicle_scripts/_civ_domestic_truck" },
{ 0x0000, "vehicle_scripts/_civ_full_size_pickup_01_ai" },
{ 0x0000, "vehicle_scripts/_civ_full_size_technical" },
{ 0x0000, "vehicle_scripts/_civ_pickup_truck_01" },
{ 0x0000, "vehicle_scripts/_civ_smartcar" },
{ 0x0000, "vehicle_scripts/_civ_workvan" },
{ 0x0000, "vehicle_scripts/_cover_drone" },
{ 0x0000, "vehicle_scripts/_cover_drone_aud" },
{ 0x0000, "vehicle_scripts/_diveboat" },
{ 0x0000, "vehicle_scripts/_diveboat_aud" },
{ 0x0000, "vehicle_scripts/_empty" },
{ 0x0000, "vehicle_scripts/_ft101_tank" },
{ 0x0000, "vehicle_scripts/_gaz" },
{ 0x0000, "vehicle_scripts/_gaz_dshk" },
{ 0x0000, "vehicle_scripts/_gaz_dshk_aud" },
{ 0x0000, "vehicle_scripts/_generic_script_model_lagos" },
{ 0x0000, "vehicle_scripts/_havoc_missile_scripted" },
{ 0x0000, "vehicle_scripts/_hovertank" },
{ 0x0000, "vehicle_scripts/_hovertank_aud" },
{ 0x0000, "vehicle_scripts/_ind_semi_truck_fuel_tanker" },
{ 0x0000, "vehicle_scripts/_jetbike" },
{ 0x0000, "vehicle_scripts/_jetbike_aud" },
{ 0x0000, "vehicle_scripts/_littlebird" },
{ 0x0000, "vehicle_scripts/_littlebird_aud" },
{ 0x0000, "vehicle_scripts/_littlebird_landing" },
{ 0x0000, "vehicle_scripts/_littlebird_player" },
{ 0x0000, "vehicle_scripts/_mi17" },
{ 0x0000, "vehicle_scripts/_mi17_aud" },
{ 0x0000, "vehicle_scripts/_mi17_noai" },
{ 0x0000, "vehicle_scripts/_mig29" },
{ 0x0000, "vehicle_scripts/_mig29_controllable" },
{ 0x0000, "vehicle_scripts/_mil_cargo_truck" },
{ 0x0000, "vehicle_scripts/_pdrone" },
{ 0x0000, "vehicle_scripts/_pdrone_aud" },
{ 0x0000, "vehicle_scripts/_pdrone_player" },
{ 0x0000, "vehicle_scripts/_pdrone_player_aud" },
{ 0x0000, "vehicle_scripts/_pdrone_security" },
{ 0x0000, "vehicle_scripts/_pdrone_security_aud" },
{ 0x0000, "vehicle_scripts/_pdrone_tactical_picker" },
{ 0x0000, "vehicle_scripts/_pdrone_threat_sensor" },
{ 0x0000, "vehicle_scripts/_pitbull" },
{ 0x0000, "vehicle_scripts/_pitbull_aud" },
{ 0x0000, "vehicle_scripts/_razorback" },
{ 0x0000, "vehicle_scripts/_razorback_fx" },
{ 0x0000, "vehicle_scripts/_s19" },
{ 0x0000, "vehicle_scripts/_sentinel_survey_drone_hud" },
{ 0x0000, "vehicle_scripts/_shrike" },
{ 0x0000, "vehicle_scripts/_sidewinder_scripted" },
{ 0x0000, "vehicle_scripts/_slamraam" },
{ 0x0000, "vehicle_scripts/_sniper_drone" },
{ 0x0000, "vehicle_scripts/_sniper_drone_aud" },
{ 0x0000, "vehicle_scripts/_uk_delivery_truck" },
{ 0x0000, "vehicle_scripts/_vehicle_missile_launcher_ai" },
{ 0x0000, "vehicle_scripts/_vehicle_multiweapon_util" },
{ 0x0000, "vehicle_scripts/_vehicle_turret_ai" },
{ 0x0000, "vehicle_scripts/_vrap" },
{ 0x0000, "vehicle_scripts/_walker_tank" },
{ 0x0000, "vehicle_scripts/_x4walker_wheels" },
{ 0x0000, "vehicle_scripts/_x4walker_wheels_aud" },
{ 0x0000, "vehicle_scripts/_x4walker_wheels_turret" },
{ 0x0000, "vehicle_scripts/_x4walker_wheels_turret_aud" },
{ 0x0000, "vehicle_scripts/_x4walker_wheels_turret_closed" },
{ 0x0000, "vehicle_scripts/_x4walker_wheels_turret_closed_aud" },
{ 0x0000, "vehicle_scripts/_xh9_warbird" },
{ 0x0000, "xmodelalias/alias_africa_civilian_male_heads" },
{ 0x0000, "xmodelalias/alias_atlas_bodyguard_heads" },
{ 0x0000, "xmodelalias/alias_civ_afr_dark_male_bodies_casual" },
{ 0x0000, "xmodelalias/alias_civ_afr_dark_male_bodies_dress" },
{ 0x0000, "xmodelalias/alias_civ_afr_dark_male_heads" },
{ 0x0000, "xmodelalias/alias_civ_afr_drk_female_bodies_cas" },
{ 0x0000, "xmodelalias/alias_civ_afr_drk_female_bodies_drs" },
{ 0x0000, "xmodelalias/alias_civ_afr_drk_female_heads" },
{ 0x0000, "xmodelalias/alias_civ_afr_lgt_fem_bod_drs_sml" },
{ 0x0000, "xmodelalias/alias_civ_afr_lgt_female_bodies_cas" },
{ 0x0000, "xmodelalias/alias_civ_afr_lgt_female_bodies_drs" },
{ 0x0000, "xmodelalias/alias_civ_afr_lgt_female_heads" },
{ 0x0000, "xmodelalias/alias_civ_afr_light_male_bodies_casual" },
{ 0x0000, "xmodelalias/alias_civ_afr_light_male_bodies_dress" },
{ 0x0000, "xmodelalias/alias_civ_afr_light_male_heads" },
{ 0x0000, "xmodelalias/alias_civ_asi_male_bodies_casual" },
{ 0x0000, "xmodelalias/alias_civ_asi_male_bodies_dress" },
{ 0x0000, "xmodelalias/alias_civ_asi_male_heads" },
{ 0x0000, "xmodelalias/alias_civ_asi_male_heads_cpt" },
{ 0x0000, "xmodelalias/alias_civ_cau_fem_bod_drs_sml" },
{ 0x0000, "xmodelalias/alias_civ_cau_fem_heads_sml" },
{ 0x0000, "xmodelalias/alias_civ_cau_female_bodies_cas" },
{ 0x0000, "xmodelalias/alias_civ_cau_female_bodies_drs" },
{ 0x0000, "xmodelalias/alias_civ_cau_female_heads" },
{ 0x0000, "xmodelalias/alias_civ_cau_male_bodies_casual" },
{ 0x0000, "xmodelalias/alias_civ_cau_male_bodies_dress" },
{ 0x0000, "xmodelalias/alias_civ_cau_male_heads" },
{ 0x0000, "xmodelalias/alias_civ_cau_male_heads_hazmat_nohat" },
{ 0x0000, "xmodelalias/alias_civ_mde_female_bodies_cas" },
{ 0x0000, "xmodelalias/alias_civ_mde_female_bodies_drs" },
{ 0x0000, "xmodelalias/alias_civ_mde_female_heads" },
{ 0x0000, "xmodelalias/alias_civ_mde_male_bodies_casual" },
{ 0x0000, "xmodelalias/alias_civ_mde_male_bodies_dress" },
{ 0x0000, "xmodelalias/alias_civ_mde_male_heads" },
{ 0x0000, "xmodelalias/alias_civ_pris_afr_dark_male_bodies" },
{ 0x0000, "xmodelalias/alias_civ_pris_cau_male_bodies" },
{ 0x0000, "xmodelalias/alias_civ_pris_mde_male_bodies" },
{ 0x0000, "xmodelalias/alias_civ_rec_funeral_male_body" },
{ 0x0000, "xmodelalias/alias_civ_rec_funeral_male_body_afr" },
{ 0x0000, "xmodelalias/alias_civ_rec_funeral_male_heads" },
{ 0x0000, "xmodelalias/alias_civ_rec_funeral_male_heads_afr" },
{ 0x0000, "xmodelalias/alias_civ_urban_dead_body_a" },
{ 0x0000, "xmodelalias/alias_civ_urban_dead_body_b" },
{ 0x0000, "xmodelalias/alias_civ_urban_dead_body_c" },
{ 0x0000, "xmodelalias/alias_civ_urban_male_heads_afr_light" },
{ 0x0000, "xmodelalias/alias_civ_worker_hardhat_s1_heads" },
{ 0x0000, "xmodelalias/alias_civilian_heads_prisoner_female" },
{ 0x0000, "xmodelalias/alias_civilian_slum_heads" },
{ 0x0000, "xmodelalias/alias_civilian_slum_heads_wht" },
{ 0x0000, "xmodelalias/alias_civilian_worker_heads" },
{ 0x0000, "xmodelalias/alias_cloak_test" },
{ 0x0000, "xmodelalias/alias_coop_cloaked_static_heads" },
{ 0x0000, "xmodelalias/alias_enemy_atlas_arctic_heads" },
{ 0x0000, "xmodelalias/alias_enemy_atlas_elite_heads" },
{ 0x0000, "xmodelalias/alias_enemy_atlas_heads" },
{ 0x0000, "xmodelalias/alias_greece_civilian_heads_males_a" },
{ 0x0000, "xmodelalias/alias_greece_civilian_heads_males_b" },
{ 0x0000, "xmodelalias/alias_kva_heads" },
{ 0x0000, "xmodelalias/alias_mp_sentinel_heads" },
{ 0x0000, "xmodelalias/alias_nigerian_army_bodies" },
{ 0x0000, "xmodelalias/alias_nigerian_army_heads" },
{ 0x0000, "xmodelalias/alias_pmc_casual_heads" },
{ 0x0000, "xmodelalias/alias_pmc_casual_heads_asi" },
{ 0x0000, "xmodelalias/alias_pmc_helmet_heads" },
{ 0x0000, "xmodelalias/alias_sentinel_arctic_bodies" },
{ 0x0000, "xmodelalias/alias_sentinel_arctic_heads" },
{ 0x0000, "xmodelalias/alias_sentinel_bodies" },
{ 0x0000, "xmodelalias/alias_sentinel_heads" },
{ 0x0000, "xmodelalias/alias_sentinel_udt_heads" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_body_females" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_body_males_a" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_body_males_b" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_body_males_d" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_body_males_f" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_head_females" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_head_males_a" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_head_males_b" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_head_males_c" },
{ 0x0000, "xmodelalias/alias_seoul_civilian_head_males_d" },
{ 0x0000, "xmodelalias/alias_us_marine_dress_bodies" },
{ 0x0000, "xmodelalias/alias_us_marine_dress_heads" },
{ 0x0000, "xmodelalias/alias_us_marine_heads" },
{ 0x0000, "maps/animated_models/foliage_tree_grey_oak_lg_a" },
{ 0x0000, "maps/createart/betrayal_art" },
{ 0x0000, "maps/createart/betrayal_fog" },
{ 0x0000, "maps/createart/betrayal_fog_hdr" },
{ 0x0000, "maps/createart/captured_art" },
{ 0x0000, "maps/createart/captured_fog" },
{ 0x0000, "maps/createart/captured_fog_hdr" },
{ 0x0000, "maps/createart/crash_art" },
{ 0x0000, "maps/createart/crash_fog" },
{ 0x0000, "maps/createart/crash_fog_hdr" },
{ 0x0000, "maps/createart/credits_s1_art" },
{ 0x0000, "maps/createart/credits_s1_fog" },
{ 0x0000, "maps/createart/credits_s1_fog_hdr" },
{ 0x0000, "maps/createart/detroit_art" },
{ 0x0000, "maps/createart/detroit_fog" },
{ 0x0000, "maps/createart/detroit_fog_hdr" },
{ 0x0000, "maps/createart/df_baghdad_art" },
{ 0x0000, "maps/createart/df_baghdad_fog" },
{ 0x0000, "maps/createart/df_baghdad_fog_hdr" },
{ 0x0000, "maps/createart/df_fly_art" },
{ 0x0000, "maps/createart/df_fly_fog" },
{ 0x0000, "maps/createart/df_fly_fog_hdr" },
{ 0x0000, "maps/createart/finale_art" },
{ 0x0000, "maps/createart/finale_fog" },
{ 0x0000, "maps/createart/finale_fog_hdr" },
{ 0x0000, "maps/createart/fusion_art" },
{ 0x0000, "maps/createart/fusion_fog" },
{ 0x0000, "maps/createart/fusion_fog_hdr" },
{ 0x0000, "maps/createart/greece_art" },
{ 0x0000, "maps/createart/greece_fog" },
{ 0x0000, "maps/createart/greece_fog_hdr" },
{ 0x0000, "maps/createart/irons_estate_art" },
{ 0x0000, "maps/createart/irons_estate_fog" },
{ 0x0000, "maps/createart/irons_estate_fog_hdr" },
{ 0x0000, "maps/createart/lab_art" },
{ 0x0000, "maps/createart/lab_fog" },
{ 0x0000, "maps/createart/lab_fog_hdr" },
{ 0x0000, "maps/createart/lagos_art" },
{ 0x0000, "maps/createart/lagos_fog" },
{ 0x0000, "maps/createart/lagos_fog_hdr" },
{ 0x0000, "maps/createart/mp_comeback_art" },
{ 0x0000, "maps/createart/mp_comeback_fog" },
{ 0x0000, "maps/createart/mp_comeback_fog_hdr" },
{ 0x0000, "maps/createart/mp_detroit_art" },
{ 0x0000, "maps/createart/mp_detroit_fog" },
{ 0x0000, "maps/createart/mp_detroit_fog_hdr" },
{ 0x0000, "maps/createart/mp_greenband_art" },
{ 0x0000, "maps/createart/mp_greenband_fog" },
{ 0x0000, "maps/createart/mp_greenband_fog_hdr" },
{ 0x0000, "maps/createart/mp_instinct_art" },
{ 0x0000, "maps/createart/mp_instinct_fog" },
{ 0x0000, "maps/createart/mp_instinct_fog_hdr" },
{ 0x0000, "maps/createart/mp_lab2_art" },
{ 0x0000, "maps/createart/mp_lab2_fog" },
{ 0x0000, "maps/createart/mp_lab2_fog_hdr" },
{ 0x0000, "maps/createart/mp_laser2_art" },
{ 0x0000, "maps/createart/mp_laser2_fog" },
{ 0x0000, "maps/createart/mp_laser2_fog_hdr" },
{ 0x0000, "maps/createart/mp_levity_art" },
{ 0x0000, "maps/createart/mp_levity_fog" },
{ 0x0000, "maps/createart/mp_levity_fog_hdr" },
{ 0x0000, "maps/createart/mp_prison_art" },
{ 0x0000, "maps/createart/mp_prison_fog" },
{ 0x0000, "maps/createart/mp_prison_fog_hdr" },
{ 0x0000, "maps/createart/mp_prison_z_art" },
{ 0x0000, "maps/createart/mp_prison_z_fog" },
{ 0x0000, "maps/createart/mp_prison_z_fog_hdr" },
{ 0x0000, "maps/createart/mp_recovery_art" },
{ 0x0000, "maps/createart/mp_recovery_fog" },
{ 0x0000, "maps/createart/mp_recovery_fog_hdr" },
{ 0x0000, "maps/createart/mp_refraction_art" },
{ 0x0000, "maps/createart/mp_refraction_fog" },
{ 0x0000, "maps/createart/mp_refraction_fog_hdr" },
{ 0x0000, "maps/createart/mp_solar_art" },
{ 0x0000, "maps/createart/mp_solar_fog" },
{ 0x0000, "maps/createart/mp_solar_fog_hdr" },
{ 0x0000, "maps/createart/mp_terrace_art" },
{ 0x0000, "maps/createart/mp_terrace_fog" },
{ 0x0000, "maps/createart/mp_terrace_fog_hdr" },
{ 0x0000, "maps/createart/mp_venus_art" },
{ 0x0000, "maps/createart/mp_venus_fog" },
{ 0x0000, "maps/createart/mp_venus_fog_hdr" },
{ 0x0000, "maps/createart/mp_vlobby_room_art" },
{ 0x0000, "maps/createart/mp_vlobby_room_fog" },
{ 0x0000, "maps/createart/mp_vlobby_room_fog_hdr" },
{ 0x0000, "maps/createart/recovery_art" },
{ 0x0000, "maps/createart/recovery_fog" },
{ 0x0000, "maps/createart/recovery_fog_hdr" },
{ 0x0000, "maps/createart/sanfran_art" },
{ 0x0000, "maps/createart/sanfran_b_art" },
{ 0x0000, "maps/createart/sanfran_b_fog" },
{ 0x0000, "maps/createart/sanfran_b_fog_hdr" },
{ 0x0000, "maps/createart/sanfran_fog" },
{ 0x0000, "maps/createart/sanfran_fog_hdr" },
{ 0x0000, "maps/createart/seoul_art" },
{ 0x0000, "maps/createart/seoul_fog" },
{ 0x0000, "maps/createart/seoul_fog_hdr" },
{ 0x0000, "maps/createfx/betrayal_fx" },
{ 0x0000, "maps/createfx/captured_fx" },
{ 0x0000, "maps/createfx/captured_sound" },
{ 0x0000, "maps/createfx/crash_fx" },
{ 0x0000, "maps/createfx/credits_s1_fx" },
{ 0x0000, "maps/createfx/detroit_fx" },
{ 0x0000, "maps/createfx/df_baghdad_fx" },
{ 0x0000, "maps/createfx/df_fly_fx" },
{ 0x0000, "maps/createfx/finale_fx" },
{ 0x0000, "maps/createfx/fusion_fx" },
{ 0x0000, "maps/createfx/greece_fx" },
{ 0x0000, "maps/createfx/irons_estate_fx" },
{ 0x0000, "maps/createfx/lab_fx" },
{ 0x0000, "maps/createfx/lagos_fx" },
{ 0x0000, "maps/createfx/mp_comeback_fx" },
{ 0x0000, "maps/createfx/mp_detroit_fx" },
{ 0x0000, "maps/createfx/mp_greenband_fx" },
{ 0x0000, "maps/createfx/mp_instinct_fx" },
{ 0x0000, "maps/createfx/mp_lab2_fx" },
{ 0x0000, "maps/createfx/mp_laser2_fx" },
{ 0x0000, "maps/createfx/mp_levity_fx" },
{ 0x0000, "maps/createfx/mp_prison_fx" },
{ 0x0000, "maps/createfx/mp_prison_z_fx" },
{ 0x0000, "maps/createfx/mp_recovery_fx" },
{ 0x0000, "maps/createfx/mp_refraction_fx" },
{ 0x0000, "maps/createfx/mp_solar_fx" },
{ 0x0000, "maps/createfx/mp_terrace_fx" },
{ 0x0000, "maps/createfx/mp_venus_fx" },
{ 0x0000, "maps/createfx/mp_vlobby_room_fx" },
{ 0x0000, "maps/createfx/recovery_fx" },
{ 0x0000, "maps/createfx/sanfran_b_fx" },
{ 0x0000, "maps/createfx/sanfran_fx" },
{ 0x0000, "maps/createfx/seoul_fx" },
{ 0x0000, "maps/mp/_adrenaline" },
{ 0x0000, "maps/mp/_aerial_pathnodes" },
{ 0x0000, "maps/mp/_animatedmodels" },
{ 0x0000, "maps/mp/_areas" },
{ 0x0000, "maps/mp/_art" },
{ 0x0000, "maps/mp/_audio" },
{ 0x0000, "maps/mp/_awards" },
{ 0x0000, "maps/mp/_braggingrights" },
{ 0x0000, "maps/mp/_compass" },
{ 0x0000, "maps/mp/_createfx" },
{ 0x0000, "maps/mp/_crib" },
{ 0x0000, "maps/mp/_destructables" },
{ 0x0000, "maps/mp/_dynamic_events" },
{ 0x0000, "maps/mp/_empgrenade" },
{ 0x0000, "maps/mp/_entityheadicons" },
{ 0x0000, "maps/mp/_events" },
{ 0x0000, "maps/mp/_exo_battery" },
{ 0x0000, "maps/mp/_exo_cloak" },
{ 0x0000, "maps/mp/_exo_hover" },
{ 0x0000, "maps/mp/_exo_mute" },
{ 0x0000, "maps/mp/_exo_ping" },
{ 0x0000, "maps/mp/_exo_repulsor" },
{ 0x0000, "maps/mp/_exo_shield" },
{ 0x0000, "maps/mp/_exo_suit" },
{ 0x0000, "maps/mp/_exocrossbow" },
{ 0x0000, "maps/mp/_exoknife" },
{ 0x0000, "maps/mp/_explosive_drone" },
{ 0x0000, "maps/mp/_explosive_gel" },
{ 0x0000, "maps/mp/_extrahealth" },
{ 0x0000, "maps/mp/_fastheal" },
{ 0x0000, "maps/mp/_flashgrenades" },
{ 0x0000, "maps/mp/_fx" },
{ 0x0000, "maps/mp/_global_fx" },
{ 0x0000, "maps/mp/_global_fx_code" },
{ 0x0000, "maps/mp/_lasersight" },
{ 0x0000, "maps/mp/_load" },
{ 0x0000, "maps/mp/_lsrmissileguidance" },
{ 0x0000, "maps/mp/_matchdata" },
{ 0x0000, "maps/mp/_menus" },
{ 0x0000, "maps/mp/_microdronelauncher" },
{ 0x0000, "maps/mp/_movers" },
{ 0x0000, "maps/mp/_mp_lights" },
{ 0x0000, "maps/mp/_mutebomb" },
{ 0x0000, "maps/mp/_na45" },
{ 0x0000, "maps/mp/_opticsthermal" },
{ 0x0000, "maps/mp/_reinforcements" },
{ 0x0000, "maps/mp/_riotshield" },
{ 0x0000, "maps/mp/_scoreboard" },
{ 0x0000, "maps/mp/_shutter" },
{ 0x0000, "maps/mp/_snd_common_mp" },
{ 0x0000, "maps/mp/_stinger" },
{ 0x0000, "maps/mp/_stingerm7" },
{ 0x0000, "maps/mp/_stock" },
{ 0x0000, "maps/mp/_target_enhancer" },
{ 0x0000, "maps/mp/_teleport" },
{ 0x0000, "maps/mp/_threatdetection" },
{ 0x0000, "maps/mp/_tracking_drone" },
{ 0x0000, "maps/mp/_trackrounds" },
{ 0x0000, "maps/mp/_tridrone" },
{ 0x0000, "maps/mp/_utility" },
{ 0x0000, "maps/mp/_vl_base" },
{ 0x0000, "maps/mp/_vl_camera" },
{ 0x0000, "maps/mp/_vl_firingrange" },
{ 0x0000, "maps/mp/_vl_selfiebooth" },
{ 0x0000, "maps/mp/_water" },
{ 0x0000, "maps/mp/_zipline" },
{ 0x0000, "maps/mp/mp_comeback_fx" },
{ 0x0000, "maps/mp/mp_comeback_precache" },
{ 0x0000, "maps/mp/mp_detroit_fx" },
{ 0x0000, "maps/mp/mp_detroit_precache" },
{ 0x0000, "maps/mp/mp_greenband_fx" },
{ 0x0000, "maps/mp/mp_greenband_precache" },
{ 0x0000, "maps/mp/mp_instinct_fx" },
{ 0x0000, "maps/mp/mp_instinct_precache" },
{ 0x0000, "maps/mp/mp_lab2_fx" },
{ 0x0000, "maps/mp/mp_lab2_precache" },
{ 0x0000, "maps/mp/mp_laser2_fx" },
{ 0x0000, "maps/mp/mp_laser2_precache" },
{ 0x0000, "maps/mp/mp_levity_fx" },
{ 0x0000, "maps/mp/mp_levity_precache" },
{ 0x0000, "maps/mp/mp_prison_fx" },
{ 0x0000, "maps/mp/mp_prison_precache" },
{ 0x0000, "maps/mp/mp_prison_z_fx" },
{ 0x0000, "maps/mp/mp_prison_z_precache" },
{ 0x0000, "maps/mp/mp_recovery_fx" },
{ 0x0000, "maps/mp/mp_recovery_precache" },
{ 0x0000, "maps/mp/mp_refraction_fx" },
{ 0x0000, "maps/mp/mp_refraction_precache" },
{ 0x0000, "maps/mp/mp_solar_fx" },
{ 0x0000, "maps/mp/mp_solar_precache" },
{ 0x0000, "maps/mp/mp_terrace_fx" },
{ 0x0000, "maps/mp/mp_terrace_precache" },
{ 0x0000, "maps/mp/mp_venus_fx" },
{ 0x0000, "maps/mp/mp_venus_precache" },
{ 0x0000, "maps/mp/mp_vlobby_room_fx" },
{ 0x0000, "maps/mp/mp_vlobby_room_precache" },
{ 0x0000, "maps/mp/gametypes/_battlebuddy" },
{ 0x0000, "maps/mp/gametypes/_battlechatter_mp" },
{ 0x0000, "maps/mp/gametypes/_class" },
{ 0x0000, "maps/mp/gametypes/_clientids" },
{ 0x0000, "maps/mp/gametypes/_damage" },
{ 0x0000, "maps/mp/gametypes/_damagefeedback" },
{ 0x0000, "maps/mp/gametypes/_deathicons" },
{ 0x0000, "maps/mp/gametypes/_dev" },
{ 0x0000, "maps/mp/gametypes/_equipment" },
{ 0x0000, "maps/mp/gametypes/_friendicons" },
{ 0x0000, "maps/mp/gametypes/_gamelogic" },
{ 0x0000, "maps/mp/gametypes/_gameobjects" },
{ 0x0000, "maps/mp/gametypes/_gamescore" },
{ 0x0000, "maps/mp/gametypes/_globalentities" },
{ 0x0000, "maps/mp/gametypes/_globallogic" },
{ 0x0000, "maps/mp/gametypes/_hardpoints" },
{ 0x0000, "maps/mp/gametypes/_healthoverlay" },
{ 0x0000, "maps/mp/gametypes/_high_jump_mp" },
{ 0x0000, "maps/mp/gametypes/_horde_armory" },
{ 0x0000, "maps/mp/gametypes/_horde_crates" },
{ 0x0000, "maps/mp/gametypes/_horde_dialog" },
{ 0x0000, "maps/mp/gametypes/_horde_drones" },
{ 0x0000, "maps/mp/gametypes/_horde_laststand" },
{ 0x0000, "maps/mp/gametypes/_horde_sentry" },
{ 0x0000, "maps/mp/gametypes/_horde_smart_grenade" },
{ 0x0000, "maps/mp/gametypes/_horde_util" },
{ 0x0000, "maps/mp/gametypes/_horde_zombies" },
{ 0x0000, "maps/mp/gametypes/_hostmigration" },
{ 0x0000, "maps/mp/gametypes/_hud" },
{ 0x0000, "maps/mp/gametypes/_hud_message" },
{ 0x0000, "maps/mp/gametypes/_hud_util" },
{ 0x0000, "maps/mp/gametypes/_killcam" },
{ 0x0000, "maps/mp/gametypes/_menus" },
{ 0x0000, "maps/mp/gametypes/_missions" },
{ 0x0000, "maps/mp/gametypes/_music_and_dialog" },
{ 0x0000, "maps/mp/gametypes/_objpoints" },
{ 0x0000, "maps/mp/gametypes/_orbital" },
{ 0x0000, "maps/mp/gametypes/_persistence" },
{ 0x0000, "maps/mp/gametypes/_player_boost_jump_mp" },
{ 0x0000, "maps/mp/gametypes/_playercards" },
{ 0x0000, "maps/mp/gametypes/_playerlogic" },
{ 0x0000, "maps/mp/gametypes/_portable_radar" },
{ 0x0000, "maps/mp/gametypes/_quickmessages" },
{ 0x0000, "maps/mp/gametypes/_rank" },
{ 0x0000, "maps/mp/gametypes/_scrambler" },
{ 0x0000, "maps/mp/gametypes/_serversettings" },
{ 0x0000, "maps/mp/gametypes/_shellshock" },
{ 0x0000, "maps/mp/gametypes/_spawnfactor" },
{ 0x0000, "maps/mp/gametypes/_spawnlogic" },
{ 0x0000, "maps/mp/gametypes/_spawnscoring" },
{ 0x0000, "maps/mp/gametypes/_spectating" },
{ 0x0000, "maps/mp/gametypes/_teams" },
{ 0x0000, "maps/mp/gametypes/_tweakables" },
{ 0x0000, "maps/mp/gametypes/_weapons" },
{ 0x0000, "maps/mp/killstreaks/_aerial_utility" },
{ 0x0000, "maps/mp/killstreaks/_agent_killstreak" },
{ 0x0000, "maps/mp/killstreaks/_airdrop" },
{ 0x0000, "maps/mp/killstreaks/_airstrike" },
{ 0x0000, "maps/mp/killstreaks/_assaultdrone_ai" },
{ 0x0000, "maps/mp/killstreaks/_autosentry" },
{ 0x0000, "maps/mp/killstreaks/_coop_util" },
{ 0x0000, "maps/mp/killstreaks/_dog_killstreak" },
{ 0x0000, "maps/mp/killstreaks/_drone_assault" },
{ 0x0000, "maps/mp/killstreaks/_drone_carepackage" },
{ 0x0000, "maps/mp/killstreaks/_drone_common" },
{ 0x0000, "maps/mp/killstreaks/_drone_recon" },
{ 0x0000, "maps/mp/killstreaks/_emp" },
{ 0x0000, "maps/mp/killstreaks/_juggernaut" },
{ 0x0000, "maps/mp/killstreaks/_killstreaks" },
{ 0x0000, "maps/mp/killstreaks/_killstreaks_init" },
{ 0x0000, "maps/mp/killstreaks/_marking_util" },
{ 0x0000, "maps/mp/killstreaks/_missile_strike" },
{ 0x0000, "maps/mp/killstreaks/_nuke" },
{ 0x0000, "maps/mp/killstreaks/_orbital_carepackage" },
{ 0x0000, "maps/mp/killstreaks/_orbital_strike" },
{ 0x0000, "maps/mp/killstreaks/_orbital_util" },
{ 0x0000, "maps/mp/killstreaks/_orbitalsupport" },
{ 0x0000, "maps/mp/killstreaks/_placeable" },
{ 0x0000, "maps/mp/killstreaks/_remoteturret" },
{ 0x0000, "maps/mp/killstreaks/_rippedturret" },
{ 0x0000, "maps/mp/killstreaks/_teamammorefill" },
{ 0x0000, "maps/mp/killstreaks/_uav" },
{ 0x0000, "maps/mp/killstreaks/_warbird" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_comeback" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_detroit" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_instinct" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_laser2" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_prison" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_recovery" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_refraction" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_solar" },
{ 0x0000, "maps/mp/killstreaks/streak_mp_terrace" },
{ 0x0000, "maps/mp/perks/_perkfunctions" },
{ 0x0000, "maps/mp/perks/_perks" },
*/

/*
// after first files codescript

{ 0x0000, "__smangles" },
{ 0x0000, "__smid" },
{ 0x0000, "__smname" },
{ 0x0000, "__smorigin" },
{ 0x0000, "_abortdefendlocation" },
{ 0x0000, "_adddropmarkerinternal" },
{ 0x0000, "_adjustcamerayawpitchrate" },
{ 0x0000, "_advancetogoal" },
{ 0x0000, "_ai_delete" },
{ 0x0000, "_ai_group" },
{ 0x0000, "_ai_health" },
{ 0x0000, "_aliveplayers" },
{ 0x0000, "_allowalternatemelee" },
{ 0x0000, "_allowweaponpickup" },
{ 0x0000, "_ams" },
{ 0x0000, "_animactive" },
{ 0x0000, "_anime" },
{ 0x0000, "_animmode" },
{ 0x0000, "_animname" },
{ 0x0000, "_anims" },
{ 0x0000, "_anims_drone" },
{ 0x0000, "_anims_player" },
{ 0x0000, "_anims_proxy" },
{ 0x0000, "_array_wait" },
{ 0x0000, "_assignnewvehicleturretuser" },
{ 0x0000, "_attachfanclip" },
{ 0x0000, "_audio" },
{ 0x0000, "_autosave_game_now" },
{ 0x0000, "_autosave_game_now_nochecks" },
{ 0x0000, "_autosave_game_now_notrestart" },
{ 0x0000, "_autosave_stealthcheck" },
{ 0x0000, "_beginlocationselection" },
{ 0x0000, "_bootup_static" },
{ 0x0000, "_cangiveability" },
{ 0x0000, "_caralarmfx" },
{ 0x0000, "_caralarmstop" },
{ 0x0000, "_cleanupshootinglocationondeath" },
{ 0x0000, "_clearabilities" },
{ 0x0000, "_clearalltextafterhudelem" },
{ 0x0000, "_clearcharacterdialogondeath" },
{ 0x0000, "_clearcharacterdialogonnotify" },
{ 0x0000, "_clearentitytarget" },
{ 0x0000, "_clearperks" },
{ 0x0000, "_clearradiodialogondeath" },
{ 0x0000, "_clearworlddialogonnotify" },
{ 0x0000, "_cloak_enemy_array" },
{ 0x0000, "_cloak_enemy_state" },
{ 0x0000, "_cloak_toggle_internal" },
{ 0x0000, "_cloaked_stealth_settings" },
{ 0x0000, "_closingdistancecheck" },
{ 0x0000, "_color" },
{ 0x0000, "_colors_go_line" },
{ 0x0000, "_createfx" },
{ 0x0000, "_createhudline" },
{ 0x0000, "_custom_anim" },
{ 0x0000, "_custom_anim_loop" },
{ 0x0000, "_custom_anim_thread" },
{ 0x0000, "_debug_vector_to_string" },
{ 0x0000, "_defendlocation" },
{ 0x0000, "_delaygrenadethrow" },
{ 0x0000, "_delete" },
{ 0x0000, "_destroyprojectileafterdelay" },
{ 0x0000, "_destructible_preanims" },
{ 0x0000, "_destructible_preanimtree" },
{ 0x0000, "_detachall" },
{ 0x0000, "_determineallynodescore" },
{ 0x0000, "_determineshotgunnodescore" },
{ 0x0000, "_dialogtablelookup" },
{ 0x0000, "_disableoffhandweapons" },
{ 0x0000, "_disableusability" },
{ 0x0000, "_disableweapon" },
{ 0x0000, "_disableweaponswitch" },
{ 0x0000, "_displayhelpertext" },
{ 0x0000, "_displayrechargehelpertext" },
{ 0x0000, "_dmg" },
{ 0x0000, "_do_a_lil_damage_and_heal" },
{ 0x0000, "_drawdebug" },
{ 0x0000, "_earthquake" },
{ 0x0000, "_effect" },
{ 0x0000, "_effect_keys" },
{ 0x0000, "_enabledetonate" },
{ 0x0000, "_enableexplosivedeath" },
{ 0x0000, "_enableoffhandweapons" },
{ 0x0000, "_enableusability" },
{ 0x0000, "_enableweapon" },
{ 0x0000, "_enableweaponswitch" },
{ 0x0000, "_ensure_player_is_decloaked" },
{ 0x0000, "_evaluatebuddycovernodes" },
{ 0x0000, "_evaluatenodeattackradius" },
{ 0x0000, "_evaluatenodeinplayerfov" },
{ 0x0000, "_evaluatenodeiscover" },
{ 0x0000, "_evaluatenodeisexposed" },
{ 0x0000, "_evaluatenodeknownenemyinradius" },
{ 0x0000, "_evaluatenodelostoplayer" },
{ 0x0000, "_evaluatenodeothershotgunnersbest" },
{ 0x0000, "_evaluatenodeplayerinradius" },
{ 0x0000, "_evaluatenodeplayervisibility" },
{ 0x0000, "_evaluatenoderangetoplayer" },
{ 0x0000, "_evaluateshotgunnercovernodes" },
{ 0x0000, "_exit" },
{ 0x0000, "_exit_menu" },
{ 0x0000, "_extended_patrol_idle_animation_list_fu"... },
{ 0x0000, "_extra_autosave_checks" },
{ 0x0000, "_facility" },
{ 0x0000, "_fastopen" },
{ 0x0000, "_findfleelocation" },
{ 0x0000, "_findnewvehicleturretuser" },
{ 0x0000, "_fire" },
{ 0x0000, "_first_frame_anim" },
{ 0x0000, "_flag_wait_trigger" },
{ 0x0000, "_force_kill" },
{ 0x0000, "_freevehicle" },
{ 0x0000, "_frozen_controls" },
{ 0x0000, "_fx" },
{ 0x0000, "_get_dummy" },
{ 0x0000, "_get_if_defined_or_default" },
{ 0x0000, "_getindex" },
{ 0x0000, "_getmodulekillstreakweapon" },
{ 0x0000, "_getpaintoutline" },
{ 0x0000, "_getplayerscore" },
{ 0x0000, "_getradarstrength" },
{ 0x0000, "_getrandomorginfrontofplayer" },
{ 0x0000, "_getscrambletypeidforstring" },
{ 0x0000, "_getteampaintoutline" },
{ 0x0000, "_getteamscore" },
{ 0x0000, "_getvehiclespawnerarray" },
{ 0x0000, "_getvehiclespawnerarray_by_spawngroup" },
{ 0x0000, "_giveweapon" },
{ 0x0000, "_glass_physics_wakeup" },
{ 0x0000, "_glass_physics_wakeup_update" },
{ 0x0000, "_global_fx_ents" },
{ 0x0000, "_goalblockedbyai" },
{ 0x0000, "_goalblockedbyplayer" },
{ 0x0000, "_gopath" },
{ 0x0000, "_group" },
{ 0x0000, "_handle_triggers_on" },
{ 0x0000, "_handlebreachgrenade" },
{ 0x0000, "_hasability" },
{ 0x0000, "_hasperk" },
{ 0x0000, "_hint_stick_get_config_suffix" },
{ 0x0000, "_hint_stick_update_breakfunc" },
{ 0x0000, "_hint_stick_update_string" },
{ 0x0000, "_ignore_settings_old" },
{ 0x0000, "_initalliedaialleycombatbehavior" },
{ 0x0000, "_initsafehouseexitkvabehavior" },
{ 0x0000, "_insertintoglobalusablelist" },
{ 0x0000, "_interactive" },
{ 0x0000, "_investigate_last_known_position_with_e"... },
{ 0x0000, "_investigate_last_known_position_wrappe"... },
{ 0x0000, "_is_godmode" },
{ 0x0000, "_isairplane" },
{ 0x0000, "_ishelicopter" },
{ 0x0000, "_kill" },
{ 0x0000, "_kill_fx" },
{ 0x0000, "_lastanimtime" },
{ 0x0000, "_lastwave" },
{ 0x0000, "_lc" },
{ 0x0000, "_lc_persists" },
{ 0x0000, "_leaderdialogwait" },
{ 0x0000, "_light" },
{ 0x0000, "_linkto" },
{ 0x0000, "_listen_drone_input" },
{ 0x0000, "_listen_for_hold_to_exit" },
{ 0x0000, "_listen_for_hold_to_exit_set_flags" },
{ 0x0000, "_loadstarted" },
{ 0x0000, "_make_overlay" },
{ 0x0000, "_manage_timer" },
{ 0x0000, "_mark_newlyspawned" },
{ 0x0000, "_max_script_health" },
{ 0x0000, "_mb" },
{ 0x0000, "_mech_globals" },
{ 0x0000, "_mech_hunt_baghdad" },
{ 0x0000, "_mech_node" },
{ 0x0000, "_mech_occupied" },
{ 0x0000, "_mgoff" },
{ 0x0000, "_mgon" },
{ 0x0000, "_missile_strike_setting" },
{ 0x0000, "_missilemissedtargetcheck" },
{ 0x0000, "_missing_fx" },
{ 0x0000, "_monitor_controls" },
{ 0x0000, "_monitor_damage" },
{ 0x0000, "_monitor_health" },
{ 0x0000, "_monitor_regen" },
{ 0x0000, "_monitor_static" },
{ 0x0000, "_monitor_threat_count" },
{ 0x0000, "_monitor_touch" },
{ 0x0000, "_monitor_volume_array" },
{ 0x0000, "_mount_snowmobile" },
{ 0x0000, "_newhudelem" },
{ 0x0000, "_nextcoverprint" },
{ 0x0000, "_nextmission" },
{ 0x0000, "_normalbehavior" },
{ 0x0000, "_notetrackfx" },
{ 0x0000, "_obituary" },
{ 0x0000, "_objective_delete" },
{ 0x0000, "_offset_position_from_tag" },
{ 0x0000, "_old_visionset" },
{ 0x0000, "_orbital_care_pod" },
{ 0x0000, "_orbital_strike_setting" },
{ 0x0000, "_patrol_endon_spotted_flag" },
{ 0x0000, "_pdrone_player_exit_return_control" },
{ 0x0000, "_pdrone_player_proxy" },
{ 0x0000, "_pdrone_player_proxy_clear" },
{ 0x0000, "_pdrone_player_proxy_delicate_flower" },
{ 0x0000, "_pdrone_stop_use_anim" },
{ 0x0000, "_pipe_fx_time" },
{ 0x0000, "_pipe_methods" },
{ 0x0000, "_pipes" },
{ 0x0000, "_play_view_model_cloak_toggle_anim" },
{ 0x0000, "_playerallow" },
{ 0x0000, "_playercleanupscrambleevents" },
{ 0x0000, "_playergetnextevent" },
{ 0x0000, "_playergetscrambleevent" },
{ 0x0000, "_playergetuniquescrambleid" },
{ 0x0000, "_playermonitorscrambleevents" },
{ 0x0000, "_playlocalsound" },
{ 0x0000, "_popopen" },
{ 0x0000, "_precache" },
{ 0x0000, "_pursueenemy" },
{ 0x0000, "_radio_queue" },
{ 0x0000, "_radiusdamage" },
{ 0x0000, "_randommissilemovement" },
{ 0x0000, "_reactionanimation" },
{ 0x0000, "_reduce_hud_target_count_on_death" },
{ 0x0000, "_remove_drone_control" },
{ 0x0000, "_remove_hud" },
{ 0x0000, "_remove_hud_on_death" },
{ 0x0000, "_remove_hudoutline_on_enemies" },
{ 0x0000, "_remove_overlay_static" },
{ 0x0000, "_remove_shield" },
{ 0x0000, "_reset_dvars" },
{ 0x0000, "_restorepreviousnameplatematerial" },
{ 0x0000, "_returnanimorigin" },
{ 0x0000, "_rotateprop" },
{ 0x0000, "_rotateyaw" },
{ 0x0000, "_s2walk" },
{ 0x0000, "_save_dvars" },
{ 0x0000, "_script_exploders" },
{ 0x0000, "_scripted_spawn" },
{ 0x0000, "_set_dvars" },
{ 0x0000, "_set_hudoutline_on_enemies" },
{ 0x0000, "_set_overlay_static_alpha" },
{ 0x0000, "_setability" },
{ 0x0000, "_setactionslot" },
{ 0x0000, "_setentitytarget" },
{ 0x0000, "_sethighestmissionifnotcheating" },
{ 0x0000, "_sethudoutline" },
{ 0x0000, "_sethudoutline_on_spawn" },
{ 0x0000, "_setlightintensity" },
{ 0x0000, "_setmissiondiffstringifnotcheating" },
{ 0x0000, "_setnameplatematerial" },
{ 0x0000, "_setperk" },
{ 0x0000, "_setplayerscore" },
{ 0x0000, "_setsaveddvar" },
{ 0x0000, "_setswitchnode" },
{ 0x0000, "_setteamscore" },
{ 0x0000, "_settext" },
{ 0x0000, "_setup_hud" },
{ 0x0000, "_setup_overlay_static" },
{ 0x0000, "_setupdooranimstyle" },
{ 0x0000, "_setvehgoalpos" },
{ 0x0000, "_setvehgoalpos_wrap" },
{ 0x0000, "_shotgunneradvance" },
{ 0x0000, "_shotgunnerambience" },
{ 0x0000, "_shotgunnerdamagefunction" },
{ 0x0000, "_shotgunnerdeath" },
{ 0x0000, "_show_contols" },
{ 0x0000, "_slomo_breach_blowback_guy" },
{ 0x0000, "_slomo_breach_c4_hostage" },
{ 0x0000, "_slomo_breach_chair_guy_animated" },
{ 0x0000, "_slomo_breach_chair_guy_normal" },
{ 0x0000, "_slomo_breach_desk_guy" },
{ 0x0000, "_slomo_breach_executed_guy" },
{ 0x0000, "_slomo_breach_executed_guy_pushed_to_fl"... },
{ 0x0000, "_slomo_breach_executioner_knife" },
{ 0x0000, "_slomo_breach_executioner_pistol" },
{ 0x0000, "_slomo_breach_fightback_guy" },
{ 0x0000, "_slomo_breach_hostage_react" },
{ 0x0000, "_slomo_breach_knife_charger" },
{ 0x0000, "_slomo_breach_knife_hostage_death" },
{ 0x0000, "_slomo_breach_pistol_guy" },
{ 0x0000, "_slowmo_breach_funcs" },
{ 0x0000, "_slowmo_functions" },
{ 0x0000, "_slowopen" },
{ 0x0000, "_snd" },
{ 0x0000, "_snd_update_soundcontextoverride" },
{ 0x0000, "_sonicaoeanim" },
{ 0x0000, "_sonicaoenotready" },
{ 0x0000, "_sortbyscore" },
{ 0x0000, "_sound" },
{ 0x0000, "_spawner_mg42_think" },
{ 0x0000, "_spawner_stealth_default" },
{ 0x0000, "_spawntargetnamegotogoal" },
{ 0x0000, "_squaddoorbreach" },
{ 0x0000, "_startdooropen" },
{ 0x0000, "_state_init" },
{ 0x0000, "_stealth" },
{ 0x0000, "_stealth_move_detection_cap" },
{ 0x0000, "_stop_mech_hunt_baghdad" },
{ 0x0000, "_stunassaultdrones" },
{ 0x0000, "_stuncivilians" },
{ 0x0000, "_stunenemies" },
{ 0x0000, "_suicide" },
{ 0x0000, "_tag_entity" },
{ 0x0000, "_takeweaponsexcept" },
{ 0x0000, "_teleportleashbehavior" },
{ 0x0000, "_tff_sync_trigger_think" },
{ 0x0000, "_tff_sync_triggers" },
{ 0x0000, "_threatdetection" },
{ 0x0000, "_timeout" },
{ 0x0000, "_timeout_pause_on_death_and_prematch" },
{ 0x0000, "_trigger_handle_triggering" },
{ 0x0000, "_unlink" },
{ 0x0000, "_unsetability" },
{ 0x0000, "_unsetperk" },
{ 0x0000, "_updatebuddycovernodes" },
{ 0x0000, "_updateenemygroupdirection" },
{ 0x0000, "_updateenemyusable" },
{ 0x0000, "_updatepainamount" },
{ 0x0000, "_updateshotgunnercovernodes" },
{ 0x0000, "_updateteamusable" },
{ 0x0000, "_useperkenabled" },
{ 0x0000, "_validateattacker" },
{ 0x0000, "_vehicle_badplace" },
{ 0x0000, "_vehicle_effect" },
{ 0x0000, "_vehicle_effect_custom_param" },
{ 0x0000, "_vehicle_is_crashing" },
{ 0x0000, "_vehicle_landvehicle" },
{ 0x0000, "_vehicle_paths" },
{ 0x0000, "_vehicle_resume_named" },
{ 0x0000, "_vehicle_spawn" },
{ 0x0000, "_vehicle_stop_named" },
{ 0x0000, "_vehicle_unload" },
{ 0x0000, "_vehicleturretreenable" },
{ 0x0000, "_vmodel_anims" },
{ 0x0000, "_vmodel_enter" },
{ 0x0000, "_vmodel_exit" },
{ 0x0000, "_vmodel_sway" },
{ 0x0000, "_vol" },
{ 0x0000, "_wait" },
{ 0x0000, "_waittillgoalornewgoal" },
{ 0x0000, "_waittillmatch" },
{ 0x0000, "_waittillmatch_notify" },
{ 0x0000, "_walk" },
{ 0x0000, "_wavedelay" },
{ 0x0000, "_waveplayerspawnindex" },
{ 0x0000, "a10_30mm_fire" },
{ 0x0000, "a10_fire_missiles" },
{ 0x0000, "a10_gun_dives" },
{ 0x0000, "a10_missile_dives" },
{ 0x0000, "a10_missile_set_target" },
{ 0x0000, "a10_precache" },
{ 0x0000, "a10_spawn_funcs" },
{ 0x0000, "a10_wait_fire_missile" },
{ 0x0000, "a10_wait_start_firing" },
{ 0x0000, "a10_wait_stop_firing" },
{ 0x0000, "aa_add_event" },
{ 0x0000, "aa_add_event_float" },
{ 0x0000, "aa_ai_functions" },
{ 0x0000, "aa_door_functions" },
{ 0x0000, "aa_explosion" },
{ 0x0000, "aa_init_stats" },
{ 0x0000, "aa_player_ads_tracking" },
{ 0x0000, "aa_player_attacks_enemy_with_ads" },
{ 0x0000, "aa_player_health_tracking" },
{ 0x0000, "aa_print_vals" },
{ 0x0000, "aa_should_start_fresh" },
{ 0x0000, "aa_spawning_functions" },
{ 0x0000, "aa_time_tracking" },
{ 0x0000, "aa_update_flags" },
{ 0x0000, "abandon_mission_warning_hint" },
{ 0x0000, "abanglecutoff" },
{ 0x0000, "abilities" },
{ 0x0000, "abilitycansetfuncs" },
{ 0x0000, "abilitychosen" },
{ 0x0000, "abilitysetfuncs" },
{ 0x0000, "abilityunsetfuncs" },
{ 0x0000, "abort" },
{ 0x0000, "abort_count" },
{ 0x0000, "abort_drones" },
{ 0x0000, "abort_wait_any_func_array" },
{ 0x0000, "abortapproachifthreatened" },
{ 0x0000, "abortlevel" },
{ 0x0000, "abortreloadwhencanshoot" },
{ 0x0000, "about_to_stop" },
{ 0x0000, "about_to_unload" },
{ 0x0000, "abouttobebreached" },
{ 0x0000, "absangleclamp180" },
{ 0x0000, "absyawtoangles" },
{ 0x0000, "absyawtoenemy" },
{ 0x0000, "absyawtoenemy2d" },
{ 0x0000, "absyawtoorigin" },
{ 0x0000, "absz" },
{ 0x0000, "abyss_player_kill" },
{ 0x0000, "ac_duct" },
{ 0x0000, "ac_duct_01" },
{ 0x0000, "ac_duct_02" },
{ 0x0000, "ac130" },
{ 0x0000, "ac130_flood_respawn" },
{ 0x0000, "ac130gunner" },
{ 0x0000, "ac130player" },
{ 0x0000, "accaracy_mod" },
{ 0x0000, "accel" },
{ 0x0000, "accel_watcher" },
{ 0x0000, "accelerating" },
{ 0x0000, "acceltime" },
{ 0x0000, "accessallmarkers" },
{ 0x0000, "accumulated_restore" },
{ 0x0000, "accumulateplayerpingdata" },
{ 0x0000, "accuracy_fake_function" },
{ 0x0000, "accuracygrowthmultiplier" },
{ 0x0000, "accuracystationarymod" },
{ 0x0000, "achieve_downed_kills" },
{ 0x0000, "achieve_slowmo_breach_kills" },
{ 0x0000, "achievement" },
{ 0x0000, "achievement_attacker" },
{ 0x0000, "achievementsniperdronetriplekill" },
{ 0x0000, "acquire_target" },
{ 0x0000, "acquired_animation" },
{ 0x0000, "acquiring_dogfight_target" },
{ 0x0000, "acquiring_lock_target" },
{ 0x0000, "action_back" },
{ 0x0000, "action_func" },
{ 0x0000, "action_gears" },
{ 0x0000, "action_killstreak" },
{ 0x0000, "action_leaderboards" },
{ 0x0000, "action_slot_num" },
{ 0x0000, "action_slot_whistle" },
{ 0x0000, "action_thread" },
{ 0x0000, "action_weapons_primary" },
{ 0x0000, "action_weapons_secondary" },
{ 0x0000, "actionnotify" },
{ 0x0000, "actionnotifymessage" },
{ 0x0000, "actionslotenabled" },
{ 0x0000, "actionslots" },
{ 0x0000, "activate_betrayal_exo_abilities" },
{ 0x0000, "activate_clientside_exploder" },
{ 0x0000, "activate_color_code_internal" },
{ 0x0000, "activate_destructibles_in_volume" },
{ 0x0000, "activate_exo_ping" },
{ 0x0000, "activate_exploder" },
{ 0x0000, "activate_exploders_in_volume" },
{ 0x0000, "activate_guy" },
{ 0x0000, "activate_heater" },
{ 0x0000, "activate_individual_exploder" },
{ 0x0000, "activate_individual_exploder_proc" },
{ 0x0000, "activate_interactives_in_volume" },
{ 0x0000, "activate_mute_volume" },
{ 0x0000, "activate_security_drone" },
{ 0x0000, "activate_splashes" },
{ 0x0000, "activate_takedown_world_prompt_on_enemy" },
{ 0x0000, "activate_takedown_world_prompt_on_truck"... },
{ 0x0000, "activate_targets" },
{ 0x0000, "activate_trigger" },
{ 0x0000, "activate_trigger_process" },
{ 0x0000, "activate_trigger_when_player_jumps" },
{ 0x0000, "activate_trigger_with_noteworthy" },
{ 0x0000, "activate_trigger_with_targetname" },
{ 0x0000, "activateagent" },
{ 0x0000, "activategroupedtridrones" },
{ 0x0000, "activateplayerhud" },
{ 0x0000, "activateratio" },
{ 0x0000, "activatethermal" },
{ 0x0000, "activation_cost" },
{ 0x0000, "active_boats" },
{ 0x0000, "active_button" },
{ 0x0000, "active_civilians" },
{ 0x0000, "active_cloaking_disable" },
{ 0x0000, "active_cloaking_enable" },
{ 0x0000, "active_drones" },
{ 0x0000, "active_events" },
{ 0x0000, "active_events_axis" },
{ 0x0000, "active_ffa_players" },
{ 0x0000, "active_objective" },
{ 0x0000, "active_vo_lockouts" },
{ 0x0000, "active_wait_spread" },
{ 0x0000, "activecounteruavs" },
{ 0x0000, "activefriendlyspawn" },
{ 0x0000, "activegrenadetimer" },
{ 0x0000, "activehordedefendlocs" },
{ 0x0000, "activenodes" },
{ 0x0000, "activeplayers" },
{ 0x0000, "activestyle" },
{ 0x0000, "activetarget" },
{ 0x0000, "activeuavs" },
{ 0x0000, "activeweapon" },
{ 0x0000, "actor_alarm_guard" },
{ 0x0000, "actor_anims" },
{ 0x0000, "actor_playscene_walker_stepover_cormack" },
{ 0x0000, "actor_playscene_walker_stepover_jackson" },
{ 0x0000, "actor_playscene_walker_stepover_will" },
{ 0x0000, "actual_spawn" },
{ 0x0000, "ad_offset_position_from_tag" },
{ 0x0000, "add_abort" },
{ 0x0000, "add_agents_to_game" },
{ 0x0000, "add_ai_to_colors" },
{ 0x0000, "add_and_select_entity" },
{ 0x0000, "add_animation" },
{ 0x0000, "add_animsound" },
{ 0x0000, "add_array_to_destructible" },
{ 0x0000, "add_avatar" },
{ 0x0000, "add_basement_enemy_flashlight" },
{ 0x0000, "add_bcs_location_mapping" },
{ 0x0000, "add_breach_func" },
{ 0x0000, "add_burke_flashlight" },
{ 0x0000, "add_button" },
{ 0x0000, "add_c4_glow" },
{ 0x0000, "add_call" },
{ 0x0000, "add_capture_enemy_momentum" },
{ 0x0000, "add_capture_friendly_momentum" },
{ 0x0000, "add_cellphone_notetracks" },
{ 0x0000, "add_cheap_flashlight" },
{ 0x0000, "add_cleanup_ent" },
{ 0x0000, "add_collision_offsets_to_path_ent" },
{ 0x0000, "add_collision_to_path" },
{ 0x0000, "add_collision_to_path_node" },
{ 0x0000, "add_contrail" },
{ 0x0000, "add_control_based_hint_strings" },
{ 0x0000, "add_coop_scene_models" },
{ 0x0000, "add_cover_node" },
{ 0x0000, "add_damage_function" },
{ 0x0000, "add_damage_fx" },
{ 0x0000, "add_damage_owner_recorder" },
{ 0x0000, "add_damagefeedback" },
{ 0x0000, "add_dds_category" },
{ 0x0000, "add_dds_category_axis" },
{ 0x0000, "add_dds_category_group" },
{ 0x0000, "add_dds_category_group_axis" },
{ 0x0000, "add_dds_countryid" },
{ 0x0000, "add_debug_element" },
{ 0x0000, "add_destructible_fx" },
{ 0x0000, "add_destructible_to_frame_queue" },
{ 0x0000, "add_destructible_type_function" },
{ 0x0000, "add_destructible_type_transient" },
{ 0x0000, "add_dialogue_line" },
{ 0x0000, "add_doc_civ_walla" },
{ 0x0000, "add_drone_to_squad" },
{ 0x0000, "add_earthquake" },
{ 0x0000, "add_endon" },
{ 0x0000, "add_enemy_flashlight" },
{ 0x0000, "add_extra_autosave_check" },
{ 0x0000, "add_fractional_data_point" },
{ 0x0000, "add_func" },
{ 0x0000, "add_fx" },
{ 0x0000, "add_global_spawn_function" },
{ 0x0000, "add_greece_starts" },
{ 0x0000, "add_hint_background" },
{ 0x0000, "add_hint_string" },
{ 0x0000, "add_hovertank_turret" },
{ 0x0000, "add_hud_line" },
{ 0x0000, "add_hudelm_position_internal" },
{ 0x0000, "add_humanoid_agent" },
{ 0x0000, "add_idle_control" },
{ 0x0000, "add_jav_glow" },
{ 0x0000, "add_kb_button" },
{ 0x0000, "add_key" },
{ 0x0000, "add_key_to_destructible" },
{ 0x0000, "add_keypairs_to_destructible" },
{ 0x0000, "add_kill_enemy_minion_momentum" },
{ 0x0000, "add_kill_enemy_momentum" },
{ 0x0000, "add_kill_friendly_minion_momentum" },
{ 0x0000, "add_kill_friendly_momentum" },
{ 0x0000, "add_lock_target" },
{ 0x0000, "add_mag_move_notetracks" },
{ 0x0000, "add_momentum" },
{ 0x0000, "add_moving_obstacle" },
{ 0x0000, "add_moving_vol_to_node" },
{ 0x0000, "add_name" },
{ 0x0000, "add_no_game_starts" },
{ 0x0000, "add_node_to_global_arrays" },
{ 0x0000, "add_noself_call" },
{ 0x0000, "add_note_track_data" },
{ 0x0000, "add_notetrack_and_get_index" },
{ 0x0000, "add_notetrack_array" },
{ 0x0000, "add_object_to_tactics_system" },
{ 0x0000, "add_objective" },
{ 0x0000, "add_option_to_selected_entities" },
{ 0x0000, "add_party_member_class_change" },
{ 0x0000, "add_passenger_to_player_pitbull" },
{ 0x0000, "add_path_node" },
{ 0x0000, "add_path_weights" },
{ 0x0000, "add_phrase_to_history" },
{ 0x0000, "add_player_flashlight" },
{ 0x0000, "add_proccess_trigger" },
{ 0x0000, "add_random_killspawner_to_spawngroup" },
{ 0x0000, "add_reactive_fx" },
{ 0x0000, "add_replace_after_load_done" },
{ 0x0000, "add_reverb" },
{ 0x0000, "add_rpg_to_tactics_system" },
{ 0x0000, "add_scene_model" },
{ 0x0000, "add_script_car" },
{ 0x0000, "add_shake_and_rumble_notetracks" },
{ 0x0000, "add_shake_and_rumble_notetracks_for_gra"... },
{ 0x0000, "add_shake_and_rumble_notetracks_for_jum"... },
{ 0x0000, "add_sit_load_ak_notetracks" },
{ 0x0000, "add_slowmo_breach_custom_function" },
{ 0x0000, "add_slowmo_breacher" },
{ 0x0000, "add_smoking_notetracks" },
{ 0x0000, "add_spawn_behavior" },
{ 0x0000, "add_spawn_function" },
{ 0x0000, "add_spawn_function_to_noteworthy" },
{ 0x0000, "add_spawn_function_to_targetname" },
{ 0x0000, "add_spawner_to_global_arrays" },
{ 0x0000, "add_start" },
{ 0x0000, "add_start_assert" },
{ 0x0000, "add_start_construct" },
{ 0x0000, "add_struct_to_global_array" },
{ 0x0000, "add_swarm_repulsor_for_ally" },
{ 0x0000, "add_target_on_dot" },
{ 0x0000, "add_target_on_los" },
{ 0x0000, "add_target_pivot" },
{ 0x0000, "add_to_animsound" },
{ 0x0000, "add_to_array" },
{ 0x0000, "add_to_bot_damage_targets" },
{ 0x0000, "add_to_bot_use_targets" },
{ 0x0000, "add_to_destroyed_count" },
{ 0x0000, "add_to_dialogue" },
{ 0x0000, "add_to_dialogue_generic" },
{ 0x0000, "add_to_flock" },
{ 0x0000, "add_to_group_civilian" },
{ 0x0000, "add_to_group_enemy" },
{ 0x0000, "add_to_javelin_targeting" },
{ 0x0000, "add_to_radio" },
{ 0x0000, "add_to_spawngroup" },
{ 0x0000, "add_to_threat_bias" },
{ 0x0000, "add_tokens_to_trigger_flags" },
{ 0x0000, "add_trace_fx" },
{ 0x0000, "add_trace_fx_proc" },
{ 0x0000, "add_trigger_func_thread" },
{ 0x0000, "add_trigger_function" },
{ 0x0000, "add_turret_on_dismount" },
{ 0x0000, "add_vehicle_anim" },
{ 0x0000, "add_vehicle_player_anim" },
{ 0x0000, "add_vision_set" },
{ 0x0000, "add_vision_sets_from_triggers" },
{ 0x0000, "add_vol_to_node" },
{ 0x0000, "add_volume_to_global_arrays" },
{ 0x0000, "add_wait" },
{ 0x0000, "add_wait_asserter" },
{ 0x0000, "add_warbird_cargo" },
{ 0x0000, "add_weapon" },
{ 0x0000, "add_z" },
{ 0x0000, "addactioncovermealiasex" },
{ 0x0000, "addactivecounteruav" },
{ 0x0000, "addactiveuav" },
{ 0x0000, "addaieventlistener_func" },
{ 0x0000, "addairexplosion" },
{ 0x0000, "addallowedthreatcallout" },
{ 0x0000, "addalternatespawnpoint" },
{ 0x0000, "addarmorypoints" },
{ 0x0000, "addattachments" },
{ 0x0000, "addattacker" },
{ 0x0000, "addautomaticattachments" },
{ 0x0000, "addcalloutresponseevent" },
{ 0x0000, "addcastname" },
{ 0x0000, "addcenterdual" },
{ 0x0000, "addcenterheading" },
{ 0x0000, "addcenterimage" },
{ 0x0000, "addcentername" },
{ 0x0000, "addcenternamedouble" },
{ 0x0000, "addcentersubtitle" },
{ 0x0000, "addcentertriple" },
{ 0x0000, "addcheckfirealias" },
{ 0x0000, "addchild" },
{ 0x0000, "addcollisiontopool" },
{ 0x0000, "addconcatdirectionalias" },
{ 0x0000, "addconcattargetalias" },
{ 0x0000, "addcratetype" },
{ 0x0000, "addcratetypes_standard" },
{ 0x0000, "adddeathicon" },
{ 0x0000, "adddropmarker" },
{ 0x0000, "added_aerial_links" },
{ 0x0000, "addedtowave" },
{ 0x0000, "addgap" },
{ 0x0000, "addgrenadethrowanimoffset" },
{ 0x0000, "addhinttrigger" },
{ 0x0000, "addhostileburstalias" },
{ 0x0000, "addinformalias" },
{ 0x0000, "addinformevent" },
{ 0x0000, "addinformreloadingaliasex" },
{ 0x0000, "additional_delete_cars" },
{ 0x0000, "additional_geo" },
{ 0x0000, "additional_tactical_logic_func" },
{ 0x0000, "additional_unlink_nodes" },
{ 0x0000, "additionalassets" },
{ 0x0000, "additionalsighttraceentities" },
{ 0x0000, "additionalvo" },
{ 0x0000, "additive_pain" },
{ 0x0000, "additive_pull_weight" },
{ 0x0000, "additiverotateroot" },
{ 0x0000, "additiveturretdriveidle" },
{ 0x0000, "additiveturretfire" },
{ 0x0000, "additiveturretidle" },
{ 0x0000, "additiveturretrotateleft" },
{ 0x0000, "additiveturretrotateright" },
{ 0x0000, "additiveusegunroot" },
{ 0x0000, "addlastperks" },
{ 0x0000, "addlaunchers" },
{ 0x0000, "addleftname" },
{ 0x0000, "addlefttitle" },
{ 0x0000, "addlevel" },
{ 0x0000, "addlightningexploder" },
{ 0x0000, "addlowermessage" },
{ 0x0000, "addmovecombataliasex" },
{ 0x0000, "addmovenoncombataliasex" },
{ 0x0000, "addnamealias" },
{ 0x0000, "addnamealiasex" },
{ 0x0000, "addnodestobechecked" },
{ 0x0000, "addnotetrack_animsound" },
{ 0x0000, "addnotetrack_attach" },
{ 0x0000, "addnotetrack_customfunction" },
{ 0x0000, "addnotetrack_detach" },
{ 0x0000, "addnotetrack_detach_gun" },
{ 0x0000, "addnotetrack_df" },
{ 0x0000, "addnotetrack_dialogue" },
{ 0x0000, "addnotetrack_flag" },
{ 0x0000, "addnotetrack_flag_clear" },
{ 0x0000, "addnotetrack_lui_notify" },
{ 0x0000, "addnotetrack_notify" },
{ 0x0000, "addnotetrack_playersound" },
{ 0x0000, "addnotetrack_set_omnvar" },
{ 0x0000, "addnotetrack_sound" },
{ 0x0000, "addnotetrack_startfxontag" },
{ 0x0000, "addnotetrack_stopfxontag" },
{ 0x0000, "addnotetrack_swapparttoefx" },
{ 0x0000, "addnotetrack_tracepartforefx" },
{ 0x0000, "addofficertosquad" },
{ 0x0000, "addonstart_animsound" },
{ 0x0000, "addoption" },
{ 0x0000, "addorderalias" },
{ 0x0000, "addorderevent" },
{ 0x0000, "addplanetolist" },
{ 0x0000, "addplayernamealias" },
{ 0x0000, "addplayertosquad" },
{ 0x0000, "addpossiblethreatcallout" },
{ 0x0000, "addposteventgeotocratebadplacearray" },
{ 0x0000, "addprereq" },
{ 0x0000, "addrankalias" },
{ 0x0000, "addreactionalias" },
{ 0x0000, "addreactionevent" },
{ 0x0000, "addresponsealias" },
{ 0x0000, "addresponseevent" },
{ 0x0000, "addresponseevent_internal" },
{ 0x0000, "addrightname" },
{ 0x0000, "addrighttitle" },
{ 0x0000, "addsafetyhealth" },
{ 0x0000, "addsituationalcombatorder" },
{ 0x0000, "addsituationalorder" },
{ 0x0000, "addspace" },
{ 0x0000, "addspacesmall" },
{ 0x0000, "addspawnpoints" },
{ 0x0000, "addspeaker" },
{ 0x0000, "addstartspawnpoints" },
{ 0x0000, "addstreaksupportprompt" },
{ 0x0000, "addsubleftname" },
{ 0x0000, "addsublefttitle" },
{ 0x0000, "addtakingfirealias" },
{ 0x0000, "addtauntalias" },
{ 0x0000, "addthreatalias" },
{ 0x0000, "addthreatcalloutalias" },
{ 0x0000, "addthreatcalloutecho" },
{ 0x0000, "addthreatcalloutlandmarkalias" },
{ 0x0000, "addthreatcalloutlocationalias" },
{ 0x0000, "addthreatcalloutqa_nextline" },
{ 0x0000, "addthreatcalloutresponsealias" },
{ 0x0000, "addthreatdistancealias" },
{ 0x0000, "addthreatelevationalias" },
{ 0x0000, "addthreatevent" },
{ 0x0000, "addthreatexposedalias" },
{ 0x0000, "addthreatobviousalias" },
{ 0x0000, "addtime" },
{ 0x0000, "addtoalivecount" },
{ 0x0000, "addtobaseangle" },
{ 0x0000, "addtobattlebuddywaitlist" },
{ 0x0000, "addtocarepackagedronelist" },
{ 0x0000, "addtocharactersarray" },
{ 0x0000, "addtodeletespike" },
{ 0x0000, "addtoexplosivedronelist" },
{ 0x0000, "addtohelilist" },
{ 0x0000, "addtolittlebirdlist" },
{ 0x0000, "addtolivescount" },
{ 0x0000, "addtoparticipantsarray" },
{ 0x0000, "addtosquad" },
{ 0x0000, "addtosystem" },
{ 0x0000, "addtoteam" },
{ 0x0000, "addtoteamcount" },
{ 0x0000, "addtototalspawned" },
{ 0x0000, "addtotrackingdronelist" },
{ 0x0000, "addtoturretlist" },
{ 0x0000, "addtowavespawner" },
{ 0x0000, "addturret" },
{ 0x0000, "adduavmodel" },
{ 0x0000, "aden_key_fr" },
{ 0x0000, "adjust_angles_to_player" },
{ 0x0000, "adjust_bounce_lookahead" },
{ 0x0000, "adjust_gravity" },
{ 0x0000, "adjust_model_speed_to_node" },
{ 0x0000, "adjust_pitbull_add_idle" },
{ 0x0000, "adjustallyaccuracyovertime" },
{ 0x0000, "adjustfov" },
{ 0x0000, "adjustlink" },
{ 0x0000, "adjustmissileoverlay" },
{ 0x0000, "adjustshadowcenter" },
{ 0x0000, "adjuststaticoverlay" },
{ 0x0000, "adrenaline" },
{ 0x0000, "adrenaline_col" },
{ 0x0000, "adrenaline_speed_scalar" },
{ 0x0000, "adrenalineinit" },
{ 0x0000, "adrenalinesettings" },
{ 0x0000, "adrenalinesupport" },
{ 0x0000, "adrone_condition_callback_to_state_deat"... },
{ 0x0000, "adrone_condition_callback_to_state_dest"... },
{ 0x0000, "adrone_condition_callback_to_state_dist"... },
{ 0x0000, "adrone_condition_callback_to_state_flyb"... },
{ 0x0000, "adrone_condition_callback_to_state_flyi"... },
{ 0x0000, "adrone_condition_callback_to_state_flyo"... },
{ 0x0000, "adrone_condition_callback_to_state_hove"... },
{ 0x0000, "adrone_condition_callback_to_state_off" },
{ 0x0000, "ads" },
{ 0x0000, "ads_hint" },
{ 0x0000, "ads_hint_breakout" },
{ 0x0000, "ads_hint_breakout_think" },
{ 0x0000, "ads_hint_clear" },
{ 0x0000, "ads_hint_display" },
{ 0x0000, "ads_on" },
{ 0x0000, "adsmonitor" },
{ 0x0000, "adstime" },
{ 0x0000, "advance_bones_and_joker_intro" },
{ 0x0000, "advance_gideon_if_player_ahead" },
{ 0x0000, "advance_regardless_of_numbers" },
{ 0x0000, "advancedtraverse" },
{ 0x0000, "advancedtraverse2" },
{ 0x0000, "advancedwindowtraverse" },
{ 0x0000, "advanceonhidingenemy" },
{ 0x0000, "advancetoenemygroup" },
{ 0x0000, "advancetoenemygroupmax" },
{ 0x0000, "advancetoenemyinterval" },
{ 0x0000, "aerial_danger_exists_for" },
{ 0x0000, "aerial_dangers_monitoring" },
{ 0x0000, "aerial_group" },
{ 0x0000, "aerial_neighbors" },
{ 0x0000, "aerial_pathnode_group_connect_dist" },
{ 0x0000, "aerial_pathnode_offset" },
{ 0x0000, "aerial_pathnodes" },
{ 0x0000, "aerial_pathnodes_force_connect" },
{ 0x0000, "aerialdrone" },
{ 0x0000, "aerialkillstreakmarker" },
{ 0x0000, "affected" },
{ 0x0000, "afk" },
{ 0x0000, "after_collpase_ents" },
{ 0x0000, "afterlandanim" },
{ 0x0000, "afterlandanimconnected" },
{ 0x0000, "aftermath_anims" },
{ 0x0000, "agent_damage_finished" },
{ 0x0000, "agent_funcs" },
{ 0x0000, "agent_gameparticipant" },
{ 0x0000, "agent_override_difficulty" },
{ 0x0000, "agent_player_conf_think" },
{ 0x0000, "agent_player_dom_think" },
{ 0x0000, "agent_player_sd_think" },
{ 0x0000, "agent_squadmember_conf_think" },
{ 0x0000, "agent_squadmember_dom_think" },
{ 0x0000, "agent_teamparticipant" },
{ 0x0000, "agent_type" },
{ 0x0000, "agentarray" },
{ 0x0000, "agentbody" },
{ 0x0000, "agentcostumetablename" },
{ 0x0000, "agentdogbark" },
{ 0x0000, "agentdogthink" },
{ 0x0000, "agentfunc" },
{ 0x0000, "aggresivelookat" },
{ 0x0000, "aggressivemode" },
{ 0x0000, "aggro_target" },
{ 0x0000, "ah_delay_playerseek" },
{ 0x0000, "ah_fast_body_cleanup" },
{ 0x0000, "ah_init_track_block" },
{ 0x0000, "ah_init_track_doors" },
{ 0x0000, "ah_morgue_doors" },
{ 0x0000, "ah_morgue_threat_proc" },
{ 0x0000, "ah_move_track_block" },
{ 0x0000, "ah_player_bodybag_slowdown" },
{ 0x0000, "ah_track_door_open" },
{ 0x0000, "ah_tranistion_doors" },
{ 0x0000, "ai" },
{ 0x0000, "ai_3d_sighting_model" },
{ 0x0000, "ai_add_player_only_damage" },
{ 0x0000, "ai_add_twenty_percent_damage" },
{ 0x0000, "ai_ally_mb_intro_anim" },
{ 0x0000, "ai_animate_props_on_death" },
{ 0x0000, "ai_array" },
{ 0x0000, "ai_array_killcount_flag_set" },
{ 0x0000, "ai_boat_bow_splash_fx" },
{ 0x0000, "ai_boat_water_foamfx" },
{ 0x0000, "ai_canal_combat_01_accuracy_think" },
{ 0x0000, "ai_canal_combat_02_accuracy_think" },
{ 0x0000, "ai_canal_combat_03_accuracy_think" },
{ 0x0000, "ai_canal_combat_04_accuracy_think" },
{ 0x0000, "ai_canal_combat_05_accuracy_think" },
{ 0x0000, "ai_charged_shot_wait_for_death" },
{ 0x0000, "ai_classname_in_level" },
{ 0x0000, "ai_classname_in_level_keys" },
{ 0x0000, "ai_clear_custom_animation_reaction" },
{ 0x0000, "ai_clear_custom_animation_reaction_and_"... },
{ 0x0000, "ai_cond_player_at_ambient_battle" },
{ 0x0000, "ai_cond_player_at_escape_battle" },
{ 0x0000, "ai_cond_player_at_pitbull_battle" },
{ 0x0000, "ai_cond_player_at_police_battle" },
{ 0x0000, "ai_cond_player_at_standoff_battle" },
{ 0x0000, "ai_cond_player_at_standoff_battle_or_da"... },
{ 0x0000, "ai_cond_player_at_tanker_battle" },
{ 0x0000, "ai_cond_player_at_van" },
{ 0x0000, "ai_cond_reached_goal" },
{ 0x0000, "ai_cond_reached_path_end" },
{ 0x0000, "ai_create_behavior_function" },
{ 0x0000, "ai_damage_think" },
{ 0x0000, "ai_deathflag" },
{ 0x0000, "ai_delete_self" },
{ 0x0000, "ai_delete_when_out_of_sight" },
{ 0x0000, "ai_detect_charged_damage" },
{ 0x0000, "ai_detection" },
{ 0x0000, "ai_detection_timeout" },
{ 0x0000, "ai_disable_swim_or_underwater_walk" },
{ 0x0000, "ai_diveboat_foam_trail" },
{ 0x0000, "ai_diveboats_chase_trail" },
{ 0x0000, "ai_dont_glow_in_thermal" },
{ 0x0000, "ai_empty" },
{ 0x0000, "ai_enable_swim_or_underwater_walk" },
{ 0x0000, "ai_end_fixed_node" },
{ 0x0000, "ai_end_ignore_all" },
{ 0x0000, "ai_end_ignore_me" },
{ 0x0000, "ai_end_magic_bullet_shield" },
{ 0x0000, "ai_flee_from_microwave" },
{ 0x0000, "ai_func_override" },
{ 0x0000, "ai_functions" },
{ 0x0000, "ai_game_mode" },
{ 0x0000, "ai_gd" },
{ 0x0000, "ai_get_behavior_function" },
{ 0x0000, "ai_go_to_goal_before_colors" },
{ 0x0000, "ai_ignore_everything" },
{ 0x0000, "ai_ignore_foliage_for_time" },
{ 0x0000, "ai_init" },
{ 0x0000, "ai_jump_over_40_down_88" },
{ 0x0000, "ai_kill" },
{ 0x0000, "ai_kill_no_ragdoll" },
{ 0x0000, "ai_kill_when_out_of_sight" },
{ 0x0000, "ai_lasers" },
{ 0x0000, "ai_lobby_think" },
{ 0x0000, "ai_mantle_over_low_cover_40" },
{ 0x0000, "ai_mb1" },
{ 0x0000, "ai_mb1_allywarp" },
{ 0x0000, "ai_mb1_drones" },
{ 0x0000, "ai_mb1_first_guard_fallback" },
{ 0x0000, "ai_mb1_jumpdown_guards" },
{ 0x0000, "ai_mb1_script_end" },
{ 0x0000, "ai_mb2" },
{ 0x0000, "ai_mb2_drones" },
{ 0x0000, "ai_mb2_enemies_run" },
{ 0x0000, "ai_mb2_enemyrun" },
{ 0x0000, "ai_mb2_gate" },
{ 0x0000, "ai_mb2_mech_watcher" },
{ 0x0000, "ai_mb2_remove_stencils" },
{ 0x0000, "ai_mb2_script_end" },
{ 0x0000, "ai_message_handler_hidden" },
{ 0x0000, "ai_message_handler_spotted" },
{ 0x0000, "ai_mode" },
{ 0x0000, "ai_motorpool_animation" },
{ 0x0000, "ai_notify" },
{ 0x0000, "ai_number" },
{ 0x0000, "ai_player_only_damage_func" },
{ 0x0000, "ai_remove_outline_waiter" },
{ 0x0000, "ai_remove_player_only_damage" },
{ 0x0000, "ai_remove_twenty_percent_damage" },
{ 0x0000, "ai_restore_ignore_setting" },
{ 0x0000, "ai_run_behavior_until_condition" },
{ 0x0000, "ai_save_ignore_setting" },
{ 0x0000, "ai_set_custom_animation_reaction" },
{ 0x0000, "ai_set_goback_override_function" },
{ 0x0000, "ai_sets_goal" },
{ 0x0000, "ai_shoot_missile" },
{ 0x0000, "ai_shoot_missile_salvo" },
{ 0x0000, "ai_shot_by_player_team_notify" },
{ 0x0000, "ai_should_be_added" },
{ 0x0000, "ai_silo_floor_01_balcony" },
{ 0x0000, "ai_silo_floor_01_wave_2_think" },
{ 0x0000, "ai_silo_floor_01_wave_3_think" },
{ 0x0000, "ai_silo_think" },
{ 0x0000, "ai_slide_across_car" },
{ 0x0000, "ai_special_retreat_watcher" },
{ 0x0000, "ai_start_balcony_death" },
{ 0x0000, "ai_start_ignore_all" },
{ 0x0000, "ai_start_ignore_me" },
{ 0x0000, "ai_start_magic_bullet_shield" },
{ 0x0000, "ai_start_pacifist" },
{ 0x0000, "ai_start_respawn_death" },
{ 0x0000, "ai_stealth_pause_handler" },
{ 0x0000, "ai_step_up_32" },
{ 0x0000, "ai_stop_death_function" },
{ 0x0000, "ai_stun" },
{ 0x0000, "ai_swim_death" },
{ 0x0000, "ai_swim_pain" },
{ 0x0000, "ai_target" },
{ 0x0000, "ai_target_force" },
{ 0x0000, "ai_target_force_damaged" },
{ 0x0000, "ai_target_force_scripted" },
{ 0x0000, "ai_thermal" },
{ 0x0000, "ai_toggle_cloak" },
{ 0x0000, "ai_toggle_cloak_animate" },
{ 0x0000, "ai_toggle_cloak_complete_vo" },
{ 0x0000, "ai_toggle_cloak_start_vo" },
{ 0x0000, "ai_twenty_percent_damage_func" },
{ 0x0000, "ai_unignore_everything" },
{ 0x0000, "ai_wading_footsteps" },
{ 0x0000, "ai_wait_go" },
{ 0x0000, "ai_water_footstep" },
{ 0x0000, "ai_water_set_depth" },
{ 0x0000, "ai_wave_monitor_retreat" },
{ 0x0000, "ai_wave_monitor_threshold" },
{ 0x0000, "ai_wave_setgoalvolume" },
{ 0x0000, "ai_wave_spawn" },
{ 0x0000, "ai_wave_spawn_volume" },
{ 0x0000, "ai_wave_spawn_volume_threshold" },
{ 0x0000, "ai_wave_spawn_volume_threshold_retreat" },
{ 0x0000, "aianim_simple" },
{ 0x0000, "aianim_simple_vehicle" },
{ 0x0000, "aiareintheroom" },
{ 0x0000, "aiarraydeleteonflag" },
{ 0x0000, "aiarrayfallbackonflag" },
{ 0x0000, "aiarrayidleloop" },
{ 0x0000, "aiarraymovetonewidlepos" },
{ 0x0000, "aiarrayoverridemodelrandom" },
{ 0x0000, "aiattack" },
{ 0x0000, "aibattlechatterloop" },
{ 0x0000, "aicount" },
{ 0x0000, "aideathenemy" },
{ 0x0000, "aideatheventthread" },
{ 0x0000, "aideathfriendly" },
{ 0x0000, "aideleteonflag" },
{ 0x0000, "aidisablestealthcombat" },
{ 0x0000, "aidisplacewaiter" },
{ 0x0000, "aienablestealthcombat" },
{ 0x0000, "aienabletotalcombat" },
{ 0x0000, "aifallbackonflag" },
{ 0x0000, "aifollow" },
{ 0x0000, "aifolloworderwaiter" },
{ 0x0000, "aigrenadedangerwaiter" },
{ 0x0000, "aigroup_create" },
{ 0x0000, "aigroup_soldierthink" },
{ 0x0000, "aigroup_spawnerdeath" },
{ 0x0000, "aigroup_spawnerempty" },
{ 0x0000, "aigroup_spawnerthink" },
{ 0x0000, "aihasweapon" },
{ 0x0000, "aihostileburstloop" },
{ 0x0000, "aiidleloop" },
{ 0x0000, "aiidleloopdisable" },
{ 0x0000, "aiinwater" },
{ 0x0000, "aikilleventthread" },
{ 0x0000, "aikills" },
{ 0x0000, "aim_accel_turnrate_lerp" },
{ 0x0000, "aim_additives_think" },
{ 0x0000, "aim_assist_bmodel" },
{ 0x0000, "aim_assist_using_bmodels_init" },
{ 0x0000, "aim_assist_with_bmodels" },
{ 0x0000, "aim_at_my_attacker" },
{ 0x0000, "aim_axis_of_selected_ents" },
{ 0x0000, "aim_burke_at_angles" },
{ 0x0000, "aim_hud" },
{ 0x0000, "aim_hud_on" },
{ 0x0000, "aim_test" },
{ 0x0000, "aim_turnrate_pitch" },
{ 0x0000, "aim_turnrate_pitch_ads" },
{ 0x0000, "aim_turnrate_yaw" },
{ 0x0000, "aim_turnrate_yaw_ads" },
{ 0x0000, "aim_turret_at_ambush_point_or_visible_e"... },
{ 0x0000, "aim_while_moving_thread" },
{ 0x0000, "aimassist_target" },
{ 0x0000, "aimblendtime" },
{ 0x0000, "aimbutdontshoot" },
{ 0x0000, "aimedatshootentorpos" },
{ 0x0000, "aimedsomewhatatenemy" },
{ 0x0000, "aimfaryawtolerance" },
{ 0x0000, "aimidlethread" },
{ 0x0000, "aimovetonewidlepos" },
{ 0x0000, "aimpitchdifftolerance" },
{ 0x0000, "aimsetupblendtime" },
{ 0x0000, "aimtarget" },
{ 0x0000, "aimweight" },
{ 0x0000, "aimweight_end" },
{ 0x0000, "aimweight_start" },
{ 0x0000, "aimweight_t" },
{ 0x0000, "aimweight_transframes" },
{ 0x0000, "aimyawdiffclosedistsq" },
{ 0x0000, "aimyawdiffclosetolerance" },
{ 0x0000, "aimyawdifffartolerance" },
{ 0x0000, "ainame" },
{ 0x0000, "ainameandrankwaiter" },
{ 0x0000, "aiofficerorders" },
{ 0x0000, "aioverridemodel" },
{ 0x0000, "aioverridemodelrandom" },
{ 0x0000, "aiowner" },
{ 0x0000, "air_strip_ambient_a10_gun_dive_1" },
{ 0x0000, "air_strip_ambient_a10_gun_dive_2" },
{ 0x0000, "air_strip_ambient_a10_gun_dive_3" },
{ 0x0000, "air_strip_ambient_dogfight_1" },
{ 0x0000, "air_strip_ambient_dogfight_2" },
{ 0x0000, "air_strip_ambient_dogfight_3" },
{ 0x0000, "airank" },
{ 0x0000, "airbrake_hint" },
{ 0x0000, "aircraft_wash" },
{ 0x0000, "aircraft_wash_thread" },
{ 0x0000, "airdropcratecollision" },
{ 0x0000, "airplane_list" },
{ 0x0000, "airstrike_drones" },
{ 0x0000, "airstrike_earthquake" },
{ 0x0000, "airstrike_flares_monitor" },
{ 0x0000, "airstrikefx" },
{ 0x0000, "airstrikeinprogress" },
{ 0x0000, "airstrikeoverrides" },
{ 0x0000, "airstriketype" },
{ 0x0000, "airtoairevent" },
{ 0x0000, "airtogroundevent" },
{ 0x0000, "aistartusingassaultvehicle" },
{ 0x0000, "aispread" },
{ 0x0000, "aistate" },
{ 0x0000, "aistealthcombatenemygotocover" },
{ 0x0000, "aisuppressai" },
{ 0x0000, "aithreadthreader" },
{ 0x0000, "aiturnnotifies" },
{ 0x0000, "aitype_check" },
{ 0x0000, "aiupdateanimstate" },
{ 0x0000, "aiupdatecombat" },
{ 0x0000, "aiupdatesuppressed" },
{ 0x0000, "aiweapon" },
{ 0x0000, "ajani" },
{ 0x0000, "akimboweaponent" },
{ 0x0000, "alarm_annoyance" },
{ 0x0000, "alarm_create_loops" },
{ 0x0000, "alarm_enable" },
{ 0x0000, "alarm_guid" },
{ 0x0000, "alarm_interval" },
{ 0x0000, "alarm_is_playing" },
{ 0x0000, "alarm_monitor_cleanup" },
{ 0x0000, "alarm_on" },
{ 0x0000, "alarm_playing" },
{ 0x0000, "alarm_reverb_distance_mix" },
{ 0x0000, "alarm_start" },
{ 0x0000, "alarm_start_loops" },
{ 0x0000, "alarm_stop_loops" },
{ 0x0000, "alarm_update_loops" },
{ 0x0000, "alarm_validate_damage" },
{ 0x0000, "alarmfx" },
{ 0x0000, "alarmfx01" },
{ 0x0000, "alarmsoundent" },
{ 0x0000, "alarmsystem" },
{ 0x0000, "alcove_clips" },
{ 0x0000, "alert_check_function" },
{ 0x0000, "alert_level" },
{ 0x0000, "alert_level_table" },
{ 0x0000, "alert_sound" },
{ 0x0000, "alert_stop_animating" },
{ 0x0000, "alert_when_another_is_hurt" },
{ 0x0000, "alertai" },
{ 0x0000, "alertaigroup" },
{ 0x0000, "alertallpoolguards" },
{ 0x0000, "alerted" },
{ 0x0000, "alerted_amount" },
{ 0x0000, "alerted_by_corpse" },
{ 0x0000, "alertedenemies" },
{ 0x0000, "alertedentity" },
{ 0x0000, "alertedinfo" },
{ 0x0000, "alertface" },
{ 0x0000, "alertgroup" },
{ 0x0000, "alerthighlighthudeffect" },
{ 0x0000, "alerttimedelay" },
{ 0x0000, "alias" },
{ 0x0000, "alias_data" },
{ 0x0000, "alias_name" },
{ 0x0000, "aliens_make_entity_sentient_func" },
{ 0x0000, "align_hint_think" },
{ 0x0000, "alignment_factor" },
{ 0x0000, "alive" },
{ 0x0000, "alivecount" },
{ 0x0000, "aliveplayers" },
{ 0x0000, "all_avatars_scheduled_for_delete" },
{ 0x0000, "all_dom_flags" },
{ 0x0000, "all_exopush_enemies_dead" },
{ 0x0000, "all_hp_zones" },
{ 0x0000, "all_players_istouching" },
{ 0x0000, "all_team_streak_col" },
{ 0x0000, "all3duiscreens" },
{ 0x0000, "allboothdisplays" },
{ 0x0000, "allenemyambushers" },
{ 0x0000, "allenemypatrollers" },
{ 0x0000, "allenemyvehicles" },
{ 0x0000, "allenvarray" },
{ 0x0000, "alley_1_big_metal_gate" },
{ 0x0000, "alley_1_complete_dialogue" },
{ 0x0000, "alley_a_dialogue" },
{ 0x0000, "alley_b_dialogue" },
{ 0x0000, "alley_beckon" },
{ 0x0000, "alley_combat_dialogue" },
{ 0x0000, "alley_dialogue" },
{ 0x0000, "alley_ending_point_trigger" },
{ 0x0000, "alley_fail_dialogue" },
{ 0x0000, "alley_flank_dialogue" },
{ 0x0000, "alley_flank_dialogue_nag" },
{ 0x0000, "alley_gideon_slide" },
{ 0x0000, "alley_meetup_dialogue" },
{ 0x0000, "alley_oncoming_dialogue" },
{ 0x0000, "alley_setup" },
{ 0x0000, "alley_veh_god_on" },
{ 0x0000, "alley1_combat" },
{ 0x0000, "alley1_force_deaths" },
{ 0x0000, "alley1_kva" },
{ 0x0000, "alley1_oncoming" },
{ 0x0000, "alley1_oncoming_burke_alley_enter" },
{ 0x0000, "alley1_oncoming_goto" },
{ 0x0000, "alley1_oncoming_grenade_awareness" },
{ 0x0000, "alley1_oncoming_truck_anims" },
{ 0x0000, "alley1_oncoming_truck_seq" },
{ 0x0000, "alley1_oncoming_truck_sweeper_monitor" },
{ 0x0000, "alley1_oncoming_turret_fire" },
{ 0x0000, "alley1_oncoming_turret_think" },
{ 0x0000, "alley1_stage1_combat" },
{ 0x0000, "alley1_stage1_rooftop_movedown" },
{ 0x0000, "alley1_stage2_combat" },
{ 0x0000, "alley1_stage2_combat_flag" },
{ 0x0000, "alley1_stage3_combat" },
{ 0x0000, "alley1_stage3_combat_flag" },
{ 0x0000, "alley1_stage3_refill_think" },
{ 0x0000, "alley1_veh_destro" },
{ 0x0000, "alley2_combat" },
{ 0x0000, "alley2_combat_enemy_vol_assign" },
{ 0x0000, "alley2_combat_player_monitor" },
{ 0x0000, "alley2_combat_vol_assign" },
{ 0x0000, "alley2_jumpers" },
{ 0x0000, "alley2_jumpers_setup" },
{ 0x0000, "alley2_kva" },
{ 0x0000, "alley2_spawner_locator" },
{ 0x0000, "alley2_stage1_combat" },
{ 0x0000, "alley2_stage2_combat" },
{ 0x0000, "alley2_stage3_combat" },
{ 0x0000, "alleys_distant_emergency_siren_blasts" },
{ 0x0000, "alleys_distant_euro_siren_loop" },
{ 0x0000, "alleys_distant_standard_siren_loop" },
{ 0x0000, "alleys_end_music" },
{ 0x0000, "alleys_music_end" },
{ 0x0000, "alleys_rpg_fight_music" },
{ 0x0000, "alleys_rpg_music" },
{ 0x0000, "alleys_rpg_music_backup_trigger" },
{ 0x0000, "alleysallymovement" },
{ 0x0000, "alleysbegin" },
{ 0x0000, "alleysbegincombatdialog" },
{ 0x0000, "alleyscafeanims" },
{ 0x0000, "alleyscheckifplayerretreated" },
{ 0x0000, "alleyscombat" },
{ 0x0000, "alleyscombatbacklinefloodspawns" },
{ 0x0000, "alleyscombatbacklineleftinteriorfloor1" },
{ 0x0000, "alleyscombatbacklineleftside" },
{ 0x0000, "alleyscombatbacklinerightinteriorfloor1" },
{ 0x0000, "alleyscombatbacklinerightinteriorfloor2" },
{ 0x0000, "alleyscombatbacklinerightside" },
{ 0x0000, "alleyscombatenemycountmonitor" },
{ 0x0000, "alleyscombatenemyorders" },
{ 0x0000, "alleyscombatenemyretreat" },
{ 0x0000, "alleyscombatenemysetup" },
{ 0x0000, "alleyscombatenterbuilding" },
{ 0x0000, "alleyscombatfinalbldgfloodspawns" },
{ 0x0000, "alleyscombatfinalbuilding" },
{ 0x0000, "alleyscombatfinalbuildinginterior" },
{ 0x0000, "alleyscombatfinalbuildingshotgunners" },
{ 0x0000, "alleyscombatfrontlinefloodspawns" },
{ 0x0000, "alleyscombatfrontlineleftbackstairs" },
{ 0x0000, "alleyscombatfrontlineleftside" },
{ 0x0000, "alleyscombatfrontlineleftsideinteriorfl"... },
{ 0x0000, "alleyscombatfrontlinerightbackatm" },
{ 0x0000, "alleyscombatfrontlinerightside" },
{ 0x0000, "alleyscombatinteriorfakebulletsactivate" },
{ 0x0000, "alleyscombatinteriorfakebulletssetup" },
{ 0x0000, "alleyscombatmidlineleftside" },
{ 0x0000, "alleyscombatmidlinerightside" },
{ 0x0000, "alleyscombatmidlinerightsideinterior" },
{ 0x0000, "alleyscombattriggertoggles" },
{ 0x0000, "alleysdialogtimer" },
{ 0x0000, "alleysdronecivilians" },
{ 0x0000, "alleysdronegawker" },
{ 0x0000, "alleysenemyretreat" },
{ 0x0000, "alleysenemyrpg" },
{ 0x0000, "alleysenemyspawns" },
{ 0x0000, "alleysflaginit" },
{ 0x0000, "alleysgatebash" },
{ 0x0000, "alleysgatebashrumblelight" },
{ 0x0000, "alleysgateriprumbleheavy" },
{ 0x0000, "alleysgateripunblockpath" },
{ 0x0000, "alleysglobalsetup" },
{ 0x0000, "alleysglobalvars" },
{ 0x0000, "alleysilanaleadstheway" },
{ 0x0000, "alleysintroanims" },
{ 0x0000, "alleysintrotransitiondialogue" },
{ 0x0000, "alleyskvaintrodialogue" },
{ 0x0000, "alleysmidpointreminder" },
{ 0x0000, "alleysmonitorgateriphint" },
{ 0x0000, "alleysobjectivesetup" },
{ 0x0000, "alleysprecache" },
{ 0x0000, "alleysremainingenemies" },
{ 0x0000, "alleysrpgguyshootfirst" },
{ 0x0000, "alleyssetcompletedobjflags" },
{ 0x0000, "alleyssniperpip" },
{ 0x0000, "alleysspawnrpgenemies" },
{ 0x0000, "alleysstartpoints" },
{ 0x0000, "alleysstreettransitiondialogue" },
{ 0x0000, "alleysvehicleexplodeondeath" },
{ 0x0000, "alleysvehiclemonitor" },
{ 0x0000, "alleysvideolog" },
{ 0x0000, "alleysvisitorcentergate" },
{ 0x0000, "alleysvisitorcentergatereminder" },
{ 0x0000, "alleyway_fight_enemies" },
{ 0x0000, "allfloorpannels" },
{ 0x0000, "allies_bunker" },
{ 0x0000, "allies_careful" },
{ 0x0000, "allies_check_cloak_state" },
{ 0x0000, "allies_cover_michell" },
{ 0x0000, "allies_dialog_col" },
{ 0x0000, "allies_inert" },
{ 0x0000, "allies_plane" },
{ 0x0000, "allies_rally_init" },
{ 0x0000, "allies_s1" },
{ 0x0000, "allies_s2" },
{ 0x0000, "allies_start_spawn_name" },
{ 0x0000, "allies_to_building_exit" },
{ 0x0000, "allies_to_drone_swarm" },
{ 0x0000, "allies_to_first_land_assist" },
{ 0x0000, "allies_to_first_land_assist_debug" },
{ 0x0000, "allies_to_fob" },
{ 0x0000, "allies_to_fob_think" },
{ 0x0000, "allies_to_hill" },
{ 0x0000, "allies_to_truck_jump" },
{ 0x0000, "allies_to_weapons_platform_video_log" },
{ 0x0000, "alliesbreachatrium" },
{ 0x0000, "alliesbreachatriumonalarm" },
{ 0x0000, "alliesbreachconfroom" },
{ 0x0000, "alliescapturing" },
{ 0x0000, "allieschopper" },
{ 0x0000, "alliesdrivein" },
{ 0x0000, "alliesexitatrium" },
{ 0x0000, "alliesexitconfroom" },
{ 0x0000, "alliesexittruck" },
{ 0x0000, "alliesflagcarrierclientnum" },
{ 0x0000, "alliesflagstatus" },
{ 0x0000, "alliesparkingdefend" },
{ 0x0000, "alliesparkingkill" },
{ 0x0000, "alliesparkingkillalt" },
{ 0x0000, "alliesparkingkillvictim" },
{ 0x0000, "alliesparkingsetup" },
{ 0x0000, "alliesredirect" },
{ 0x0000, "alliesshootpooltargets" },
{ 0x0000, "alliesvulnerabletime" },
{ 0x0000, "allieswarningtime" },
{ 0x0000, "allow_backstabbers" },
{ 0x0000, "allow_boost_jump" },
{ 0x0000, "allow_death_delay" },
{ 0x0000, "allow_death_during_zipline" },
{ 0x0000, "allow_death_timer" },
{ 0x0000, "allow_dog_paired_melee_vs_ai" },
{ 0x0000, "allow_early_back_out" },
{ 0x0000, "allow_exo_climb" },
{ 0x0000, "allow_fake_shooting" },
{ 0x0000, "allow_pipe_damage" },
{ 0x0000, "allow_player_hovertank_mount" },
{ 0x0000, "allow_player_input_1" },
{ 0x0000, "allow_player_input_2" },
{ 0x0000, "allow_player_zip" },
{ 0x0000, "allow_random_killers" },
{ 0x0000, "allow_swimming" },
{ 0x0000, "allow_threat_paint" },
{ 0x0000, "allowable_double_attachments" },
{ 0x0000, "allowboostingabovetriggerradius" },
{ 0x0000, "allowcarry" },
{ 0x0000, "allowclasschoice" },
{ 0x0000, "allowdronedelivery" },
{ 0x0000, "allowedcallouts" },
{ 0x0000, "allowedpartialreloadontheruntime" },
{ 0x0000, "allowempdamage" },
{ 0x0000, "allowenemyspectate" },
{ 0x0000, "allowfauxdeath" },
{ 0x0000, "allowfreespectate" },
{ 0x0000, "allowlaststandai" },
{ 0x0000, "allowlatecomers" },
{ 0x0000, "allowmeleedamage" },
{ 0x0000, "allowneutral" },
{ 0x0000, "allowplayerscore" },
{ 0x0000, "allowshoot" },
{ 0x0000, "allowteamchoice" },
{ 0x0000, "allowtelefrag" },
{ 0x0000, "allowuse" },
{ 0x0000, "allowvehicledamage" },
{ 0x0000, "allowvote" },
{ 0x0000, "allowweapons" },
{ 0x0000, "alltargetlogicarray" },
{ 0x0000, "alltargetmax" },
{ 0x0000, "alltargetmin" },
{ 0x0000, "alltargetsarray" },
{ 0x0000, "alltriggerarray" },
{ 0x0000, "allvfx_struct" },
{ 0x0000, "ally" },
{ 0x0000, "ally_advance_ahead_upon_killing_group" },
{ 0x0000, "ally_ai_active" },
{ 0x0000, "ally_alert_vol" },
{ 0x0000, "ally_anims" },
{ 0x0000, "ally_determine_move_speed" },
{ 0x0000, "ally_dynamic_run_set" },
{ 0x0000, "ally_enable_boost_traversals" },
{ 0x0000, "ally_fire_on_dam" },
{ 0x0000, "ally_grapple" },
{ 0x0000, "ally_jet_shoot_think" },
{ 0x0000, "ally_move_dynamic_speed" },
{ 0x0000, "ally_mover" },
{ 0x0000, "ally_one_handed_grenade_proc" },
{ 0x0000, "ally_redirect_goto_node" },
{ 0x0000, "ally_reset_dynamic_speed" },
{ 0x0000, "ally_s2_squad_member_1" },
{ 0x0000, "ally_s2_squad_member_2" },
{ 0x0000, "ally_s2_squad_member_3" },
{ 0x0000, "ally_s2_squad_member_4" },
{ 0x0000, "ally_shoot_rpg_at_drones" },
{ 0x0000, "ally_squad_member_1" },
{ 0x0000, "ally_squad_member_2" },
{ 0x0000, "ally_squad_member_3" },
{ 0x0000, "ally_squad_member_4" },
{ 0x0000, "ally_stop_dynamic_speed" },
{ 0x0000, "ally_vo_controller" },
{ 0x0000, "ally_vo_org" },
{ 0x0000, "allyagentthink" },
{ 0x0000, "allybreachconfroomanddie" },
{ 0x0000, "allyburkeparkingsetup" },
{ 0x0000, "allyclaimedtarget" },
{ 0x0000, "allyclearforcegoalonend" },
{ 0x0000, "allyconfroomdeath" },
{ 0x0000, "allyexithandlevictim" },
{ 0x0000, "allyexitpool" },
{ 0x0000, "allyexittruck" },
{ 0x0000, "allyinfiltrators" },
{ 0x0000, "allypoolclimb" },
{ 0x0000, "allypoolkill" },
{ 0x0000, "allypoolsetup" },
{ 0x0000, "allyredirect" },
{ 0x0000, "allyredirectgotonode" },
{ 0x0000, "allyredirectnoteworthy" },
{ 0x0000, "allyscrambleanimations" },
{ 0x0000, "allysetupconfroom" },
{ 0x0000, "allysetupstruggle" },
{ 0x0000, "allyshootpooltarget" },
{ 0x0000, "allyshootwalkwaytarget" },
{ 0x0000, "allysquad" },
{ 0x0000, "allystealthanimations" },
{ 0x0000, "allystruggleslomo" },
{ 0x0000, "allystrugglesuccess" },
{ 0x0000, "allytanks" },
{ 0x0000, "allywalkwaykill" },
{ 0x0000, "allywalkwaykillvictim" },
{ 0x0000, "almost_dead" },
{ 0x0000, "alpha_leader" },
{ 0x0000, "alpha_leader_think" },
{ 0x0000, "alpha_squad" },
{ 0x0000, "alpha_squad_and_player" },
{ 0x0000, "alphabetize" },
{ 0x0000, "alphabetize_localized_string" },
{ 0x0000, "already_dumpped" },
{ 0x0000, "already_got_end_level_notetrack" },
{ 0x0000, "already_ran_function" },
{ 0x0000, "already_set" },
{ 0x0000, "already_used" },
{ 0x0000, "alreadyaddedtoalivecount" },
{ 0x0000, "alt_rspns_random_test" },
{ 0x0000, "alt_rspns_test_func" },
{ 0x0000, "alternates" },
{ 0x0000, "altmeleedeath" },
{ 0x0000, "altmeleevictimorientation" },
{ 0x0000, "always_loop_ents" },
{ 0x0000, "always_pain" },
{ 0x0000, "always_sprint" },
{ 0x0000, "always_wake_drones" },
{ 0x0000, "alwaysdrawfriendlynames" },
{ 0x0000, "alwayslookatfirsttarget" },
{ 0x0000, "alwaysrocketdeath" },
{ 0x0000, "alwaysrunforward" },
{ 0x0000, "alwaysstaticout" },
{ 0x0000, "alwaysusepistol" },
{ 0x0000, "am_i_hit" },
{ 0x0000, "am_i_moving" },
{ 0x0000, "amb_push_oneshots" },
{ 0x0000, "amb_pushing" },
{ 0x0000, "amb_sky_combat" },
{ 0x0000, "amb_sky_combat_setup" },
{ 0x0000, "ambience" },
{ 0x0000, "ambience_inner" },
{ 0x0000, "ambience_outer" },
{ 0x0000, "ambient_animate" },
{ 0x0000, "ambient_battle_deployable_cover" },
{ 0x0000, "ambient_building_fires_fob_drone_swarm" },
{ 0x0000, "ambient_combat" },
{ 0x0000, "ambient_combat_allies" },
{ 0x0000, "ambient_combat_axis" },
{ 0x0000, "ambient_combat_vo" },
{ 0x0000, "ambient_deck" },
{ 0x0000, "ambient_dialogue_manager" },
{ 0x0000, "ambient_drones" },
{ 0x0000, "ambient_eq" },
{ 0x0000, "ambient_explosion_before_landing" },
{ 0x0000, "ambient_explosion_courtyard" },
{ 0x0000, "ambient_explosion_dirt_cooling_towers" },
{ 0x0000, "ambient_explosion_fireball_cooling_towe"... },
{ 0x0000, "ambient_explosion_play" },
{ 0x0000, "ambient_explosions" },
{ 0x0000, "ambient_fan_rotate" },
{ 0x0000, "ambient_fires_inside_building" },
{ 0x0000, "ambient_flare_fx" },
{ 0x0000, "ambient_gas_explosion_loading_zone" },
{ 0x0000, "ambient_hangar" },
{ 0x0000, "ambient_hangar_fan_blade_rotate" },
{ 0x0000, "ambient_hangar_fan_blades_setup" },
{ 0x0000, "ambient_hangar_workers" },
{ 0x0000, "ambient_hangar_workers_spawn_settings" },
{ 0x0000, "ambient_large_pipe_effects_courtyard" },
{ 0x0000, "ambient_mb1_crane" },
{ 0x0000, "ambient_mb2_claw_platform" },
{ 0x0000, "ambient_mb2_crane" },
{ 0x0000, "ambient_mb2_cranes" },
{ 0x0000, "ambient_mb2_tanks" },
{ 0x0000, "ambient_model_fix" },
{ 0x0000, "ambient_modifier" },
{ 0x0000, "ambient_police_drone_vo" },
{ 0x0000, "ambient_police_drones" },
{ 0x0000, "ambient_reverb" },
{ 0x0000, "ambient_shrike_flyby" },
{ 0x0000, "ambient_smk_walkway" },
{ 0x0000, "ambient_sniper_rockets" },
{ 0x0000, "ambient_soldier_vo_01" },
{ 0x0000, "ambient_soldier_vo_02" },
{ 0x0000, "ambient_soldier_vo_03" },
{ 0x0000, "ambient_soldier_vo_04" },
{ 0x0000, "ambient_soldier_vo_05" },
{ 0x0000, "ambient_soldier_vo_06" },
{ 0x0000, "ambient_track" },
{ 0x0000, "ambient_underwater_effects_rescue" },
{ 0x0000, "ambient_warbird_fire" },
{ 0x0000, "ambient_warbird_shooting_think" },
{ 0x0000, "ambient_warbird_wait_to_fire" },
{ 0x0000, "ambientanimation" },
{ 0x0000, "ambientcloudskill" },
{ 0x0000, "ambientcloudsloadin" },
{ 0x0000, "ambientdelay" },
{ 0x0000, "ambientevent" },
{ 0x0000, "ambienteventstart" },
{ 0x0000, "ambientexp" },
{ 0x0000, "ambienthdr" },
{ 0x0000, "ambulance_damage_part" },
{ 0x0000, "ambulance_firstframe_function" },
{ 0x0000, "ambulance_max_health" },
{ 0x0000, "ambulance_objective_update" },
{ 0x0000, "ambulance_part_monitor" },
{ 0x0000, "ambulance_push_active" },
{ 0x0000, "ambulance_push_attach" },
{ 0x0000, "ambulance_push_idle" },
{ 0x0000, "ambulance_push_sequence_end" },
{ 0x0000, "ambulance_push_step_away" },
{ 0x0000, "ambush_ambushed_vo" },
{ 0x0000, "ambush_breakout" },
{ 0x0000, "ambush_duration" },
{ 0x0000, "ambush_end" },
{ 0x0000, "ambush_entrances" },
{ 0x0000, "ambush_events" },
{ 0x0000, "ambush_heli_explosion" },
{ 0x0000, "ambush_player_if_alive_exopush" },
{ 0x0000, "ambush_trap_ent" },
{ 0x0000, "ambush_wait" },
{ 0x0000, "ambush_yaw" },
{ 0x0000, "ambushendtime" },
{ 0x0000, "ambushnode" },
{ 0x0000, "ambushtimer" },
{ 0x0000, "americans" },
{ 0x0000, "americans_setup" },
{ 0x0000, "ammo" },
{ 0x0000, "ammo_cache_think_global" },
{ 0x0000, "ammo_icon" },
{ 0x0000, "ammo_icon_fade_in" },
{ 0x0000, "ammo_icon_fade_out" },
{ 0x0000, "ammo_icon_think" },
{ 0x0000, "ammo_icon_trig" },
{ 0x0000, "ammo_max" },
{ 0x0000, "ammo_pickup" },
{ 0x0000, "ammocheatinterval" },
{ 0x0000, "ammocheattime" },
{ 0x0000, "ammofeeder" },
{ 0x0000, "ammopickup" },
{ 0x0000, "ammopickup_scalar" },
{ 0x0000, "ammopickupfunc" },
{ 0x0000, "ammopickupmodel" },
{ 0x0000, "ammorefillprimary" },
{ 0x0000, "ammorefillsecondary" },
{ 0x0000, "amount" },
{ 0x0000, "amount_in_sights" },
{ 0x0000, "amplify_vfx" },
{ 0x0000, "ams_enabled" },
{ 0x0000, "ams_get_state" },
{ 0x0000, "ams_init" },
{ 0x0000, "ams_intensity" },
{ 0x0000, "ams_player_health" },
{ 0x0000, "ams_proxy_vehicle_speed" },
{ 0x0000, "ams_set_intensity" },
{ 0x0000, "ams_set_proxy_vehicle" },
{ 0x0000, "ams_set_state" },
{ 0x0000, "ams_start" },
{ 0x0000, "ams_stop" },
{ 0x0000, "amsx_get" },
{ 0x0000, "amsx_get_proxy" },
{ 0x0000, "amsx_get_proxy_vehicle_ent" },
{ 0x0000, "amv_jetbike_height_time" },
{ 0x0000, "amv_jetbike_height_val" },
{ 0x0000, "angle" },
{ 0x0000, "angle_interpolate" },
{ 0x0000, "angle_lerp" },
{ 0x0000, "angle_offset" },
{ 0x0000, "angleaccel" },
{ 0x0000, "anglelimit" },
{ 0x0000, "anglerangethread" },
{ 0x0000, "angles_and_origin" },
{ 0x0000, "angles_clamp_180" },
{ 0x0000, "angles_lerp" },
{ 0x0000, "angles_origin" },
{ 0x0000, "anglescheck" },
{ 0x0000, "anglesclamp180" },
{ 0x0000, "anglesondeath" },
{ 0x0000, "anglesonkill" },
{ 0x0000, "anglessubtract" },
{ 0x0000, "anglevalid" },
{ 0x0000, "angspeed" },
{ 0x0000, "anim_1" },
{ 0x0000, "anim_2" },
{ 0x0000, "anim_3" },
{ 0x0000, "anim_addmodel" },
{ 0x0000, "anim_animationendnotify" },
{ 0x0000, "anim_array" },
{ 0x0000, "anim_at_entity" },
{ 0x0000, "anim_at_self" },
{ 0x0000, "anim_blend_time_override" },
{ 0x0000, "anim_burke_boost_lets_go" },
{ 0x0000, "anim_burke_crawl" },
{ 0x0000, "anim_changes_pushplayer" },
{ 0x0000, "anim_custom_animmode" },
{ 0x0000, "anim_custom_animmode_loop" },
{ 0x0000, "anim_custom_animmode_loop_solo" },
{ 0x0000, "anim_custom_animmode_on_guy" },
{ 0x0000, "anim_custom_animmode_solo" },
{ 0x0000, "anim_deathnotify" },
{ 0x0000, "anim_debug" },
{ 0x0000, "anim_dialogueendnotify" },
{ 0x0000, "anim_disablepain" },
{ 0x0000, "anim_dontpushplayer" },
{ 0x0000, "anim_down" },
{ 0x0000, "anim_end_early" },
{ 0x0000, "anim_end_early_animationendnotify" },
{ 0x0000, "anim_end_early_deathnotify" },
{ 0x0000, "anim_end_early_dialogueendnotify" },
{ 0x0000, "anim_end_early_facialendnotify" },
{ 0x0000, "anim_exists" },
{ 0x0000, "anim_facialanim" },
{ 0x0000, "anim_facialendnotify" },
{ 0x0000, "anim_facialfiller" },
{ 0x0000, "anim_first_frame" },
{ 0x0000, "anim_first_frame_on_guy" },
{ 0x0000, "anim_first_frame_solo" },
{ 0x0000, "anim_first_frame_with_finale_gameplay" },
{ 0x0000, "anim_generic" },
{ 0x0000, "anim_generic_custom_animmode" },
{ 0x0000, "anim_generic_custom_animmode_loop" },
{ 0x0000, "anim_generic_first_frame" },
{ 0x0000, "anim_generic_gravity" },
{ 0x0000, "anim_generic_loop" },
{ 0x0000, "anim_generic_queue" },
{ 0x0000, "anim_generic_reach" },
{ 0x0000, "anim_generic_reach_and_arrive" },
{ 0x0000, "anim_generic_run" },
{ 0x0000, "anim_generic_teleport" },
{ 0x0000, "anim_gunhand" },
{ 0x0000, "anim_guninhand" },
{ 0x0000, "anim_handle_notetrack" },
{ 0x0000, "anim_idle_down" },
{ 0x0000, "anim_idle_up" },
{ 0x0000, "anim_is_death" },
{ 0x0000, "anim_laserbuoy" },
{ 0x0000, "anim_last_frame_solo" },
{ 0x0000, "anim_link_tag_model" },
{ 0x0000, "anim_loop" },
{ 0x0000, "anim_loop_hatch_anims_solo" },
{ 0x0000, "anim_loop_packet" },
{ 0x0000, "anim_loop_packet_solo" },
{ 0x0000, "anim_loop_solo" },
{ 0x0000, "anim_loop_solo_vm" },
{ 0x0000, "anim_loop_vm" },
{ 0x0000, "anim_moveto" },
{ 0x0000, "anim_node" },
{ 0x0000, "anim_org" },
{ 0x0000, "anim_org_ajani_post_breach" },
{ 0x0000, "anim_playsound_func" },
{ 0x0000, "anim_pos" },
{ 0x0000, "anim_prep" },
{ 0x0000, "anim_prop_init_threads" },
{ 0x0000, "anim_prop_models" },
{ 0x0000, "anim_prop_models_animtree" },
{ 0x0000, "anim_props" },
{ 0x0000, "anim_props_animated" },
{ 0x0000, "anim_pushplayer" },
{ 0x0000, "anim_rate_to_speed" },
{ 0x0000, "anim_reach" },
{ 0x0000, "anim_reach_and_approach" },
{ 0x0000, "anim_reach_and_approach_node_solo" },
{ 0x0000, "anim_reach_and_approach_solo" },
{ 0x0000, "anim_reach_and_idle" },
{ 0x0000, "anim_reach_and_idle_solo" },
{ 0x0000, "anim_reach_and_plant" },
{ 0x0000, "anim_reach_and_plant_and_arrive" },
{ 0x0000, "anim_reach_cleanup" },
{ 0x0000, "anim_reach_cleanup_solo" },
{ 0x0000, "anim_reach_failsafe" },
{ 0x0000, "anim_reach_fix" },
{ 0x0000, "anim_reach_idle" },
{ 0x0000, "anim_reach_solo" },
{ 0x0000, "anim_reach_success" },
{ 0x0000, "anim_reach_together" },
{ 0x0000, "anim_reach_together_with_overrides" },
{ 0x0000, "anim_reach_with_funcs" },
{ 0x0000, "anim_relative" },
{ 0x0000, "anim_removemodel" },
{ 0x0000, "anim_roundabout_rappel_1" },
{ 0x0000, "anim_roundabout_rappel_2" },
{ 0x0000, "anim_scene_building_exit_cormack" },
{ 0x0000, "anim_scene_building_exit_will" },
{ 0x0000, "anim_scene_building_jump" },
{ 0x0000, "anim_scene_walker_stepover" },
{ 0x0000, "anim_scene_will_grabs_car_door" },
{ 0x0000, "anim_scene_will_grabs_car_door_post_che"... },
{ 0x0000, "anim_self_set_real_time" },
{ 0x0000, "anim_self_set_time" },
{ 0x0000, "anim_sequence" },
{ 0x0000, "anim_set_rate" },
{ 0x0000, "anim_set_rate_internal" },
{ 0x0000, "anim_set_rate_single" },
{ 0x0000, "anim_set_real_time" },
{ 0x0000, "anim_set_time" },
{ 0x0000, "anim_simple" },
{ 0x0000, "anim_simple_notify" },
{ 0x0000, "anim_single" },
{ 0x0000, "anim_single_droppod_custom" },
{ 0x0000, "anim_single_end_early" },
{ 0x0000, "anim_single_failsafe" },
{ 0x0000, "anim_single_failsafeonguy" },
{ 0x0000, "anim_single_internal" },
{ 0x0000, "anim_single_mech" },
{ 0x0000, "anim_single_qte_middle" },
{ 0x0000, "anim_single_qte_middle_fail" },
{ 0x0000, "anim_single_queue" },
{ 0x0000, "anim_single_run" },
{ 0x0000, "anim_single_run_solo" },
{ 0x0000, "anim_single_solo" },
{ 0x0000, "anim_single_solo_custom" },
{ 0x0000, "anim_single_solo_d" },
{ 0x0000, "anim_single_solo_in_place" },
{ 0x0000, "anim_single_solo_internal_vm" },
{ 0x0000, "anim_single_solo_run" },
{ 0x0000, "anim_single_solo_vm" },
{ 0x0000, "anim_single_solo_with_lerp" },
{ 0x0000, "anim_single_solo_with_special_walk" },
{ 0x0000, "anim_single_solo_with_wait_flag" },
{ 0x0000, "anim_single_to_delete" },
{ 0x0000, "anim_single_to_delete_solo" },
{ 0x0000, "anim_single_to_loop" },
{ 0x0000, "anim_single_to_loop_solo" },
{ 0x0000, "anim_single_with_gameplay" },
{ 0x0000, "anim_spawn_generic_model" },
{ 0x0000, "anim_spawn_model" },
{ 0x0000, "anim_spawn_tag_model" },
{ 0x0000, "anim_spawner_teleport" },
{ 0x0000, "anim_speed" },
{ 0x0000, "anim_start_at_groundpos" },
{ 0x0000, "anim_start_pos" },
{ 0x0000, "anim_start_pos_solo" },
{ 0x0000, "anim_state" },
{ 0x0000, "anim_stop" },
{ 0x0000, "anim_stopanimscripted" },
{ 0x0000, "anim_struct" },
{ 0x0000, "anim_struct_exfil" },
{ 0x0000, "anim_struct2" },
{ 0x0000, "anim_tag" },
{ 0x0000, "anim_teleport" },
{ 0x0000, "anim_teleport_solo" },
{ 0x0000, "anim_time" },
{ 0x0000, "anim_up" },
{ 0x0000, "anim_van_intro" },
{ 0x0000, "anim_wait_func" },
{ 0x0000, "anim_weight" },
{ 0x0000, "anim_with_teleport" },
{ 0x0000, "animal_anims" },
{ 0x0000, "animalanimations" },
{ 0x0000, "animalias" },
{ 0x0000, "animarchetype" },
{ 0x0000, "animarray" },
{ 0x0000, "animarrayanyexist" },
{ 0x0000, "animarrayfuncs" },
{ 0x0000, "animarraypickrandom" },
{ 0x0000, "animate_collapse_ent" },
{ 0x0000, "animate_dead_body" },
{ 0x0000, "animate_drills" },
{ 0x0000, "animate_drive_idle" },
{ 0x0000, "animate_drive_idle_on_dummies" },
{ 0x0000, "animate_guys" },
{ 0x0000, "animate_on_goal" },
{ 0x0000, "animate_player_on_rig_simple" },
{ 0x0000, "animate_props_on_death" },
{ 0x0000, "animate_script_origin" },
{ 0x0000, "animate_the_other_guys" },
{ 0x0000, "animate_turret_with_viewmodel" },
{ 0x0000, "animated_gun" },
{ 0x0000, "animated_lights" },
{ 0x0000, "animated_pod_function" },
{ 0x0000, "animated_prop_anims" },
{ 0x0000, "animateddeath" },
{ 0x0000, "animatedpalmtrees" },
{ 0x0000, "animatemodel" },
{ 0x0000, "animatemoveintoplace" },
{ 0x0000, "animatetreewind" },
{ 0x0000, "animation_process" },
{ 0x0000, "animation_think" },
{ 0x0000, "animcbs" },
{ 0x0000, "animdodgeobstaclelistener" },
{ 0x0000, "animdown" },
{ 0x0000, "anime" },
{ 0x0000, "animent" },
{ 0x0000, "animflagnameindex" },
{ 0x0000, "animhasfacialoverride" },
{ 0x0000, "animidledown" },
{ 0x0000, "animidleup" },
{ 0x0000, "animname" },
{ 0x0000, "animnode" },
{ 0x0000, "animontag" },
{ 0x0000, "animontag_ragdoll_death" },
{ 0x0000, "animontag_ragdoll_death_fall" },
{ 0x0000, "animontag_unloading_vehicle_explosion" },
{ 0x0000, "animplaybackrate" },
{ 0x0000, "animref" },
{ 0x0000, "anims" },
{ 0x0000, "animsapplied" },
{ 0x0000, "animscript_sittag" },
{ 0x0000, "animscript_target" },
{ 0x0000, "animscriptdonotetracksthread" },
{ 0x0000, "animsequence" },
{ 0x0000, "animset" },
{ 0x0000, "animsets" },
{ 0x0000, "animsound_aliases" },
{ 0x0000, "animsound_exists" },
{ 0x0000, "animsound_hud_extralines" },
{ 0x0000, "animsound_hudlimit" },
{ 0x0000, "animsound_start_tracker" },
{ 0x0000, "animsound_start_tracker_loop" },
{ 0x0000, "animsound_tagged" },
{ 0x0000, "animsound_tracker" },
{ 0x0000, "animsounds" },
{ 0x0000, "animsounds_thisframe" },
{ 0x0000, "animstate" },
{ 0x0000, "animsubstate" },
{ 0x0000, "animtree" },
{ 0x0000, "animup" },
{ 0x0000, "anml_doberman" },
{ 0x0000, "announcerdisabled" },
{ 0x0000, "annoyance_tracker" },
{ 0x0000, "antiintrusion" },
{ 0x0000, "any_enemy_is_able_to_attack" },
{ 0x0000, "any_players_istouching" },
{ 0x0000, "any_wheel_on_ground" },
{ 0x0000, "anyattachmentisscope" },
{ 0x0000, "anyplayersinkillcam" },
{ 0x0000, "anystingermissilelockedon" },
{ 0x0000, "anythingistouching" },
{ 0x0000, "anythingtouchingtrigger" },
{ 0x0000, "apex" },
{ 0x0000, "apm_mine_deletekillcament" },
{ 0x0000, "applied_reverb" },
{ 0x0000, "apply_difficulty_frac_with_func" },
{ 0x0000, "apply_difficulty_step_with_func" },
{ 0x0000, "apply_end_fog" },
{ 0x0000, "apply_fog" },
{ 0x0000, "apply_friendly_fire_damage_modifier" },
{ 0x0000, "apply_jump_fx" },
{ 0x0000, "apply_option_to_selected_fx" },
{ 0x0000, "apply_reinforcement_perk" },
{ 0x0000, "apply_reverb" },
{ 0x0000, "apply_truckjunk" },
{ 0x0000, "apply_whizby" },
{ 0x0000, "applybombcarrierclass" },
{ 0x0000, "applyemp" },
{ 0x0000, "applyflagcarrierclass" },
{ 0x0000, "applyflash" },
{ 0x0000, "applyloadout" },
{ 0x0000, "applyperks" },
{ 0x0000, "applyprisonturretradararrow" },
{ 0x0000, "approach_barracks_combat_setup" },
{ 0x0000, "approach_handle_murica_movement_left" },
{ 0x0000, "approach_idle_ents" },
{ 0x0000, "approach_scene_ents" },
{ 0x0000, "approach_spawn_functions" },
{ 0x0000, "approach_types" },
{ 0x0000, "approachconditioncheckfunc" },
{ 0x0000, "approaching" },
{ 0x0000, "approaching_roundabout_dialogue" },
{ 0x0000, "approaching_standoff" },
{ 0x0000, "approachnumber" },
{ 0x0000, "approachtype" },
{ 0x0000, "approachtypefunc" },
{ 0x0000, "approachwaittillclose" },
{ 0x0000, "aquiring_targets_think" },
{ 0x0000, "ar_moment" },
{ 0x0000, "arc_point" },
{ 0x0000, "arcade_plane_controls" },
{ 0x0000, "arcademode" },
{ 0x0000, "arcademode_hud_timer" },
{ 0x0000, "arcademode_stop_timer" },
{ 0x0000, "arcademode_stoptime" },
{ 0x0000, "archetype_exists" },
{ 0x0000, "archetypechanged" },
{ 0x0000, "archetypeexists" },
{ 0x0000, "archetypes" },
{ 0x0000, "archive" },
{ 0x0000, "are_we_close" },
{ 0x0000, "aredifferent" },
{ 0x0000, "arm_repair_attempt" },
{ 0x0000, "armada_intro_screen" },
{ 0x0000, "armed" },
{ 0x0000, "armordamagehints" },
{ 0x0000, "armorpiercingmod" },
{ 0x0000, "armorvestmod" },
{ 0x0000, "armorygiveexoability" },
{ 0x0000, "armorypoints" },
{ 0x0000, "armorypurchasefail" },
{ 0x0000, "armorythink" },
{ 0x0000, "array" },
{ 0x0000, "array_2dadd" },
{ 0x0000, "array_add" },
{ 0x0000, "array_call" },
{ 0x0000, "array_checkaddattachment" },
{ 0x0000, "array_combine" },
{ 0x0000, "array_combine_all" },
{ 0x0000, "array_combine_keys" },
{ 0x0000, "array_combine_multiple" },
{ 0x0000, "array_combine_non_integer_indices" },
{ 0x0000, "array_combine_unique" },
{ 0x0000, "array_compare" },
{ 0x0000, "array_contains" },
{ 0x0000, "array_delete" },
{ 0x0000, "array_delete_evenly" },
{ 0x0000, "array_exclude" },
{ 0x0000, "array_find" },
{ 0x0000, "array_first" },
{ 0x0000, "array_index_by_classname" },
{ 0x0000, "array_index_by_parameters" },
{ 0x0000, "array_index_by_script_index" },
{ 0x0000, "array_insert" },
{ 0x0000, "array_kill" },
{ 0x0000, "array_levelcall" },
{ 0x0000, "array_levelthread" },
{ 0x0000, "array_levelthread_safe" },
{ 0x0000, "array_merge" },
{ 0x0000, "array_merge_links" },
{ 0x0000, "array_notify" },
{ 0x0000, "array_randomize" },
{ 0x0000, "array_remove" },
{ 0x0000, "array_remove_array" },
{ 0x0000, "array_remove_dead" },
{ 0x0000, "array_remove_duplicates" },
{ 0x0000, "array_remove_index" },
{ 0x0000, "array_remove_nokeys" },
{ 0x0000, "array_removeclaimedtargets" },
{ 0x0000, "array_removedead" },
{ 0x0000, "array_removedead_keepkeys" },
{ 0x0000, "array_removedead_or_dying" },
{ 0x0000, "array_removefirstinqueue" },
{ 0x0000, "array_removeundefined" },
{ 0x0000, "array_reverse" },
{ 0x0000, "array_safe_delete" },
{ 0x0000, "array_setgoalvolume" },
{ 0x0000, "array_sort_by_handler" },
{ 0x0000, "array_sort_with_func" },
{ 0x0000, "array_sound_start" },
{ 0x0000, "array_spawn" },
{ 0x0000, "array_spawn_allow_fail" },
{ 0x0000, "array_spawn_cg" },
{ 0x0000, "array_spawn_function" },
{ 0x0000, "array_spawn_function_noteworthy" },
{ 0x0000, "array_spawn_function_targetname" },
{ 0x0000, "array_spawn_noteworthy" },
{ 0x0000, "array_spawn_targetname" },
{ 0x0000, "array_spawn_targetname_allow_fail" },
{ 0x0000, "array_spawn_targetname_cg" },
{ 0x0000, "array_spawn_targetname_stagger" },
{ 0x0000, "array_thread" },
{ 0x0000, "array_thread_mod_delayed" },
{ 0x0000, "array_thread_safe" },
{ 0x0000, "array_thread4" },
{ 0x0000, "array_thread5" },
{ 0x0000, "array_wait" },
{ 0x0000, "array_waitlogic1" },
{ 0x0000, "array_waitlogic2" },
{ 0x0000, "array_waittill_player_lookat" },
{ 0x0000, "array_waittill_player_lookat_proc" },
{ 0x0000, "arrayinsertion" },
{ 0x0000, "arrayremovevalue" },
{ 0x0000, "arrays_color_spawners" },
{ 0x0000, "arrays_of_colorcoded_nodes" },
{ 0x0000, "arrays_of_colorcoded_volumes" },
{ 0x0000, "arrays_of_colorforced_ai" },
{ 0x0000, "arrivalanim" },
{ 0x0000, "arrivalendstance" },
{ 0x0000, "arrivalnodetype" },
{ 0x0000, "arrivalpathgoalpos" },
{ 0x0000, "arrivalstance" },
{ 0x0000, "arrivalstartdist" },
{ 0x0000, "arrivaltype" },
{ 0x0000, "arrive" },
{ 0x0000, "art_print_fog" },
{ 0x0000, "artendfogfileexport" },
{ 0x0000, "artendvisionfileexport" },
{ 0x0000, "artfxprintlnfog" },
{ 0x0000, "artifact_pulse" },
{ 0x0000, "artifacts" },
{ 0x0000, "artifacts_fade" },
{ 0x0000, "artillery_earthquake" },
{ 0x0000, "artillerydangercenters" },
{ 0x0000, "artilleryshellshock" },
{ 0x0000, "artstartfogfileexport" },
{ 0x0000, "artstartvisionfileexport" },
{ 0x0000, "assault_drone_stinger_target_pos" },
{ 0x0000, "assault_vehicle_ai_aerial_follow_path_o"... },
{ 0x0000, "assault_vehicle_ai_aerial_movement" },
{ 0x0000, "assault_vehicle_ai_aerial_pathing_c4" },
{ 0x0000, "assault_vehicle_ai_aerial_pathing_turre"... },
{ 0x0000, "assault_vehicle_ai_air_movement_func" },
{ 0x0000, "assault_vehicle_ai_can_see_living_enemy" },
{ 0x0000, "assault_vehicle_ai_end_on_owner_disconn"... },
{ 0x0000, "assault_vehicle_ai_enemy_exists_and_is_"... },
{ 0x0000, "assault_vehicle_ai_enemy_moved_air" },
{ 0x0000, "assault_vehicle_ai_enemy_moved_ground" },
{ 0x0000, "assault_vehicle_ai_follow_path" },
{ 0x0000, "assault_vehicle_ai_get_camera_position" },
{ 0x0000, "assault_vehicle_ai_get_nearest_node" },
{ 0x0000, "assault_vehicle_ai_ground_movement" },
{ 0x0000, "assault_vehicle_ai_ground_movement_loop" },
{ 0x0000, "assault_vehicle_ai_init" },
{ 0x0000, "assault_vehicle_ai_move_to_aerial_node" },
{ 0x0000, "assault_vehicle_ai_path_timeout_time" },
{ 0x0000, "assault_vehicle_ai_pick_aerial_node" },
{ 0x0000, "assault_vehicle_ai_threat" },
{ 0x0000, "assault_vehicle_ai_weapons" },
{ 0x0000, "assaultfullstaticondeath" },
{ 0x0000, "assaulthandledeath" },
{ 0x0000, "assaulthandletimeoutwarning" },
{ 0x0000, "assaulthudremove" },
{ 0x0000, "assaulthudsetup" },
{ 0x0000, "assaultobjectiveevent" },
{ 0x0000, "assaultplayerexit" },
{ 0x0000, "assaultsetinactivity" },
{ 0x0000, "assaultvehiclemonitorweapons" },
{ 0x0000, "assert_existance_of_anim" },
{ 0x0000, "assert_existance_of_anim_vm" },
{ 0x0000, "assert_existance_of_looping_anim" },
{ 0x0000, "assert_if_anim_not_defined" },
{ 0x0000, "assert_if_identical_origins" },
{ 0x0000, "assertdisplayed" },
{ 0x0000, "assertdisplayed_b" },
{ 0x0000, "asset_name" },
{ 0x0000, "asset_names" },
{ 0x0000, "asset_type" },
{ 0x0000, "assign_animals_tree" },
{ 0x0000, "assign_animtree" },
{ 0x0000, "assign_cloak_model" },
{ 0x0000, "assign_drone_tree" },
{ 0x0000, "assign_fx_to_trigger" },
{ 0x0000, "assign_generic_human_tree" },
{ 0x0000, "assign_goal_node" },
{ 0x0000, "assign_goal_vol" },
{ 0x0000, "assign_model" },
{ 0x0000, "assign_nodes_to_zipline_guys" },
{ 0x0000, "assign_npcid" },
{ 0x0000, "assign_script_breachgroup_to_ents" },
{ 0x0000, "assign_spawns" },
{ 0x0000, "assign_spawns_version_2" },
{ 0x0000, "assign_spawns_version_3" },
{ 0x0000, "assign_unique_id" },
{ 0x0000, "assignawards" },
{ 0x0000, "assigned_brush" },
{ 0x0000, "assigned_model" },
{ 0x0000, "assigned_model_b" },
{ 0x0000, "assigned_parent" },
{ 0x0000, "assignpracticeroundclasses" },
{ 0x0000, "assignteamspawns" },
{ 0x0000, "assistedsuicide" },
{ 0x0000, "assistedsuicideevent" },
{ 0x0000, "assistplayer" },
{ 0x0000, "assistpoints" },
{ 0x0000, "assists_disabled" },
{ 0x0000, "ast_mus_on" },
{ 0x0000, "at_goal" },
{ 0x0000, "at_path_end" },
{ 0x0000, "at_rest" },
{ 0x0000, "at_start" },
{ 0x0000, "at_van_enemy_cleanup" },
{ 0x0000, "atbrinkofdeath" },
{ 0x0000, "atconcealmentnode" },
{ 0x0000, "atk_bomber" },
{ 0x0000, "atk_bomber_no_path_to_bomb_count" },
{ 0x0000, "atk_bomber_update" },
{ 0x0000, "atlas_base_weapon_manager" },
{ 0x0000, "atlas_base_weapon_manager_elevator" },
{ 0x0000, "atlas_building_roof_walla" },
{ 0x0000, "atlas_drone_damage_function" },
{ 0x0000, "atlas_guard" },
{ 0x0000, "atlas_guard_dialogue_line1" },
{ 0x0000, "atlas_guard1" },
{ 0x0000, "atlas_guard2" },
{ 0x0000, "atlas_guard3" },
{ 0x0000, "atlas_guard4" },
{ 0x0000, "atlas_guard5" },
{ 0x0000, "atlas_guard6" },
{ 0x0000, "atlas_guard7" },
{ 0x0000, "atlas_intercepts" },
{ 0x0000, "atlas_sign_flicker" },
{ 0x0000, "atlas_suv_impact_fx" },
{ 0x0000, "atlas_suv_rider_no_react" },
{ 0x0000, "atlas_suv_rider_react" },
{ 0x0000, "atlas_suv_rider_think" },
{ 0x0000, "atlas_van_explode" },
{ 0x0000, "atlas1" },
{ 0x0000, "atlas2" },
{ 0x0000, "atlascard_cormack_walk" },
{ 0x0000, "atlascard_irons_grab_card" },
{ 0x0000, "atlascard_irons_handshake" },
{ 0x0000, "atlascard_irons_leave" },
{ 0x0000, "atlascard_irons_place_hand" },
{ 0x0000, "atlascard_irons_tap" },
{ 0x0000, "atlascard_irons_turn" },
{ 0x0000, "atlascard_irons_walk" },
{ 0x0000, "atlasdrn_condition_callback_to_state_de"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_de"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_di"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_fl"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_fl"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_fl"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_ho"... },
{ 0x0000, "atlasdrn_condition_callback_to_state_of"... },
{ 0x0000, "atlasdrn_lens_focus" },
{ 0x0000, "atm_is_muted" },
{ 0x0000, "atm_max_off_time" },
{ 0x0000, "atm_max_on_time" },
{ 0x0000, "atm_mute_time" },
{ 0x0000, "atm_off_time" },
{ 0x0000, "atmosfogdistancescale" },
{ 0x0000, "atmosfogenabled" },
{ 0x0000, "atmosfogextinctionstrength" },
{ 0x0000, "atmosfoghalfplanedistance" },
{ 0x0000, "atmosfoghazecolor" },
{ 0x0000, "atmosfoghazespread" },
{ 0x0000, "atmosfoghazestrength" },
{ 0x0000, "atmosfogheightfogbaseheight" },
{ 0x0000, "atmosfogheightfogenabled" },
{ 0x0000, "atmosfogheightfoghalfplanedistance" },
{ 0x0000, "atmosfoginscatterstrength" },
{ 0x0000, "atmosfogskyangularfalloffenabled" },
{ 0x0000, "atmosfogskydistance" },
{ 0x0000, "atmosfogskyfalloffanglerange" },
{ 0x0000, "atmosfogskyfalloffstartangle" },
{ 0x0000, "atmosfogstartdistance" },
{ 0x0000, "atmosfogsundirection" },
{ 0x0000, "atmosfogsunfogcolor" },
{ 0x0000, "atrium_breach_signal_start" },
{ 0x0000, "atrium_timer_expire" },
{ 0x0000, "atriumanimations" },
{ 0x0000, "atriumboostjump" },
{ 0x0000, "atriumboostjumpguy" },
{ 0x0000, "atriumbreachexplosionnotetrack" },
{ 0x0000, "atriumbreachidle" },
{ 0x0000, "atriumbreachidleburke" },
{ 0x0000, "atriumbreachidleinfiltrators" },
{ 0x0000, "atriumbreachmonitoralliesinposition" },
{ 0x0000, "atriumdoorbreachdamage" },
{ 0x0000, "atriumdoorsopen" },
{ 0x0000, "atriumdoorsopenonalarm" },
{ 0x0000, "atriumlookatdialogue" },
{ 0x0000, "atriumreminderdialogue" },
{ 0x0000, "atriumsetupdialogue" },
{ 0x0000, "atriumshootfirstdialogue" },
{ 0x0000, "atriumtimer" },
{ 0x0000, "atriumtimewindow" },
{ 0x0000, "atrrestoremech" },
{ 0x0000, "attach_assault_drone_lights" },
{ 0x0000, "attach_bone" },
{ 0x0000, "attach_cig" },
{ 0x0000, "attach_cig_self" },
{ 0x0000, "attach_clip" },
{ 0x0000, "attach_ent" },
{ 0x0000, "attach_fixed_scanner" },
{ 0x0000, "attach_flashlight_in_hand" },
{ 0x0000, "attach_flashlight_on_gun" },
{ 0x0000, "attach_flashlight_on_vehicle_unload" },
{ 0x0000, "attach_fx_to_mechanism" },
{ 0x0000, "attach_housing" },
{ 0x0000, "attach_light_to_face" },
{ 0x0000, "attach_light_to_police_car" },
{ 0x0000, "attach_littlebird_parts" },
{ 0x0000, "attach_model_override" },
{ 0x0000, "attach_or_link" },
{ 0x0000, "attach_phone" },
{ 0x0000, "attach_player_current_weapon_to_anim_ta"... },
{ 0x0000, "attach_player_current_weapon_to_rig" },
{ 0x0000, "attach_pointlight_to_beam" },
{ 0x0000, "attach_scanner" },
{ 0x0000, "attach_scanner_turret" },
{ 0x0000, "attach_tag" },
{ 0x0000, "attach_wakefx" },
{ 0x0000, "attach_weapon_to_tag_sync" },
{ 0x0000, "attachdistortionfx" },
{ 0x0000, "attachedguys" },
{ 0x0000, "attachedmodels" },
{ 0x0000, "attachedpath" },
{ 0x0000, "attachedpropmodel" },
{ 0x0000, "attachedproptag" },
{ 0x0000, "attachedusemodel" },
{ 0x0000, "attachflag" },
{ 0x0000, "attachgrenademodel" },
{ 0x0000, "attachhat" },
{ 0x0000, "attachhead" },
{ 0x0000, "attachmentdeath" },
{ 0x0000, "attachmentexplode" },
{ 0x0000, "attachmentmap_attachtoperk" },
{ 0x0000, "attachmentmap_basetounique" },
{ 0x0000, "attachmentmap_tobase" },
{ 0x0000, "attachmentmap_tounique" },
{ 0x0000, "attachmentmap_uniquetobase" },
{ 0x0000, "attachmentperkmap" },
{ 0x0000, "attachmenttype" },
{ 0x0000, "attachmissiles" },
{ 0x0000, "attachmodelti" },
{ 0x0000, "attachprops" },
{ 0x0000, "attachpropsfunction" },
{ 0x0000, "attachusemodel" },
{ 0x0000, "attachweapon" },
{ 0x0000, "attack_accuracy" },
{ 0x0000, "attack_available" },
{ 0x0000, "attack_behavior" },
{ 0x0000, "attack_damage_trigger" },
{ 0x0000, "attack_delay" },
{ 0x0000, "attack_drone_audio_handler" },
{ 0x0000, "attack_drone_flybys_audio" },
{ 0x0000, "attack_drone_formation_init" },
{ 0x0000, "attack_drone_init" },
{ 0x0000, "attack_drone_kamikaze_audio" },
{ 0x0000, "attack_drone_kamikaze_flying_fx" },
{ 0x0000, "attack_drone_queen_1shot_handler" },
{ 0x0000, "attack_drone_queen_audio" },
{ 0x0000, "attack_drone_queen_flybys_audio" },
{ 0x0000, "attack_drone_queen_flying_fx" },
{ 0x0000, "attack_drones_nofly_zone_radius" },
{ 0x0000, "attack_drones_num_drones_per_queen" },
{ 0x0000, "attack_drones_num_queens" },
{ 0x0000, "attack_heli_cleanup" },
{ 0x0000, "attack_heli_fx" },
{ 0x0000, "attack_heli_safe_volumes" },
{ 0x0000, "attack_hint_display" },
{ 0x0000, "attack_if_buddy_killed" },
{ 0x0000, "attack_origin_condition_threadd" },
{ 0x0000, "attack_player_for_time" },
{ 0x0000, "attack_sight_required" },
{ 0x0000, "attackback" },
{ 0x0000, "attacked_by_dog" },
{ 0x0000, "attacker_isonmyteam" },
{ 0x0000, "attacker_troop_isonmyteam" },
{ 0x0000, "attackercandamageitem" },
{ 0x0000, "attackerdata" },
{ 0x0000, "attackerent" },
{ 0x0000, "attackerinlaststand" },
{ 0x0000, "attackerinremotekillstreak" },
{ 0x0000, "attackerishittingteam" },
{ 0x0000, "attackerlist" },
{ 0x0000, "attackeronground" },
{ 0x0000, "attackerposition" },
{ 0x0000, "attackers" },
{ 0x0000, "attackerstance" },
{ 0x0000, "attackertable" },
{ 0x0000, "attackheliaiburstsize" },
{ 0x0000, "attackheliexcluders" },
{ 0x0000, "attackhelifov" },
{ 0x0000, "attackheligraceperiod" },
{ 0x0000, "attackhelikillsai" },
{ 0x0000, "attackhelimemory" },
{ 0x0000, "attackhelimovetime" },
{ 0x0000, "attackheliplayerbreak" },
{ 0x0000, "attackhelirange" },
{ 0x0000, "attackhelitargetreaquire" },
{ 0x0000, "attackhelitimeout" },
{ 0x0000, "attacking_player" },
{ 0x0000, "attackmiss" },
{ 0x0000, "attackmisstracktargetthread" },
{ 0x0000, "attacknode" },
{ 0x0000, "attacknothingtodo" },
{ 0x0000, "attackoffset" },
{ 0x0000, "attackradius" },
{ 0x0000, "attackradiussq" },
{ 0x0000, "attackstate" },
{ 0x0000, "attacksuppressableenemy" },
{ 0x0000, "attackteleportthread" },
{ 0x0000, "attackvisibleenemy" },
{ 0x0000, "attackzheight" },
{ 0x0000, "attackzheightdown" },
{ 0x0000, "attempt_execute" },
{ 0x0000, "attempt_mark_enemy" },
{ 0x0000, "attract_range" },
{ 0x0000, "attract_strength" },
{ 0x0000, "attractor" },
{ 0x0000, "attractor2" },
{ 0x0000, "attractornumber" },
{ 0x0000, "aud" },
{ 0x0000, "aud_2b_missile_final" },
{ 0x0000, "aud_2b_missile1" },
{ 0x0000, "aud_2b_missile2" },
{ 0x0000, "aud_2b_missile3" },
{ 0x0000, "aud_ac_units" },
{ 0x0000, "aud_add_progress_map" },
{ 0x0000, "aud_alarm_submix" },
{ 0x0000, "aud_ally_card_accept" },
{ 0x0000, "aud_ally_card_error" },
{ 0x0000, "aud_ally_card_swipe" },
{ 0x0000, "aud_ambient_animations" },
{ 0x0000, "aud_ambient_helicopter" },
{ 0x0000, "aud_approaching_poolhouse" },
{ 0x0000, "aud_ascent_final_warbird" },
{ 0x0000, "aud_atlas_suv_explo" },
{ 0x0000, "aud_autopsy_entrance" },
{ 0x0000, "aud_autopsy_entrance_vo" },
{ 0x0000, "aud_autopsy_knife_pry_door" },
{ 0x0000, "aud_avs_enemy_warbird" },
{ 0x0000, "aud_avs_enemy_warbird_2" },
{ 0x0000, "aud_avs_enemy_warbird_grapple" },
{ 0x0000, "aud_avs_intro_allies_1" },
{ 0x0000, "aud_avs_intro_allies_2" },
{ 0x0000, "aud_background_chatter" },
{ 0x0000, "aud_background_chatter_gate" },
{ 0x0000, "aud_balcony_aircraft_wait" },
{ 0x0000, "aud_ball_fountain" },
{ 0x0000, "aud_bet_exo_climb_gear_lt" },
{ 0x0000, "aud_bet_exo_climb_gear_rt" },
{ 0x0000, "aud_bet_exo_climb_hit_lt" },
{ 0x0000, "aud_bet_exo_climb_hit_rt" },
{ 0x0000, "aud_bet_exo_climb_settle_lt" },
{ 0x0000, "aud_bet_exo_climb_settle_rt" },
{ 0x0000, "aud_bet_exo_climb_windup_lt" },
{ 0x0000, "aud_bet_exo_climb_windup_rt" },
{ 0x0000, "aud_big_gate_open_stage_1" },
{ 0x0000, "aud_big_gate_open_stage_2" },
{ 0x0000, "aud_big_gate_pre_open" },
{ 0x0000, "aud_big_gate_stop_stage_1" },
{ 0x0000, "aud_big_gate_stop_stage_2" },
{ 0x0000, "aud_briefing" },
{ 0x0000, "aud_building_drop" },
{ 0x0000, "aud_building_pre_drop" },
{ 0x0000, "aud_burke_bus1_land" },
{ 0x0000, "aud_burke_hill_slide_stump" },
{ 0x0000, "aud_burke_intro_anim" },
{ 0x0000, "aud_burke_ledge_jump" },
{ 0x0000, "aud_burke_nearing_cliff" },
{ 0x0000, "aud_burke_open_door" },
{ 0x0000, "aud_burke_river_over_log" },
{ 0x0000, "aud_burke_riverbank_footstep_left" },
{ 0x0000, "aud_burke_riverbank_footstep_right" },
{ 0x0000, "aud_burke_riverbank_slide" },
{ 0x0000, "aud_burke_step_over_log" },
{ 0x0000, "aud_burke_stumble_knee" },
{ 0x0000, "aud_burke_stumble_run" },
{ 0x0000, "aud_burke_takedown" },
{ 0x0000, "aud_burke_tree_cover_01" },
{ 0x0000, "aud_burke_wall_climb" },
{ 0x0000, "aud_burke_water_deep_step" },
{ 0x0000, "aud_burke_water_enter" },
{ 0x0000, "aud_burke_water_exit" },
{ 0x0000, "aud_burke_water_fall_forward" },
{ 0x0000, "aud_burke_water_footstep_left" },
{ 0x0000, "aud_burke_water_footstep_right" },
{ 0x0000, "aud_burke_water_jump" },
{ 0x0000, "aud_burke_water_shallow_step" },
{ 0x0000, "aud_burke_water_slip" },
{ 0x0000, "aud_cap_45_onearm_toss" },
{ 0x0000, "aud_cap_escape_to_heli_truck_1" },
{ 0x0000, "aud_cap_escape_to_heli_truck_2" },
{ 0x0000, "aud_cap_heli_sfx_01" },
{ 0x0000, "aud_cap_heli_sfx_02" },
{ 0x0000, "aud_cap_heli_sfx_03" },
{ 0x0000, "aud_cap_heli_sfx_04" },
{ 0x0000, "aud_cap_heli_sfx_05" },
{ 0x0000, "aud_cap_heli_sfx_06" },
{ 0x0000, "aud_cap_interrogation_transition_vo" },
{ 0x0000, "aud_cap_s2_trolley_sfx_01" },
{ 0x0000, "aud_cap_s2_trolley_sfx_02" },
{ 0x0000, "aud_cap_s2_trolley_sfx_03" },
{ 0x0000, "aud_cap_s2_trolley_sfx_03_crk" },
{ 0x0000, "aud_cap_s2_trolley_sfx_04" },
{ 0x0000, "aud_cap_s2_trolley_sfx_05" },
{ 0x0000, "aud_cap_s2_trolley_sfx_06" },
{ 0x0000, "aud_cap_s2_trolley_sfx_07" },
{ 0x0000, "aud_cap_s2_trolley_sfx_08" },
{ 0x0000, "aud_cap_s2_trolley_sfx_09" },
{ 0x0000, "aud_cap_s2_trolley_sfx_10" },
{ 0x0000, "aud_cap_sml_onearm_toss" },
{ 0x0000, "aud_captured_foley_override_handler" },
{ 0x0000, "aud_captured_setup_anims" },
{ 0x0000, "aud_cave_ambience" },
{ 0x0000, "aud_cave_cascade" },
{ 0x0000, "aud_check_sound_done" },
{ 0x0000, "aud_chopper_sniper_bullet" },
{ 0x0000, "aud_chopper_sniper_whizby" },
{ 0x0000, "aud_clamp" },
{ 0x0000, "aud_clear_sticky_threat" },
{ 0x0000, "aud_close_sounds" },
{ 0x0000, "aud_combat_clearing_1_warbird" },
{ 0x0000, "aud_combat_clearing_2_littlebird_1" },
{ 0x0000, "aud_combat_clearing_2_littlebird_2" },
{ 0x0000, "aud_combat_clearing_3_littlebird_1" },
{ 0x0000, "aud_combat_clearing_3_littlebird_2" },
{ 0x0000, "aud_conduit_smash" },
{ 0x0000, "aud_copy_vector" },
{ 0x0000, "aud_cormack_approach" },
{ 0x0000, "aud_cormack_final_monitor_smash" },
{ 0x0000, "aud_cormack_final_smash_promo" },
{ 0x0000, "aud_cormack_grapple_kill" },
{ 0x0000, "aud_cormack_monitor_smash_promo" },
{ 0x0000, "aud_cormack_rappel_cable" },
{ 0x0000, "aud_courtyard_hangar_door_close" },
{ 0x0000, "aud_courtyard_hangar_door_hack" },
{ 0x0000, "aud_courtyard_hangar_door_hack_idle" },
{ 0x0000, "aud_courtyard_hangar_door_open" },
{ 0x0000, "aud_crane_mount_crouch_jump" },
{ 0x0000, "aud_crane_mount_lt_hand_hit" },
{ 0x0000, "aud_crane_mount_lt_hand_rest" },
{ 0x0000, "aud_crane_mount_rt_hand_hit" },
{ 0x0000, "aud_crane_mount_rt_hand_rest" },
{ 0x0000, "aud_crash_wakeup_sfx" },
{ 0x0000, "aud_create_drive_envs" },
{ 0x0000, "aud_create_entity" },
{ 0x0000, "aud_create_linked_entity" },
{ 0x0000, "aud_ctyard_vrap01" },
{ 0x0000, "aud_ctyard_vrap02" },
{ 0x0000, "aud_ctyard_vrap04" },
{ 0x0000, "aud_ctyard_vrap05" },
{ 0x0000, "aud_delete_on_sounddone" },
{ 0x0000, "aud_destroy_deployed_pod" },
{ 0x0000, "aud_det_foley_override_handler" },
{ 0x0000, "aud_detach_from_vtol" },
{ 0x0000, "aud_disable_deathsdoor_audio" },
{ 0x0000, "aud_dna_bomb_01" },
{ 0x0000, "aud_dna_bomb_02" },
{ 0x0000, "aud_door" },
{ 0x0000, "aud_door_takedown_mix_handler" },
{ 0x0000, "aud_door_takedown_scream" },
{ 0x0000, "aud_drone_attack" },
{ 0x0000, "aud_drone_investigating" },
{ 0x0000, "aud_drone_start_jets" },
{ 0x0000, "aud_drone_view_intro_start" },
{ 0x0000, "aud_drone_view_intro_target" },
{ 0x0000, "aud_drop_pod_fire" },
{ 0x0000, "aud_drop_pod_land_fail" },
{ 0x0000, "aud_drop_pod_land_success" },
{ 0x0000, "aud_drop_pod_trophy_kill" },
{ 0x0000, "aud_duck" },
{ 0x0000, "aud_dyanmic_event" },
{ 0x0000, "aud_dynamic_event_startup" },
{ 0x0000, "aud_enable_deathsdoor_audio" },
{ 0x0000, "aud_engine_disable" },
{ 0x0000, "aud_engine_throttle_amount" },
{ 0x0000, "aud_engine_wait" },
{ 0x0000, "aud_enter_vtol" },
{ 0x0000, "aud_escape_doctor_bodybag" },
{ 0x0000, "aud_escape_give_gun_exo" },
{ 0x0000, "aud_escape_guard_takedown_door" },
{ 0x0000, "aud_escape_keycard" },
{ 0x0000, "aud_estate_grounds_ambience" },
{ 0x0000, "aud_estate_grounds_emitters" },
{ 0x0000, "aud_estate_living_ambience" },
{ 0x0000, "aud_estate_security_ambience" },
{ 0x0000, "aud_exfil_door_1" },
{ 0x0000, "aud_exfil_door_2a" },
{ 0x0000, "aud_exfil_door_2b" },
{ 0x0000, "aud_exfil_vtol_ascend" },
{ 0x0000, "aud_exfil_vtol_grapple" },
{ 0x0000, "aud_exfil_vtol_start" },
{ 0x0000, "aud_exfil_vtol_wind" },
{ 0x0000, "aud_exit_vtol" },
{ 0x0000, "aud_exo_climb_burke" },
{ 0x0000, "aud_exo_climb_flank_land" },
{ 0x0000, "aud_exo_climb_flank_over" },
{ 0x0000, "aud_exo_climb_gear_lt" },
{ 0x0000, "aud_exo_climb_gear_rt" },
{ 0x0000, "aud_exo_climb_gideon_land" },
{ 0x0000, "aud_exo_climb_hit_lt" },
{ 0x0000, "aud_exo_climb_hit_rt" },
{ 0x0000, "aud_exo_climb_mount_jump" },
{ 0x0000, "aud_exo_climb_mount_land" },
{ 0x0000, "aud_exo_climb_rest_lt" },
{ 0x0000, "aud_exo_climb_rest_rt" },
{ 0x0000, "aud_exo_climb_slide_push" },
{ 0x0000, "aud_exo_climb_slide_start" },
{ 0x0000, "aud_exo_climb_slide_stop" },
{ 0x0000, "aud_exo_climb_windup_lt" },
{ 0x0000, "aud_exo_climb_windup_rt" },
{ 0x0000, "aud_facility_breach_start" },
{ 0x0000, "aud_fade_in" },
{ 0x0000, "aud_fade_in_music" },
{ 0x0000, "aud_fade_loop_out_and_delete" },
{ 0x0000, "aud_fade_loop_out_and_delete_temp" },
{ 0x0000, "aud_fade_out" },
{ 0x0000, "aud_fade_out_and_delete" },
{ 0x0000, "aud_fadeup_intro_loop" },
{ 0x0000, "aud_fall_scream" },
{ 0x0000, "aud_falls_climbing" },
{ 0x0000, "aud_fin_rocket_damage_vfx" },
{ 0x0000, "aud_find_exploder" },
{ 0x0000, "aud_flag_handler" },
{ 0x0000, "aud_foam_room_emitters" },
{ 0x0000, "aud_foliage_insects" },
{ 0x0000, "aud_foliage_mix" },
{ 0x0000, "aud_foliage_movement" },
{ 0x0000, "aud_forest_ambience" },
{ 0x0000, "aud_forest_ambient_loops" },
{ 0x0000, "aud_fountains" },
{ 0x0000, "aud_garage_hyd_wrench" },
{ 0x0000, "aud_garage_lift" },
{ 0x0000, "aud_gas_sfx" },
{ 0x0000, "aud_get_ambi_submix" },
{ 0x0000, "aud_get_envelope_domain" },
{ 0x0000, "aud_get_music_submix" },
{ 0x0000, "aud_get_optional_param" },
{ 0x0000, "aud_get_player_locamote_state" },
{ 0x0000, "aud_get_progress_map" },
{ 0x0000, "aud_get_sticky_threat" },
{ 0x0000, "aud_get_threat_level" },
{ 0x0000, "aud_gideon_autopsy_halls_start" },
{ 0x0000, "aud_gideon_heli_runout_kick" },
{ 0x0000, "aud_gideon_heli_runout_start" },
{ 0x0000, "aud_gideon_test_chamber_ascend_start" },
{ 0x0000, "aud_gideon_test_chamber_bodybag_1" },
{ 0x0000, "aud_gideon_test_chamber_bodybag_2" },
{ 0x0000, "aud_gideon_test_chamber_climb_stairs_1" },
{ 0x0000, "aud_gideon_test_chamber_climb_stairs_2" },
{ 0x0000, "aud_gideon_test_chamber_descend_stairs" },
{ 0x0000, "aud_gideon_test_chamber_descend_stairs_"... },
{ 0x0000, "aud_gideon_test_chamber_door_kick" },
{ 0x0000, "aud_gideon_test_chamber_security" },
{ 0x0000, "aud_gideon_test_chamber_stair_door" },
{ 0x0000, "aud_grapple_from_foliage" },
{ 0x0000, "aud_grapple_infil" },
{ 0x0000, "aud_grapple_kill_foliage" },
{ 0x0000, "aud_grapple_land_debris" },
{ 0x0000, "aud_grapple_launch" },
{ 0x0000, "aud_grapple_monitor" },
{ 0x0000, "aud_grates" },
{ 0x0000, "aud_ground_veh_deathwatch" },
{ 0x0000, "aud_ground_veh_loops" },
{ 0x0000, "aud_ground_veh_speed_mapping" },
{ 0x0000, "aud_guard_station_ambience" },
{ 0x0000, "aud_guard_station_main_door" },
{ 0x0000, "aud_guardhouse_foley_cormack" },
{ 0x0000, "aud_gun_throw_logic" },
{ 0x0000, "aud_handle_alarms" },
{ 0x0000, "aud_handle_buoy_sfx" },
{ 0x0000, "aud_handle_clearing_dambs" },
{ 0x0000, "aud_handle_earthquake" },
{ 0x0000, "aud_handle_gangam_jets" },
{ 0x0000, "aud_handle_incoming" },
{ 0x0000, "aud_handle_map_setups" },
{ 0x0000, "aud_handle_river_progress_flags" },
{ 0x0000, "aud_handle_river_sfx" },
{ 0x0000, "aud_handle_river_shallow_flag" },
{ 0x0000, "aud_handle_so_missile" },
{ 0x0000, "aud_handle_vista_jets" },
{ 0x0000, "aud_handle_warning_vo" },
{ 0x0000, "aud_handle_wave_incoming" },
{ 0x0000, "aud_handle_waves_crash" },
{ 0x0000, "aud_hangar_ambience" },
{ 0x0000, "aud_hangar_car_door_exit" },
{ 0x0000, "aud_hangar_door_exit" },
{ 0x0000, "aud_hangar_door_open" },
{ 0x0000, "aud_hangar_walla" },
{ 0x0000, "aud_hatch_gideon" },
{ 0x0000, "aud_hatch_plr" },
{ 0x0000, "aud_hazmat_guy_foley" },
{ 0x0000, "aud_hazmat_guy_pushes_alarm" },
{ 0x0000, "aud_heli_battle_flyover" },
{ 0x0000, "aud_heli_crash_pos" },
{ 0x0000, "aud_heli_escape_idle_sfx" },
{ 0x0000, "aud_heli_manticore_flyover" },
{ 0x0000, "aud_helicopter_deathwatch" },
{ 0x0000, "aud_helo_spotlight_spawn" },
{ 0x0000, "aud_hostage_truck_hits_water" },
{ 0x0000, "aud_hostage_truck_over_curb" },
{ 0x0000, "aud_hostage_truck_over_edge" },
{ 0x0000, "aud_hostage_truck_tbone" },
{ 0x0000, "aud_human_activity_streams" },
{ 0x0000, "aud_ilana_carmack_escape_controlroom" },
{ 0x0000, "aud_ilana_carmack_escape_controlroom_at"... },
{ 0x0000, "aud_ilana_carmack_escape_hallway" },
{ 0x0000, "aud_ilana_carmack_escape_hallway_end" },
{ 0x0000, "aud_ilana_carmack_escape_takedown" },
{ 0x0000, "aud_ilana_carmack_rescue_01" },
{ 0x0000, "aud_impact_monitor" },
{ 0x0000, "aud_impact_system_diveboat" },
{ 0x0000, "aud_impact_system_hovertank" },
{ 0x0000, "aud_impact_system_jetbike" },
{ 0x0000, "aud_in_zone" },
{ 0x0000, "aud_incin_after" },
{ 0x0000, "aud_incin_after_loop1" },
{ 0x0000, "aud_incin_amb_kill" },
{ 0x0000, "aud_incin_blackout" },
{ 0x0000, "aud_incin_cart_done" },
{ 0x0000, "aud_incin_cart_push" },
{ 0x0000, "aud_incin_cart_push_stop" },
{ 0x0000, "aud_incin_cart_start" },
{ 0x0000, "aud_incin_flame_logic_first_burst" },
{ 0x0000, "aud_incin_flame_loop" },
{ 0x0000, "aud_incin_flame_loop_2" },
{ 0x0000, "aud_incin_pilot_light" },
{ 0x0000, "aud_incin_pilot_light1" },
{ 0x0000, "aud_incin_pilot_light2" },
{ 0x0000, "aud_incin_pilot_light3" },
{ 0x0000, "aud_incin_pilot_light4" },
{ 0x0000, "aud_incin_pilot_light5" },
{ 0x0000, "aud_incin_pipe_burst" },
{ 0x0000, "aud_incin_pipe_grab" },
{ 0x0000, "aud_init" },
{ 0x0000, "aud_insect_sound" },
{ 0x0000, "aud_intel" },
{ 0x0000, "aud_interrogation_music_pt1" },
{ 0x0000, "aud_interrogation_music_pt2" },
{ 0x0000, "aud_interrogation_scene" },
{ 0x0000, "aud_into_mech_missle" },
{ 0x0000, "aud_intro_caravan_mute" },
{ 0x0000, "aud_intro_caravan_passby" },
{ 0x0000, "aud_intro_caravan_unmute" },
{ 0x0000, "aud_intro_drone" },
{ 0x0000, "aud_intro_foley" },
{ 0x0000, "aud_intro_heli_flyover" },
{ 0x0000, "aud_intro_to_elev_walla" },
{ 0x0000, "aud_intro_truck_gate" },
{ 0x0000, "aud_intro_truck_passby_01" },
{ 0x0000, "aud_intro_truck_passby_02" },
{ 0x0000, "aud_intro_truck_stop" },
{ 0x0000, "aud_introblack_bullet" },
{ 0x0000, "aud_irons_reveal_bomb_shake" },
{ 0x0000, "aud_irons_reveal_bomb_shake_02" },
{ 0x0000, "aud_irons_reveal_star_trek_door" },
{ 0x0000, "aud_irons_says_hello" },
{ 0x0000, "aud_ironsstealth" },
{ 0x0000, "aud_is_even" },
{ 0x0000, "aud_is_specops" },
{ 0x0000, "aud_jeep_death_listener" },
{ 0x0000, "aud_knox_keypad" },
{ 0x0000, "aud_knox_thermite" },
{ 0x0000, "aud_knox_thermite_promo" },
{ 0x0000, "aud_lab_ambient_emitters" },
{ 0x0000, "aud_lab_foley_override_handler" },
{ 0x0000, "aud_lab_intro_screen" },
{ 0x0000, "aud_lab_phone_wait" },
{ 0x0000, "aud_lab_tech_chair_startle_1" },
{ 0x0000, "aud_lab_tech_chair_startle_2" },
{ 0x0000, "aud_lab_tech_desk_bump" },
{ 0x0000, "aud_laser_energy_beam_start" },
{ 0x0000, "aud_laser_pre_move_down" },
{ 0x0000, "aud_last_time" },
{ 0x0000, "aud_level_fadein" },
{ 0x0000, "aud_limp_exo" },
{ 0x0000, "aud_limp_off" },
{ 0x0000, "aud_limp_on" },
{ 0x0000, "aud_little_bird_hit" },
{ 0x0000, "aud_lockdown_alarm" },
{ 0x0000, "aud_lowstealth" },
{ 0x0000, "aud_manticore_crane" },
{ 0x0000, "aud_max" },
{ 0x0000, "aud_mech_crush_guy" },
{ 0x0000, "aud_mech_grapple_pitch_up" },
{ 0x0000, "aud_mech_idle_sfx" },
{ 0x0000, "aud_mech_jump" },
{ 0x0000, "aud_mech_missile_fire" },
{ 0x0000, "aud_mech_obj_move" },
{ 0x0000, "aud_mech_obj_move_end" },
{ 0x0000, "aud_mech_obj_move_wait" },
{ 0x0000, "aud_mech_panic_walla_watcher" },
{ 0x0000, "aud_mech_scanner" },
{ 0x0000, "aud_mech_trucks_enter" },
{ 0x0000, "aud_mech1_bg_truck" },
{ 0x0000, "aud_mechkill_catchdude" },
{ 0x0000, "aud_median_impact" },
{ 0x0000, "aud_meet_atlast_roof_explode" },
{ 0x0000, "aud_microwave_grenade" },
{ 0x0000, "aud_microwave_grenade_sparks_dude" },
{ 0x0000, "aud_microwave_grenade_sparks_env" },
{ 0x0000, "aud_min" },
{ 0x0000, "aud_monitor_irons" },
{ 0x0000, "aud_morgue_bodybag_doors" },
{ 0x0000, "aud_morgue_bodybag_line_emt" },
{ 0x0000, "aud_morgue_computer_door_entry_sfx" },
{ 0x0000, "aud_mus_boost" },
{ 0x0000, "aud_music_state" },
{ 0x0000, "aud_num_alive_enemies" },
{ 0x0000, "aud_observation_guard_radio" },
{ 0x0000, "aud_old_music_state" },
{ 0x0000, "aud_onearm_weapon_swap" },
{ 0x0000, "aud_overrides" },
{ 0x0000, "aud_pa_announc_01" },
{ 0x0000, "aud_pa_announc_02" },
{ 0x0000, "aud_pa_announc_03" },
{ 0x0000, "aud_pa_announc_04" },
{ 0x0000, "aud_painting_fall" },
{ 0x0000, "aud_panic_walla" },
{ 0x0000, "aud_patching_in_foley" },
{ 0x0000, "aud_patrol_helo_debris_sfx" },
{ 0x0000, "aud_penthouse_front_door" },
{ 0x0000, "aud_percent_chance" },
{ 0x0000, "aud_piston_ent" },
{ 0x0000, "aud_pitbull_crash_concussion" },
{ 0x0000, "aud_play" },
{ 0x0000, "aud_play_announcer_warning" },
{ 0x0000, "aud_play_distance_attenuated_2d" },
{ 0x0000, "aud_play_dust" },
{ 0x0000, "aud_play_dynamic_explosion" },
{ 0x0000, "aud_play_horror_ambience" },
{ 0x0000, "aud_play_laser_move_down" },
{ 0x0000, "aud_play_laser_move_up" },
{ 0x0000, "aud_play_line_emitter" },
{ 0x0000, "aud_play_pcap_vo" },
{ 0x0000, "aud_play_pod_impact" },
{ 0x0000, "aud_play_point_source_loop" },
{ 0x0000, "aud_play_rocket_travel_loops" },
{ 0x0000, "aud_play_tank_explosion" },
{ 0x0000, "aud_play_trophy_fire" },
{ 0x0000, "aud_player_bus_exo_jump" },
{ 0x0000, "aud_player_bus_exo_land" },
{ 0x0000, "aud_player_bus_jump_handplant" },
{ 0x0000, "aud_player_bus_land" },
{ 0x0000, "aud_player_bus1_exo_land" },
{ 0x0000, "aud_player_bus1_land" },
{ 0x0000, "aud_player_climb_foley" },
{ 0x0000, "aud_player_climb_to_ledge" },
{ 0x0000, "aud_player_computer" },
{ 0x0000, "aud_player_computer_gl_timing_fix" },
{ 0x0000, "aud_player_computer_promo" },
{ 0x0000, "aud_player_exo_punch_driver" },
{ 0x0000, "aud_player_exo_punch_metal_plate" },
{ 0x0000, "aud_player_gets_in_tank" },
{ 0x0000, "aud_player_grab_mirror" },
{ 0x0000, "aud_player_hill_slide" },
{ 0x0000, "aud_player_jump_back_to_bus" },
{ 0x0000, "aud_player_jump_to_truck" },
{ 0x0000, "aud_player_land_back_on_bus" },
{ 0x0000, "aud_player_land_on_truck" },
{ 0x0000, "aud_player_rappel_complete" },
{ 0x0000, "aud_player_throw_driver" },
{ 0x0000, "aud_player_throw_metal_plate" },
{ 0x0000, "aud_player_wall_climb_01" },
{ 0x0000, "aud_player_wall_climb_02" },
{ 0x0000, "aud_player_wall_climb_03" },
{ 0x0000, "aud_player_wall_climb_04" },
{ 0x0000, "aud_player_wall_climb_05" },
{ 0x0000, "aud_playermech_end" },
{ 0x0000, "aud_playermech_foley_override_handler" },
{ 0x0000, "aud_playermech_start" },
{ 0x0000, "aud_plr_hit" },
{ 0x0000, "aud_plr_hit_vo_line" },
{ 0x0000, "aud_plr_hit_vo_look" },
{ 0x0000, "aud_plr_hit_vo_move_back" },
{ 0x0000, "aud_plr_hit_vo_move_forward" },
{ 0x0000, "aud_plr_inside_mech" },
{ 0x0000, "aud_pod_arm_reach" },
{ 0x0000, "aud_pod_hits_ground" },
{ 0x0000, "aud_pod_hits_ground_corrected" },
{ 0x0000, "aud_pod_scene_begin" },
{ 0x0000, "aud_pod_turbulence_01" },
{ 0x0000, "aud_pod_turbulence_02" },
{ 0x0000, "aud_poolhouse_ambience" },
{ 0x0000, "aud_post_courtyard_emitters" },
{ 0x0000, "aud_print" },
{ 0x0000, "aud_print_3d_on_ent" },
{ 0x0000, "aud_print_debug" },
{ 0x0000, "aud_print_error" },
{ 0x0000, "aud_print_synch" },
{ 0x0000, "aud_print_warning" },
{ 0x0000, "aud_print_zone" },
{ 0x0000, "aud_print_zone_small" },
{ 0x0000, "aud_rappel_player_hookup" },
{ 0x0000, "aud_rappel_player_movement_start" },
{ 0x0000, "aud_rappel_player_movement_stop" },
{ 0x0000, "aud_reached_penthouse" },
{ 0x0000, "aud_ready_hooks" },
{ 0x0000, "aud_recon_foley" },
{ 0x0000, "aud_red_light" },
{ 0x0000, "aud_reinforcements_door1" },
{ 0x0000, "aud_reinforcements_door2" },
{ 0x0000, "aud_rescue_drone" },
{ 0x0000, "aud_rescue_sfx_a" },
{ 0x0000, "aud_rescue_sfx_b" },
{ 0x0000, "aud_rescue_sfx_c" },
{ 0x0000, "aud_rescue_sfx_d" },
{ 0x0000, "aud_rescue_sfx_e" },
{ 0x0000, "aud_rescue_sfx_f" },
{ 0x0000, "aud_rescue_sfx_g" },
{ 0x0000, "aud_rocket_launch_start" },
{ 0x0000, "aud_rocket_stage_01_start" },
{ 0x0000, "aud_rooftop_warbird_departing" },
{ 0x0000, "aud_rooftop_wind_volume" },
{ 0x0000, "aud_rooftops_ambience" },
{ 0x0000, "aud_rotate_vector_yaw" },
{ 0x0000, "aud_run_tank_system" },
{ 0x0000, "aud_s1_elevator_boss_foley" },
{ 0x0000, "aud_s1_elevator_cormack_foley" },
{ 0x0000, "aud_s1_elevator_guard_foley" },
{ 0x0000, "aud_s1_elevator_kick_1" },
{ 0x0000, "aud_s1_elevator_kick_2" },
{ 0x0000, "aud_s2walk_alarm_tone_lp" },
{ 0x0000, "aud_s2walk_cell_prisoners" },
{ 0x0000, "aud_s2walk_cells_foley_mix" },
{ 0x0000, "aud_s2walk_clear_foley_mix" },
{ 0x0000, "aud_s2walk_cormack_punched" },
{ 0x0000, "aud_s2walk_door_close" },
{ 0x0000, "aud_s2walk_door_open" },
{ 0x0000, "aud_s2walk_emitters" },
{ 0x0000, "aud_s2walk_execution_fire" },
{ 0x0000, "aud_s2walk_execution_kneeling_prisoners" },
{ 0x0000, "aud_s2walk_flyby_1" },
{ 0x0000, "aud_s2walk_guard_3_foley_01" },
{ 0x0000, "aud_s2walk_guard_3_foley_02" },
{ 0x0000, "aud_s2walk_guard_hip_radio" },
{ 0x0000, "aud_s2walk_guard_radios" },
{ 0x0000, "aud_s2walk_ilona_push" },
{ 0x0000, "aud_s2walk_loudspeaker2_line1" },
{ 0x0000, "aud_s2walk_loudspeaker2_line2" },
{ 0x0000, "aud_s2walk_prisoner_2_beating" },
{ 0x0000, "aud_s2walk_start_cormack_foley" },
{ 0x0000, "aud_s2walk_start_gideon_bodyfall" },
{ 0x0000, "aud_s2walk_start_gideon_foley" },
{ 0x0000, "aud_s2walk_start_guard_1_foley" },
{ 0x0000, "aud_s2walk_start_guard_1_grabpush" },
{ 0x0000, "aud_s2walk_start_guard_2_foley" },
{ 0x0000, "aud_s2walk_start_guard_2_grab" },
{ 0x0000, "aud_s2walk_start_guard_2_grabpush" },
{ 0x0000, "aud_s2walk_start_guard_2_push" },
{ 0x0000, "aud_s2walk_start_guard_3_foley" },
{ 0x0000, "aud_s2walk_start_guard_3_walkup_foley" },
{ 0x0000, "aud_s2walk_start_ilona_foley" },
{ 0x0000, "aud_s2walk_start_player_foley" },
{ 0x0000, "aud_s2walk_temp_guard_vo" },
{ 0x0000, "aud_s2walk_trigger_start" },
{ 0x0000, "aud_s2walk_yard_prisoners_whimpering" },
{ 0x0000, "aud_s3escape_doctor_radio" },
{ 0x0000, "aud_scale_envelope" },
{ 0x0000, "aud_scale_vector" },
{ 0x0000, "aud_scale_vector_2d" },
{ 0x0000, "aud_scanner_door_open" },
{ 0x0000, "aud_security_alarm" },
{ 0x0000, "aud_security_center_drones_on" },
{ 0x0000, "aud_security_countdown" },
{ 0x0000, "aud_security_hatch_exit" },
{ 0x0000, "aud_security_main_screen" },
{ 0x0000, "aud_security_plant_emp" },
{ 0x0000, "aud_security_prints" },
{ 0x0000, "aud_security_reboot" },
{ 0x0000, "aud_security_vent" },
{ 0x0000, "aud_security_welcome" },
{ 0x0000, "aud_separation_door" },
{ 0x0000, "aud_separation_elevator" },
{ 0x0000, "aud_separation_logic" },
{ 0x0000, "aud_server_room_door_crack" },
{ 0x0000, "aud_server_room_door_enter" },
{ 0x0000, "aud_server_room_door_kick" },
{ 0x0000, "aud_server_room_thermite" },
{ 0x0000, "aud_server_thermite_burn_loop" },
{ 0x0000, "aud_server_thermite_burn_start" },
{ 0x0000, "aud_server_thermite_out" },
{ 0x0000, "aud_set_ambi_submix" },
{ 0x0000, "aud_set_level_fade_time" },
{ 0x0000, "aud_set_mission_failed_music" },
{ 0x0000, "aud_set_music_submix" },
{ 0x0000, "aud_set_point_source_loop_volume" },
{ 0x0000, "aud_set_spec_ops" },
{ 0x0000, "aud_set_sticky_threat" },
{ 0x0000, "aud_set_timescale" },
{ 0x0000, "aud_setup_drop_pod_loop" },
{ 0x0000, "aud_shack_explode" },
{ 0x0000, "aud_shack_explode_whizby" },
{ 0x0000, "aud_slomo_wait" },
{ 0x0000, "aud_smooth" },
{ 0x0000, "aud_sonar_vision_off" },
{ 0x0000, "aud_sonar_vision_on" },
{ 0x0000, "aud_spark_1" },
{ 0x0000, "aud_spark_2" },
{ 0x0000, "aud_spark_3" },
{ 0x0000, "aud_spark_4" },
{ 0x0000, "aud_spark_5" },
{ 0x0000, "aud_sprinklers" },
{ 0x0000, "aud_start_dna_events" },
{ 0x0000, "aud_start_dna_events_cg" },
{ 0x0000, "aud_start_exfil_foley" },
{ 0x0000, "aud_start_nyse_fire" },
{ 0x0000, "aud_start_slow_mo_gunshot_callback" },
{ 0x0000, "aud_stealth_broken_timer" },
{ 0x0000, "aud_stealth_melee" },
{ 0x0000, "aud_stop_and_delete_ent" },
{ 0x0000, "aud_stop_cormack_foley" },
{ 0x0000, "aud_stop_headspace_ambience" },
{ 0x0000, "aud_stop_horror_ambience" },
{ 0x0000, "aud_stop_line_emitter" },
{ 0x0000, "aud_stop_mech_panic_walla_watcher" },
{ 0x0000, "aud_stop_mute_device_for_vo" },
{ 0x0000, "aud_stop_point_source_loop" },
{ 0x0000, "aud_stop_slow_mo_gunshot_callback" },
{ 0x0000, "aud_stop_sound_logic" },
{ 0x0000, "aud_stop_training_mute_device" },
{ 0x0000, "aud_stop_vrap_mute_device" },
{ 0x0000, "aud_table_pulldown" },
{ 0x0000, "aud_tank_death_listener" },
{ 0x0000, "aud_tank_field_littlebird" },
{ 0x0000, "aud_tank_field_warbird" },
{ 0x0000, "aud_tank_fire_watch" },
{ 0x0000, "aud_tank_road_littlebird_1" },
{ 0x0000, "aud_tank_road_littlebird_2" },
{ 0x0000, "aud_tank_section_vehicles_handler" },
{ 0x0000, "aud_tank_section_vehicles_spawned" },
{ 0x0000, "aud_tanker_crash" },
{ 0x0000, "aud_tanker_fall_down" },
{ 0x0000, "aud_tennis_court_wakeup" },
{ 0x0000, "aud_tire_splash" },
{ 0x0000, "aud_titan_siege_mode_adj_left_side" },
{ 0x0000, "aud_titan_siege_mode_adj_left_side_back" },
{ 0x0000, "aud_titan_siege_mode_adj_right_side" },
{ 0x0000, "aud_titan_siege_mode_adj_right_side_bac"... },
{ 0x0000, "aud_training_s2_potus_ziptie_release" },
{ 0x0000, "aud_transport_chopper" },
{ 0x0000, "aud_trolley_music" },
{ 0x0000, "aud_truck_dodge_slowmo_start" },
{ 0x0000, "aud_truck_dodge_slowmo_whoosh" },
{ 0x0000, "aud_truck_hits_divider" },
{ 0x0000, "aud_truck_hits_ground" },
{ 0x0000, "aud_truck_jump_slowmo" },
{ 0x0000, "aud_truck_punch_slowmo" },
{ 0x0000, "aud_truck1_engine_pullup" },
{ 0x0000, "aud_truck2_engine_drive" },
{ 0x0000, "aud_truck2_engine_idle" },
{ 0x0000, "aud_truck2_engine_pullup" },
{ 0x0000, "aud_trucks_arrive" },
{ 0x0000, "aud_turret_entry" },
{ 0x0000, "aud_turrets_activate" },
{ 0x0000, "aud_use_string_tables" },
{ 0x0000, "aud_var_nade_type" },
{ 0x0000, "aud_vector_magnitude_2d" },
{ 0x0000, "aud_vehicle_ride_data" },
{ 0x0000, "aud_vrap_mute_start" },
{ 0x0000, "aud_vtol_excellerate_end" },
{ 0x0000, "aud_vtol_excellerate_start" },
{ 0x0000, "aud_vtol_exterior_idle" },
{ 0x0000, "aud_vtol_land" },
{ 0x0000, "aud_vtol_passed" },
{ 0x0000, "aud_wait_delay" },
{ 0x0000, "aud_wait_for_mission_fail_music" },
{ 0x0000, "aud_wakeup_amb" },
{ 0x0000, "aud_wakeup_mech_cooldown_pings" },
{ 0x0000, "aud_wakeup_mix" },
{ 0x0000, "aud_warehouse_mech_lift" },
{ 0x0000, "aud_warehouse_mech_lift_alarm" },
{ 0x0000, "aud_warehouse_mech_lift_vo" },
{ 0x0000, "aud_warehouse_roof_machines" },
{ 0x0000, "aud_warehouse_roof_machines_line" },
{ 0x0000, "aud_warning_vo" },
{ 0x0000, "aud_watch_for_anim_end" },
{ 0x0000, "aud_water_footsteps_foley" },
{ 0x0000, "aud_water_footsteps_override" },
{ 0x0000, "aud_water_sound" },
{ 0x0000, "aud_waterfall_ambience" },
{ 0x0000, "aud_windmill_sniper_whizby" },
{ 0x0000, "aud_zap_logic_change" },
{ 0x0000, "aud_zap_scene" },
{ 0x0000, "audiblesightplaying" },
{ 0x0000, "audio" },
{ 0x0000, "audio_buzzer_struct" },
{ 0x0000, "audio_jet_counter" },
{ 0x0000, "audio_monitor_chopper01_death" },
{ 0x0000, "audio_monitor_chopper02_death" },
{ 0x0000, "audio_org" },
{ 0x0000, "audio_presets_music_cue_groups" },
{ 0x0000, "audio_presets_music_cues" },
{ 0x0000, "audio_presets_music_moods" },
{ 0x0000, "audio_presets_vehicle_maps" },
{ 0x0000, "audio_presets_vehicles" },
{ 0x0000, "audio_push_1_box_drop" },
{ 0x0000, "audio_push_1_box_pickup" },
{ 0x0000, "audio_push_1_box_push" },
{ 0x0000, "audio_push_1_crane_move_1" },
{ 0x0000, "audio_push_1_crane_move_2" },
{ 0x0000, "audio_push_1_crane_move_3" },
{ 0x0000, "audio_push_2_box_drop" },
{ 0x0000, "audio_push_2_box_pickup" },
{ 0x0000, "audio_push_2_box_push" },
{ 0x0000, "audio_push_2_crane_move_1" },
{ 0x0000, "audio_push_2_crane_move_2" },
{ 0x0000, "audio_push_2_crane_move_3" },
{ 0x0000, "audio_start_wrestling_exo_guy" },
{ 0x0000, "audio_start_wrestling_guy2" },
{ 0x0000, "audio_start_wrestling_guy3" },
{ 0x0000, "audio_start_wrestling_guy4" },
{ 0x0000, "audio_start_wrestling_guy5" },
{ 0x0000, "audio_stingers_school_bodies_room" },
{ 0x0000, "audio_stringtable_mapname" },
{ 0x0000, "audio_zones" },
{ 0x0000, "audx_attenuate" },
{ 0x0000, "audx_delete_on_sounddone_internal" },
{ 0x0000, "audx_do_dynamic_explosion_math" },
{ 0x0000, "audx_duck" },
{ 0x0000, "audx_fade_in_internal" },
{ 0x0000, "audx_fade_out_internal" },
{ 0x0000, "audx_play_distance_attenuated_2d_intern"... },
{ 0x0000, "audx_play_line_emitter_internal" },
{ 0x0000, "audx_print_3d_timer" },
{ 0x0000, "audx_set_spec_ops" },
{ 0x0000, "audx_slomo_wait" },
{ 0x0000, "auto_adjust_difficulty_player_movement_"... },
{ 0x0000, "auto_adjust_difficulty_player_positione"... },
{ 0x0000, "auto_adjust_difficulty_track_player_dea"... },
{ 0x0000, "auto_adjust_difficulty_track_player_sho"... },
{ 0x0000, "auto_adjust_enemy_death_detection" },
{ 0x0000, "auto_adjust_enemy_died" },
{ 0x0000, "auto_adjust_flags" },
{ 0x0000, "auto_adjust_new_zone" },
{ 0x0000, "auto_adjust_results" },
{ 0x0000, "auto_adust_zone_complete" },
{ 0x0000, "auto_combat_music" },
{ 0x0000, "auto_mg42_target" },
{ 0x0000, "auto_mgturretlink" },
{ 0x0000, "auto_occumulator_base" },
{ 0x0000, "auto_recloak" },
{ 0x0000, "autoadjust_playerspots" },
{ 0x0000, "autoassign" },
{ 0x0000, "autoclose" },
{ 0x0000, "autofocus_hipenable" },
{ 0x0000, "autofocus_hipenable_bike" },
{ 0x0000, "autofocus_loop" },
{ 0x0000, "autopsy_cleanup" },
{ 0x0000, "autopsy_create_fodder_techs" },
{ 0x0000, "autopsy_doctor_door_doctor" },
{ 0x0000, "autopsy_doctor_door_enemies" },
{ 0x0000, "autopsy_doctor_door_enemy_ammo" },
{ 0x0000, "autopsy_doctor_door_enemy_think" },
{ 0x0000, "autopsy_doctor_door_fail" },
{ 0x0000, "autopsy_doctor_door_gideon" },
{ 0x0000, "autopsy_doctor_door_no_hint" },
{ 0x0000, "autopsy_doctor_door_player" },
{ 0x0000, "autopsy_door_action" },
{ 0x0000, "autopsy_door_tech" },
{ 0x0000, "autopsy_first_frame_entry_doors" },
{ 0x0000, "autopsy_fodder_tech_animate" },
{ 0x0000, "autopsy_fodder_tech_think" },
{ 0x0000, "autopsy_guard" },
{ 0x0000, "autopsy_guard_player_hit" },
{ 0x0000, "autopsy_main_doctor" },
{ 0x0000, "autopsy_start" },
{ 0x0000, "autoresettime" },
{ 0x0000, "autosave_by_name" },
{ 0x0000, "autosave_by_name_silent" },
{ 0x0000, "autosave_by_name_thread" },
{ 0x0000, "autosave_check_override" },
{ 0x0000, "autosave_check_pitbull_moving" },
{ 0x0000, "autosave_check_pitbull_no_recent_accel" },
{ 0x0000, "autosave_check_pitbull_upright" },
{ 0x0000, "autosave_fly_check" },
{ 0x0000, "autosave_hostile_drone_check" },
{ 0x0000, "autosave_jetbike_check_too_slow" },
{ 0x0000, "autosave_jetbike_check_trailing" },
{ 0x0000, "autosave_now" },
{ 0x0000, "autosave_now_silent" },
{ 0x0000, "autosave_now_trigger" },
{ 0x0000, "autosave_or_timeout" },
{ 0x0000, "autosave_proximity_threat_func" },
{ 0x0000, "autosave_recon" },
{ 0x0000, "autosave_stealth" },
{ 0x0000, "autosave_stealth_meter_check" },
{ 0x0000, "autosave_stealth_silent" },
{ 0x0000, "autosave_stealth_spotted_check" },
{ 0x0000, "autosave_tactical" },
{ 0x0000, "autosave_tactical_grenade_check" },
{ 0x0000, "autosave_tactical_grenade_check_dieout" },
{ 0x0000, "autosave_tactical_player_nades" },
{ 0x0000, "autosave_tactical_proc" },
{ 0x0000, "autosave_tactical_setup" },
{ 0x0000, "autosave_threat_check_enabled" },
{ 0x0000, "autosave_timeout" },
{ 0x0000, "autosaveammocheck" },
{ 0x0000, "autosavecheck" },
{ 0x0000, "autosavecheck_not_picky" },
{ 0x0000, "autosaveconfcentercombatcheck" },
{ 0x0000, "autosaveconfcenterstealthcheck" },
{ 0x0000, "autosavehealthcheck" },
{ 0x0000, "autosavenamethink" },
{ 0x0000, "autosaveplayercheck" },
{ 0x0000, "autosaveprint" },
{ 0x0000, "autosaves_think" },
{ 0x0000, "autosavesniperdronestealth" },
{ 0x0000, "autosavethreatcheck" },
{ 0x0000, "autoshootanimrate" },
{ 0x0000, "autospot_is_close_to_player" },
{ 0x0000, "autospotadswatcher" },
{ 0x0000, "autospotdeathwatcher" },
{ 0x0000, "autotarget" },
{ 0x0000, "auxillary_hud" },
{ 0x0000, "available" },
{ 0x0000, "available_crash_paths" },
{ 0x0000, "availablepositions" },
{ 0x0000, "avalanche_environment" },
{ 0x0000, "avalanche_falling_death" },
{ 0x0000, "avatar" },
{ 0x0000, "avatar_after_spawn" },
{ 0x0000, "avatar_scheduled_for_removal" },
{ 0x0000, "avatar_spawnpoint" },
{ 0x0000, "avatarinfo" },
{ 0x0000, "avengedplayerevent" },
{ 0x0000, "avm_add_envelope" },
{ 0x0000, "avm_add_in_state_callback" },
{ 0x0000, "avm_add_init_state_callback" },
{ 0x0000, "avm_add_loops" },
{ 0x0000, "avm_add_oneshot" },
{ 0x0000, "avm_add_oneshots" },
{ 0x0000, "avm_add_param_map_env" },
{ 0x0000, "avm_add_state_transition" },
{ 0x0000, "avm_begin_behavior_data" },
{ 0x0000, "avm_begin_behavior_def" },
{ 0x0000, "avm_begin_loop_data" },
{ 0x0000, "avm_begin_loop_def" },
{ 0x0000, "avm_begin_oneshot_data" },
{ 0x0000, "avm_begin_oneshot_def" },
{ 0x0000, "avm_begin_param_map" },
{ 0x0000, "avm_begin_preset_def" },
{ 0x0000, "avm_begin_state_data" },
{ 0x0000, "avm_begin_state_def" },
{ 0x0000, "avm_begin_state_group" },
{ 0x0000, "avm_change_smoothing_rate" },
{ 0x0000, "avm_compute_alpha_from_rc" },
{ 0x0000, "avm_compute_doppler_pitch" },
{ 0x0000, "avm_compute_smoothing_rc_from_alpha" },
{ 0x0000, "avm_create_vehicle_proxy" },
{ 0x0000, "avm_end_behavior_data" },
{ 0x0000, "avm_end_behavior_def" },
{ 0x0000, "avm_end_loop_data" },
{ 0x0000, "avm_end_loop_def" },
{ 0x0000, "avm_end_oneshot_data" },
{ 0x0000, "avm_end_oneshot_def" },
{ 0x0000, "avm_end_param_map" },
{ 0x0000, "avm_end_preset_def" },
{ 0x0000, "avm_end_state_data" },
{ 0x0000, "avm_end_state_def" },
{ 0x0000, "avm_end_state_group" },
{ 0x0000, "avm_get_running_instance_count" },
{ 0x0000, "avm_get_update_rate" },
{ 0x0000, "avm_init" },
{ 0x0000, "avm_register_callback" },
{ 0x0000, "avm_set_instance_master_volume" },
{ 0x0000, "avm_set_loop_mute_state" },
{ 0x0000, "avmx_add_behavior_shortcut_param_maps" },
{ 0x0000, "avmx_add_instance" },
{ 0x0000, "avmx_add_oneshot_ducking_scalar" },
{ 0x0000, "avmx_add_preset" },
{ 0x0000, "avmx_are_all_defined" },
{ 0x0000, "avmx_continuously_update_snd_ent" },
{ 0x0000, "avmx_create_instance_struct" },
{ 0x0000, "avmx_create_param_io_struct" },
{ 0x0000, "avmx_create_preset" },
{ 0x0000, "avmx_fade_stop_and_delete_sound_obj" },
{ 0x0000, "avmx_generate_instance_name" },
{ 0x0000, "avmx_get" },
{ 0x0000, "avmx_get_behavior_instance_struct" },
{ 0x0000, "avmx_get_behavior_preset_struct" },
{ 0x0000, "avmx_get_behavior_restricted_oneshots" },
{ 0x0000, "avmx_get_callback" },
{ 0x0000, "avmx_get_current_instance_sound_item_in"... },
{ 0x0000, "avmx_get_envelope" },
{ 0x0000, "avmx_get_fadein_time" },
{ 0x0000, "avmx_get_fadeout_time" },
{ 0x0000, "avmx_get_instance" },
{ 0x0000, "avmx_get_instance_name" },
{ 0x0000, "avmx_get_instance_preset" },
{ 0x0000, "avmx_get_instance_preset_name" },
{ 0x0000, "avmx_get_instance_sound_item_output" },
{ 0x0000, "avmx_get_instance_sound_item_volume" },
{ 0x0000, "avmx_get_instance_state_struct" },
{ 0x0000, "avmx_get_master_volume" },
{ 0x0000, "avmx_get_oneshot_poly_mode" },
{ 0x0000, "avmx_get_oneshot_update_mode" },
{ 0x0000, "avmx_get_preset" },
{ 0x0000, "avmx_get_preset_name" },
{ 0x0000, "avmx_get_sound_alias" },
{ 0x0000, "avmx_get_sound_alias_count" },
{ 0x0000, "avmx_get_sound_instance" },
{ 0x0000, "avmx_get_state_preset_struct" },
{ 0x0000, "avmx_get_vehicle_entity" },
{ 0x0000, "avmx_handle_oneshot_ducking" },
{ 0x0000, "avmx_is_player_mode" },
{ 0x0000, "avmx_is_vehicle_proxy" },
{ 0x0000, "avmx_launch_state_machines" },
{ 0x0000, "avmx_map_input" },
{ 0x0000, "avmx_map_io" },
{ 0x0000, "avmx_monitor_death" },
{ 0x0000, "avmx_monitor_oneshot_done" },
{ 0x0000, "avmx_normalize_ranged_value" },
{ 0x0000, "avmx_preset_determine_param_map_env_own"... },
{ 0x0000, "avmx_preset_determine_param_map_owner" },
{ 0x0000, "avmx_preset_set_param_map_defaults" },
{ 0x0000, "avmx_remove_instance" },
{ 0x0000, "avmx_remove_oneshot_ducking_scalar" },
{ 0x0000, "avmx_set_behavior_oneshot_overrides" },
{ 0x0000, "avmx_set_instance_init_callback" },
{ 0x0000, "avmx_set_instance_master_volume" },
{ 0x0000, "avmx_set_loop_play_state" },
{ 0x0000, "avmx_set_loop_volume" },
{ 0x0000, "avmx_set_oneshot_ducking_scalar" },
{ 0x0000, "avmx_set_oneshot_update_mode" },
{ 0x0000, "avmx_set_preset_name" },
{ 0x0000, "avmx_start_instance" },
{ 0x0000, "avmx_start_loop" },
{ 0x0000, "avmx_start_oneshot_alias" },
{ 0x0000, "avmx_state_condition_function" },
{ 0x0000, "avmx_state_enter_action_function" },
{ 0x0000, "avmx_state_enter_action_init_data" },
{ 0x0000, "avmx_state_enter_action_play_loops" },
{ 0x0000, "avmx_state_enter_action_play_oneshots" },
{ 0x0000, "avmx_state_exit_action_function" },
{ 0x0000, "avmx_stop_instance" },
{ 0x0000, "avmx_stop_loop" },
{ 0x0000, "avmx_stop_snd_ent" },
{ 0x0000, "avmx_update_instance_loop_assets" },
{ 0x0000, "avmx_update_loop_ducking_scalar" },
{ 0x0000, "avmx_update_loops" },
{ 0x0000, "avmx_update_oneshot_duck_scalar" },
{ 0x0000, "avmx_update_sound_ent_output_param" },
{ 0x0000, "avmx_vehicle_getspeed" },
{ 0x0000, "avoid_players" },
{ 0x0000, "avoidairstrikelocations" },
{ 0x0000, "avoidcarepackages" },
{ 0x0000, "avoidcornervisibleenemies" },
{ 0x0000, "avoidenemiesbydistance" },
{ 0x0000, "avoidenemyspawn" },
{ 0x0000, "avoidfullvisibleenemies" },
{ 0x0000, "avoidgasclouds" },
{ 0x0000, "avoidgrenades" },
{ 0x0000, "avoidkillstreakonspawntimer" },
{ 0x0000, "avoidlastattackerlocation" },
{ 0x0000, "avoidlastdeathlocation" },
{ 0x0000, "avoidmines" },
{ 0x0000, "avoidrecentlyused" },
{ 0x0000, "avoidsamespawn" },
{ 0x0000, "avoidspawninhp" },
{ 0x0000, "avoidtelefrag" },
{ 0x0000, "award_intel" },
{ 0x0000, "award_player_exo_challenge_kill_for_sce"... },
{ 0x0000, "awardcapturepoints" },
{ 0x0000, "awardedfinalsurvivor" },
{ 0x0000, "awardgameevent" },
{ 0x0000, "awardhordeheadshots" },
{ 0x0000, "awardhordekill" },
{ 0x0000, "awardhorderevive" },
{ 0x0000, "awardhorderoundnumber" },
{ 0x0000, "awardhordweaponlevel" },
{ 0x0000, "awardpoints" },
{ 0x0000, "awardxp" },
{ 0x0000, "aware_aievents" },
{ 0x0000, "awareness_meter_fail" },
{ 0x0000, "awareness_param" },
{ 0x0000, "axis_check_cloak_state" },
{ 0x0000, "axis_global_accuracy_mod" },
{ 0x0000, "axis_start_spawn_name" },
{ 0x0000, "axiscapturing" },
{ 0x0000, "axischopper" },
{ 0x0000, "axisflagcarrierclientnum" },
{ 0x0000, "axisflagstatus" },
{ 0x0000, "axismode" },
{ 0x0000, "azm_get_current_zone" },
{ 0x0000, "azm_get_damb_enable" },
{ 0x0000, "azm_get_filter_bypass" },
{ 0x0000, "azm_get_filter_enable" },
{ 0x0000, "azm_get_mix_bypass" },
{ 0x0000, "azm_get_mix_enable" },
{ 0x0000, "azm_get_occlusion_bypass" },
{ 0x0000, "azm_get_occlusion_enable" },
{ 0x0000, "azm_get_quad_enable" },
{ 0x0000, "azm_get_reverb_bypass" },
{ 0x0000, "azm_get_reverb_enable" },
{ 0x0000, "azm_init" },
{ 0x0000, "azm_print_enter_blend" },
{ 0x0000, "azm_print_exit_blend" },
{ 0x0000, "azm_print_progress" },
{ 0x0000, "azm_set_current_zone" },
{ 0x0000, "azm_set_damb_enable" },
{ 0x0000, "azm_set_filter_bypass" },
{ 0x0000, "azm_set_filter_enable" },
{ 0x0000, "azm_set_mix_bypass" },
{ 0x0000, "azm_set_mix_enable" },
{ 0x0000, "azm_set_occlusion_bypass" },
{ 0x0000, "azm_set_occlusion_enable" },
{ 0x0000, "azm_set_quad_enable" },
{ 0x0000, "azm_set_reverb_bypass" },
{ 0x0000, "azm_set_reverb_enable" },
{ 0x0000, "azm_set_zone_dynamic_ambience" },
{ 0x0000, "azm_set_zone_mix" },
{ 0x0000, "azm_set_zone_occlusion" },
{ 0x0000, "azm_set_zone_reverb" },
{ 0x0000, "azm_set_zone_streamed_ambience" },
{ 0x0000, "azm_start_zone" },
{ 0x0000, "azm_stop_zone" },
{ 0x0000, "azm_stop_zones" },
{ 0x0000, "azm_use_string_table" },
{ 0x0000, "azmx_blend_zones" },
{ 0x0000, "azmx_get_blend_args" },
{ 0x0000, "azmx_get_preset_from_string_table" },
{ 0x0000, "azmx_get_zone_preset_from_stringtable_i"... },
{ 0x0000, "azmx_is_valid_damb_blend_request" },
{ 0x0000, "azmx_is_valid_mix_blend_request" },
{ 0x0000, "azmx_is_valid_samb_blend_request" },
{ 0x0000, "azmx_load_zone" },
{ 0x0000, "azmx_restart_damb" },
{ 0x0000, "azmx_restart_mix" },
{ 0x0000, "azmx_restart_occlusion" },
{ 0x0000, "azmx_restart_reverb" },
{ 0x0000, "azmx_restart_stream" },
{ 0x0000, "azmx_set_param_internal" },
{ 0x0000, "azmx_wait_till_fade_done_and_remove_zon"... },
//

*/